@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -54,6 +54,7 @@ class GovernmentForms_Base {
 	/*
 	 * PDF related variables
 	 */
+	public $pdf_object = NULL;
 	public $template_index = array();
 	public $current_template_index = NULL;
 	public $page_offsets = array( 0, 0 ); //x, y
@@ -119,6 +120,9 @@ class GovernmentForms_Base {
 	 *
 	 */
 	function MoneyFormat($value, $pretty = TRUE) {
+		if ( !is_numeric( $value ) ) {
+			return FALSE;
+		}
 		if ( $pretty == TRUE ) {
 			$thousand_sep = ',';
 		} else {
@@ -401,10 +405,13 @@ class GovernmentForms_Base {
 	}
 
 	function drawNormal( $value, $schema ) {
-		//Strip off the function element to prevent infinite loop
-		unset($schema['function']);
-		$this->Draw( $value, $schema );
-		return TRUE;
+		if ( $value !== FALSE ) { //If value is FALSE don't draw anything, this prevents a blank cell from being drawn overtop of other text.
+			unset($schema['function']); //Strip off the function element to prevent infinite loop
+			$this->Draw( $value, $schema );
+			return TRUE;
+		}
+
+		return FALSE;
 	}
 
 	function addPage( $schema = NULL ) {
@@ -412,13 +419,46 @@ class GovernmentForms_Base {
 
 		$pdf->AddPage();
 		if ( $this->getShowBackground() == TRUE AND isset($this->template_index[$schema['template_page']]) ) {
-			$pdf->useTemplate( $this->template_index[$schema['template_page']],$this->getTemplateOffsets('x'), $this->getTemplateOffsets('y') );
+			if ( isset($schema['combine_templates']) AND is_array($schema['combine_templates']) ) {
+				$template_schema = $this->getTemplateSchema();
+
+				//Handle combining multiple template together with a X,Y offset.
+				foreach( $schema['combine_templates'] as $combine_template ) {
+					Debug::text('Combining Template Pages... Template: '. $combine_template['template_page'] .' Y: '. $combine_template['y'], __FILE__, __LINE__, __METHOD__, 10);
+					$pdf->useTemplate( $this->template_index[$combine_template['template_page']],$combine_template['x']+$this->getTemplateOffsets('x'), $combine_template['y']+$this->getTemplateOffsets('y') );
+
+					$this->setPageOffsets( $combine_template['x'], $combine_template['y']);
+					$this->current_template_index = $schema['template_page'];
+					$this->initPage( $template_schema );
+				}
+				unset($combine_templates);
+				$this->setPageOffsets( 0, 0 ); //Reset page offsets after each template is initialized.
+			} else {
+				$pdf->useTemplate( $this->template_index[$schema['template_page']],$this->getTemplateOffsets('x'), $this->getTemplateOffsets('y') );
+			}
 		}
 		$this->current_template_index = $schema['template_page'];
 
+
 		return TRUE;
 	}
 
+	function initPage( $template_schema ) {
+		if ( is_array($template_schema) ) {
+			foreach( $template_schema as $field => $init_schema ) {
+				if ( is_numeric($field) ) {
+					//Debug::text(' Initializing Template Page... Field: '. $field, __FILE__, __LINE__, __METHOD__, 10);
+					$this->Draw( $this->$field, $init_schema );
+				}
+			}
+			unset($template_schema, $field, $init_schema);
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	//Generic draw function that works strictly off the coordinate map.
 	//It checks for a variable specific function before running though, so we can handle more complex
 	//drawing functionality.
@@ -433,11 +473,6 @@ class GovernmentForms_Base {
 			unset($schema['value']);
 		}
 
-		//on_background flag forces that item to only be shown if the background is as well.
-		if ( isset($schema['on_background']) AND $schema['on_background'] == TRUE AND $this->getShowBackground() == FALSE ) {
-			return FALSE;
-		}
-
 		//If custom function is defined, pass off to that immediate.
 		//Else, try the generic drawing method.
 		if ( isset($schema['function'])  ) {
@@ -458,11 +493,18 @@ class GovernmentForms_Base {
 
 		//Make sure we don't load the same template more than once.
 		if ( isset($schema['template_page']) AND $schema['template_page'] != $this->current_template_index ) {
+			//Debug::text('Adding new page: '. $schema .' Template Page: '. $schema['template_page'], __FILE__, __LINE__, __METHOD__, 10);
 			$this->addPage( $schema );
 		} else {
 			//Debug::text('Skipping template... Value: '. $value, __FILE__, __LINE__, __METHOD__, 10);
 		}
 
+		//on_background flag forces that item to only be shown if the background is as well.
+		//This has to go below any addPage() call, otherwise pages won't be added if the first cell is only to be shown on the background.
+		if ( isset($schema['on_background']) AND $schema['on_background'] == TRUE AND $this->getShowBackground() == FALSE ) {
+			return FALSE;
+		}
+
 		if ( isset($schema['font']) ) {
 			if ( !isset($schema['font']['font']) ) {
 				$schema['font']['font'] = $this->default_font;
@@ -500,7 +542,7 @@ class GovernmentForms_Base {
 			$pdf->setXY( $coordinates['x']+$this->getPageOffsets('x'), $coordinates['y']+$this->getPageOffsets('y') );
 
 			if ( $this->getDebug() == TRUE ) {
-				$pdf->setDrawColor( 255, 0 , 0 );
+				$pdf->setDrawColor( 0, 0 , 255 );
 				$coordinates['border'] = 1;
 			} else {
 				if ( !isset($coordinates['border']) ) {
@@ -509,10 +551,10 @@ class GovernmentForms_Base {
 			}
 
 			if ( isset($schema['multicell']) AND $schema['multicell'] == TRUE ) {
-				Debug::text('Drawing MultiCell... Value: '. $value, __FILE__, __LINE__, __METHOD__, 10);
+				//Debug::text('Drawing MultiCell... Value: '. $value, __FILE__, __LINE__, __METHOD__, 10);
 				$pdf->MultiCell( $coordinates['w'],$coordinates['h'], $value , $coordinates['border'], strtoupper($coordinates['halign']), $coordinates['fill'] );
 			} else {
-				Debug::text('Drawing Cell... Value: '. $value, __FILE__, __LINE__, __METHOD__, 10);
+				//Debug::text('Drawing Cell... Value: '. $value, __FILE__, __LINE__, __METHOD__, 10);
 				$pdf->Cell( $coordinates['w'],$coordinates['h'], $value , $coordinates['border'], 0, strtoupper($coordinates['halign']), $coordinates['fill'] );
 			}
 			unset($coordinates);
