@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -59,13 +59,30 @@ class GovernmentForms_CA_T4 extends GovernmentForms_CA {
 				$retval = array(
 								'government' => TTi18n::gettext('Government (Multiple Employees/Page)'),
 								'employee' => TTi18n::gettext('Employee (One Employee/Page)'),
-									);
+								);
 				break;
 		}
 
 		return $retval;
 	}
 
+	function getPayrollDeductionObject() {
+		if ( !isset($this->payroll_deduction_obj) ) {
+			require_once( Environment::getBasePath(). DIRECTORY_SEPARATOR . 'classes'. DIRECTORY_SEPARATOR .'payroll_deduction'. DIRECTORY_SEPARATOR .'PayrollDeduction.class.php');
+			$this->payroll_deduction_obj = new PayrollDeduction( 'CA', NULL);
+			$this->payroll_deduction_obj->setDate( TTDate::getTimeStamp( $this->year, 12, 31 ) );
+		}
+
+		return $this->payroll_deduction_obj;
+	}
+	function getCPPMaximumEarnings() {
+		return $this->getPayrollDeductionObject()->getCPPMaximumEarnings();
+	}
+
+	function getEIMaximumEarnings() {
+		return $this->getPayrollDeductionObject()->getEIMaximumEarnings();
+	}
+
 	//Set the type of form to display/print. Typically this would be:
 	// government or employee.
 	function getType() {
@@ -412,7 +429,7 @@ class GovernmentForms_CA_T4 extends GovernmentForms_CA {
 																	),
 											),
 								'l24' => array(
-												'function' => 'drawSplitDecimalFloat',
+												'function' =>  array( 'filterL24', 'drawSplitDecimalFloat' ),
 												'coordinates' => array(
 																	array(
 																		'x' => 483,
@@ -431,7 +448,7 @@ class GovernmentForms_CA_T4 extends GovernmentForms_CA {
 																	),
 											),
 								'l26' => array(
-												'function' => 'drawSplitDecimalFloat',
+												'function' => array( 'filterL26', 'drawSplitDecimalFloat' ),
 												'coordinates' => array(
 																	array(
 																		'x' => 483,
@@ -719,6 +736,24 @@ class GovernmentForms_CA_T4 extends GovernmentForms_CA {
 		return implode("\n", $retarr );
 	}
 
+	function filterL24( $value ) {
+		Debug::Text('zzzzValue: '. $value .' Max: '. $this->getEIMaximumEarnings() , __FILE__, __LINE__, __METHOD__,10);
+		if ( $value > $this->getEIMaximumEarnings() ) {
+			return $this->getEIMaximumEarnings();
+		}
+
+		Debug::Text('zzzzbValue: '. $value, __FILE__, __LINE__, __METHOD__,10);
+		return $value;
+	}
+
+	function filterL26( $value ) {
+		if ( $value > $this->getCPPMaximumEarnings() ) {
+			return $this->getCPPMaximumEarnings();
+		}
+
+		return $value;
+	}
+
 	function _outputXML() {
 
 		//Maps other income box codes to XML element names.
