@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -532,14 +532,14 @@ class GovernmentForms_CA_T4Sum extends GovernmentForms_CA {
 		//$xml->TReturn->4->T4Summary->PPRTR_SIN->addChild('pprtr_2_sin', '' );
 
 		$xml->Return->T4->T4Summary->addChild('T4_TAMT');
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empt_incamt', $this->l14 );
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empe_cpp_amt', $this->l16 );
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empe_eip_amt', $this->l18 );
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_rpp_cntrb_amt', $this->l20 );
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_itx_ddct_amt', $this->l22 );
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_padj_amt', $this->l52 );
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empr_cpp_amt', $this->l27 );
-		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empr_eip_amt', $this->l19 );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empt_incamt', $this->MoneyFormat( $this->l14, FALSE ) );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empe_cpp_amt', $this->MoneyFormat( $this->l16, FALSE ) );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empe_eip_amt', $this->MoneyFormat( $this->l18, FALSE ) );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_rpp_cntrb_amt', $this->MoneyFormat( $this->l20, FALSE ) );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_itx_ddct_amt', $this->MoneyFormat( $this->l22, FALSE ) );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_padj_amt', $this->MoneyFormat( $this->l52, FALSE ) );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empr_cpp_amt', $this->MoneyFormat( $this->l27, FALSE ) );
+		$xml->Return->T4->T4Summary->T4_TAMT->addChild('tot_empr_eip_amt', $this->MoneyFormat( $this->l19, FALSE ) );
 
 		return TRUE;
 	}
