@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -1053,7 +1053,7 @@ class GovernmentForms_US_940 extends GovernmentForms_US {
 		//Taxable FUTA wages
 
 		//Either fill out line 9, or line 10. So if line 10 is filled out, ignore this.
-		if ( $this->l10 == '' ) {
+		if ( $this->l10 == '' OR $this->l10 == 0 ) {
 			$this->l9 = $this->l7 * $this->futa_tax_rate;
 			return $this->l9;
 		}
