@@ -74,7 +74,7 @@ class Hashed_Cache_Lite extends Cache_Lite
 			foreach ($dir_parts as $dir_part) {
 				$new_dir .= $dir_part;
 				if (!file_exists($new_dir) && !mkdir($new_dir, 0771, true)) {
-					Cache_Lite::raiseError('Cache_Lite : problem creating directory \"$dir\" !', -3);
+					$this->raiseError('Cache_Lite : problem creating directory \"'. $dir .'\" !', -3);
 					return false;
 				}
 				$new_dir .= DIR_SEP;
