@@ -525,14 +525,15 @@ class Cache_Lite
         if ($fp) {
             clearstatcache(); // because the filesize can be cached by PHP itself...
             $length = @filesize($this->_file);
-            $mqr = get_magic_quotes_runtime();
-            set_magic_quotes_runtime(0);
+            //Deprecated in PHP v5.3, forced to disabled in TimeTrex installer.
+            //$mqr = get_magic_quotes_runtime();
+            //set_magic_quotes_runtime(0);
             if ($this->_readControl) {
                 $hashControl = @fread($fp, 32);
                 $length = $length - 32;
             }
             $data = @fread($fp, $length);
-            set_magic_quotes_runtime($mqr);
+            //set_magic_quotes_runtime($mqr);
             if ($this->_fileLocking) @flock($fp, LOCK_UN);
             @fclose($fp);
             if ($this->_readControl) {
