@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4401 $
- * $Id: AccrualFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
- * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
+ * $Revision: 6071 $
+ * $Id: AccrualFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -81,7 +81,8 @@ class AccrualFactory extends Factory {
 
 										'-1030-accrual_policy' => TTi18n::gettext('Accrual Policy'),
 										'-1040-type' => TTi18n::gettext('Type'),
-										'-1050-time_stamp' => TTi18n::gettext('Date'),
+										//'-1050-time_stamp' => TTi18n::gettext('Date'),
+										'-1050-date_stamp' => TTi18n::gettext('Date'), //Date stamp is combination of time_stamp and user_date.date_stamp columns.
 										'-1060-amount' => TTi18n::gettext('Amount'),
 
 										'-1090-title' => TTi18n::gettext('Title'),
@@ -96,7 +97,7 @@ class AccrualFactory extends Factory {
 							);
 				break;
 			case 'list_columns':
-				$retval = Misc::arrayIntersectByKey( array('accrual_policy', 'type', 'time_stamp', 'amount'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				$retval = Misc::arrayIntersectByKey( array('accrual_policy', 'type', 'date_stamp', 'amount'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
 				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
@@ -105,7 +106,7 @@ class AccrualFactory extends Factory {
 								'accrual_policy',
 								'type',
 								'amount',
-								'time_stamp'
+								'date_stamp'
 								);
 				break;
 			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
@@ -131,6 +132,7 @@ class AccrualFactory extends Factory {
 										'type_id' => 'Type',
 										'type' => FALSE,
 										'user_date_total_id' => 'UserDateTotalID',
+										'date_stamp' => FALSE,
 										'time_stamp' => 'TimeStamp',
 										'amount' => 'Amount',
 										'deleted' => 'Deleted',
@@ -406,11 +408,12 @@ class AccrualFactory extends Factory {
 		return TRUE;
 	}
 
-	static function deleteOrphans($user_id) {
+	static function deleteOrphans($user_id, $date_stamp ) {
 		Debug::text('Attempting to delete Orphaned Records for User ID: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
 		//Remove orphaned entries
 		$alf = TTnew( 'AccrualListFactory' );
-		$alf->getOrphansByUserId( $user_id );
+		//$alf->getOrphansByUserId( $user_id );
+		$alf->getOrphansByUserIdAndDate( $user_id, $date_stamp );
 		Debug::text('Found Orphaned Records: '. $alf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		if ( $alf->getRecordCount() > 0 ) {
 			foreach( $alf as $a_obj ) {
@@ -425,7 +428,6 @@ class AccrualFactory extends Factory {
 					AccrualBalanceFactory::calcBalance( $user_id, $accrual_policy_id );
 				}
 			}
-
 		}
 
 		return TRUE;
@@ -489,19 +491,23 @@ class AccrualFactory extends Factory {
 								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
 							}
 							break;
+						case 'date_stamp': //This is a combination of the time_stamp and user_date.date_stamp columns.
+							$data[$variable] = TTDate::getAPIDate( 'DATE', strtotime( $this->getColumn( $variable ) ) );
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
 							}
 							break;
 					}
-
 				}
 			}
 			$this->getPermissionColumns( &$data, $this->getUser(), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
+		Debug::Arr($data, 'Data Object: ', __FILE__, __LINE__, __METHOD__, 10);
+
 		return $data;
 	}
 
