@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: AccrualListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 6071 $
+ * $Id: AccrualListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -418,6 +418,50 @@ class AccrualListFactory extends AccrualFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getOrphansByUserIdAndDate($user_id, $date_stamp, $where = NULL, $order = NULL) {
+		if ( $user_id == '') {
+			return FALSE;
+		}
+
+		if ( $date_stamp == '' ) {
+			return FALSE;
+		}
+
+		$apf = new AccrualPolicyFactory();
+		$udtf = new UserDateTotalFactory();
+		$udf = new UserDateFactory();
+
+		$ph = array(
+					'user_id' => $user_id,
+					//Filter the accrual rows to one day before and one day after as an optimization.
+					'date_stamp1' => $this->db->BindDate( TTDate::getBeginDayEpoch( TTDate::getMiddleDayEpoch( $date_stamp )-86400 ) ),
+					'date_stamp2' => $this->db->BindDate( TTDate::getBeginDayEpoch( TTDate::getMiddleDayEpoch( $date_stamp )+86400 ) ),
+					);
+
+		//Make sure we check if user_date rows are deleted where user_date_total rows are not.
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $udtf->getTable() .' as b ON a.user_date_total_id = b.id
+					LEFT JOIN '. $udf->getTable() .' as c ON b.user_date_id = c.id
+					LEFT JOIN '. $apf->getTable() .' as d ON a.accrual_policy_id = d.id
+					where	a.user_id = ?
+						AND ( a.time_stamp >= ? AND a.time_stamp <= ? )
+						AND (
+								( b.id is NULL OR b.deleted = 1 )
+								OR
+								( b.deleted = 0 AND ( c.id is NULL OR c.deleted = 1) )
+							)
+						AND ( a.type_id = 10 OR a.type_id = 20 OR ( a.type_id = 75 AND d.type_id = 30 ) )
+						AND a.deleted = 0';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getSumByUserIdAndAccrualPolicyId($user_id, $accrual_policy_id) {
 		if ( $user_id == '') {
 			return FALSE;
@@ -494,28 +538,24 @@ class AccrualListFactory extends AccrualFactory implements IteratorAggregate {
 			}
 		}
 
-		$additional_order_fields = array( 'accrual_policy','accrual_policy_type_id' );
+		$additional_order_fields = array( 'accrual_policy','accrual_policy_type_id','date_stamp' );
 		$sort_column_aliases = array(
 									 'accrual_policy_type' => 'accrual_policy_type_id',
 									 'type' => 'type_id',
 									 );
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 		if ( $order == NULL ) {
-			$order = array( 'accrual_policy_id' => 'asc', );
+			$order = array( 'accrual_policy_id' => 'asc', 'date_stamp' => 'desc');
 			$strict = FALSE;
 		} else {
-			//Always sort by last name,first name after other columns
-			/*
-			if ( !isset($order['effective_date']) ) {
-				$order['effective_date'] = 'desc';
-			}
-			*/
 			$strict = TRUE;
 		}
 		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		$uf = new UserFactory();
+		$udtf = new UserDateTotalFactory();
+		$udf = new UserDateFactory();
 		$bf = new BranchFactory();
 		$df = new DepartmentFactory();
 		$ugf = new UserGroupFactory();
@@ -530,6 +570,7 @@ class AccrualListFactory extends AccrualFactory implements IteratorAggregate {
 					select 	a.*,
 							ab.name as accrual_policy,
 							ab.type_id as accrual_policy_type_id,
+							CASE WHEN udf.date_stamp is NOT NULL THEN udf.date_stamp ELSE a.time_stamp END as date_stamp,
 							b.first_name as first_name,
 							b.last_name as last_name,
 							b.country as country,
@@ -540,13 +581,16 @@ class AccrualListFactory extends AccrualFactory implements IteratorAggregate {
 							d.id as default_department_id,
 							d.name as default_department,
 							e.id as group_id,
-							e.name as group,
+							e.name as "group",
 							f.id as title_id,
 							f.name as title
 					from 	'. $this->getTable() .' as a
 						LEFT JOIN '. $apf->getTable() .' as ab ON ( a.accrual_policy_id = ab.id AND ab.deleted = 0 )
 						LEFT JOIN '. $uf->getTable() .' as b ON ( a.user_id = b.id AND b.deleted = 0 )
 
+						LEFT JOIN '. $udtf->getTable() .' as udtf ON a.user_date_total_id = udtf.id
+						LEFT JOIN '. $udf->getTable() .' as udf ON udtf.user_date_id = udf.id
+
 						LEFT JOIN '. $bf->getTable() .' as c ON ( b.default_branch_id = c.id AND c.deleted = 0)
 						LEFT JOIN '. $df->getTable() .' as d ON ( b.default_department_id = d.id AND d.deleted = 0)
 						LEFT JOIN '. $ugf->getTable() .' as e ON ( b.group_id = e.id AND e.deleted = 0 )
@@ -568,7 +612,7 @@ class AccrualListFactory extends AccrualFactory implements IteratorAggregate {
 			$query  .=	' AND a.user_id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
-			$query  .=	' AND ab.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['accrual_policy_id']) AND isset($filter_data['accrual_policy_id'][0]) AND !in_array(-1, (array)$filter_data['accrual_policy_id']) ) {
 			$query  .=	' AND a.accrual_policy_id in ('. $this->getListSQL($filter_data['accrual_policy_id'], $ph) .') ';
