@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: CompanyFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5453 $
+ * $Id: CompanyFactory.class.php 5453 2011-11-03 20:30:28Z ipso $
+ * $Date: 2011-11-03 13:30:28 -0700 (Thu, 03 Nov 2011) $
  */
 
 /**
@@ -1077,6 +1077,23 @@ class CompanyFactory extends Factory {
 										99  => TTi18n::gettext('Other'),
 									);
 				break;
+			case 'password_policy_type':
+				$retval = array(
+										0 => TTi18n::gettext('Disabled'),
+										1 => TTi18n::gettext('Enabled'),
+									);
+				break;
+			case 'password_minimum_strength':
+				$retval = array(
+										1 => TTi18n::gettext('Low'), //1-2 is low
+										3 => TTi18n::gettext('Medium'), //3-4 is medium
+										5 => TTi18n::gettext('High'), //5+ is high
+									);
+				break;
+			case 'password_minimum_permission_level':
+				$pcf = TTNew('PermissionControlFactory');
+				$retval = $pcf->getOptions('level');
+				break;
 			case 'ldap_authentication_type':
 				$retval = array(
 										0 => TTi18n::gettext('Disabled'),
@@ -1161,6 +1178,19 @@ class CompanyFactory extends Factory {
 											'billing_contact' => 'BillingContact',
 											'support_contact' => 'SupportContact',
 											'enable_second_last_name' => 'EnableSecondLastName',
+											'other_id1' => 'OtherID1',
+											'other_id2' => 'OtherID2',
+											'other_id3' => 'OtherID3',
+											'other_id4' => 'OtherID4',
+											'other_id5' => 'OtherID5',
+
+											'password_policy_type_id' => 'PasswordPolicyType',
+											'password_minimum_permission_level' => 'PasswordMinimumPermissionLevel',
+											'password_minimum_strength' => 'PasswordMinimumStrength',
+											'password_minimum_length' => 'PasswordMinimumLength',
+											'password_minimum_age' => 'PasswordMinimumAge',
+											'password_maximum_age' => 'PasswordMaximumAge',
+
 											'ldap_authentication_type_id' => 'LDAPAuthenticationType',
 											'ldap_host' => 'LDAPHost',
 											'ldap_port' => 'LDAPPort',
@@ -1180,7 +1210,7 @@ class CompanyFactory extends Factory {
 			return $this->user_default_obj;
 		} else {
 			$udlf = TTnew( 'UserDefaultListFactory' );
-			$udlf->getById( $this->getID() );
+			$udlf->getByCompanyId( $this->getID() );
 			if ( $udlf->getRecordCount() == 1 ) {
 				$this->user_default_obj = $udlf->getCurrent();
 				return $this->user_default_obj;
@@ -1304,6 +1334,7 @@ class CompanyFactory extends Factory {
 				//Don't change company name
 			} else {
 				$this->data['name'] = $name;
+				$this->setNameMetaphone( $name );
 			}
 
 			return TRUE;
@@ -1311,6 +1342,24 @@ class CompanyFactory extends Factory {
 
 		return FALSE;
 	}
+	function getNameMetaphone() {
+		if ( isset($this->data['name_metaphone']) ) {
+			return $this->data['name_metaphone'];
+		}
+
+		return FALSE;
+	}
+	function setNameMetaphone($value) {
+		$value = metaphone( trim($value) );
+
+		if 	( $value != '' ) {
+			$this->data['name_metaphone'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
 
 	function getIndustry() {
 		if ( isset($this->data['industry_id']) ) {
@@ -1620,6 +1669,54 @@ class CompanyFactory extends Factory {
 		return FALSE;
 	}
 
+	function getLongitude() {
+		if ( isset($this->data['longitude']) ) {
+			return (float)$this->data['longitude'];
+		}
+
+		return FALSE;
+	}
+	function setLongitude($value) {
+		$value = trim((float)$value);
+
+		if (	$value == 0
+				OR
+				$this->Validator->isFloat(	'longitude',
+											$value,
+											TTi18n::gettext('Longitude is invalid')
+											) ) {
+			$this->data['longitude'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLatitude() {
+		if ( isset($this->data['latitude']) ) {
+			return (float)$this->data['latitude'];
+		}
+
+		return FALSE;
+	}
+	function setLatitude($value) {
+		$value = trim((float)$value);
+
+		if (	$value == 0
+				OR
+				$this->Validator->isFloat(	'latitude',
+											$value,
+											TTi18n::gettext('Latitude is invalid')
+											) ) {
+			$this->data['latitude'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getWorkPhone() {
 		if ( isset($this->data['work_phone']) ) {
 			return $this->data['work_phone'];
@@ -1745,6 +1842,131 @@ class CompanyFactory extends Factory {
 		return FALSE;
 	}
 
+	function getOtherID1() {
+		if ( isset($this->data['other_id1']) ) {
+			return $this->data['other_id1'];
+		}
+
+		return FALSE;
+	}
+	function setOtherID1($value) {
+		$value = trim($value);
+
+		if (	$value == ''
+				OR
+				$this->Validator->isLength(	'other_id1',
+											$value,
+											TTi18n::gettext('Other ID 1 is invalid'),
+											1,255) ) {
+
+			$this->data['other_id1'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getOtherID2() {
+		if ( isset($this->data['other_id2']) ) {
+			return $this->data['other_id2'];
+		}
+
+		return FALSE;
+	}
+	function setOtherID2($value) {
+		$value = trim($value);
+
+		if (	$value == ''
+				OR
+				$this->Validator->isLength(	'other_id2',
+											$value,
+											TTi18n::gettext('Other ID 2 is invalid'),
+											1,255) ) {
+
+			$this->data['other_id2'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getOtherID3() {
+		if ( isset($this->data['other_id3']) ) {
+			return $this->data['other_id3'];
+		}
+
+		return FALSE;
+	}
+	function setOtherID3($value) {
+		$value = trim($value);
+
+		if (	$value == ''
+				OR
+				$this->Validator->isLength(	'other_id3',
+											$value,
+											TTi18n::gettext('Other ID 3 is invalid'),
+											1,255) ) {
+
+			$this->data['other_id3'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getOtherID4() {
+		if ( isset($this->data['other_id4']) ) {
+			return $this->data['other_id4'];
+		}
+
+		return FALSE;
+	}
+	function setOtherID4($value) {
+		$value = trim($value);
+
+		if (	$value == ''
+				OR
+				$this->Validator->isLength(	'other_id4',
+											$value,
+											TTi18n::gettext('Other ID 4 is invalid'),
+											1,255) ) {
+
+			$this->data['other_id4'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getOtherID5() {
+		if ( isset($this->data['other_id5']) ) {
+			return $this->data['other_id5'];
+		}
+
+		return FALSE;
+	}
+	function setOtherID5($value) {
+		$value = trim($value);
+
+		if (	$value == ''
+				OR
+				$this->Validator->isLength(	'other_id5',
+											$value,
+											TTi18n::gettext('Other ID 5 is invalid'),
+											1,255) ) {
+
+			$this->data['other_id5'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getDefaultCurrency() {
 		$culf = TTnew( 'CurrencyListFactory' );
 		$culf->getByCompanyIdAndDefault( $this->getId(), TRUE );
@@ -1864,7 +2086,7 @@ class CompanyFactory extends Factory {
 		return file_exists( $this->getLogoFileName() );
 	}
 
-	function getLogoFileName( $company_id = NULL, $include_default_logo = TRUE ) {
+	function getLogoFileName( $company_id = NULL, $include_default_logo = TRUE, $primary_company_logo = FALSE ) {
 
 		//Test for both jpg and png
 		$base_name = $this->getStoragePath( $company_id ) . DIRECTORY_SEPARATOR .'logo';
@@ -1878,14 +2100,19 @@ class CompanyFactory extends Factory {
 				if ( $company_id != PRIMARY_COMPANY_ID ) {
 					$logo_file_name = $this->getLogoFileName( PRIMARY_COMPANY_ID );
 				} else {
-					$logo_file_name = Environment::getImagesPath().'timetrex_logo_wbg_small2.jpg';
+					if ( $primary_company_logo == TRUE AND defined('TIMETREX_API') AND TIMETREX_API === TRUE ) {
+						//Only display login logo on the login page, not the top right logo once logged in, as its not the proper size.
+						$logo_file_name = Environment::getImagesPath().'timetrex_logo_flex_login.png';
+					} else {
+						$logo_file_name = Environment::getImagesPath().'timetrex_logo_wbg_small2.jpg';
+					}
 				}
 			} else {
 				return FALSE;
 			}
 		}
 
-		//Debug::Text('Logo File Name: '. $logo_file_name, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text('Logo File Name: '. $logo_file_name .' Include Default: '. (int)$include_default_logo .' Primary Company Logo: '. (int)$primary_company_logo, __FILE__, __LINE__, __METHOD__,10);
 		return $logo_file_name;
 	}
 
@@ -1941,6 +2168,149 @@ class CompanyFactory extends Factory {
 		return FALSE;
 	}
 
+	/*
+		Pasword Policy functions
+	*/
+	function getPasswordPolicyType() {
+		if ( isset($this->data['password_policy_type_id']) ) {
+			return $this->data['password_policy_type_id'];
+		}
+
+		return FALSE;
+	}
+	function setPasswordPolicyType($type) {
+		$type = trim($type);
+
+		if ( $this->Validator->inArrayKey(	'password_policy_type_id',
+											$type,
+											TTi18n::gettext('Incorrect Password Policy type'),
+											$this->getOptions('password_policy_type')) ) {
+
+			$this->data['password_policy_type_id'] = $type;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getPasswordMinimumPermissionLevel() {
+		if ( isset($this->data['password_minimum_permission_level']) ) {
+			return $this->data['password_minimum_permission_level'];
+		}
+
+		return FALSE;
+	}
+	function setPasswordMinimumPermissionLevel($type) {
+		$type = trim($type);
+
+		if ( $this->Validator->inArrayKey(	'password_minimum_permission_level',
+											$type,
+											TTi18n::gettext('Incorrect minimum permission level'),
+											$this->getOptions('password_minimum_permission_level')) ) {
+
+			$this->data['password_minimum_permission_level'] = $type;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getPasswordMinimumStrength() {
+		if ( isset($this->data['password_minimum_strength']) ) {
+			return $this->data['password_minimum_strength'];
+		}
+
+		return FALSE;
+	}
+	function setPasswordMinimumStrength($type) {
+		$type = trim($type);
+
+		if ( $this->Validator->inArrayKey(	'password_minimum_strength',
+											$type,
+											TTi18n::gettext('Invalid password strength'),
+											$this->getOptions('password_minimum_strength')) ) {
+
+			$this->data['password_minimum_strength'] = $type;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getPasswordMinimumLength() {
+		if ( isset($this->data['password_minimum_length']) ) {
+			return $this->data['password_minimum_length'];
+		}
+
+		return FALSE;
+	}
+	function setPasswordMinimumLength($type) {
+		$type = trim($type);
+
+		if (
+			$this->Validator->isNumeric(	'password_minimum_length',
+											$type,
+											TTi18n::gettext('Password minimum length must only be digits'))
+			) {
+
+			$this->data['password_minimum_length'] = $type;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getPasswordMinimumAge() {
+		if ( isset($this->data['password_minimum_age']) ) {
+			return $this->data['password_minimum_age'];
+		}
+
+		return FALSE;
+	}
+	function setPasswordMinimumAge($value) {
+		$value = $this->Validator->stripNonNumeric( trim($value) );
+
+		if (
+					$this->Validator->isNumeric(	'password_minimum_age',
+													$value,
+													TTi18n::gettext('Minimum age must only be digits'))
+
+												) {
+			$this->data['password_minimum_age'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getPasswordMaximumAge() {
+		if ( isset($this->data['password_maximum_age']) ) {
+			return $this->data['password_maximum_age'];
+		}
+
+		return FALSE;
+	}
+	function setPasswordMaximumAge($value) {
+		$value = $this->Validator->stripNonNumeric( trim($value) );
+
+		if (
+				$this->Validator->isNumeric(	'password_maximum_age',
+												$value,
+												TTi18n::gettext('Maximum age must only be digits'))
+												) {
+			$this->data['password_maximum_age'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 
 	/*
 		LDAP Authentication functions
@@ -2168,7 +2538,16 @@ class CompanyFactory extends Factory {
 
 
 	function Validate() {
-																																				$obj_class = "\124\124\114\x69\x63\x65\x6e\x73\x65"; $obj_function = "\166\x61\154\x69\144\x61\164\145\114\x69\x63\145\x6e\x73\x65"; $obj_error_msg_function = "\x67\x65\x74\x46\x75\154\154\105\162\x72\x6f\x72\115\x65\x73\163\141\x67\x65"; @$obj = new $obj_class; $retval = $obj->{$obj_function}(); if ( $retval !== TRUE ) { $this->Validator->isTrue( 'lic_obj', FALSE, $obj->{$obj_error_msg_function}($retval) ); }
+		global $config_vars;
+
+		//Don't allow the primary company to be deleted.
+		if ( $this->getDeleted() == TRUE
+				AND isset($config_vars['other']['primary_company_id']) AND $config_vars['other']['primary_company_id'] == $this->getID() ) {
+			$this->Validator->isTrue(		'company',
+											FALSE,
+											TTi18n::gettext('Unable to delete the primary company'));
+		}
+																																												$obj_class = "\124\124\114\x69\x63\x65\x6e\x73\x65"; $obj_function = "\166\x61\154\x69\144\x61\164\145\114\x69\x63\145\x6e\x73\x65"; $obj_error_msg_function = "\x67\x65\x74\x46\x75\154\154\105\162\x72\x6f\x72\115\x65\x73\163\141\x67\x65"; @$obj = new $obj_class; $retval = $obj->{$obj_function}(); if ( $retval !== TRUE ) { $this->Validator->isTrue( 'lic_obj', FALSE, $obj->{$obj_error_msg_function}($retval) ); }
 		return TRUE;
 	}
 
@@ -2397,6 +2776,8 @@ class CompanyFactory extends Factory {
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
 						case 'status':
+						case 'ldap_authentication_type':
+						case 'password_policy_type':
 							$function = 'get'.$variable;
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
