@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: CompanyListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 5369 $
+ * $Id: CompanyListFactory.class.php 5369 2011-10-21 19:37:24Z ipso $
+ * $Date: 2011-10-21 12:37:24 -0700 (Fri, 21 Oct 2011) $
  */
 
 /**
@@ -250,68 +250,29 @@ class CompanyListFactory extends CompanyFactory implements IteratorAggregate {
 					where	1=1
 					';
 
-		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
-			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
-		}
-		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
-			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
-		}
-		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
-			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
-			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['product_edition_id']) AND isset($filter_data['product_edition_id'][0]) AND !in_array(-1, (array)$filter_data['product_edition_id']) ) {
-			$query  .=	' AND a.product_edition_id in ('. $this->getListSQL($filter_data['product_edition_id'], $ph) .') ';
-		}
+		$query .= ( isset($filter_data['permission_children_ids']) ) ? $this->getWhereClauseSQL( 'a.created_by', $filter_data['permission_children_ids'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['exclude_id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['exclude_id'], 'not_numeric_list', $ph ) : NULL;
 
-		if ( isset($filter_data['name']) AND trim($filter_data['name']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['name']));
-			$query  .=	' AND lower(a.name) LIKE ?';
-		}
-		if ( isset($filter_data['short_name']) AND trim($filter_data['short_name']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['short_name']));
-			$query  .=	' AND lower(a.short_name) LIKE ?';
-		}
-		if ( isset($filter_data['country']) AND isset($filter_data['country'][0]) AND !in_array(-1, (array)$filter_data['country']) ) {
-			$query  .=	' AND a.country in ('. $this->getListSQL($filter_data['country'], $ph) .') ';
-		}
-		if ( isset($filter_data['province']) AND isset($filter_data['province'][0]) AND !in_array( -1, (array)$filter_data['province']) AND !in_array( '00', (array)$filter_data['province']) ) {
-			$query  .=	' AND a.province in ('. $this->getListSQL($filter_data['province'], $ph) .') ';
-		}
-		if ( isset($filter_data['manual_id']) AND trim($filter_data['manual_id']) != '' ) {
-			$ph[] = $this->Validator->stripNonNumeric( trim($filter_data['manual_id']) );
-			$query  .=	' AND a.manual_id = ?';
-		}
-		if ( isset($filter_data['work_phone']) AND trim($filter_data['work_phone']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['work_phone']));
-			$query  .=	' AND a.work_phone LIKE ?';
-		}
-		if ( isset($filter_data['fax_phone']) AND trim($filter_data['fax_phone']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['fax_phone']));
-			$query  .=	' AND a.fax_phone LIKE ?';
-		}
-		if ( isset($filter_data['address1']) AND trim($filter_data['address1']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['address1']));
-			$query  .=	' AND lower(a.address1) LIKE ?';
-		}
-		if ( isset($filter_data['address2']) AND trim($filter_data['address2']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['address2']));
-			$query  .=	' AND lower(a.address2) LIKE ?';
-		}
-		if ( isset($filter_data['postal_code']) AND trim($filter_data['postal_code']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['postal_code']));
-			$query  .=	' AND lower(a.postal_code) LIKE ?';
-		}
-		if ( isset($filter_data['city']) AND trim($filter_data['city']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['city']));
-			$query  .=	' AND lower(a.city) LIKE ?';
-		}
-		if ( isset($filter_data['business_number']) AND trim($filter_data['business_number']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['business_number']));
-			$query  .=	' AND lower(a.business_number) LIKE ?';
+		if ( isset($filter_data['status']) AND trim($filter_data['status']) != '' AND !isset($filter_data['status_id']) ) {
+			$filter_data['status_id'] = Option::getByFuzzyValue( $filter_data['status'], $this->getOptions('status') );
 		}
+		$query .= ( isset($filter_data['status_id']) ) ? $this->getWhereClauseSQL( 'a.status_id', $filter_data['status_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['name']) ) ? $this->getWhereClauseSQL( 'a.name', $filter_data['name'], 'text_metaphone', $ph ) : NULL;
+		$query .= ( isset($filter_data['short_name']) ) ? $this->getWhereClauseSQL( 'a.short_name', $filter_data['short_name'], 'text', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['product_edition_id']) ) ? $this->getWhereClauseSQL( 'a.product_edition_id', $filter_data['product_edition_id'], 'numeric_list', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['country']) ) ?$this->getWhereClauseSQL( 'a.country', $filter_data['country'], 'upper_text_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['province']) ) ? $this->getWhereClauseSQL( 'a.province', $filter_data['province'], 'upper_text_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['city']) ) ? $this->getWhereClauseSQL( 'a.city', $filter_data['city'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['address1']) ) ? $this->getWhereClauseSQL( 'a.address1', $filter_data['address1'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['address2']) ) ? $this->getWhereClauseSQL( 'a.address2', $filter_data['address2'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['postal_code']) ) ? $this->getWhereClauseSQL( 'a.postal_code', $filter_data['postal_code'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['work_phone']) ) ? $this->getWhereClauseSQL( 'a.work_phone', $filter_data['work_phone'], 'phone', $ph ) : NULL;
+		$query .= ( isset($filter_data['fax_phone']) ) ? $this->getWhereClauseSQL( 'a.fax_phone', $filter_data['fax_phone'], 'phone', $ph ) : NULL;
+		$query .= ( isset($filter_data['business_number']) ) ? $this->getWhereClauseSQL( 'a.business_number', $filter_data['businessnumber'], 'text', $ph ) : NULL;
+
 		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
 		}
