@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: Authentication.class.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5902 $
+ * $Id: Authentication.class.php 5902 2011-12-30 19:19:27Z ipso $
+ * $Date: 2011-12-30 11:19:27 -0800 (Fri, 30 Dec 2011) $
  */
 
 
@@ -46,6 +46,7 @@
 class Authentication {
 	protected $name = 'SessionID';
 	protected $idle = 14400; //Max IDLE time
+	protected $expire_session; //When TRUE, cookie is expired when browser closes.
 	protected $session_id = NULL;
 	protected $ip_address = NULL;
 	protected $created_date = NULL;
@@ -58,6 +59,11 @@ class Authentication {
 
 		$this->db = $db;
 
+		$this->rl = TTNew('RateLimit');
+		$this->rl->setID( 'authentication_'.$_SERVER['REMOTE_ADDR'] );
+		$this->rl->setAllowedCalls( 20 );
+		$this->rl->setTimeFrame( 900 ); //15 minutes
+
 		return TRUE;
 	}
 
@@ -105,6 +111,15 @@ class Authentication {
 		return FALSE;
 	}
 
+	//Expire Session when browser is closed?
+	function getEnableExpireSession() {
+		return $this->expire_session;
+	}
+	function setEnableExpireSession($bool) {
+		$this->expire_session = (bool)$bool;
+		return TRUE;
+	}
+
 	function getCreatedDate() {
 		return $this->created_date;
 	}
@@ -360,7 +375,12 @@ class Authentication {
 
 	private function setCookie() {
 		if ( $this->getSessionID() ) {
-			setcookie($this->getName(), $this->getSessionID(), time()+9999999, Environment::getBaseURL(), NULL, $this->isSSL() );
+			$cookie_expires = time()+7776000; //90 Days
+			if ( $this->getEnableExpireSession() === TRUE ) {
+				$cookie_expires = 0; //Expire when browser closes.
+			}
+			Debug::text('Cookie Expires: '. $cookie_expires, __FILE__, __LINE__, __METHOD__, 10);
+			setcookie($this->getName(), $this->getSessionID(), $cookie_expires, Environment::getBaseURL(), NULL, $this->isSSL() );
 
 			return TRUE;
 		}
@@ -374,6 +394,24 @@ class Authentication {
 		return TRUE;
 	}
 
+	private function UpdateLastLoginDate() {
+		$ph = array(
+					'last_login_date' => TTDate::getTime(),
+					'user_id' => (int)$this->getObject()->getID(),
+					);
+
+		$query = 'update users set last_login_date = ?
+					where id = ?';
+
+		try {
+			$this->db->Execute($query, $ph);
+		} catch (Exception $e) {
+			throw new DBError($e);
+		}
+
+		return TRUE;
+	}
+
 	private function Update() {
 		$ph = array(
 					'updated_date' => TTDate::getTime(),
@@ -483,55 +521,75 @@ class Authentication {
 		}
 
 		Debug::text('Login Type: '. $type, __FILE__, __LINE__, __METHOD__, 10);
+		try {
+			//Prevent brute force attacks by IP address.
+			//Allowed up to 20 attempts in a 30 min period.
+			if ( $this->rl->check() == FALSE ) {
+				Debug::Text('Excessive failed password attempts... Preventing login from: '. $_SERVER['REMOTE_ADDR'] .' for up to 15 minutes...', __FILE__, __LINE__, __METHOD__,10);
+				sleep(5); //Excessive password attempts, sleep longer.
+				return FALSE;
+			}
 
-		if ( strtolower($type) == 'user_name' ) {
-			if ( $this->checkCompanyStatus( $user_name ) == TRUE ) {
-				//Lowercase regular user_names here only.
-				$password_result = $this->checkPassword( strtolower($user_name), $password);
+			if ( strtolower($type) == 'user_name' ) {
+				if ( $this->checkCompanyStatus( $user_name ) == TRUE ) {
+					//Lowercase regular user_names here only.
+					$password_result = $this->checkPassword( strtolower($user_name), $password);
+				} else {
+					$password_result = FALSE; //No company by that user name.
+				}
+			} elseif (strtolower($type) == 'phone_id') {
+				$password_result = $this->checkPhonePassword($user_name, $password);
+			} elseif (strtolower($type) == 'ibutton') {
+				$password_result = $this->checkIButton($user_name);
+			} elseif (strtolower($type) == 'barcode') {
+				$password_result = $this->checkBarcode($user_name, $password);
+			} elseif (strtolower($type) == 'finger_print') {
+				$password_result = $this->checkFingerPrint( $user_name );
+			} elseif (strtolower($type) == 'client_pc') {
+				//This is for client application persistent connections, use:
+				//Login Type: client_pc
+				//Station Type: PC
+
+				//$password_result = $this->checkClientPC( $user_name );
+				$password_result = $this->checkBarcode($user_name, $password);
 			} else {
 				return FALSE;
 			}
-		} elseif (strtolower($type) == 'phone_id') {
-			$password_result = $this->checkPhonePassword($user_name, $password);
-		} elseif (strtolower($type) == 'ibutton') {
-			$password_result = $this->checkIButton($user_name);
-		} elseif (strtolower($type) == 'barcode') {
-			$password_result = $this->checkBarcode($user_name, $password);
-		} elseif (strtolower($type) == 'finger_print') {
-			$password_result = $this->checkFingerPrint( $user_name );
-		} elseif (strtolower($type) == 'client_pc') {
-			//This is for client application persistent connections, use:
-			//Login Type: client_pc
-			//Station Type: PC
 
-			//$password_result = $this->checkClientPC( $user_name );
-			$password_result = $this->checkBarcode($user_name, $password);
-		} else {
-			return FALSE;
+			if ( $password_result === TRUE ) {
+				Debug::text('Login Succesful!', __FILE__, __LINE__, __METHOD__, 10);
+
+				$this->setSessionID( $this->genSessionID() );
+				$this->setIPAddress();
+				$this->setCreatedDate();
+				$this->setUpdatedDate();
+
+				//Sets session cookie.
+				$this->setCookie();
+
+				//Write data to db.
+				$this->Write();
+
+				//Only update last_login_date when using user_name to login to the web interface.
+				if ( strtolower($type) == 'user_name' ) {
+					$this->UpdateLastLoginDate();
+				}
+
+				TTLog::addEntry( $this->getObject()->getID(), 100,  TTi18n::getText('SourceIP').': '. $this->getIPAddress() .' '. TTi18n::getText('Type').': '. $type .' '.  TTi18n::getText('SessionID') .': '.$this->getSessionID() .' '.  TTi18n::getText('UserID').': '. $this->getObject()->getId(), $this->getObject()->getID() , 'authentication'); //Login
+
+				$this->rl->delete(); //Clear failed password rate limit upon successful login.
+
+				return TRUE;
+			}
+
+			Debug::text('Login Failed! Attempt: '. $this->rl->getAttempts(), __FILE__, __LINE__, __METHOD__, 10);
+
+			sleep( ($this->rl->getAttempts()*0.5) ); //If password is incorrect, sleep for some time to slow down brute force attacks.
+		} catch (Exception $e) {
+			//Database not initialized, or some error, redirect to Install page.
+			throw new DBError($e, 'DBInitialize');
 		}
 
-		if ( $password_result === TRUE ) {
-
-			Debug::text('Login Succesful!', __FILE__, __LINE__, __METHOD__, 10);
-
-			$this->setSessionID( $this->genSessionID() );
-			$this->setIPAddress();
-			$this->setCreatedDate();
-			$this->setUpdatedDate();
-
-			//Sets session cookie.
-			$this->setCookie();
-
-			//Write data to db.
-			$this->Write();
-
-			TTLog::addEntry( $this->getObject()->getID(), 100,  TTi18n::getText('SourceIP').': '. $this->getIPAddress() .' '. TTi18n::getText('Type').': '. $type .' '.  TTi18n::getText('SessionID') .': '.$this->getSessionID() .' '.  TTi18n::getText('UserID').': '. $this->getObject()->getId(), $this->getObject()->getID() , 'authentication'); //Login
-
-			return TRUE;
-		}
-
-		Debug::text('Login Failed!', __FILE__, __LINE__, __METHOD__, 10);
-
 		return FALSE;
 	}
 
@@ -565,12 +623,6 @@ class Authentication {
 			}
 		}
 
-		/*
-		if ( $session_id == '' AND isset($_COOKIE[$this->getName()]) ) {
-			$session_id = $_COOKIE[$this->getName()];
-		}
-		*/
-
 		Debug::text('Session ID: '. $session_id .' URL: '. $_SERVER['REQUEST_URI'], __FILE__, __LINE__, __METHOD__, 10);
 		//Checks session cookie, returns user_id;
 		if ( isset( $session_id ) ) {
@@ -583,16 +635,21 @@ class Authentication {
 				as well as the MD5 of their user-agent string.
 				Could also use "behind proxy IP address" if one is supplied.
 			*/
-			$this->setSessionID( $session_id );
-			$this->setIPAddress();
+			try {
+				$this->setSessionID( $session_id );
+				$this->setIPAddress();
 
-			if ( $this->Read() == TRUE ) {
+				if ( $this->Read() == TRUE ) {
 
-				//touch UpdatedDate
-				$this->Update();
+					//touch UpdatedDate
+					$this->Update();
 
-				$profiler->stopTimer( "Authentication::Check()");
-				return TRUE;
+					$profiler->stopTimer( "Authentication::Check()");
+					return TRUE;
+				}
+			} catch (Exception $e) {
+				//Database not initialized, or some error, redirect to Install page.
+				throw new DBError($e, 'DBInitialize');
 			}
 		}
 
