@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: CalculatePayStub.class.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 6071 $
+ * $Id: CalculatePayStub.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -202,8 +202,6 @@ class CalculatePayStub extends PayStubFactory {
 	}
 
 	function getDeductionObjectArrayForSorting( $obj ) {
-		//$psealf = TTnew( 'PayStubEntryAccountListFactory' );
-		//$type_map_arr = $psealf->getByTypeArrayByCompanyIdAndStatusId( $this->getUserObject()->getCompany(), 10 );
 		$type_map_arr = $this->getPayStubEntryAccountsTypeArray();
 
 		//Debug::Arr($type_map_arr, 'PS Account Type Map Array: ', __FILE__, __LINE__, __METHOD__,10);
@@ -228,7 +226,9 @@ class CalculatePayStub extends PayStubFactory {
 			$arr['obj_id'] = $obj->getId();
 			$arr['id'] = substr($arr['type'],0,1).$obj->getId();
 			$arr['name'] = $obj->getCompanyDeductionObject()->getName();
-			$arr['order'] = $obj->getCompanyDeductionObject()->getPayStubEntryAccountObject()->getTypeCalculationOrder();
+			//Need more than just TypeCalculationOrder to prevent Federal/Prov income tax from being calculated BEFORE CPP/EI.
+			//$arr['order'] = $obj->getCompanyDeductionObject()->getPayStubEntryAccountObject()->getTypeCalculationOrder();
+			$arr['order'] = $obj->getCompanyDeductionObject()->getPayStubEntryAccountObject()->getTypeCalculationOrder() . str_pad( $obj->getCompanyDeductionObject()->getCalculationOrder(), 5, 0, STR_PAD_LEFT);
 			$arr['obj'] = $obj;
 			$arr['require_accounts'] = array();
 
@@ -268,7 +268,7 @@ class CalculatePayStub extends PayStubFactory {
 			$arr['obj_id'] = $obj->getId();
 			$arr['id'] = substr($arr['type'],0,1).$obj->getId();
 			$arr['name'] = $obj->getDescription();
-			$arr['order'] = $obj->getPayStubEntryNameObject()->getTypeCalculationOrder();
+			$arr['order'] = $obj->getPayStubEntryNameObject()->getTypeCalculationOrder() . str_pad( $obj->getPayStubEntryNameObject()->getOrder(), 5, 0, STR_PAD_LEFT);
 			$arr['obj'] = $obj;
 
 			$arr['affect_accounts'] = $obj->getPayStubEntryNameId();
@@ -297,7 +297,6 @@ class CalculatePayStub extends PayStubFactory {
 				foreach ( $udlf as $ud_obj ) {
 					Debug::text('User Deduction: ID: '. $ud_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
 					if ( $ud_obj->getCompanyDeductionObject()->getStatus() == 10 ) {
-						//$deduction_order_arr = $this->calculateDeductionOrder( $deduction_order_arr, $ud_obj );
 						$global_id = substr(get_class( $ud_obj ),0,1) . $ud_obj->getId();
 						$deduction_order_arr[$global_id] = $this->getDeductionObjectArrayForSorting( $ud_obj );
 
@@ -314,7 +313,6 @@ class CalculatePayStub extends PayStubFactory {
 			if ( $psalf->getRecordCount() > 0 ) {
 				foreach ( $psalf as $psa_obj ) {
 					Debug::text('PS Amendment ID: '. $psa_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
-					//$deduction_order_arr = $this->calculateDeductionOrder( $deduction_order_arr, $ud_obj );
 					$global_id = substr(get_class( $psa_obj ),0,1) . $psa_obj->getId();
 					$deduction_order_arr[$global_id] = $this->getDeductionObjectArrayForSorting( $psa_obj );
 
@@ -411,7 +409,7 @@ class CalculatePayStub extends PayStubFactory {
 			//Use the end of the current date for the transaction date, as if the employee is terminated
 			//on the same day they are generating the pay stub, the transaction date could be before the end date
 			//as the end date is at 11:59PM
-			
+
 			//For now make sure that the transaction date for a terminated employee is never before their termination date.
 			if ( TTDate::getEndDayEpoch( TTDate::getTime() ) < $this->getUserObject()->getTerminationDate() ) {
 				$pay_stub->setTransactionDate( $this->getUserObject()->getTerminationDate() );
@@ -485,8 +483,10 @@ class CalculatePayStub extends PayStubFactory {
 
 						//Determine if this deduction is valid based on start/end dates.
 						//Determine if this deduction is valid based on min/max length of service.
+						//Determine if this deduction is valid based on min/max user age.
 						if ( $ud_obj->getCompanyDeductionObject()->isActiveDate( $pay_stub->getPayPeriodObject()->getEndDate() ) == TRUE
-								AND $ud_obj->getCompanyDeductionObject()->isActiveLengthOfService( $this->getUserObject(), $pay_stub->getPayPeriodObject()->getEndDate() ) == TRUE ) {
+								AND $ud_obj->getCompanyDeductionObject()->isActiveLengthOfService( $this->getUserObject(), $pay_stub->getPayPeriodObject()->getEndDate() ) == TRUE
+								AND $ud_obj->getCompanyDeductionObject()->isActiveUserAge( $this->getUserObject(), $pay_stub->getPayPeriodObject()->getEndDate() ) == TRUE ) {
 
 								$amount = $ud_obj->getDeductionAmount( $this->getUserObject()->getId(), $pay_stub, $this->getPayPeriodObject() );
 								Debug::text('User Deduction: '. $ud_obj->getCompanyDeductionObject()->getName() .' Amount: '. $amount .' Calculation Order: '. $ud_obj->getCompanyDeductionObject()->getCalculationOrder(), __FILE__, __LINE__, __METHOD__,10);
@@ -509,7 +509,7 @@ class CalculatePayStub extends PayStubFactory {
 						if ( isset($amount) AND $amount != 0 ) {
 							Debug::text('Pay Stub Amendment Amount: '. $amount , __FILE__, __LINE__, __METHOD__,10);
 
-							$pay_stub->addEntry( $psa_obj->getPayStubEntryNameId() , $amount, $psa_obj->getUnits(), $psa_obj->getRate(), $psa_obj->getDescription(), $psa_obj->getID(), NULL, NULL, $psa_obj->getYTDAdjustment() );
+							$pay_stub->addEntry( $psa_obj->getPayStubEntryNameId(), $amount, $psa_obj->getUnits(), $psa_obj->getRate(), $psa_obj->getDescription(), $psa_obj->getID(), NULL, NULL, $psa_obj->getYTDAdjustment() );
 
 							//Keep in mind this causes pay stubs to be re-generated every time, as this modifies the updated time
 							//to slightly more then the pay stub creation time.
@@ -571,8 +571,6 @@ class CalculatePayStub extends PayStubFactory {
 		UserGenericStatusFactory::queueGenericStatus( $generic_queue_status_label, 10, $pay_stub->Validator->getTextErrors(), NULL );
 
 		$pay_stub->FailTransaction(); //Reduce transaction count by one.
-		//$pay_stub->FailTransaction(); //Reduce transaction count by one.
-
 		$pay_stub->CommitTransaction();
 
 		return FALSE;
