@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4300 $
- * $Id: Debug.class.php 4300 2011-02-25 19:49:45Z ipso $
- * $Date: 2011-02-25 11:49:45 -0800 (Fri, 25 Feb 2011) $
+ * $Revision: 5891 $
+ * $Id: Debug.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -105,6 +105,11 @@ class Debug {
 		return self::$enable_log;
 	}
 
+	//Used to add timing to each debug call.
+	static function getExecutionTime() {
+		return ceil( (microtime( TRUE )-$_SERVER['REQUEST_TIME'])*1000 );
+	}
+
 	static function Text($text = NULL, $file = __FILE__, $line = __LINE__, $method = __METHOD__, $verbosity = 9) {
 		if ( $verbosity > self::getVerbosity() OR self::$enable == FALSE ) {
 			return FALSE;
@@ -114,7 +119,7 @@ class Debug {
 			$method = "[Function]";
 		}
 
-		$text = 'DEBUG ['. $line .']:'. "\t" .'<b>'. $method .'()</b>: '. $text ."<br>\n";
+		$text = 'DEBUG [L'. $line .'] ['. self::getExecutionTime() .'ms]:'. "\t" .'<b>'. $method .'()</b>: '. $text ."<br>\n";
 
 		if ( self::$buffer_output == TRUE ) {
 			self::$debug_buffer[] = array($verbosity, $text);
@@ -130,6 +135,19 @@ class Debug {
 		return true;
 	}
 
+	static function profileTimers( $profile_obj ) {
+		if ( !is_object($profile_obj) ) {
+			return FALSE;
+		}
+
+		ob_start();
+		$profile_obj->printTimers();
+		$ob_contents = ob_get_contents();
+		ob_end_clean();
+
+		return $ob_contents;
+	}
+
 	static function backTrace() {
 		ob_start();
 		debug_print_backtrace();
@@ -158,7 +176,7 @@ class Debug {
 			$method = "[Function]";
 		}
 
-		$output = 'DEBUG ['. $line .'] Array: <b>'. $method .'()</b>: '. $text ."\n";
+		$output = 'DEBUG [L'. $line .'] ['. self::getExecutionTime() .'ms] Array: <b>'. $method .'()</b>: '. $text ."\n";
 		$output .= "<pre>\n". self::varDump($array) ."</pre><br>\n";
 
 		if (self::$buffer_output == TRUE) {
@@ -231,7 +249,7 @@ class Debug {
 				$output .= '---------------[ '. Date('r') .' (PID: '.getmypid().') ]---------------'.$eol;
 
 				$fp = @fopen( $file_name,'a' );
-				@fwrite($fp, $output);
+				@fwrite($fp, strip_tags( $output ) );
 				@fclose($fp);
 				unset($output);
 			}
