@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4295 $
- * $Id: Environment.class.php 4295 2011-02-24 21:11:56Z ipso $
- * $Date: 2011-02-24 13:11:56 -0800 (Thu, 24 Feb 2011) $
+ * $Revision: 5891 $
+ * $Id: Environment.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -52,6 +52,10 @@ class Environment {
 		return str_replace('classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR .'core', '', dirname( __FILE__ ) );
 	}
 
+	static function getHostName() {
+		return Misc::getHostName( TRUE );
+	}
+
 	static function getBaseURL() {
 		global $config_vars;
 
