@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: ExceptionFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 5133 $
+ * $Id: ExceptionFactory.class.php 5133 2011-08-16 22:53:51Z ipso $
+ * $Date: 2011-08-16 15:53:51 -0700 (Tue, 16 Aug 2011) $
  */
 
 /**
@@ -152,6 +152,11 @@ class ExceptionFactory extends Factory {
 											'default_department_id' => FALSE,
 											'default_department' => FALSE,
 
+											'branch_id' => FALSE,
+											'branch' => FALSE,
+											'department_id' => FALSE,
+											'department' => FALSE,
+
 											'deleted' => 'Deleted',
 											);
 			return $variable_function_map;
@@ -348,6 +353,9 @@ class ExceptionFactory extends Factory {
 					case 20:
 						$retval = '#FFFF00'; #'yellow';
 						break;
+					case 25:
+						$retval = '#FF9900'; #'orange';
+						break;
 					case 30:
 						$retval = '#FF0000'; #'red';
 						break;
@@ -373,6 +381,9 @@ class ExceptionFactory extends Factory {
 					case 20:
 						$retval = '#0000FF'; #'blue';
 						break;
+					case 25:
+						$retval = '#FF9900'; #'blue';
+						break;
 					case 30:
 						$retval = '#FF0000'; #'red';
 						break;
@@ -622,6 +633,10 @@ class ExceptionFactory extends Factory {
 						case 'default_branch':
 						case 'default_department_id':
 						case 'default_department':
+						case 'branch_id':
+						case 'branch':
+						case 'department_id':
+						case 'department':
 						case 'severity_id':
 						case 'exception_policy_type_id':
 							$data[$variable] = $this->getColumn( $variable );
