@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: ExceptionListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 6071 $
+ * $Id: ExceptionListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -202,21 +202,15 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 			return FALSE;
 		}
 
-		$uf = new UserFactory();
 		$udf = new UserDateFactory();
 		$epf = new ExceptionPolicyFactory();
 		$ppf = new PayPeriodFactory();
 		$rf = new RequestFactory();
-/*
-							b.date_stamp as user_date_stamp,
-							d.severity_id as severity_id,
-							d.type_id as exception_policy_type_id
-
-*/
 
 		$ph = array(
 					'user_id' => $user_id,
-					'date_stamp' => $this->db->BindDate( TTDate::getBeginDayEpoch( TTDate::getTime() ) ),
+					'date_stamp1' => $this->db->BindDate( TTDate::getBeginDayEpoch( TTDate::getTime()-(32*86400) ) ), //Narrow down the date range as a performance optimizaiton.
+					'date_stamp2' => $this->db->BindDate( TTDate::getBeginDayEpoch( TTDate::getTime() ) ), //Exclude any exceptions before today.
 					'status_id' => $pay_period_status,
 					);
 
@@ -225,13 +219,12 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 							count(*) as total
 					from	'. $this->getTable() .' as a
 					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
-					LEFT JOIN '. $uf->getTable() .' as c ON b.user_id = c.id
 					LEFT JOIN '. $epf->getTable() .' as d ON a.exception_policy_id = d.id
 					LEFT JOIN '. $ppf->getTable() .' as e ON b.pay_period_id = e.id
 					where
 						b.user_id = ?
 						AND a.type_id = 50
-						AND b.date_stamp <= ?
+						AND ( b.date_stamp >= ? AND b.date_stamp <= ? )
 						AND e.status_id = ?
 						AND NOT EXISTS ( select z.id from '. $rf->getTable() .' as z where z.user_date_id = a.user_date_id AND z.status_id = 30 )
 						AND ( a.deleted = 0 AND b.deleted = 0 AND e.deleted=0)
@@ -264,6 +257,7 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 					'date_stamp' => $this->db->BindDate( TTDate::getBeginDayEpoch( $before_epoch  ) ),
 					);
 
+		//Ignore pre-mature exceptions when counting exceptions.
 		$query = '
 					select 	d.severity_id as severity_id,
 							count(*) as count
@@ -274,6 +268,7 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 					LEFT JOIN '. $ppf->getTable() .' as e ON b.pay_period_id = e.id
 					where
 						e.id = ?
+						AND a.type_id = 50
 						AND b.date_stamp <= ?
 						AND ( a.deleted = 0 AND b.deleted = 0 AND e.deleted=0)
 					GROUP BY d.severity_id
@@ -503,16 +498,16 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 			case 'week':
 				$total_date_units = round( TTDate::getWeekDifference($start_date, $end_date) );
 				Debug::Text('Total Weeks: '. $total_date_units, __FILE__, __LINE__, __METHOD__,10);
-
 				break;
 			case 'month':
 				$total_date_units = ceil( TTDate::getMonthDifference($start_date, $end_date) );
-				if ( $total_date_units == 0 ) {
-					$total_date_units = 1;
-				}
 				Debug::Text('Total Months: '. $total_date_units, __FILE__, __LINE__, __METHOD__,10);
 				break;
 		}
+		//Avoid division by 0 error.
+		if ( $total_date_units == 0 ) {
+			$total_date_units = 1;
+		}
 
 		$ph = array(
 					'company_id' => $company_id,
@@ -938,6 +933,8 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 		$utf = new UserTitleFactory();
 		$ppf = new PayPeriodFactory();
 		$epf = new ExceptionPolicyFactory();
+		$pf = new PunchFactory();
+		$pcf = new PunchControlFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
@@ -954,7 +951,7 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 							c.last_name as last_name,
 							c.status_id as user_status_id,
 							c.group_id as group_id,
-							f.name as group,
+							f.name as "group",
 							c.title_id as title_id,
 							g.name as title,
 							c.default_branch_id as default_branch_id,
@@ -962,6 +959,11 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 							c.default_department_id as default_department_id,
 							e.name as default_department,
 
+							pcf.branch_id as branch_id,
+							bf.name as branch,
+							pcf.department_id as department_id,
+							df.name as department,
+
 							y.first_name as created_by_first_name,
 							y.middle_name as created_by_middle_name,
 							y.last_name as created_by_last_name,
@@ -969,6 +971,11 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 							z.middle_name as updated_by_middle_name,
 							z.last_name as updated_by_last_name
 					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $pf->getTable() .' as pf ON ( a.punch_id IS NOT NULL AND a.punch_id = pf.id AND pf.deleted = 0)
+						LEFT JOIN '. $pcf->getTable() .' as pcf ON ( ( ( pf.id IS NOT NULL AND pf.punch_control_id = pcf.id ) OR ( a.punch_control_id is NOT NULL AND a.punch_control_id = pcf.id ) ) AND pcf.deleted = 0)
+						LEFT JOIN '. $bf->getTable() .' as bf ON pcf.branch_id = bf.id
+						LEFT JOIN '. $df->getTable() .' as df ON pcf.department_id = df.id
+
 						LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
 						LEFT JOIN '. $uf->getTable() .' as c ON b.user_id = c.id
 						LEFT JOIN '. $bf->getTable() .' as d ON c.default_branch_id = d.id
@@ -1026,6 +1033,13 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 			$query  .=	' AND c.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
 		}
 
+		if ( isset($filter_data['branch_id']) AND isset($filter_data['branch_id'][0]) AND !in_array(-1, (array)$filter_data['branch_id']) ) {
+			$query  .=	' AND pcf.branch_id in ('. $this->getListSQL($filter_data['branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['department_id']) AND isset($filter_data['department_id'][0]) AND !in_array(-1, (array)$filter_data['department_id']) ) {
+			$query  .=	' AND pcf.department_id in ('. $this->getListSQL($filter_data['department_id'], $ph) .') ';
+		}
+
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
 			$ph[] = $this->db->BindDate($filter_data['start_date']);
 			$query  .=	' AND b.date_stamp >= ?';
@@ -1042,6 +1056,8 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		//Debug::Arr($ph, 'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
