@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: Factory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5749 $
+ * $Id: Factory.class.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 
 /**
@@ -101,6 +101,23 @@ abstract class Factory {
 		return $this->progress_bar_obj;
 	}
 
+	//Generic function to return and cache class objects
+	//ListFactory, ListFactoryMethod, Variable, ID, IDMethod
+	function getGenericObject( $list_factory, $id, $variable, $list_factory_method = 'getById', $id_method = 'getID' ) {
+		if ( isset($this->$variable) AND is_object( $this->$variable ) AND $id == $this->$variable->$id_method() ) { //Make sure we always compare that the object IDs match.
+			return $this->$variable;
+		} else {
+			$lf = TTnew( $list_factory );
+			$lf->$list_factory_method( $id );
+			if ( $lf->getRecordCount() == 1 ) {
+				$this->$variable = $lf->getCurrent();
+				return $this->$variable;
+			}
+
+			return FALSE;
+		}
+	}
+
 	/*
 	 * Cache functions
 	 */
@@ -783,6 +800,206 @@ abstract class Factory {
 		return FALSE;
 	}
 
+	///SQL where clause Syntax:
+	//  * or % as wildcard.
+	//  "<query>" as exact match, no default wildcard and no metaphone
+
+	//Handles '*' and '%' as wildcards, defaults to wildcard on the end always.
+	//If no wildcard is to be added, the last character should be |
+	protected function handleSQLSyntax( $arg ) {
+		$arg = str_replace('*', '%', trim($arg) );
+
+		if ( strpos($arg, '%') === FALSE AND ( strpos( $arg, '|') === FALSE AND strpos( $arg, '"') === FALSE ) ) {
+			$arg .= '%';
+		}
+
+		return $this->stripSQLSyntax( $arg );
+	}
+
+	protected function stripSQLSyntax( $arg ) {
+		return str_replace( array('"'), '', $arg); //Strip syntax characters out.
+	}
+
+	protected function getWhereClauseSQL( $columns, $args, $type, &$ph, $query_stub = NULL, $and = TRUE ) {
+		Debug::Text('Type: '. $type .' Query Stub: '. $query_stub .' AND: '. (int)$and, __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($columns, 'Columns: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($args, 'Args: ', __FILE__, __LINE__, __METHOD__,10);
+		switch( strtolower($type) ) {
+			case 'text':
+				if ( isset($args) AND !is_array($args) AND trim($args) != '' ) {
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						$query_stub = 'lower('. $columns .') LIKE ?';
+					}
+
+					$ph[] = $this->handleSQLSyntax( strtolower($args) );
+					$retval = $query_stub;
+				}
+				break;
+			case 'text_metaphone':
+				if ( isset($args) AND !is_array($args) AND trim($args) != '' ) {
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						$query_stub = '( lower('. $columns .') LIKE ? OR '. $columns .'_metaphone LIKE ? )';
+					}
+
+					$ph[] = $this->handleSQLSyntax( strtolower($args) );
+					if ( strpos($args, '"') !== FALSE ) { //ignores metaphone search.
+						$ph[] = '';
+					} else {
+						$ph[] = $this->handleSQLSyntax( metaphone( $args ) );
+					}
+					$retval = $query_stub;
+				}
+				break;
+			case 'text_list':
+			case 'lower_text_list':
+			case 'upper_text_list':
+				if ( !is_array($args) ) {
+					$args = (array)$args;
+				}
+
+				if ( $type == 'upper_text_list' OR $type == 'lower_text_list' ) {
+					if ( $type == 'upper_text_list' ) {
+						$text_case = CASE_UPPER;
+					} else {
+						$text_case = CASE_LOWER;
+					}
+					$args = array_flip( array_change_key_case( array_flip( $args ), $text_case ) );
+				}
+
+				if ( isset($args) AND isset($args[0]) AND !in_array( -1, $args) AND !in_array( '00', $args) ) {
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						$query_stub = $columns .' in (?)';
+					}
+					$retval = str_replace('?', $this->getListSQL($args, $ph), $query_stub );
+				}
+
+				break;
+			case 'province':
+				if ( !is_array($args) ) {
+					$args = (array)$args;
+				}
+
+				if ( isset($args) AND isset($args[0]) AND !in_array( -1, $args) AND !in_array( '00', $args) ) {
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						$query_stub = $columns .' in (?)';
+					}
+					$retval = str_replace('?', $this->getListSQL($args, $ph), $query_stub );
+				}
+				break;
+			case 'phone':
+				if ( isset($args) AND !is_array($args) AND trim($args) != '' ) {
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						$query_stub = "( replace( replace( replace( replace( replace( replace( ". $columns .", ' ', ''), '-', ''), '(', ''), ')', ''), '+', ''), '.', '') LIKE ? OR ". $columns ." LIKE ? )";
+					}
+
+					$ph[] = $ph[] = $this->handleSQLSyntax( preg_replace('/[^0-9\%\*\"]/','', strtolower($args) ) ); //Need the same value twice for the query stub.
+					$retval = $query_stub;
+				}
+				break;
+			case 'numeric':
+				if ( !is_array($args) ) { //Can't check isset() on a NULL value.
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						if ( $args === NULL ) {
+							$query_stub = $columns .' is NULL';
+						} else {
+							$args = $this->Validator->stripNonNumeric( $args );
+							if ( is_numeric( $args ) ) {
+								$ph[] = $args;
+								$query_stub = $columns .' = ?';
+							}
+						}
+					}
+
+					$retval = $query_stub;
+				}
+				break;
+			case 'numeric_list':
+				if ( !is_array($args) ) {
+					$args = (array)$args;
+				}
+				if ( isset($args) AND isset($args[0]) AND !in_array( -1, $args) ) {
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						$query_stub = $columns .' in (?)';
+					}
+					$retval = str_replace('?', $this->getListSQL($args, $ph), $query_stub );
+				}
+				break;
+			case 'not_numeric_list':
+				if ( !is_array($args) ) {
+					$args = (array)$args;
+				}
+				if ( isset($args) AND isset($args[0]) AND !in_array( -1, $args) ) {
+					if ( $query_stub == '' AND !is_array($columns) ) {
+						$query_stub = $columns .' not in (?)';
+					}
+					$retval = str_replace('?', $this->getListSQL($args, $ph), $query_stub );
+				}
+				break;
+			case 'tag':
+				//We need company_id and object_type_id passed in.
+				if ( isset($args['company_id']) AND isset($args['object_type_id']) AND isset($args['tag']) ) {
+					//Parse the tags search syntax to determine ANY, AND, OR searches.
+					$parsed_tags = CompanyGenericTagFactory::parseTags($args['tag']);
+					Debug::Arr($parsed_tags, 'Parsed Tags: ', __FILE__, __LINE__, __METHOD__,10);
+					if ( is_array($parsed_tags) ) {
+						$retval = '';
+						if ( isset($parsed_tags['add']) AND count($parsed_tags['add']) > 0 ) {
+							$query_stub = ' EXISTS 	(
+														select 1
+														from company_generic_tag_map as cgtm
+														INNER JOIN company_generic_tag as cgt ON (cgtm.tag_id = cgt.id)
+														WHERE cgt.company_id = '. (int)$args['company_id'] .'
+															AND cgtm.object_type_id = '. (int)$args['object_type_id'] .'
+															AND a.id = cgtm.object_id
+															AND ( lower(cgt.name) in (?) )
+														group by cgtm.object_id
+														HAVING COUNT(*) = '. count( $parsed_tags['add'] ) .'
+													)';
+							$retval .= str_replace('?', $this->getListSQL($parsed_tags['add'], $ph), $query_stub );
+							if ( isset($parsed_tags['delete']) AND count($parsed_tags['delete']) > 0 ) {
+								$retval .= ' AND ';
+							}
+						}
+
+						if ( isset($parsed_tags['delete']) AND count($parsed_tags['delete']) > 0 ) {
+							$query_stub = ' NOT EXISTS 	(
+														select 1
+														from company_generic_tag_map as cgtm
+														INNER JOIN company_generic_tag as cgt ON (cgtm.tag_id = cgt.id)
+														WHERE cgt.company_id = '. (int)$args['company_id'] .'
+															AND cgtm.object_type_id = '. (int)$args['object_type_id'] .'
+															AND a.id = cgtm.object_id
+															AND ( lower(cgt.name) in (?) )
+														group by cgtm.object_id
+														HAVING COUNT(*) = '. count( $parsed_tags['delete'] ) .'
+													)';
+							$retval .= str_replace('?', $this->getListSQL($parsed_tags['delete'], $ph), $query_stub );
+						}
+					}
+				}
+
+				if ( !isset($retval) ) {
+					$retval = '';
+				}
+				break;
+			default:
+				Debug::Text('Invalid type: '. $type, __FILE__, __LINE__, __METHOD__,10);
+				break;
+		}
+
+		if ( isset($retval) ) {
+			$and_sql = NULL;
+			if ( $and == TRUE ) {
+				$and_sql = 'AND ';
+			}
+
+			Debug::Arr($ph, 'Query Stub: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+			return ' '.$and_sql.$retval.' '; //Wrap each query stub in spaces.
+		}
+
+		return NULL;
+	}
+
 	//Parses out the exact column name, without any aliases, or = signs in it.
 	private function parseColumnName($column) {
 		$column = trim($column);
@@ -825,7 +1042,7 @@ abstract class Factory {
 			}
 
 			if ( isset($sql_chunks) ) {
-				$sql = implode(",", $sql_chunks);
+				$sql = implode(',', $sql_chunks);
 
 				if ($append_where == TRUE) {
 					return ' where '.$sql;
@@ -1060,7 +1277,6 @@ abstract class Factory {
 		try {
 			$rs = $this->getEmptyRecordSet( $this->getId() );
 			$this->old_data = $rs->fields; //Store old data in memory for detailed audit log.
-			//Debug::arr($rs->fields,'Data Arr Fields', __FILE__, __LINE__, __METHOD__,10);
 		} catch (Exception $e) {
 			throw new DBError($e);
 		}
@@ -1071,7 +1287,7 @@ abstract class Factory {
 
 		//Debug::Arr($rs->fields, 'RecordSet: ', __FILE__, __LINE__, __METHOD__, 9);
 		//Debug::Arr($this->data, 'Data Array: ', __FILE__, __LINE__, __METHOD__, 9);
-		//Debug::Arr( array_diff_assoc($rs->fields, $this->data), 'Data Array: ', __FILE__, __LINE__, __METHOD__, 9);\
+		//Debug::Arr( array_diff_assoc($rs->fields, $this->data), 'Data Array: ', __FILE__, __LINE__, __METHOD__, 9);
 
 		//If no columns changed, this will be FALSE.
 		$query = $this->db->GetUpdateSQL($rs, $this->data);
@@ -1081,34 +1297,6 @@ abstract class Factory {
 			$query = TRUE;
 		} else {
 			Debug::text('Data changed, set updated date: ', __FILE__, __LINE__, __METHOD__, 9);
-
-			//Always run update query even if only updated_date was changed. Otherwise
-			//we need to run two getEmptyRecordSet() calls, and two getUpdateSQL calls.
-			/*
-			if ( $this->setUpdatedDate() !== FALSE ) {
-				$this->data['updated_date'] = NULL;
-			}
-			if ( $this->setUpdatedBy() !== FALSE ) {
-				$this->data['updated_by'] = NULL;
-			}
-
-			//Create new record set with new columns
-			//**This causes another query to be executed, because it needs to re-check the updated_date columns.
-			//
-			try {
-				$rs = $this->getEmptyRecordSet( $this->getId() );
-			} catch (Exception $e) {
-				throw new DBError($e);
-			}
-
-			//Update new columns so ADODB knows they changed.
-			$this->setUpdatedDate();
-			$this->setUpdatedBy();
-
-			//Debug::arr($this->data,'bData Arr', __FILE__, __LINE__, __METHOD__,10);
-
-			$query = $this->db->GetUpdateSQL($rs, $this->data);
-			*/
 		}
 
 		//Debug::text('Update Query: '. $query, __FILE__, __LINE__, __METHOD__, 9);
@@ -1173,14 +1361,15 @@ abstract class Factory {
 		//Run Pre-Save function
 		//This is called before validate so it can do extra calculations,etc before validation.
 		//Should this AND validate() NOT be called when delete flag is set?
-		if (method_exists($this,'preSave') ) {
+		if ( method_exists($this,'preSave') ) {
 			Debug::text('Calling preSave()' , __FILE__, __LINE__, __METHOD__,10);
 			if ( $this->preSave() === FALSE ) {
 				throw new GeneralError('preSave() failed.');
 			}
 		}
 
-		//Don't validate when deleting
+		//Don't validate when deleting, so we can delete records that may have some invalid options.
+		//However we can still manually call this function to check if we need too.
 		if ( $this->getDeleted() == FALSE AND $this->isValid() === FALSE ) {
 			throw new GeneralError('Invalid Data, not saving.');
 		}
@@ -1214,7 +1403,6 @@ abstract class Factory {
 			}
 
 			try {
-				//$query = $this->getInsertQuery($this->data);
 				$query = $this->getInsertQuery();
 			} catch (Exception $e) {
 				throw new DBError($e);
@@ -1261,7 +1449,7 @@ abstract class Factory {
 			//Run postSave function.
 			if ( method_exists($this,'postSave') ) {
 				Debug::text('Calling postSave()' , __FILE__, __LINE__, __METHOD__,10);
-				if ( $this->postSave() === FALSE ) {
+				if ( $this->postSave( array_diff_assoc( (array)$this->old_data, (array)$this->data ) ) === FALSE ) {
 					throw new GeneralError('postSave() failed.');
 				}
 			}
@@ -1355,8 +1543,7 @@ abstract class Factory {
 	}
 
 	function clearData() {
-		$this->data = array();
-		$this->tmp_data = array();
+		$this->data = $this->tmp_data = $this->old_data = array();
 		$this->next_insert_id = NULL;
 
 		return TRUE;
