@@ -360,7 +360,8 @@ class GeneralLedgerExport_Record extends GeneralLedgerExport_JournalEntry {
 	}
 
 	function setAmount($value) {
-		if ( $this->isFloat( $value ) AND strlen( $value ) <= 10 AND $value > 0 ) {
+		//Allow negative values, for example if someone is trying to export negative values (for things like vacation accrual)
+		if ( $this->isFloat( $value ) AND strlen( $value ) <= 10 AND $value != 0 ) {
 			$this->record_data['amount'] = $value;
 
 			return TRUE;
