@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -146,6 +146,7 @@ class LogDetailFactory extends Factory {
 		return FALSE;
 	}
 
+/*
 	function normalizeField( $obj, $field ) {
 		$retval = str_replace('_id', '', $field);
 
@@ -358,6 +359,7 @@ class LogDetailFactory extends Factory {
 					$columns = array(
 									'sex' => TTi18n::gettext('Sex'),
 									'second_last_name' => TTi18n::gettext('Second Surname'),
+									'password_updated_date' => TTi18n::gettext('Password Updated'),
 									);
 					break;
 				case 'UserPreferenceFactory':
@@ -451,6 +453,16 @@ class LogDetailFactory extends Factory {
 									'unit_price_type_id' => TTi18n::gettext('Price Type'),
 									'upc' => TTi18n::gettext('UPC'),
 									);
+				case 'InvoiceFactory':
+				case 'InvoiceListFactory':
+					$columns = array(
+									'billing_contact_id' => TTi18n::gettext('Billing Contact'),
+									'shipping_contact_id' => TTi18n::gettext('Shipping Contact'),
+									'other_contact_id' => TTi18n::gettext('Other Contact'),
+									'shipping_policy_id' => TTi18n::gettext('Shipping Policy'),
+									);
+					break;
+
 			}
 
 			$display_field = Option::getByKey($field, array_merge($global_columns, $columns) );
@@ -535,6 +547,7 @@ class LogDetailFactory extends Factory {
 			case 'supervisor_user_id':
 			case 'support_contact':
 			case 'sales_contact':
+			case 'sales_contact_id':
 			case 'user_id':
 				$lf = TTnew( 'UserListFactory' );
 				$lf->getById( $value );
@@ -703,6 +716,30 @@ class LogDetailFactory extends Factory {
 					}
 				}
 				break;
+			case 'billing_contact_id':
+			case 'shipping_contact_id':
+			case 'other_contact_id':
+				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+					$lf = TTnew( 'ClientContactListFactory' );
+					$lf->getById( $value );
+					if ( $lf->getRecordCount() > 0 ) {
+						$retval = $lf->getCurrent()->getFullName();
+					} else {
+						$retval = TTi18n::getText('--');
+					}
+				}
+				break;
+			case 'shipping_policy_id':
+				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+					$lf = TTnew( 'ShippingPolicyListFactory' );
+					$lf->getById( $value );
+					if ( $lf->getRecordCount() > 0 ) {
+						$retval = $lf->getCurrent()->getName();
+					} else {
+						$retval = TTi18n::getText('--');
+					}
+				}
+				break;
 			case 'product_id':
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 					$lf = TTnew( 'ProductListFactory' );
@@ -736,6 +773,16 @@ class LogDetailFactory extends Factory {
 					}
 				}
 				break;
+			case 'invoice_date':
+			case 'order_date':
+			case 'shipped_date':
+			case 'required_date':
+				if ( $value != '' ) {
+					$retval = TTDate::getDate('DATE', $value );
+				} else {
+					$retval = NULL;
+				}
+				break;
 			//
 			//End Professional Edition tables
 			//
@@ -791,6 +838,7 @@ class LogDetailFactory extends Factory {
 					case 'hire_date':
 					case 'birth_date':
 					case 'termination_date':
+					case 'password_updated_date':
 						$retval = TTDate::getDate('DATE', $value );
 						break;
 					case 'sex_id':
@@ -1051,6 +1099,10 @@ class LogDetailFactory extends Factory {
 					case 'start_day_of_week':
 						$retval = Option::getByKey($value, TTDate::getDayOfWeekArray()  );
 						break;
+					case 'timesheet_verify_before_end_date':
+					case 'timesheet_verify_before_transaction_date':
+						$retval = Misc::removeTrailingZeros( TTDate::getDays( $value ), 0 );
+						break;
 					case 'maximum_shift_time':
 					case 'new_day_trigger_time':
 						$retval = TTDate::getTimeUnit( $value );
@@ -1303,7 +1355,7 @@ class LogDetailFactory extends Factory {
 	function getDisplayNewValue( $obj ) {
 		return $this->getDisplayValue( $obj, $this->getNewValue() );
 	}
-
+*/
 	//When comparing the two arrays, if there are sub-arrays, we need to *always* include those, as we can't actually
 	//diff the two, because they are already saved by the time we get to this function, so there will never be any changes to them.
 	//We don't want to include sub-arrays, as the sub-classes should handle the logging themselves.
@@ -1373,6 +1425,7 @@ class LogDetailFactory extends Factory {
 				}
 			} else { //Add
 				//Debug::text('Not editing, skipping the diff process...', __FILE__, __LINE__, __METHOD__, 10);
+				//No need to store data that is added, as its already in the database, and if it gets changed or deleted we store it then.
 				$old_data = array();
 				$diff_arr = $object->data;
 			}
@@ -1387,7 +1440,10 @@ class LogDetailFactory extends Factory {
 							$diff_arr['password'],
 							$diff_arr['phone_password'],
 							$diff_arr['password_reset_key'],
+							$diff_arr['password_updated_date'],
 							$diff_arr['full_name'],
+							$diff_arr['first_name_metaphone'],
+							$diff_arr['last_name_metaphone'],
 							$diff_arr['finger_print_1'],
 							$diff_arr['finger_print_2'],
 							$diff_arr['finger_print_3'],
@@ -1398,6 +1454,17 @@ class LogDetailFactory extends Factory {
 							$diff_arr['finger_print_4_updated_date']
 							);
 					break;
+				case 'PayPeriodScheduleFactory':
+				case 'PayPeriodScheduleListFactory':
+					unset(
+							$diff_arr['primary_date_ldom'],
+							$diff_arr['primary_transaction_date_ldom'],
+							$diff_arr['primary_transaction_date_bd'],
+							$diff_arr['secondary_date_ldom'],
+							$diff_arr['secondary_transaction_date_ldom'],
+							$diff_arr['secondary_transaction_date_bd']
+							);
+					break;
 				case 'StationFactory':
 				case 'StationListFactory':
 					unset(
@@ -1416,7 +1483,9 @@ class LogDetailFactory extends Factory {
 							$diff_arr['actual_time_stamp'],
 							$diff_arr['original_time_stamp'],
 							$diff_arr['punch_control_id'],
-							$diff_arr['station_id']
+							$diff_arr['station_id'],
+							$diff_arr['latitude'],
+							$diff_arr['longitude']
 							);
 					break;
 				case 'PunchControlFactory':
