@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: LogFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 5559 $
+ * $Id: LogFactory.class.php 5559 2011-11-18 18:44:31Z ipso $
+ * $Date: 2011-11-18 10:44:31 -0800 (Fri, 18 Nov 2011) $
  */
 
 /**
@@ -82,6 +82,12 @@ class LogFactory extends Factory {
 											'bank_account'						=> TTi18n::getText('Bank Account'),
 											'roe'								=> TTi18n::getText('Record of Employment'),
 											'station'							=> TTi18n::getText('Station'),
+											'station_user_group'				=> TTi18n::getText('Station Employee Group'),
+											'station_branch'					=> TTi18n::getText('Station Branch'),
+											'station_department'				=> TTi18n::getText('Station Department'),
+											'station_include_user'				=> TTi18n::getText('Station Include Employee'),
+											'station_exclude_user'				=> TTi18n::getText('Station Exclude Employee'),
+											'station'							=> TTi18n::getText('Station'),
 											'punch'								=> TTi18n::getText('Punch'),
 											'punch_control'						=> TTi18n::getText('Punch Control'),
 											'schedule'							=> TTi18n::getText('Schedule'),
@@ -616,7 +622,7 @@ class LogFactory extends Factory {
 	}
 
 	function getDetails() {
-		if ( $this->isNew() == FALSE AND is_object( $this->getUserObject() ) ) {
+		if ( getTTProductEdition() > 10 AND $this->isNew() == FALSE AND is_object( $this->getUserObject() ) ) {
 			//Get class for this table
 			Debug::Text( 'Table: '. $this->getTableName(), __FILE__, __LINE__, __METHOD__,10);
 			require_once( Environment::getBasePath() . DIRECTORY_SEPARATOR . 'includes'. DIRECTORY_SEPARATOR .'TableMap.inc.php');
@@ -631,9 +637,9 @@ class LogFactory extends Factory {
 					foreach( $ldlf as $ld_obj ) {
 						$detail_row[] = array(
 											'field' => $ld_obj->getField(),
-											'display_field' => $ld_obj->getDisplayField( $class ),
-											'old_value' => $ld_obj->getDisplayOldValue( $class ),
-											'new_value' => $ld_obj->getDisplayNewValue( $class ),
+											'display_field' => LogDetailDisplay::getDisplayField( $class, $ld_obj->getField() ),
+											'old_value' => LogDetailDisplay::getDisplayOldValue( $class, $ld_obj->getField(), $ld_obj->getOldValue() ),
+											'new_value' => LogDetailDisplay::getDisplayNewValue( $class, $ld_obj->getField(), $ld_obj->getNewValue() ),
 											);
 					}
 
