@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: OtherFieldFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5164 $
+ * $Id: OtherFieldFactory.class.php 5164 2011-08-26 23:00:02Z ipso $
+ * $Date: 2011-08-26 16:00:02 -0700 (Fri, 26 Aug 2011) $
  */
 
 /**
@@ -55,6 +55,9 @@ class OtherFieldFactory extends Factory {
 		switch( $name ) {
 			case 'type':
 				$retval = array(
+											2  => TTi18n::gettext('Company'),
+											4  => TTi18n::gettext('Branch'),
+											5  => TTi18n::gettext('Department'),
 											10  => TTi18n::gettext('Employee'),
 											15  => TTi18n::gettext('Punch'),
 											20  => TTi18n::gettext('Job'),
@@ -191,7 +194,11 @@ class OtherFieldFactory extends Factory {
 	}
 
 	function getType() {
-		return $this->data['type_id'];
+		if ( isset($this->data['type_id']) ) {
+			return $this->data['type_id'];
+		}
+
+		return FALSE;
 	}
 	function setType($type) {
 		$type = trim($type);
