@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: OtherFieldListFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5164 $
+ * $Id: OtherFieldListFactory.class.php 5164 2011-08-26 23:00:02Z ipso $
+ * $Date: 2011-08-26 16:00:02 -0700 (Fri, 26 Aug 2011) $
  */
 
 /**
@@ -121,14 +121,14 @@ class OtherFieldListFactory extends OtherFieldFactory implements IteratorAggrega
 
 		$ph = array(
 					'id' => (int)$id,
-					'type_id' => (int)$type_id,
+					//'type_id' => (int)$type_id,
 					);
 
 		$query = '
 					select 	*
 					from	'. $this->getTable() .' as a
 					where	company_id = ?
-						AND type_id = ?
+						AND type_id in ('. $this->getListSQL($type_id, $ph) .')
 						AND deleted = 0';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
@@ -170,40 +170,60 @@ class OtherFieldListFactory extends OtherFieldFactory implements IteratorAggrega
 		return $this;
 	}
 
-	function getByCompanyIdAndTypeIDArray($id, $type_id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+	function getByCompanyIdAndTypeIDArray($id, $type_id, $key_prefix = NULL, $name_prefix = NULL ) {
 		$oflf = new OtherFieldListFactory();
 		$oflf->getByCompanyIdAndTypeID( $id, $type_id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL );
 		if ( $oflf->getRecordCount() > 0 ) {
 			foreach($oflf as $obj) {
+				if ( is_array($key_prefix) ) {
+					if ( isset($key_prefix[$obj->getType()]) ) {
+						$prefix = $key_prefix[$obj->getType()];
+					} else {
+						$prefix = NULL;
+					}
+				} else {
+					$prefix = $key_prefix;
+				}
+
+				if ( is_array($name_prefix) ) {
+					if ( isset($name_prefix[$obj->getType()]) ) {
+						$prefix2 = $name_prefix[$obj->getType()];
+					} else {
+						$prefix2 = NULL;
+					}
+				} else {
+					$prefix2 = $name_prefix;
+				}
+
 				if ( $obj->getOtherID1() != '' ) {
-					$retarr['other_id1'] = $obj->getOtherID1();
+					$retarr[$prefix.'other_id1'] = $prefix2.$obj->getOtherID1();
 				}
 				if ( $obj->getOtherID2() != '' ) {
-					$retarr['other_id2'] = $obj->getOtherID2();
+					$retarr[$prefix.'other_id2'] = $prefix2.$obj->getOtherID2();
 				}
 				if ( $obj->getOtherID3() != '' ) {
-					$retarr['other_id3'] = $obj->getOtherID3();
+					$retarr[$prefix.'other_id3'] = $prefix2.$obj->getOtherID3();
 				}
 				if ( $obj->getOtherID4() != '' ) {
-					$retarr['other_id4'] = $obj->getOtherID4();
+					$retarr[$prefix.'other_id4'] = $prefix2.$obj->getOtherID4();
 				}
 				if ( $obj->getOtherID5() != '' ) {
-					$retarr['other_id5'] = $obj->getOtherID5();
+					$retarr[$prefix.'other_id5'] = $prefix2.$obj->getOtherID5();
 				}
 				if ( $obj->getOtherID6() != '' ) {
-					$retarr['other_id6'] = $obj->getOtherID6();
+					$retarr[$prefix.'other_id6'] = $prefix2.$obj->getOtherID6();
 				}
 				if ( $obj->getOtherID7() != '' ) {
-					$retarr['other_id7'] = $obj->getOtherID7();
+					$retarr[$prefix.'other_id7'] = $prefix2.$obj->getOtherID7();
 				}
 				if ( $obj->getOtherID8() != '' ) {
-					$retarr['other_id8'] = $obj->getOtherID8();
+					$retarr[$prefix.'other_id8'] = $prefix2.$obj->getOtherID8();
 				}
 				if ( $obj->getOtherID9() != '' ) {
-					$retarr['other_id9'] = $obj->getOtherID9();
+					$retarr[$prefix.'other_id9'] = $prefix2.$obj->getOtherID9();
 				}
 				if ( $obj->getOtherID10() != '' ) {
-					$retarr['other_id10'] = $obj->getOtherID10();
+					$retarr[$prefix.'other_id10'] = $prefix2.$obj->getOtherID10();
 				}
 			}
 
