@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: PermissionControlListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 6071 $
+ * $Id: PermissionControlListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -305,9 +305,10 @@ class PermissionControlListFactory extends PermissionControlFactory implements I
 			}
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array( 'total_users' );
+
 		if ( $order == NULL ) {
-			$order = array( 'name' => 'asc' );
+			$order = array( 'level' => 'asc', 'name' => 'asc' );
 			$strict = FALSE;
 		} else {
 			//Always sort by last name,first name after other columns
@@ -320,19 +321,24 @@ class PermissionControlListFactory extends PermissionControlFactory implements I
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		$uf = new UserFactory();
+		$puf = new PermissionUserFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
 					);
 
 		$query = '
-					select 	a.*,
+					select
+							_ADODB_COUNT
+							a.*,
+							( select count(*) from '. $puf->getTable() .' as puf_tmp where puf_tmp.permission_control_id = a.id ) as total_users,
 							y.first_name as created_by_first_name,
 							y.middle_name as created_by_middle_name,
 							y.last_name as created_by_last_name,
 							z.first_name as updated_by_first_name,
 							z.middle_name as updated_by_middle_name,
 							z.last_name as updated_by_last_name
+							_ADODB_COUNT
 					from 	'. $this->getTable() .' as a
 						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
 						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
