@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: StationExcludeUserFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5089 $
+ * $Id: StationExcludeUserFactory.class.php 5089 2011-08-06 19:51:55Z ipso $
+ * $Date: 2011-08-06 12:51:55 -0700 (Sat, 06 Aug 2011) $
  */
 
 /**
@@ -46,6 +46,8 @@ class StationExcludeUserFactory extends Factory {
 	protected $table = 'station_exclude_user';
 	protected $pk_sequence_name = 'station_exclude_user_id_seq'; //PK Sequence name
 
+	var $user_obj = NULL;
+
 	function getStation() {
 		if ( isset($this->data['station_id']) ) {
 			return $this->data['station_id'];
@@ -77,6 +79,21 @@ class StationExcludeUserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getUserObject() {
+		if ( is_object($this->user_obj) ) {
+			return $this->user_obj;
+		} else {
+			$ulf = TTnew( 'UserListFactory' );
+			$ulf->getById( $this->getExcludeUser() );
+			if ( $ulf->getRecordCount() == 1 ) {
+				$this->user_obj = $ulf->getCurrent();
+				return $this->user_obj;
+			}
+
+			return FALSE;
+		}
+	}
+
 	function getExcludeUser() {
 		if ( isset($this->data['user_id']) ) {
 			return $this->data['user_id'];
@@ -147,5 +164,14 @@ class StationExcludeUserFactory extends Factory {
 	function setDeletedBy($id = NULL) {
 		return FALSE;
 	}
+
+	function addLog( $log_action ) {
+		$u_obj = $this->getUserObject();
+		if ( is_object($u_obj) ) {
+			return TTLog::addEntry( $this->getStation(), $log_action, TTi18n::getText('Employee').': '. $u_obj->getFullName( FALSE, TRUE ) , NULL, $this->getTable() );
+		}
+
+		return FALSE;
+	}
 }
 ?>
