@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4453 $
- * $Id: StationFactory.class.php 4453 2011-03-28 18:15:14Z ipso $
- * $Date: 2011-03-28 11:15:14 -0700 (Mon, 28 Mar 2011) $
+ * $Revision: 5963 $
+ * $Id: StationFactory.class.php 5963 2012-01-04 16:31:38Z ipso $
+ * $Date: 2012-01-04 08:31:38 -0800 (Wed, 04 Jan 2012) $
  */
 include_once('Net/IPv4.php');
 
@@ -66,8 +66,8 @@ class StationFactory extends Factory {
 
 				if ( getTTProductEdition() >= 15 ) {
 					$retval[20]	= TTi18n::gettext('PHONE');
-					$retval[25]	= TTi18n::gettext('WirelessWeb');
-					$retval[28]	= TTi18n::gettext('iPhone');
+					$retval[25]	= TTi18n::gettext('WirelessWeb (WAP)');
+					$retval[28]	= TTi18n::gettext('SmartPhone (iPhone/Android)');
 					$retval[30]	= TTi18n::gettext('iBUTTON');
 					$retval[40]	= TTi18n::gettext('Barcode');
 					$retval[50]	= TTi18n::gettext('FingerPrint');
@@ -177,6 +177,8 @@ class StationFactory extends Factory {
 										1048576	=> TTi18n::gettext('Enable: External Proximity Card Reader'),
 										2097152 => TTi18n::gettext('Enable: Pre-Punch Message'),
 										4194304	=> TTi18n::gettext('Enable: Post-Punch Message'),
+
+										1073741824 => TTi18n::gettext('Enable: Diagnostic Logs'),
 									);
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 					$retval[128]  = TTi18n::gettext('Enable: Job');
@@ -618,21 +620,16 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setTimeZone($time_zone) {
-		$time_zone = trim($time_zone);
+		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
 		$upf = TTnew( 'UserPreferenceFactory' );
 
-		$key = Option::getByValue($time_zone, $upf->getOptions('time_zone') );
-		if ($key !== FALSE) {
-			$time_zone = $key;
-		}
-
 		if ( $time_zone == 0
 				OR
 				$this->Validator->inArrayKey(	'time_zone',
 											$time_zone,
 											TTi18n::gettext('Incorrect Time Zone'),
-											$upf->getOptions('time_zone')) ) {
+											Misc::trimSortPrefix( $upf->getOptions('time_zone') ) ) ) {
 
 			$this->data['time_zone'] = $time_zone;
 
@@ -679,6 +676,10 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setGroup($ids) {
+		if ( $ids == '' ) {
+			$ids = array(); //This is for the API, it sends FALSE when no branches are selected, so this will delete all branches.
+		}
+
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
 			$tmp_ids = array();
@@ -768,6 +769,9 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setBranch($ids) {
+		if ( $ids == '' ) {
+			$ids = array(); //This is for the API, it sends FALSE when no branches are selected, so this will delete all branches.
+		}
 		//Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		//Debug::Arr($ids, 'IDs: ', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
@@ -858,6 +862,10 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setDepartment($ids) {
+		if ( $ids == '' ) {
+			$ids = array(); //This is for the API, it sends FALSE when no branches are selected, so this will delete all branches.
+		}
+
 		//Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
 			$tmp_ids = array();
@@ -924,6 +932,10 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setIncludeUser($ids) {
+		if ( $ids == '' ) {
+			$ids = array(); //This is for the API, it sends FALSE when no branches are selected, so this will delete all branches.
+		}
+
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
 			$tmp_ids = array();
@@ -989,6 +1001,10 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setExcludeUser($ids) {
+		if ( $ids == '' ) {
+			$ids = array(); //This is for the API, it sends FALSE when no branches are selected, so this will delete all branches.
+		}
+
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
 			$tmp_ids = array();
@@ -1377,7 +1393,7 @@ class StationFactory extends Factory {
 
 		if 	(	$this->Validator->isDate(		'last_punch_time_stamp',
 												$epoch,
-												TTi18n::gettext('Incorrect Date')) ) {
+												TTi18n::gettext('Incorrect last punch date')) ) {
 
 			$this->data['last_punch_time_stamp'] = $epoch;
 
@@ -1404,7 +1420,7 @@ class StationFactory extends Factory {
 
 		if 	(	$this->Validator->isDate(		'last_poll_date',
 												$epoch,
-												TTi18n::gettext('Incorrect Date')) ) {
+												TTi18n::gettext('Incorrect last poll date')) ) {
 
 			$this->data['last_poll_date'] = $epoch;
 
@@ -1454,7 +1470,7 @@ class StationFactory extends Factory {
 
 		if 	(	$this->Validator->isDate(		'last_push_date',
 												$epoch,
-												TTi18n::gettext('Incorrect Date')) ) {
+												TTi18n::gettext('Incorrect last push date')) ) {
 
 			$this->data['last_push_date'] = $epoch;
 
@@ -1504,7 +1520,7 @@ class StationFactory extends Factory {
 
 		if 	(	$this->Validator->isDate(		'last_partial_push_date',
 												$epoch,
-												TTi18n::gettext('Incorrect Date')) ) {
+												TTi18n::gettext('Incorrect last partial push date')) ) {
 
 			$this->data['last_partial_push_date'] = $epoch;
 
@@ -1730,7 +1746,7 @@ class StationFactory extends Factory {
 
 		if 	(	$this->Validator->isDate(		'allowed_date',
 												$epoch,
-												TTi18n::gettext('Incorrect Date')) ) {
+												TTi18n::gettext('Incorrect allowed date')) ) {
 
 			$this->data['allowed_date'] = $epoch;
 
@@ -1918,8 +1934,8 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 
-	static function getOrCreatePCStation( $station_id, $company_id ) {
-		Debug::text('Checking for Station ID: '. $station_id .' Company ID: '. $company_id, __FILE__, __LINE__, __METHOD__, 10);
+	static function getOrCreateStation( $station_id, $company_id, $type_id = 10 ) {
+		Debug::text('Checking for Station ID: '. $station_id .' Company ID: '. $company_id .' Type: '. $type_id, __FILE__, __LINE__, __METHOD__, 10);
 		$slf = new StationListFactory();
 		$slf->getByStationIdandCompanyId( $station_id, $company_id );
 		if ( $slf->getRecordCount() == 1 ) {
@@ -1931,10 +1947,22 @@ class StationFactory extends Factory {
 			$sf = TTnew( 'StationFactory' );
 			$sf->setCompany( $company_id );
 			$sf->setStatus( 'ENABLED' );
-			$sf->setType( 'PC' );
+
+			switch ( $type_id ) {
+				case 10: //PC
+					$station = NULL;
+					$description = substr( $_SERVER['HTTP_USER_AGENT'], 0, 250);
+					break;
+				case 28: //Phone/Mobile App
+					$station = NULL; //Can't get UDID on iOS5, but we can on Android.
+					$description = TTi18n::getText('Mobile Application').': '.substr( $_SERVER['HTTP_USER_AGENT'], 0, 250);
+					break;
+			}
+
+			$sf->setType( $type_id );
+			$sf->setDescription( $description );
+			$sf->setStation( $station );
 			$sf->setSource( $_SERVER['REMOTE_ADDR'] );
-			$sf->setStation();
-			$sf->setDescription( substr( $_SERVER['HTTP_USER_AGENT'], 0, 250) );
 			if ( $sf->Save(FALSE) ) {
 				$retval = $sf->getStation();
 			}
@@ -1990,6 +2018,14 @@ class StationFactory extends Factory {
 
 					$function = 'set'.$function;
 					switch( $key ) {
+						case 'last_punch_time_stamp':
+						case 'last_poll_date':
+						case 'last_push_date':
+						case 'last_partial_push_date':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
 						case 'group':
 							$this->setGroup( $data[$key] );
 							break;
@@ -2032,20 +2068,17 @@ class StationFactory extends Factory {
 					switch( $variable ) {
 						case 'status':
 						case 'type':
-/*
-						case 'branch_selection_type':
-						case 'department_selection_type':
-						case 'group_selection_type':
-						case 'poll_frequency':
-						case 'push_frequency':
-						case 'time_clock_command':
-						case 'mode_flag':
-*/
 							$function = 'get'.$variable;
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
 							}
 							break;
+						case 'last_punch_time_stamp':
+						case 'last_poll_date':
+						case 'last_push_date':
+						case 'last_partial_push_date':
+							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', $this->$function() );
+							break;
 						case 'group':
 							$data[$variable] = $this->getGroup();
 							break;
