@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: StationUserGroupFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5089 $
+ * $Id: StationUserGroupFactory.class.php 5089 2011-08-06 19:51:55Z ipso $
+ * $Date: 2011-08-06 12:51:55 -0700 (Sat, 06 Aug 2011) $
  */
 
 /**
@@ -46,6 +46,8 @@ class StationUserGroupFactory extends Factory {
 	protected $table = 'station_user_group';
 	protected $pk_sequence_name = 'station_user_group_id_seq'; //PK Sequence name
 
+	var $group_obj = NULL;
+
 	function getStation() {
 		if ( isset($this->data['station_id']) ) {
 			return $this->data['station_id'];
@@ -77,6 +79,20 @@ class StationUserGroupFactory extends Factory {
 		return FALSE;
 	}
 
+	function getGroupObject() {
+		if ( is_object($this->group_obj) ) {
+			return $this->group_obj;
+		} else {
+			$uglf = TTnew( 'UserGroupListFactory' );
+			$uglf->getById( $this->getGroup() );
+			if ( $uglf->getRecordCount() == 1 ) {
+				$this->group_obj = $uglf->getCurrent();
+				return $this->group_obj;
+			}
+
+			return FALSE;
+		}
+	}
 	function getGroup() {
 		if ( isset($this->data['group_id']) ) {
 			return $this->data['group_id'];
@@ -148,5 +164,14 @@ class StationUserGroupFactory extends Factory {
 	function setDeletedBy($id = NULL) {
 		return FALSE;
 	}
+
+	function addLog( $log_action ) {
+		$g_obj = $this->getGroupObject();
+		if ( is_object($g_obj) ) {
+			return TTLog::addEntry( $this->getStation(), $log_action, TTi18n::getText('Group').': '. $g_obj->getName() , NULL, $this->getTable() );
+		}
+
+		return FALSE;
+	}
 }
 ?>
