@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: TTDate.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 6071 $
+ * $Id: TTDate.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -438,7 +438,11 @@ class TTDate {
 
 		if ( $str == '' ) {
 			Debug::text('No date to parse! String: '. $str .' Date Format: '. self::$date_format, __FILE__, __LINE__, __METHOD__, 10);
-			return FALSE;
+			//return FALSE;
+
+			//Return NULL so we can determine the difference between a blank/null value and an incorrect parsing.
+			//NULL is required so NULL is used in the database rather than 0. Especially for termination dates for users.
+			return NULL;
 		}
 
 		//Debug::text('String: '. $str .' Date Format: '. self::$date_format, __FILE__, __LINE__, __METHOD__, 10);
@@ -513,7 +517,7 @@ class TTDate {
 					//Debug::Arr($date_arr, 'Date Match Arr!', __FILE__, __LINE__, __METHOD__, 10);
 
 					//; preg_match('/[a-z]/', $date_arr['month']) != 0
-					if ( $textual_month == TRUE) {
+					if ( $textual_month == TRUE AND isset(self::$month_arr[strtolower($date_arr['month'])]) ) {
 						$numeric_month = self::$month_arr[strtolower($date_arr['month'])];
 						//Debug::text('  Numeric Month: '. $numeric_month, __FILE__, __LINE__, __METHOD__, 10);
 						$date_arr['month'] = $numeric_month;
@@ -724,8 +728,20 @@ class TTDate {
 
 	}
 
-	public static function doesRangeSpanMidnight( $start_epoch, $end_epoch ) {
-		if ( self::getDayOfYear( $start_epoch ) != self::getDayOfYear( $end_epoch ) ) {
+	public static function doesRangeSpanMidnight( $start_epoch, $end_epoch, $match_midnight = FALSE ) {
+		//Debug::text('Start Epoch: '. TTDate::getDate('DATE+TIME', $start_epoch) .'  End Epoch: '. TTDate::getDate('DATE+TIME', $end_epoch), __FILE__, __LINE__, __METHOD__, 10);
+		if ( self::getDayOfYear( $start_epoch ) != self::getDayOfYear( $end_epoch )
+			OR (
+					$match_midnight == TRUE
+					AND
+						(
+							//Match If both start and end time is exactly midnight
+							( $start_epoch == $end_epoch AND TTDate::getHour( $start_epoch ) == 0 ) )
+							OR
+							//Match if start time is exactly midnight
+							$start_epoch == TTDate::getBeginDayEpoch( $start_epoch )
+						)
+			) {
 			return TRUE; //Range spans midnight.
 		}
 
@@ -1096,17 +1112,17 @@ class TTDate {
 	public static function getYearQuarterMonth( $epoch = NULL ) {
 		$year_quarter_months = array(
 									1 => 1,
-									2 => 2,
-									3 => 3,
-									4 => 1,
+									2 => 1,
+									3 => 1,
+									4 => 2,
 									5 => 2,
-									6 => 3,
-									7 => 1,
-									8 => 2,
+									6 => 2,
+									7 => 3,
+									8 => 3,
 									9 => 3,
-									10 => 1,
-									11 => 2,
-									12 => 3,
+									10 => 4,
+									11 => 4,
+									12 => 4,
 								);
 
 		$month = TTDate::getMonth( $epoch );
@@ -2044,7 +2060,7 @@ class TTDate {
 			case 'this_quarter':
 				$quarter = TTDate::getYearQuarter( $epoch );
 				$quarter_dates = TTDate::getYearQuarters( $epoch, $quarter );
-				Debug::Arr($quarter_dates, 'Quarter Dates: Quarter: '. $quarter, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::Arr($quarter_dates, 'Quarter Dates: Quarter: '. $quarter, __FILE__, __LINE__, __METHOD__,10);
 
 				$start_date = $quarter_dates['start'];
 				$end_date = $quarter_dates['end'];
@@ -2173,11 +2189,10 @@ class TTDate {
 		}
 
 		if ( isset($start_date) AND isset($end_date) ) {
-			Debug::text('Period: '. $time_period .' Start: '. TTDate::getDate('DATE+TIME', $start_date ) .'('.$start_date.') End: '. TTDate::getDate('DATE+TIME', $end_date ) .'('.$end_date.')', __FILE__, __LINE__, __METHOD__,10);
-
+			//Debug::text('Period: '. $time_period .' Start: '. TTDate::getDate('DATE+TIME', $start_date ) .'('.$start_date.') End: '. TTDate::getDate('DATE+TIME', $end_date ) .'('.$end_date.')', __FILE__, __LINE__, __METHOD__,10);
 			return array('start_date' => $start_date, 'end_date' => $end_date );
 		} elseif ( isset($pay_period_ids) ) {
-			Debug::text('Period: '. $time_period .' returning just pay_period_ids...', __FILE__, __LINE__, __METHOD__,10);
+			//Debug::text('Period: '. $time_period .' returning just pay_period_ids...', __FILE__, __LINE__, __METHOD__,10);
 			return array('pay_period_id' => $pay_period_ids );
 		}
 
@@ -2206,6 +2221,7 @@ class TTDate {
 						'-'.$sort_prefix.'12-'. $column_name_prefix .'date_dow_week' 			=> $column_name.' - '. TTi18n::gettext('Day of Week+Week'),
 						'-'.$sort_prefix.'14-'. $column_name_prefix .'date_dow_month' 			=> $column_name.' - '. TTi18n::gettext('Day of Week+Month'),
 						'-'.$sort_prefix.'16-'. $column_name_prefix .'date_dow_month_year'		=> $column_name.' - '. TTi18n::gettext('Day of Week+Month+Year'),
+						'-'.$sort_prefix.'18-'. $column_name_prefix .'date_dow_dom_month_year'	=> $column_name.' - '. TTi18n::gettext('Day of Week+Day Of Month+Year'),
 
 						'-'.$sort_prefix.'20-'. $column_name_prefix .'date_week' 				=> $column_name.' - '. TTi18n::gettext('Week'),
 						'-'.$sort_prefix.'22-'. $column_name_prefix .'date_week_month' 			=> $column_name.' - '. TTi18n::gettext('Week+Month'),
@@ -2225,11 +2241,12 @@ class TTDate {
 					   );
 
 		if ( $include_pay_period == TRUE ) {
+			//Don't use the $column_name on these, as there is only one type of pay period columns.
 			$pay_period_arr = array(
-						'-'.$sort_prefix.'70-'. $column_name_prefix .'pay_period' 				=> $column_name.' - '. TTi18n::gettext('Pay Period'),
-						'-'.$sort_prefix.'71-'. $column_name_prefix .'pay_period_start_date' 	=> $column_name.' - '. TTi18n::gettext('Pay Period - Start Date'),
-						'-'.$sort_prefix.'72-'. $column_name_prefix .'pay_period_end_date' 		=> $column_name.' - '. TTi18n::gettext('Pay Period - End Date'),
-						'-'.$sort_prefix.'73-'. $column_name_prefix .'pay_period_transaction_date' => $column_name.' - '. TTi18n::gettext('Pay Period - Transaction Date'),
+						'-'.$sort_prefix.'70-'. $column_name_prefix .'pay_period' 				=> TTi18n::gettext('Pay Period'),
+						'-'.$sort_prefix.'71-'. $column_name_prefix .'pay_period_start_date' 	=> TTi18n::gettext('Pay Period - Start Date'),
+						'-'.$sort_prefix.'72-'. $column_name_prefix .'pay_period_end_date' 		=> TTi18n::gettext('Pay Period - End Date'),
+						'-'.$sort_prefix.'73-'. $column_name_prefix .'pay_period_transaction_date' => TTi18n::gettext('Pay Period - Transaction Date'),
 					);
 			$retarr = array_merge( $retarr, $pay_period_arr );
 		}
@@ -2246,9 +2263,11 @@ class TTDate {
 			$column = $tmp_column[1];
 		}
 
-		if ($epoch == NULL OR $epoch == '' ) { //Epoch can be a string sometimes.
-			$epoch = self::getTime();
-		}
+		//Don't use todays date, as that can cause a lot of confusion in reports, especially when displaying time not assigned to a pay period
+		//and the pay period dates all show today. Just leave blank.
+		//if ($epoch == NULL OR $epoch == '' ) { //Epoch can be a string sometimes.
+		//	$epoch = self::getTime();
+		//}
 
 		$start_week_day = 0;
 		if ( is_object( $user_obj ) ) {
@@ -2259,76 +2278,67 @@ class TTDate {
 		}
 
 		if ( $post_processing == TRUE ) {
+			$split_epoch = explode('-', $epoch);
+
 			//Human friendly display, NOT for sorting.
 			switch( $column ) {
 				case 'pay_period_start_date':
 				case 'pay_period_end_date':
 				case 'pay_period_transaction_date':
-					if ( isset($params['include_pay_period_dates']) AND $params['include_pay_period_dates'] == FALSE ) {
-						$retval = NULL;
-					} else {
-						$retval = TTDate::getDate( 'DATE', $epoch );
-					}
+					$retval = TTDate::getDate( 'DATE', $epoch );
 					break;
 				case 'date_stamp':
 					$retval = TTDate::getDate( 'DATE', strtotime($epoch) );
 					break;
 				case 'time_stamp':
-					$retval = TTDate::getDate( 'TIME', $epoch );
+					$retval = TTDate::getDate( 'TIME', strtotime($epoch) );
 					break;
 				case 'date_time_stamp':
-					$retval = TTDate::getDate( 'DATE+TIME', $epoch );
+					$retval = TTDate::getDate( 'DATE+TIME', strtotime($epoch) );
 					break;
 				case 'date_dow':
-					//$retval = date('D', $epoch);
 					$retval = TTDate::getDayOfWeekName( $epoch );
 					break;
 				case 'date_dow_week':
-					$split_epoch = explode('-', $epoch);
 					$retval = TTDate::getDayOfWeekName( $split_epoch[1] ).' '.$split_epoch[0];
 					break;
 				case 'date_dow_month':
-					$split_epoch = explode('-', $epoch);
 					$retval = TTDate::getDayOfWeekName( $split_epoch[1] ).'-'.TTDate::getMonthName( $split_epoch[0] );
 					break;
 				case 'date_dow_month_year':
-					$split_epoch = explode('-', $epoch);
 					$retval = TTDate::getDayOfWeekName( $split_epoch[2] ).'-'.TTDate::getMonthName( $split_epoch[1] ).'-'.$split_epoch[0];
 					break;
+				case 'date_dow_dom_month_year':
+					$retval = TTDate::getDayOfWeekName( $split_epoch[2] ).' '. $split_epoch[1] .'-'.TTDate::getMonthName( $split_epoch[1] ).'-'.$split_epoch[0];
+					break;
 				case 'date_week':
 					$retval = $epoch;
 					break;
 				case 'date_week_month':
-					$split_epoch = explode('-', $epoch);
 					$retval = $split_epoch[1].' '.TTDate::getMonthName( $split_epoch[0] );
 					break;
 				case 'date_week_month_year':
-					$split_epoch = explode('-', $epoch);
 					$retval = $split_epoch[2].' '.TTDate::getMonthName( $split_epoch[1] ).'-'.$split_epoch[0];
 					break;
 				case 'date_dom':
 					$retval = $epoch;
 					break;
 				case 'date_dom_month':
-					$split_epoch = explode('-', $epoch);
 					$retval = $split_epoch[1].'-'.TTDate::getMonthName( $split_epoch[0] );
 					break;
 				case 'date_dom_month_year':
-					$split_epoch = explode('-', $epoch);
 					$retval = $split_epoch[2].'-'.TTDate::getMonthName( $split_epoch[1], TRUE ).'-'.$split_epoch[0];
 					break;
 				case 'date_month':
 					$retval = TTDate::getMonthName( $epoch );
 					break;
 				case 'date_month_year':
-					$split_epoch = explode('-', $epoch);
 					$retval = TTDate::getMonthName( $split_epoch[1] ).'-'.$split_epoch[0];
 					break;
 				case 'date_quarter':
 					$retval = $epoch;
 					break;
 				case 'date_quarter_year':
-					$split_epoch = explode('-', $epoch);
 					$retval = $split_epoch[1].'-'.$split_epoch[0];
 					break;
 				case 'date_year':
@@ -2360,6 +2370,7 @@ class TTDate {
 				$column_prefix.'date_dow_week' => date('W-w', $epoch ),
 				$column_prefix.'date_dow_month' => date('m-w', $epoch ),
 				$column_prefix.'date_dow_month_year' => date('Y-m-w', $epoch ),
+				$column_prefix.'date_dow_dom_month_year' => date('Y-m-w-W', $epoch ),
 				$column_prefix.'date_week' => date('W', $epoch ),
 				$column_prefix.'date_week_month' => date('m-W', $epoch ),
 				$column_prefix.'date_week_month_year' => date('Y-m-W', $epoch ),
@@ -2373,10 +2384,18 @@ class TTDate {
 				$column_prefix.'date_year' => TTDate::getYear( $epoch ),
 			);
 
-			if ( !isset($params['include_pay_period_dates']) OR $params['include_pay_period_dates'] == TRUE ) {
-				$retval[$column_prefix.'pay_period_start_date'] = $epoch;
-				$retval[$column_prefix.'pay_period_end_date'] = $epoch;
-				$retval[$column_prefix.'pay_period_transaction_date'] = $epoch;
+			//Only display these dates if they are passed in separately in the $param array.
+			if ( isset( $params['pay_period_start_date'] ) AND $params['pay_period_start_date'] != '' AND isset( $params['pay_period_end_date'] ) AND $params['pay_period_end_date'] != '' ) {
+				$retval[$column_prefix.'pay_period'] = array('sort' => $params['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $params['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $params['pay_period_end_date'] ) );
+			}
+			if ( isset( $params['pay_period_start_date'] ) AND $params['pay_period_start_date'] != '' ) {
+				$retval[$column_prefix.'pay_period_start_date'] = $params['pay_period_start_date'];
+			}
+			if ( isset( $params['pay_period_end_date'] ) AND $params['pay_period_end_date'] != ''  ) {
+				$retval[$column_prefix.'pay_period_end_date'] = $params['pay_period_end_date'];
+			}
+			if ( isset( $params['pay_period_transaction_date'] ) AND $params['pay_period_transaction_date'] != ''  ) {
+				$retval[$column_prefix.'pay_period_transaction_date'] = $params['pay_period_transaction_date'];
 			}
 		}
 
