@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4676 $
- * $Id: TTi18n.class.php 4676 2011-05-13 21:31:41Z ipso $
- * $Date: 2011-05-13 14:31:41 -0700 (Fri, 13 May 2011) $
+ * $Revision: 5891 $
+ * $Id: TTi18n.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /*
@@ -506,7 +506,7 @@ class TTi18n {
 		require_once( 'I18Nv2/Language.php' );
 
 		// We use self::getLanguage() because I18Nv2_Language() expects a 2 char lang code.
-		$lang = &new I18Nv2_Language( self::getLanguage(), 'UTF-8' );
+		$lang = new I18Nv2_Language( self::getLanguage(), 'UTF-8' );
 
 		$retarr = $lang->getAllCodes();
 		//asort($retarr);
@@ -527,12 +527,34 @@ class TTi18n {
 		return $retarr2;
 	}
 
-	static public function getText( $str ) {
+	static public function getTextStringArgs( $str, $args ) {
+		if ( $args != '' ) {
+			if ( !is_array($args) ) {
+				$args = (array)$args;
+			}
+
+			$i=1;
+			foreach( $args as $arg ) {
+				$tr['%'.$i] = $arg;
+
+				$i++;
+			}
+
+			return strtr($str, $tr);
+		}
+
+		return $str;
+	}
+
+	static public function getText( $str, $args = FALSE ) {
+		if ( $args != '' ) {
+			$str = self::getTextStringArgs( $str, $args );
+		}
 		return self::getTranslationHandler()->get( $str );
 	}
 
-	static public function gt( $str ) {
-		return self::getText( $str );
+	static public function gt( $str, $args = FALSE ) {
+		return self::getText( $str, $args );
 	}
 
 	/**
@@ -976,7 +998,7 @@ class NativeGettextTranslationHandler implements TranslationHandler {
 		bindtextdomain("$domain", Environment::getBasePath() .DIRECTORY_SEPARATOR .'interface' . DIRECTORY_SEPARATOR . 'locale');
 
 		// Tell gettext which codeset to use for output.
-		bind_textdomain_codeset ( $domain, 'UTF-8');
+		bind_textdomain_codeset( $domain, 'UTF-8');
 
 		return TRUE;
 	}
