@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: UserDateFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5749 $
+ * $Id: UserDateFactory.class.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 
 /**
@@ -95,8 +95,6 @@ class UserDateFactory extends Factory {
 	}
 
 	function findPayPeriod() {
-		Debug::Text('Attempting to find Pay Period for Start Date: '. $this->getDateStamp() , __FILE__, __LINE__, __METHOD__,10);
-
 		if ( $this->getDateStamp() > 0 AND $this->getUser() > 0 ) {
 			//FIXME: With MySQL since it doesn't handle timezones very well I think we need to
 			//get the timezone of the payperiod schedule for this user, and set the timezone to that
@@ -113,7 +111,6 @@ class UserDateFactory extends Factory {
 			if ( $pay_period->getId() !== FALSE ) {
 				return $pay_period->getId();
 			}
-
 		}
 
 		Debug::Text('Attempt failed: ', __FILE__, __LINE__, __METHOD__,10);
@@ -192,44 +189,48 @@ class UserDateFactory extends Factory {
 	}
 
 	static function findOrInsertUserDate($user_id, $date, $timezone = NULL ) {
-		$date = TTDate::getMiddleDayEpoch( $date ); //Use mid day epoch so the timezone conversion across DST doesn't affect the date.
+		if ( $user_id > 0 AND $date > 0 ) {
+			$date = TTDate::getMiddleDayEpoch( $date ); //Use mid day epoch so the timezone conversion across DST doesn't affect the date.
 
-		if ( $timezone == NULL ) {
-			//Find the employees preferred timezone, base the user date off that instead of the pay period timezone,
-			//as it can be really confusing to the user if they punch in at 10AM on Sept 27th, but it records as Sept 26th because
-			//the PP Schedule timezone is 12hrs different or something.
-			$uplf = TTnew( 'UserPreferenceListFactory' );
-			$uplf->getByUserID( $user_id );
-			if ( $uplf->getRecordCount() > 0 ) {
-				$timezone = $uplf->getCurrent()->getTimeZone();
+			if ( $timezone == NULL ) {
+				//Find the employees preferred timezone, base the user date off that instead of the pay period timezone,
+				//as it can be really confusing to the user if they punch in at 10AM on Sept 27th, but it records as Sept 26th because
+				//the PP Schedule timezone is 12hrs different or something.
+				$uplf = TTnew( 'UserPreferenceListFactory' );
+				$uplf->getByUserID( $user_id );
+				if ( $uplf->getRecordCount() > 0 ) {
+					$timezone = $uplf->getCurrent()->getTimeZone();
+				}
 			}
-		}
 
-		$date = TTDate::convertTimeZone( $date, $timezone );
-		Debug::text(' Using TimeZone: '. $timezone .' Date: '. TTDate::getDate('DATE+TIME', $date) .'('.$date.')', __FILE__, __LINE__, __METHOD__,10);
+			$date = TTDate::convertTimeZone( $date, $timezone );
+			Debug::text(' Using TimeZone: '. $timezone .' Date: '. TTDate::getDate('DATE+TIME', $date) .'('.$date.')', __FILE__, __LINE__, __METHOD__,10);
 
-		$udlf = TTnew( 'UserDateListFactory' );
-		$udlf->getByUserIdAndDate( $user_id, $date );
-		if ( $udlf->getRecordCount() == 1 ) {
-			$id = $udlf->getCurrent()->getId();
-			Debug::text(' Found Already Existing User Date ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-			return $id;
-		} elseif ( $udlf->getRecordCount() == 0 ) {
-			Debug::text(' Inserting new UserDate row.', __FILE__, __LINE__, __METHOD__,10);
+			$udlf = TTnew( 'UserDateListFactory' );
+			$udlf->getByUserIdAndDate( $user_id, $date );
+			if ( $udlf->getRecordCount() == 1 ) {
+				$id = $udlf->getCurrent()->getId();
+				Debug::text(' Found Already Existing User Date ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
+				return $id;
+			} elseif ( $udlf->getRecordCount() == 0 ) {
+				Debug::text(' Inserting new UserDate row. User ID: '. $user_id .' Date: '. $date , __FILE__, __LINE__, __METHOD__,10);
 
-			//Insert new row
-			$udf = TTnew( 'UserDateFactory' );
-			$udf->setUser( $user_id );
-			$udf->setDateStamp( $date );
-			$udf->setPayPeriod();
+				//Insert new row
+				$udf = TTnew( 'UserDateFactory' );
+				$udf->setUser( $user_id );
+				$udf->setDateStamp( $date );
+				$udf->setPayPeriod();
 
-			if ( $udf->isValid() ) {
-				return $udf->Save();
-			} else {
-				Debug::text(' INVALID user date row. Pay Period Locked?', __FILE__, __LINE__, __METHOD__,10);
+				if ( $udf->isValid() ) {
+					return $udf->Save();
+				} else {
+					Debug::text(' INVALID user date row. Pay Period Locked?', __FILE__, __LINE__, __METHOD__,10);
+				}
+			} elseif ( $udlf->getRecordCount() > 1 ) {
+				Debug::text(' More then 1 user date row was detected!!: '. $udlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 			}
-		} elseif ( $udlf->getRecordCount() > 1 ) {
-			Debug::text(' More then 1 user date row was detected!!: '. $udlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+		} else {
+			Debug::text(' Invalid arguments... User ID: '. $user_id .' Date: '. $date, __FILE__, __LINE__, __METHOD__,10);
 		}
 
 		Debug::text(' Cant find or insert User Date ID. User ID: '. $user_id .' Date: '. $date, __FILE__, __LINE__, __METHOD__,10);
