@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: Validator.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5248 $
+ * $Id: Validator.class.php 5248 2011-09-28 16:04:58Z ipso $
+ * $Date: 2011-09-28 09:04:58 -0700 (Wed, 28 Sep 2011) $
  */
 
 /**
@@ -181,6 +181,16 @@ class Validator {
 
 		return FALSE;
 	}
+	function isNotRegEx($label, $value, $msg, $regex) {
+		//Debug::text('Value: '. $value .' RegEx: '. $regex, __FILE__, __LINE__, __METHOD__, $this->verbosity);
+		if ( preg_match($regex,$value) == FALSE ) {
+			return TRUE;
+		}
+
+		$this->Error($label, $msg);
+
+		return FALSE;
+	}
 
 	function isLength($label, $value, $msg = NULL, $min = 1, $max = 255) {
 		$len = strlen($value);
@@ -196,6 +206,35 @@ class Validator {
 		return TRUE;
 	}
 
+	function isLengthBeforeDecimal($label, $value, $msg = NULL, $min = 1, $max = 255) {
+		$len = strlen( Misc::getBeforeDecimal($value) );
+
+		//Debug::text('Value: '. $value .' Length: '. $len .' Min: '. $min .' Max: '. $max, __FILE__, __LINE__, __METHOD__, $this->verbosity);
+
+		if ($len < $min OR $len > $max) {
+			$this->Error($label, $msg);
+
+			return FALSE;
+		}
+
+		return TRUE;
+	}
+
+	function isLengthAfterDecimal($label, $value, $msg = NULL, $min = 1, $max = 255) {
+		$len = strlen( Misc::getAfterDecimal($value, FALSE) );
+
+		//Debug::text('Value: '. $value .' Length: '. $len .' Min: '. $min .' Max: '. $max, __FILE__, __LINE__, __METHOD__, $this->verbosity);
+
+		if ($len < $min OR $len > $max) {
+			$this->Error($label, $msg);
+
+			return FALSE;
+		}
+
+		return TRUE;
+	}
+
+
 	function isPhoneNumber($label, $value, $msg = NULL) {
 
 		//Strip out all non-numeric characters.
@@ -367,6 +406,18 @@ class Validator {
 		return FALSE;
 	}
 
+	function isEmailAdvanced($label, $value, $msg = NULL, $error_level = TRUE ) {
+		//Debug::text('Raw Email: '. $value, __FILE__, __LINE__, __METHOD__, $this->verbosity);
+
+		if ( Misc::isEmail( $value, TRUE, $error_level ) === TRUE ) {
+			return TRUE;
+		}
+
+		$this->Error($label, $msg);
+
+		return FALSE;
+	}
+
 	function isIPAddress($label, $value, $msg = NULL) {
 		//Debug::text('Raw IP: '. $value, __FILE__, __LINE__, __METHOD__, $this->verbosity);
 
@@ -393,7 +444,7 @@ class Validator {
 
 	function isDate($label, $value, $msg = NULL) {
 		//Because most epochs are stored as 4-byte integers, make sure we are within range.
-		if ( $value != '' AND is_numeric($value) AND $value >= -2147483648 AND $value <= 2147483647) {
+		if ( $value !== FALSE AND $value != '' AND is_numeric($value) AND $value >= -2147483648 AND $value <= 2147483647) {
 			$date = gmdate('U', $value);
 			//Debug::text('Raw Date: '. $value .' Converted Value: '. $date, __FILE__, __LINE__, __METHOD__, $this->verbosity);
 
@@ -429,11 +480,12 @@ class Validator {
 		return str_replace(' ', '', trim($value));
 	}
 
+	function stripNumeric($value) {
+		$retval = preg_replace('/[0-9]/','',$value);
+		return $retval;
+	}
 	function stripNonNumeric($value) {
 		$retval = preg_replace('/[^0-9]/','',$value);
-
-		//Debug::Text('Numeric String:'. $retval, __FILE__, __LINE__, __METHOD__, $this->verbosity);
-
 		return $retval;
 	}
 
