@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4355 $
- * $Id: HierarchyControlFactory.class.php 4355 2011-03-10 20:01:16Z ipso $
- * $Date: 2011-03-10 12:01:16 -0800 (Thu, 10 Mar 2011) $
+ * $Revision: 5442 $
+ * $Id: HierarchyControlFactory.class.php 5442 2011-11-03 00:09:30Z ipso $
+ * $Date: 2011-11-02 17:09:30 -0700 (Wed, 02 Nov 2011) $
  */
 
 /**
@@ -54,11 +54,17 @@ class HierarchyControlFactory extends Factory {
 				$hotlf = TTnew( 'HierarchyObjectTypeListFactory' );
 				$retval = $hotlf->getOptions('object_type');
 				break;
+			case 'short_object_type':
+				$hotlf = TTnew( 'HierarchyObjectTypeListFactory' );
+				$retval = $hotlf->getOptions('short_object_type');
+				break;
 			case 'columns':
 				$retval = array(
 										'-1010-name' => TTi18n::gettext('Name'),
 										'-1020-description' => TTi18n::gettext('Description'),
-										'-1030-object_type_display' => TTi18n::gettext('Objects'),
+										'-1030-superiors' => TTi18n::gettext('Superiors'),
+										'-1030-subordinates' => TTi18n::gettext('Subordinates'),
+										'-1050-object_type_display' => TTi18n::gettext('Objects'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -73,6 +79,8 @@ class HierarchyControlFactory extends Factory {
 				$retval = array(
 								'name',
 								'description',
+								'superiors',
+								'subordinates',
 								'object_type_display'
 								);
 				break;
@@ -95,6 +103,8 @@ class HierarchyControlFactory extends Factory {
 										'company_id' => 'Company',
 										'name' => 'Name',
 										'description' => 'Description',
+										'superiors' => FALSE,
+										'subordinates' => FALSE,
 										'object_type' => 'ObjectType',
 										'object_type_display' => FALSE,
 										'user' => 'User',
@@ -190,14 +200,15 @@ class HierarchyControlFactory extends Factory {
 
 	function getObjectTypeDisplay() {
 		$object_type_ids = $this->getObjectType();
-		$object_types = $this->getOptions('object_type');
+		$object_types = $this->getOptions('short_object_type');
 
+		$retval = array();
 		foreach( $object_type_ids as $object_type_id ) {
 			$retval[] = Option::getByKey( $object_type_id, $object_types );
-
 		}
+		sort($retval); //Maintain consistent order.
 
-		return implode("\n", $retval );
+		return implode(',', $retval );
 	}
 
 	function getObjectType() {
@@ -410,6 +421,10 @@ class HierarchyControlFactory extends Factory {
 
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
+						case 'superiors':
+						case 'subordinates':
+							$data[$variable] = $this->getColumn($variable);
+							break;
 						case 'object_type_display':
 							$data[$variable] = $this->getObjectTypeDisplay();
 							break;
