@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: HolidayFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 5963 $
+ * $Id: HolidayFactory.class.php 5963 2012-01-04 16:31:38Z ipso $
+ * $Date: 2012-01-04 08:31:38 -0800 (Wed, 04 Jan 2012) $
  */
 
 /**
@@ -302,12 +302,12 @@ class HolidayFactory extends Factory {
 		}
 
 		if ( $this->getHolidayPolicyObject()->getAverageTimeWorkedDays() == TRUE ) {
+			Debug::text('Using worked days only...', __FILE__, __LINE__, __METHOD__,10);
 			$last_days_worked_count = $udtlf->getDaysWorkedByUserIDAndStartDateAndEndDate($user_id, ( $this->getDateStamp() - ( $this->getHolidayPolicyObject()->getAverageTimeDays() * 86400) ), $this->getDateStamp()-86400  );
 		} else {
-			Debug::text('NOT Using worked days!', __FILE__, __LINE__, __METHOD__,10);
-			$last_days_worked_count = $this->getHolidayPolicyObject()->getAverageTimeDays();
+			$last_days_worked_count = $this->getHolidayPolicyObject()->getAverageDays();
 		}
-		Debug::text('Last Days Worked:'. $last_days_worked_count, __FILE__, __LINE__, __METHOD__,10);
+		Debug::text('Average time over days:'. $last_days_worked_count, __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $this->getHolidayPolicyObject()->getIncludeOverTime() == TRUE ) {
 			Debug::text('Including OverTime!', __FILE__, __LINE__, __METHOD__,10);
@@ -414,6 +414,12 @@ class HolidayFactory extends Factory {
 						$worked_before_days_count = $udtlf->getDaysWorkedByUserIDAndStartDateAndEndDateAndDayOfWeek($user_obj->getId(), ( $this->getDateStamp() - ( ($this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays()*7) * 86400 ) ), $this->getDateStamp()-86400, TTDate::getDayOfWeek( $this->getDateStamp() ) );
 					} else { //Calendar Days
 						$worked_before_days_count = $udtlf->getDaysWorkedByUserIDAndStartDateAndEndDate($user_obj->getId(), ( $this->getDateStamp() - ( $this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays() * 86400) ), $this->getDateStamp()-86400  );
+
+						if ( $this->getHolidayPolicyObject()->getIncludePaidAbsenceTime() == TRUE ) {
+							$paid_absence_before_days_count = $udtlf->getDaysPaidAbsenceByUserIDAndStartDateAndEndDate($user_obj->getId(), ( $this->getDateStamp() - ( $this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays() * 86400) ), $this->getDateStamp()-86400  );
+							Debug::text('Employee has paid absence days prior: '. $paid_absence_before_days_count .' days and worked days: '. $worked_before_days_count .' (Must be at least: '. $this->getHolidayPolicyObject()->getMinimumWorkedDays() .')', __FILE__, __LINE__, __METHOD__,10);
+							$worked_before_days_count += $paid_absence_before_days_count;
+						}
 					}
 				}
 				Debug::text('Employee has worked the prior: '. $worked_before_days_count .' days (Must be at least: '. $this->getHolidayPolicyObject()->getMinimumWorkedDays() .')', __FILE__, __LINE__, __METHOD__,10);
