@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4401 $
- * $Id: RecurringHolidayFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
- * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
+ * $Revision: 4879 $
+ * $Id: RecurringHolidayFactory.class.php 4879 2011-06-25 00:17:58Z ipso $
+ * $Date: 2011-06-24 17:17:58 -0700 (Fri, 24 Jun 2011) $
  */
 
 /**
@@ -554,6 +554,7 @@ class RecurringHolidayFactory extends Factory {
 			return FALSE;
 		}
 
+		//http://www.statutoryholidays.com/
 		switch (strtolower($country)) {
 			case 'ca':
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
@@ -629,11 +630,28 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				//BC Holidays
+				Debug::text('Saving.... Xmas', __FILE__, __LINE__, __METHOD__, 10);
+				$rhf = TTnew( 'RecurringHolidayFactory' );
+				$rhf->setCompany( $company_id );
+				$rhf->setName( 'Boxing Day' ); //ON - Boxing day.
+				$rhf->setType( 10 );
+				$rhf->setSpecialDay( 0 );
+
+				//$rhf->setWeekInterval( $data['week_interval'] );
+				//$rhf->setDayOfWeek( $data['day_of_week'] );
+				$rhf->setDayOfMonth( 26 );
+				$rhf->setMonth( 12 );
+
+				if ( $rhf->isValid() ) {
+					$rhf->Save();
+				}
+
 				Debug::text('Saving.... British Columbia Day', __FILE__, __LINE__, __METHOD__, 10);
 				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
-				$rhf->setName( 'BC - British Columbia Day' );
+				//Known as different names in different provinces. BC, SK, MN, NB, NU.
+				//PEI calls this Islander Day, MN calls it Louis Reil day.
+				$rhf->setName( 'Civic Holiday' );
 				$rhf->setType( 20 );
 				$rhf->setSpecialDay( 0 );
 				$rhf->setWeekInterval( 1 );
@@ -645,11 +663,10 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				//AB Holidays
 				Debug::text('Saving.... Family Day', __FILE__, __LINE__, __METHOD__, 10);
 				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
-				$rhf->setName( 'AB - Family Day' );
+				$rhf->setName( 'Family Day' ); //BC, AB, SK, ON
 				$rhf->setType( 20 );
 				$rhf->setSpecialDay( 0 );
 				$rhf->setWeekInterval( 3 );
@@ -661,7 +678,6 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-
 				//Holidays across different provinces
 				Debug::text('Saving.... Victoria Day', __FILE__, __LINE__, __METHOD__, 10);
 				$rhf = TTnew( 'RecurringHolidayFactory' );
