@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4849 $
- * $Id: Install.class.php 4849 2011-06-21 18:28:02Z ipso $
- * $Date: 2011-06-21 11:28:02 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5415 $
+ * $Id: Install.class.php 5415 2011-10-28 15:22:21Z ipso $
+ * $Date: 2011-10-28 08:22:21 -0700 (Fri, 28 Oct 2011) $
  */
 
 /**
@@ -66,7 +66,9 @@ class Install {
 		ini_set('default_socket_timeout', 5);
 		ini_set('allow_url_fopen', 1);
 
-		if( (bool)ini_get( 'enable_dl' ) == TRUE AND (bool)ini_get( 'safe_mode' ) == FALSE ) {
+		//As of PHP v5.3 some SAPI's don't support dl(), however it appears that php.ini can still have it enabled.
+		//Double check to make sure the dl() function exists prior to calling it.
+		if ( version_compare(PHP_VERSION, '5.3.0', '<') AND function_exists('dl') == TRUE AND (bool)ini_get( 'enable_dl' ) == TRUE AND (bool)ini_get( 'safe_mode' ) == FALSE ) {
 			$prefix = (PHP_SHLIB_SUFFIX === 'dll') ? 'php_' : '';
 
 			if ( extension_loaded('mysql') == FALSE ) {
@@ -222,9 +224,6 @@ class Install {
 			if ( isset($config_vars['type']) AND $config_vars['type'] != '' ) {
 				$section['database'] = preg_replace('/^type\s*=.*/im', 'type = '. trim($config_vars['type']), $section['database']);
 			}
-			if ( isset($config_vars['host']) AND $config_vars['host'] != '' ) {
-				$section['database'] = preg_replace('/^host\s*=.*/im', 'host = '. trim($config_vars['host']), $section['database']);
-			}
 			if ( isset($config_vars['database_name']) AND $config_vars['database_name'] != '' ) {
 				$section['database'] = preg_replace('/^database_name\s*=.*/im', 'database_name = '. trim($config_vars['database_name']), $section['database']);
 			}
@@ -796,7 +795,7 @@ class Install {
 
 		$query = 'show engines';
 		$storage_engines = $db_conn->getAll($query);
-		Debug::Arr($storage_engines, 'Available Storage Engines:', __FILE__, __LINE__, __METHOD__,9);
+		//Debug::Arr($storage_engines, 'Available Storage Engines:', __FILE__, __LINE__, __METHOD__,9);
 		if ( is_array($storage_engines) ) {
 			foreach( $storage_engines as $key => $data ) {
 				Debug::Text('Engine: '. $data['Engine'] .' Support: '. $data['Support'], __FILE__, __LINE__, __METHOD__,10);
