@@ -18,9 +18,9 @@ INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1230796800, 71415, 15.4
 INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1230796800, 116105, 16.8, 2857);
 INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1230796800, 116105, 17.95, 4192);
 
-INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NF', 1230796800, 31061, 7.7, 0);
-INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NF', 1230796800, 62121, 12.8, 1584);
-INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NF', 1230796800, 62121, 15.5, 3261);
+INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1230796800, 31061, 7.7, 0);
+INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1230796800, 62121, 12.8, 1584);
+INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1230796800, 62121, 15.5, 3261);
 
 INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1230796800, 36885, 5.9, 0);
 INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1230796800, 73772, 8.6, 996);
@@ -40,10 +40,10 @@ INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1230796800, 40113, 11,
 INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1230796800, 114610, 13, 802);
 INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1230796800, 114610, 15, 3094);
 
-INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1230796800, 38832, 7.04, 0);
-INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1230796800, 77664, 9.68, 1025);
-INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1230796800, 126264, 11.44, 2392);
-INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1230796800, 126264, 12.76, 4059);
+INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 38832, 7.04, 0);
+INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 77664, 9.68, 1025);
+INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 126264, 11.44, 2392);
+INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 126264, 12.76, 4059);
 
 
 INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 2650, 0, 0);
