@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -566,6 +566,8 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 
 		$sort_column_aliases = array(
 									 'status' => 'a.status_id',
+									 'created_date' => 'c.created_date',
+									 'created_by' => 'c.created_by',
 									 );
 
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
@@ -603,6 +605,8 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 						SELECT
 								c.*,
 								a.*,
+								c.created_date as created_date,
+								c.created_by as created_by,
 								b.id as id,
 								a.user_id as to_user_id,
 								aa.first_name as to_first_name,
