@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3934 $
- * $Id: EFT.class.php 3934 2010-11-17 23:29:44Z ipso $
- * $Date: 2010-11-17 15:29:44 -0800 (Wed, 17 Nov 2010) $
+ * $Revision: 6071 $
+ * $Id: EFT.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /*
@@ -170,13 +170,28 @@ class EFT {
 		return TRUE;
 	}
 
+	function getBusinessNumber() {
+		if ( isset($this->header_data['business_number']) ) {
+			return $this->header_data['business_number'];
+		}
+	}
+	function setBusinessNumber($value) {
+		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 10 ) {
+			$this->header_data['business_number'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getOriginatorID() {
 		if ( isset($this->header_data['originator_id']) ) {
 			return $this->header_data['originator_id'];
 		}
 	}
-
 	function setOriginatorID($value) {
+		$value = trim($value);
 		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 10 ) {
 			$this->header_data['originator_id'] = $value;
 
@@ -191,8 +206,8 @@ class EFT {
 			return $this->header_data['originator_short_name'];
 		}
 	}
-
 	function setOriginatorShortName($value) {
+		$value = trim($value);
 		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 26 ) {
 			$this->header_data['originator_short_name'] = $value;
 
@@ -207,7 +222,6 @@ class EFT {
 			return $this->header_data['file_creation_number'];
 		}
 	}
-
 	function setFileCreationNumber($value) {
 		if ( $this->isNumeric( $value ) AND strlen( $value ) <= 4 ) {
 			$this->header_data['file_creation_number'] = $value;
@@ -218,12 +232,26 @@ class EFT {
 		return FALSE;
 	}
 
+	function getInitialEntryNumber() {
+		if ( isset($this->header_data['initial_entry_number']) ) {
+			return $this->header_data['initial_entry_number'];
+		}
+	}
+	function setInitialEntryNumber($value) {
+		if ( $this->isNumeric( $value ) AND strlen( $value ) <= 15 ) {
+			$this->header_data['initial_entry_number'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getFileCreationDate() {
 		if ( isset($this->header_data['file_creation_date']) ) {
 			return $this->header_data['file_creation_date'];
 		}
 	}
-
 	function setFileCreationDate($value) {
 		if ( $value != '' ) {
 			$this->header_data['file_creation_date'] = $value;
@@ -239,9 +267,8 @@ class EFT {
 			return $this->header_data['data_center'];
 		}
 	}
-
 	function setDataCenter($value) {
-		if ( $this->isNumeric( $value ) AND strlen( $value ) <= 5 ) {
+		if ( $this->isNumeric( $value ) AND strlen( $value ) <= 10 ) {
 			$this->header_data['data_center'] = $value;
 
 			return TRUE;
@@ -249,6 +276,21 @@ class EFT {
 
 		return FALSE;
 	}
+	function getDataCenterName() {
+		if ( isset($this->header_data['data_center_name']) ) {
+			return $this->header_data['data_center_name'];
+		}
+	}
+	function setDataCenterName($value) {
+		$value = trim($value);
+		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 23 ) {
+			$this->header_data['data_center_name'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
 
 	function setRecord( $obj ){
 		$this->data[] = $obj;
@@ -496,7 +538,7 @@ class EFT_record extends EFT {
 	}
 
 	function setAccount($value) {
-		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 13 ) {
+		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 17 ) { //Needs to be 17 digits for US, 13 for CAD?
 			$this->record_data['account'] = $value;
 
 			return TRUE;
@@ -1105,9 +1147,8 @@ class EFT_File_Format_HSBC Extends EFT {
 class EFT_File_Format_ACH Extends EFT {
 	/*
 	Validator Program: http://www.download.com/3001-2066_4-10344585.html
-	http://chat.cashproweb.com/cpuniversity/portal/training/Technical_Resources/NACHA%20FORMAT_LNA%20and%20SFB.pdf
-	http://members.aol.com/getmydata/pskb/NACHA-ACH-CCD-Format.htm
-	Google: nacha 94 byte file format
+	http://www.google.ca/url?sa=t&rct=j&q=ach%20file%20format%20immediate%20origin&source=web&cd=4&ved=0CEMQFjAD&url=http%3A%2F%2Fwww.commercebank.com%2FPDFs%2Fconnections%2FACH-fileformats.pdf&ei=mb0VT5tdo6OIAo3lqNwN&usg=AFQjCNEI0pnOfN65qRpVtCLYWTIM4inKtQ&cad=rja
+	Google: nacha 94 byte file format OR International ACH (IAT) NACHA File Formats
 
 		File Header Record
 			Batch Header Record
@@ -1146,8 +1187,8 @@ class EFT_File_Format_ACH Extends EFT {
 	private function compileFileHeader() {
 		$line[] = '1'; //1 Record
 		$line[] = '01'; //Priority code
-		$line[] = $this->padRecord( $this->getDataCenter(), 10, 'AN');; //Immidiate destination - '072000805' - Standard Federal Bank
-		$line[] = $this->padRecord( $this->getOriginatorID(), 10, 'N'); //Immediate Origin - Recommend IRS Federal Tax ID Number
+		$line[] = ' '.$this->padRecord( $this->getDataCenter(), 9, 'N'); //Immidiate destination - Must be proceeded with a space then 9 digits. '072000805' - Standard Federal Bank
+		$line[] = ' '.$this->padRecord( $this->getOriginatorID(), 9, 'N'); //Immediate Origin - Must be proceeded with a space then 9 digits. Recommend IRS Federal Tax ID Number
 
 		$line[] = $this->padRecord( date('ymd', $this->getFileCreationDate() ), 6, 'N');
 		$line[] = $this->padRecord( date('Hi', $this->getFileCreationDate() ), 4, 'N');
@@ -1158,8 +1199,8 @@ class EFT_File_Format_ACH Extends EFT {
 		$line[] = $this->padRecord( 10 , 2, 'N'); //Blocking factor
 		$line[] = $this->padRecord( 1 , 1, 'N'); //Format code
 
-		$line[] = $this->padRecord( 'Standard Federal Bank', 23, 'AN'); //Immidiate destination name- Standard Federal Bank
-		$line[] = $this->padRecord( $this->getOriginatorShortName(), 23, 'AN'); //Company Short Name
+		$line[] = $this->padRecord( strtoupper( $this->getDataCenterName() ), 23, 'AN'); //Immidiate destination name. Optional
+		$line[] = $this->padRecord( strtoupper( $this->getOriginatorShortName() ), 23, 'AN'); //Company Short Name. Optional
 
 		$line[] = $this->padRecord( '', 8, 'AN'); //File Reference Code
 
@@ -1178,19 +1219,16 @@ class EFT_File_Format_ACH Extends EFT {
 		} else {
 			$line[] = '225'; //Batch Type
 		}
-		$line[] = $this->padRecord( $this->getOriginatorShortName(), 16, 'AN'); //Company Short Name
+		$line[] = $this->padRecord( strtoupper( $this->getOriginatorShortName() ), 16, 'AN'); //Company Short Name
 		$line[] = $this->padRecord( '', 20, 'AN'); //Discretionary Data
-		$line[] = $this->padRecord( $this->getOriginatorID(), 10, 'N'); //Immediate Origin - Recommend IRS Federal Tax ID Number
+		$line[] = $this->padRecord( $this->getBusinessNumber(), 10, 'N'); //Company Identification - Recommend IRS Federal Tax ID Number
 		$line[] = $this->padRecord( 'PPD', 3, 'AN'); //Standard Entry Class. (PPD, CCD,CTX,TEL,WEB)
-		$line[] = $this->padRecord( 'Payroll', 10, 'AN'); //Entry Description
+		$line[] = $this->padRecord( 'PAYROLL', 10, 'AN'); //Entry Description
 		$line[] = $this->padRecord( date('ymd', $this->getFileCreationDate() ), 6, 'N'); //Date
 		$line[] = $this->padRecord( date('ymd', $due_date ), 6, 'N'); //Date to post funds.
-
 		$line[] = $this->padRecord( '', 3, 'AN'); //Blank
 		$line[] = '1'; //Originator Status Code
-		$line[] = $this->getDataCenter(); //Originating Bank Transit - Standard Federal Bank
-		//$line[] = '07200080'; //Originating Bank Transit - Standard Federal Bank
-
+		$line[] = $this->padRecord( $this->getDataCenter(), 8, 'N' ); //Originating Bank Transit
 		$line[] = $this->padRecord( $this->batch_number, 7, 'N'); //Batch Number
 
 		$retval = $this->padLine( implode('', $line), 94 );
@@ -1200,7 +1238,7 @@ class EFT_File_Format_ACH Extends EFT {
 		return $retval;
 	}
 
-	private function compileBatchControl( $type, $record ) {
+	private function compileBatchControl( $type, $batch_amount, $hash ) {
 		$line[] = '8'; //8 Record
 
 		if ( $type == 'C' ) {
@@ -1210,18 +1248,13 @@ class EFT_File_Format_ACH Extends EFT {
 		}
 
 		$line[] = $this->padRecord( 1, 6, 'N'); //Entry and Addenda count.
-		$line[] = $this->padRecord( substr($record->getTransit(),0,8), 10, 'N'); //Entry hash
-
+		$line[] = $this->padRecord( substr( str_pad( $hash, 10, 0, STR_PAD_LEFT), -10), 10, 'N'); //Entry hash. If it exceeds 10 digits, use just the last 10.
 		$line[] = $this->padRecord( 0, 12, 'N'); //Debit Total
-		$line[] = $this->padRecord( $this->removeDecimal( $record->getAmount() ), 12, 'N'); //Credit Total
-
-		$line[] = $this->padRecord( $this->getOriginatorID(), 10, 'N'); //Immediate Origin - Recommend IRS Federal Tax ID Number
+		$line[] = $this->padRecord( $this->removeDecimal( $batch_amount ), 12, 'N'); //Credit Total
+		$line[] = $this->padRecord( $this->getBusinessNumber(), 10, 'N'); //Company Identification - Recommend IRS Federal Tax ID Number
 		$line[] = $this->padRecord( '', 19, 'AN'); //Blank
 		$line[] = $this->padRecord( '', 6, 'AN'); //Blank
-
-		$line[] = $this->getDataCenter(); //Originating Bank Transit - Standard Federal Bank
-		//$line[] = '07200080'; //Originating Bank Transit - Standard Federal Bank
-
+		$line[] = $this->padRecord( $this->getDataCenter(), 8, 'N' ); //Originating Bank Transit
 		$line[] = $this->padRecord( $this->batch_number, 7, 'N'); //Batch Number
 
 		$retval = $this->padLine( implode('', $line), 94 );
@@ -1242,12 +1275,24 @@ class EFT_File_Format_ACH Extends EFT {
 		}
 
 		$i=1;
+		$max=count($this->data);
+		$prev_due_date = FALSE;
+		$batch_amount = 0;
+		$hash = 0;
 		foreach ( $this->data as $key => $record ) {
 			//Debug::Arr($record, 'Record Object:', __FILE__, __LINE__, __METHOD__, 10);
 
-			//Because each batch only has a due date, put each record into its own batch
+			//Because each batch only has a due date, only start a new batch if the DueDate changes.
 			//Add batch record here
-			$retval[] = $this->compileBatchHeader( $record->getType(), $record->getDueDate() );
+			if ( $prev_due_date == FALSE OR $prev_due_date != $record->getDueDate() ) {
+				if ( $prev_due_date !== FALSE ) {
+					//Close the previous batch before starting a new one.
+					$retval[] = $this->compileBatchControl( $record->getType(), $batch_amount, $hash );
+				}
+				$retval[] = $this->compileBatchHeader( $record->getType(), $record->getDueDate() );
+				$batch_amount = 0;
+				$hash = 0;
+			}
 
 			$line[] = '6'; //6 Record (PPD)
 			$line[] = '22'; //Transaction code - Deposit destined for checking account
@@ -1258,30 +1303,28 @@ class EFT_File_Format_ACH Extends EFT {
 			Debug::Text('Institution: '. $record->getInstitution() .' Transit: '.$record->getTransit().' Bank Account Number: '. $record->getAccount(), __FILE__, __LINE__, __METHOD__, 10);
 
 			$line[] = $this->padRecord( $this->removeDecimal( $record->getAmount() ), 10, 'N'); //Amount
-
 			$line[] = $this->padRecord( $record->getOriginatorReferenceNumber(), 15, 'AN'); //transaction identification number
-
 			$line[] = $this->padRecord( $record->getName(), 22, 'AN'); //Name of receiver
-
 			$line[] = $this->padRecord( '', 2, 'AN'); //discretionary data
-
 			$line[] = $this->padRecord( 0, 1, 'N'); //Addenda record indicator
-			//Discrepancy between the file validator and the PDF file that explains the format.
-			//$line[] = '07200080'; //Originating Bank Transit - Standard Federal Bank
-			$line[] = $this->getDataCenter(); //Originating Bank Transit - Standard Federal Bank
-			$line[] = $this->padRecord( 1, 14, 'N'); //Trace number. Bank assigns?
+			$line[] = $this->padRecord( $this->getInitialEntryNumber() . str_pad( $i, ( 15-strlen($this->getInitialEntryNumber()) ), 0, STR_PAD_LEFT), 15, 'N'); //Trace number. Bank assigns?
 
 			$d_record = $this->padLine( implode('', $line), 94 );
-			Debug::Text('PPD Record:'. $d_record .' - Length: '. strlen($d_record), __FILE__, __LINE__, __METHOD__, 10);
 
 			$retval[] = $d_record;
 
+			$batch_amount += $record->getAmount();
+			$prev_due_date = $record->getDueDate();
+			$hash += substr($record->getTransit(),0,8);
+			Debug::Text('PPD Record:'. $d_record .' - DueDate: '. $record->getDueDate() .' Batch Amount: '. $batch_amount .' Length: '. strlen($d_record) .' Hash1: '. substr($record->getTransit(),0,8) .' Hash2: '. $hash, __FILE__, __LINE__, __METHOD__, 10);
+
 			//Add BatchControl Record Here
-			$retval[] = $this->compileBatchControl( $record->getType(), $record );
+			if ( $i == $max ) {
+				$retval[] = $this->compileBatchControl( $record->getType(), $batch_amount, $hash );
+			}
 
 			unset($line);
 			unset($d_record);
-
 			$i++;
 		}
 
@@ -1293,7 +1336,6 @@ class EFT_File_Format_ACH Extends EFT {
 		return FALSE;
 	}
 
-
 	private function compileFileControl() {
 		if ( count($this->data) == 0 ) {
 			return FALSE;
