@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: PayStubEntryAccountFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 5289 $
+ * $Id: PayStubEntryAccountFactory.class.php 5289 2011-10-06 19:40:31Z ipso $
+ * $Date: 2011-10-06 12:40:31 -0700 (Thu, 06 Oct 2011) $
  */
 
 /**
@@ -1029,11 +1029,21 @@ class PayStubEntryAccountFactory extends Factory {
 			$pself = TTnew( 'PayStubEntryListFactory' );
 			$pself->getByEntryNameId( $this->getId() );
 			if ( $pself->getRecordCount() > 0 ) {
-				Debug::text('PSE Account is in use... Disabling instead.', __FILE__, __LINE__, __METHOD__, 10);
+				Debug::text('PSE Account is in use by Pay Stubs... Disabling instead.', __FILE__, __LINE__, __METHOD__, 10);
 				$this->setDeleted(FALSE); //Can't delete, account is in use.
 				$this->setStatus(20); //Disable instead
 			} else {
-				Debug::text('PSE Account is NOT in use... Deleting...', __FILE__, __LINE__, __METHOD__, 10);
+				Debug::text('aPSE Account is NOT in use... Deleting...', __FILE__, __LINE__, __METHOD__, 10);
+			}
+
+			$psalf = TTnew( 'PayStubAmendmentListFactory' );
+			$psalf->getByPayStubEntryNameID( $this->getId() );
+			if ( $psalf->getRecordCount() > 0 ) {
+				Debug::text('PSE Account is in use by PS Amendments... Disabling instead.', __FILE__, __LINE__, __METHOD__, 10);
+				$this->setDeleted(FALSE); //Can't delete, account is in use.
+				$this->setStatus(20); //Disable instead
+			} else {
+				Debug::text('bPSE Account is NOT in use... Deleting...', __FILE__, __LINE__, __METHOD__, 10);
 			}
 		}
 
