@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: PayStubEntryAccountListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 6071 $
+ * $Id: PayStubEntryAccountListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -381,7 +381,7 @@ class PayStubEntryAccountListFactory extends PayStubEntryAccountFactory implemen
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 
 		if ( $order == NULL ) {
-			$order = array( 'a.status_id' => 'asc', 'a.type_id' => 'asc');
+			$order = array( 'a.status_id' => 'asc', 'a.type_id' => 'asc', 'a.ps_order' => 'asc');
 			$strict = FALSE;
 		} else {
 			//Always try to order by status first so INACTIVE records go to the bottom.
@@ -423,6 +423,32 @@ class PayStubEntryAccountListFactory extends PayStubEntryAccountFactory implemen
 					where	a.company_id = ?
 					';
 
+		$query .= ( isset($filter_data['permission_children_ids']) ) ? $this->getWhereClauseSQL( 'a.created_by', $filter_data['permission_children_ids'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['exclude_id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['exclude_id'], 'not_numeric_list', $ph ) : NULL;
+
+		if ( isset($filter_data['status']) AND trim($filter_data['status']) != '' AND !isset($filter_data['status_id']) ) {
+			$filter_data['status_id'] = Option::getByFuzzyValue( $filter_data['status'], $this->getOptions('status') );
+		}
+		$query .= ( isset($filter_data['status_id']) ) ? $this->getWhereClauseSQL( 'a.status_id', $filter_data['status_id'], 'numeric_list', $ph ) : NULL;
+
+		if ( isset($filter_data['type']) AND trim($filter_data['type']) != '' AND !isset($filter_data['type_id']) ) {
+			$filter_data['type_id'] = Option::getByFuzzyValue( $filter_data['type'], $this->getOptions('type') );
+		}
+		$query .= ( isset($filter_data['type_id']) ) ? $this->getWhereClauseSQL( 'a.type_id', $filter_data['type_id'], 'numeric_list', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['name']) ) ? $this->getWhereClauseSQL( 'a.name', $filter_data['name'], 'text', $ph ) : NULL;
+
+		if ( isset($filter_data['created_by']) AND trim($filter_data['created_by']) != '' ) {
+			$ph[] = $ph[] = strtolower(trim($filter_data['created_by']));
+			$query  .=	' AND (lower(y.first_name) LIKE ? OR lower(y.last_name) LIKE ? ) ';
+		}
+		if ( isset($filter_data['updated_by']) AND trim($filter_data['updated_by']) != '' ) {
+			$ph[] = $ph[] = strtolower(trim($filter_data['updated_by']));
+			$query  .=	' AND (lower(z.first_name) LIKE ? OR lower(z.last_name) LIKE ? ) ';
+		}
+
+/*
 		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
 		}
@@ -438,6 +464,8 @@ class PayStubEntryAccountListFactory extends PayStubEntryAccountFactory implemen
 		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
 			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
 		}
+
+
 		if ( isset($filter_data['name']) AND trim($filter_data['name']) != '' ) {
 			$ph[] = strtolower(trim($filter_data['name']));
 			$query  .=	' AND lower(a.name) LIKE ?';
@@ -448,7 +476,7 @@ class PayStubEntryAccountListFactory extends PayStubEntryAccountFactory implemen
 		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
 			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
 		}
-
+*/
 		$query .= 	'
 						AND a.deleted = 0
 					';
