@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: PayStubEntryFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 6071 $
+ * $Id: PayStubEntryFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -173,10 +173,27 @@ class PayStubEntryFactory extends Factory {
 			return FALSE;
 		}
 
-		if (  $this->Validator->isFloat(				'rate',
+		if (	empty($value) OR
+				(
+				$this->Validator->isFloat(				'rate',
 														$value,
-														TTi18n::gettext('Invalid Rate')
-														) ) {
+														TTi18n::gettext('Invalid Rate') )
+				AND
+				$this->Validator->isLength(				'rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits'),
+											0,
+											21) //Need to include decimal.
+				AND
+				$this->Validator->isLengthBeforeDecimal('rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits before the decimal'),
+											0,
+											16)
+				)
+			) {
+			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
+			//$this->data['rate'] = Misc::MoneyFormat( $value, FALSE );
 			$this->data['rate'] = $value;
 
 			return TRUE;
@@ -199,10 +216,29 @@ class PayStubEntryFactory extends Factory {
 			return FALSE;
 		}
 
-		if (  $this->Validator->isFloat(				'units',
+		Debug::text('Rate: '. $value, __FILE__, __LINE__, __METHOD__,10);
+
+		if (	empty($value) OR
+				(
+				$this->Validator->isFloat(				'units',
 														$value,
-														TTi18n::gettext('Invalid Units')
-														) ) {
+														TTi18n::gettext('Invalid Units') )
+				AND
+				$this->Validator->isLength(				'units',
+											$value,
+											TTi18n::gettext('Units has too many digits'),
+											0,
+											21) //Need to include decimal
+				AND
+				$this->Validator->isLengthBeforeDecimal('units',
+											$value,
+											TTi18n::gettext('Units has too many digits before the decimal'),
+											0,
+											16)
+				)
+			) {
+			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
+			//$this->data['units'] = Misc::MoneyFormat( $value, FALSE );
 			$this->data['units'] = $value;
 
 			return TRUE;
@@ -274,6 +310,7 @@ class PayStubEntryFactory extends Factory {
 	function setAmount($value) {
 		$value = trim($value);
 
+		//PHP v5.3.5 has a bug that it converts large values with 0's on the end into scientific notation.
 		Debug::text('Amount: '. $value .' Name: '. $this->getPayStubEntryNameId() , __FILE__, __LINE__, __METHOD__,10);
 
 		//if ($value == NULL OR $value == '' OR $value < 0) {
@@ -284,13 +321,25 @@ class PayStubEntryFactory extends Factory {
 
 		if (  $this->Validator->isFloat(				'amount',
 														$value,
-														TTi18n::gettext('Invalid Amount')
-														) ) {
-			//$this->data['amount'] = number_format( $value, 2, '.', '');
-			$this->data['amount'] = round( $value, 2);
+														TTi18n::gettext('Invalid Amount') )
+				AND
+				$this->Validator->isLength(				'amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits'),
+											0,
+											21) //Need to include decimal
+				AND
+				$this->Validator->isLengthBeforeDecimal('amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits before the decimal'),
+											0,
+											16)
+			) {
+			$this->data['amount'] = Misc::MoneyFormat( $value, FALSE );
 
 			return TRUE;
 		}
+
 		return FALSE;
 	}
 	function getYTDAmount() {
@@ -313,7 +362,7 @@ class PayStubEntryFactory extends Factory {
 														$value,
 														TTi18n::gettext('Invalid YTD Amount')
 														) ) {
-			$this->data['ytd_amount'] = round( $value,2);
+			$this->data['ytd_amount'] = Misc::MoneyFormat( $value, FALSE );
 
 			return TRUE;
 		}
