@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4582 $
- * $Id: PayStubEntryListFactory.class.php 4582 2011-04-26 15:47:38Z ipso $
- * $Date: 2011-04-26 08:47:38 -0700 (Tue, 26 Apr 2011) $
+ * $Revision: 5891 $
+ * $Id: PayStubEntryListFactory.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -1120,11 +1120,15 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 					'entry_name_id' => $entry_name_id,
 					);
 
+		$psf = new PayStubFactory();
+
+		//Make sure we ignore pay stub entries attached to deleted pay stubs.
 		$query = '
-					select 	*
-					from	'. $this->getTable() .'
-					where	pay_stub_entry_name_id = ?
-						AND deleted = 0';
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $psf->getTable() .' as psf ON ( a.pay_stub_id = psf.id )
+					where	a.pay_stub_entry_name_id = ?
+						AND ( a.deleted = 0 AND psf.deleted = 0 )';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
@@ -1569,6 +1573,9 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 											'group',
 											'title',
 											'currency',
+											'pay_period_transaction_date',
+											'pay_stub_transaction_date',
+											'user_id',
 											);
 
 		if ( $order == NULL ) {
@@ -1631,6 +1638,13 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 							if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
 								$query  .=	' AND cc.id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
 							}
+							if ( isset($filter_data['include_user_id']) AND isset($filter_data['include_user_id'][0]) AND !in_array(-1, (array)$filter_data['include_user_id']) ) {
+								$query  .=	' AND cc.id in ('. $this->getListSQL($filter_data['include_user_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['exclude_user_id']) AND isset($filter_data['exclude_user_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_user_id']) ) {
+								$query  .=	' AND cc.id in ('. $this->getListSQL($filter_data['exclude_user_id'], $ph) .') ';
+							}
+
 							if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
 								$query  .=	' AND cc.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
 							}
