@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4600 $
- * $Id: PayStubListFactory.class.php 4600 2011-04-28 21:35:12Z ipso $
- * $Date: 2011-04-28 14:35:12 -0700 (Thu, 28 Apr 2011) $
+ * $Revision: 4993 $
+ * $Id: PayStubListFactory.class.php 4993 2011-07-15 23:32:11Z ipso $
+ * $Date: 2011-07-15 16:32:11 -0700 (Fri, 15 Jul 2011) $
  */
 
 /**
@@ -932,7 +932,7 @@ class PayStubListFactory extends PayStubFactory implements IteratorAggregate {
 							b.default_department_id as default_department_id,
 							df.name as default_department,
 							b.group_id as group_id,
-							ugf.name as group,
+							ugf.name as "group",
 							b.title_id as title_id,
 							utf.name as title,
 
