@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4287 $
- * $Id: PayStubAmendmentFactory.class.php 4287 2011-02-24 00:17:02Z ipso $
- * $Date: 2011-02-23 16:17:02 -0800 (Wed, 23 Feb 2011) $
+ * $Revision: 6071 $
+ * $Id: PayStubAmendmentFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -425,15 +425,38 @@ class PayStubAmendmentFactory extends Factory {
 	function setRate($value) {
 		$value = trim($value);
 
+		//Pull out only digits and periods.
+		$value = $this->Validator->stripNonFloat($value);
+
 		if ($value == 0 OR $value == '') {
 			$value = NULL;
 		}
 
 		if (	empty($value) OR
+				(
 				$this->Validator->isFloat(				'rate',
 														$value,
-														TTi18n::gettext('Invalid Rate')
-														) ) {
+														TTi18n::gettext('Invalid Rate') )
+				AND
+				$this->Validator->isLength(				'rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits'),
+											0,
+											21) //Need to include decimal.
+				AND
+				$this->Validator->isLengthBeforeDecimal('rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits before the decimal'),
+											0,
+											16)
+				AND
+				$this->Validator->isLengthAfterDecimal(	'rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits after the decimal'),
+											0,
+											4)
+				)
+			) {
 			Debug::text('Setting Rate to: '. $value, __FILE__, __LINE__, __METHOD__,10);
 			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
 			//$this->data['rate'] = Misc::MoneyFormat( $value, FALSE );
@@ -455,15 +478,38 @@ class PayStubAmendmentFactory extends Factory {
 	function setUnits($value) {
 		$value = trim($value);
 
+		//Pull out only digits and periods.
+		$value = $this->Validator->stripNonFloat($value);
+
 		if ($value == 0 OR $value == '') {
 			$value = NULL;
 		}
 
 		if (	empty($value) OR
+				(
 				$this->Validator->isFloat(				'units',
 														$value,
-														TTi18n::gettext('Invalid Units')
-														) ) {
+														TTi18n::gettext('Invalid Units') )
+				AND
+				$this->Validator->isLength(				'units',
+											$value,
+											TTi18n::gettext('Units has too many digits'),
+											0,
+											21) //Need to include decimal
+				AND
+				$this->Validator->isLengthBeforeDecimal('units',
+											$value,
+											TTi18n::gettext('Units has too many digits before the decimal'),
+											0,
+											16)
+				AND
+				$this->Validator->isLengthAfterDecimal(	'units',
+											$value,
+											TTi18n::gettext('Units has too many digits after the decimal'),
+											0,
+											4)
+				)
+			) {
 			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
 			//$this->data['units'] = Misc::MoneyFormat( $value, FALSE );
 			$this->data['units'] = $value;
@@ -587,7 +633,7 @@ class PayStubAmendmentFactory extends Factory {
 
 	function getAmount() {
 		if ( isset($this->data['amount']) ) {
-			return $this->data['amount'];
+			return Misc::removeTrailingZeros( $this->data['amount'], 2);
 		}
 
 		return NULL;
@@ -595,6 +641,9 @@ class PayStubAmendmentFactory extends Factory {
 	function setAmount($value) {
 		$value = trim($value);
 
+		//Pull out only digits and periods.
+		$value = $this->Validator->stripNonFloat($value);
+
 		Debug::text('Amount: '. $value .' Name: '. $this->getPayStubEntryNameId() , __FILE__, __LINE__, __METHOD__,10);
 
 		if ($value == NULL OR $value == '') {
@@ -603,13 +652,31 @@ class PayStubAmendmentFactory extends Factory {
 
 		if (  $this->Validator->isFloat(				'amount',
 														$value,
-														TTi18n::gettext('Invalid Amount')
-														) ) {
-			//$this->data['amount'] = number_format( $value, 2, '.', '');
+														TTi18n::gettext('Invalid Amount') )
+				AND
+				$this->Validator->isLength(				'amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits'),
+											0,
+											21) //Need to include decimal
+				AND
+				$this->Validator->isLengthBeforeDecimal('amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits before the decimal'),
+											0,
+											16)
+				AND
+				$this->Validator->isLengthAfterDecimal(	'amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits after the decimal'),
+											0,
+											4)
+			) {
 			$this->data['amount'] = Misc::MoneyFormat( $value, FALSE );
 
 			return TRUE;
 		}
+
 		return FALSE;
 	}
 
@@ -806,7 +873,7 @@ class PayStubAmendmentFactory extends Factory {
 				AND $this->getRate() != '' AND $this->getUnits() != ''
 				) {
 			Debug::Text('Calculating Amount...', __FILE__, __LINE__, __METHOD__,10);
-			$this->setAmount( bcmul( $this->getRate(), $this->getUnits() ) );
+			$this->setAmount( bcmul( $this->getRate(), $this->getUnits(), 4 ) );
 		}
 
 		return TRUE;
