@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4401 $
- * $Id: PayStubAmendmentListFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
- * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
+ * $Revision: 5289 $
+ * $Id: PayStubAmendmentListFactory.class.php 5289 2011-10-06 19:40:31Z ipso $
+ * $Date: 2011-10-06 12:40:31 -0700 (Thu, 06 Oct 2011) $
  */
 
 /**
@@ -121,6 +121,38 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		return $this;
 	}
 
+	function getByPayStubEntryNameID($psen_id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $psen_id == '') {
+			return FALSE;
+		}
+
+		$strict_order = TRUE;
+		if ( $order == NULL ) {
+			$strict_order = FALSE;
+		}
+
+		$ph = array(
+					'psen_id' => $psen_id,
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					where
+						a.pay_stub_entry_name_id = ?
+						AND a.deleted = 0';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict_order );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getByIdAndCompanyId($id, $company_id, $order = NULL) {
 		if ( $id == '') {
 			return FALSE;
@@ -510,6 +542,8 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 			return FALSE;
 		}
 
+		$psealf = new PayStubEntryAccountListFactory();
+
 		$ph = array(
 					'authorized' => $this->toBool($authorized) ,
 					'start_date' => $start_date,
@@ -520,21 +554,24 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		//Because of percent amounts, make sure we order by effective date FIRST,
 		//Then FIXED amounts, then percents.
 
-
 		//Pay period end dates never equal the start start date, so >= and <= are proper.
 
 		//06-Oct-06: Start including YTD_adjustment entries for the new pay stub calculation system.
 		//						AND ytd_adjustment = 0
+
+		//Make sure we ignore any pay stub amendments that happen to belong to deleted pay stub accounts.
 		$query = '
-					select 	*
-					from	'. $this->getTable() .'
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $psealf->getTable() .' as psea
 					where
-						authorized = ?
-						AND effective_date >= ?
-						AND effective_date <= ?
-						AND user_id in ('.$this->getListSQL($user_id, $ph) .')
-						AND deleted = 0
-					ORDER BY effective_date asc, type_id asc
+						a.pay_stub_entry_name_id = psea.id
+						AND a.authorized = ?
+						AND a.effective_date >= ?
+						AND a.effective_date <= ?
+						AND a.user_id in ('.$this->getListSQL($user_id, $ph) .')
+						AND ( a.deleted = 0 AND psea.deleted = 0 )
+					ORDER BY a.effective_date asc, a.type_id asc
 				';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
