@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: RecurringPayStubAmendmentFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 5457 $
+ * $Id: RecurringPayStubAmendmentFactory.class.php 5457 2011-11-04 20:49:58Z ipso $
+ * $Date: 2011-11-04 13:49:58 -0700 (Fri, 04 Nov 2011) $
  */
 
 /**
@@ -545,10 +545,29 @@ class RecurringPayStubAmendmentFactory extends Factory {
 		}
 
 		if (	empty($value) OR
+				(
 				$this->Validator->isFloat(				'rate',
 														$value,
-														TTi18n::gettext('Invalid Rate')
-														) ) {
+														TTi18n::gettext('Invalid Rate') )
+				AND
+				$this->Validator->isLength(				'rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits'),
+											0,
+											21) //Need to include decimal.
+				AND
+				$this->Validator->isLengthBeforeDecimal('rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits before the decimal'),
+											0,
+											16)
+				AND
+				$this->Validator->isLengthAfterDecimal(	'rate',
+											$value,
+											TTi18n::gettext('Rate has too many digits after the decimal'),
+											0,
+											4)
+				) ) {
 			Debug::text('Setting Rate to: '. $value, __FILE__, __LINE__, __METHOD__,10);
 			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
 			//$this->data['rate'] = Misc::MoneyFormat( $value, FALSE );
@@ -575,10 +594,29 @@ class RecurringPayStubAmendmentFactory extends Factory {
 		}
 
 		if (	empty($value) OR
+				(
 				$this->Validator->isFloat(				'units',
 														$value,
-														TTi18n::gettext('Invalid Units')
-														) ) {
+														TTi18n::gettext('Invalid Units') )
+				AND
+				$this->Validator->isLength(				'units',
+											$value,
+											TTi18n::gettext('Units has too many digits'),
+											0,
+											21) //Need to include decimal
+				AND
+				$this->Validator->isLengthBeforeDecimal('units',
+											$value,
+											TTi18n::gettext('Units has too many digits before the decimal'),
+											0,
+											16)
+				AND
+				$this->Validator->isLengthAfterDecimal(	'units',
+											$value,
+											TTi18n::gettext('Units has too many digits after the decimal'),
+											0,
+											4)
+				) ) {
 			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
 			//$this->data['units'] = Misc::MoneyFormat( $value, FALSE );
 			$this->data['units'] = $value;
@@ -607,13 +645,31 @@ class RecurringPayStubAmendmentFactory extends Factory {
 
 		if (  $this->Validator->isFloat(				'amount',
 														$value,
-														TTi18n::gettext('Invalid Amount')
-														) ) {
-			//$this->data['amount'] = number_format( $value, 2, '.', '');
-			$this->data['amount'] = round( $value, 2);
+														TTi18n::gettext('Invalid Amount') )
+				AND
+				$this->Validator->isLength(				'amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits'),
+											0,
+											21) //Need to include decimal
+				AND
+				$this->Validator->isLengthBeforeDecimal('amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits before the decimal'),
+											0,
+											16)
+				AND
+				$this->Validator->isLengthAfterDecimal(	'amount',
+											$value,
+											TTi18n::gettext('Amount has too many digits after the decimal'),
+											0,
+											4)
+			) {
+			$this->data['amount'] = Misc::MoneyFormat( $value, FALSE );
 
 			return TRUE;
 		}
+
 		return FALSE;
 	}
 
@@ -949,16 +1005,6 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	}
 
 	function preSave() {
-		/*
-		if ( $this->getAmount() != '' ) {
-			$this->setPercentAmount(0);
-		}
-
-		if ( $this->getPercentAmount() != '' ) {
-			$this->setAmount(0);
-		}
-		*/
-
 		if ( $this->getFrequency() == 40 ) {
 			if ( TTDate::getDayOfMonth( $this->getStartDate() ) > 28 ) {
 				Debug::text(' Start Date is After the 28th, making the 28th: ', __FILE__, __LINE__, __METHOD__,10);
@@ -973,7 +1019,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 					AND $this->getRate() != 0 AND $this->getUnits() != 0
 					AND $this->getRate() != '' AND $this->getUnits() != ''
 					) {
-				$this->setAmount( $this->getRate() * $this->getUnits() );
+				$this->setAmount( bcmul( $this->getRate(), $this->getUnits(), 4 ) );
 			}
 		}
 
