@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: PayPeriodFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5891 $
+ * $Id: PayPeriodFactory.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -73,6 +73,7 @@ class PayPeriodFactory extends Factory {
 
 										'-1500-total_punches' => TTi18n::gettext('Punches'),
 										'-1505-pending_requests' => TTi18n::gettext('Pending Requests'),
+										'-1510-exceptions_critical' => TTi18n::gettext('Critical'),
 										'-1510-exceptions_high' => TTi18n::gettext('High'),
 										'-1512-exceptions_medium' => TTi18n::gettext('Medium'),
 										'-1514-exceptions_low' => TTi18n::gettext('Low'),
@@ -140,6 +141,7 @@ class PayPeriodFactory extends Factory {
 
 											'total_punches' => 'TotalPunches',
 											'pending_requests' => 'PendingRequests',
+											'exceptions_critical' => 'Exceptions',
 											'exceptions_high' => 'Exceptions',
 											'exceptions_medium' => 'Exceptions',
 											'exceptions_low' => 'Exceptions',
@@ -297,6 +299,33 @@ class PayPeriodFactory extends Factory {
 		return FALSE;
 	}
 
+	function getPayPeriodDates( $filter_start_date = NULL, $filter_end_date = NULL, $include_pay_period_id = FALSE ) {
+		//Debug::Text('Start Date: '. TTDate::getDate('DATE', $this->getStartDate()) .' End Date: '. TTDate::getDate('DATE', $this->getEndDate()) .' Filter: Start: '. TTDate::getDate('DATE', $filter_start_date ) .' End: '. TTDate::getDate('DATE', $filter_end_date), __FILE__, __LINE__, __METHOD__,10);
+		if ( $this->getStartDate() > 0 AND $this->getEndDate() > 0 ) {
+
+			for( $i = (int)$this->getStartDate(); $i <= (int)$this->getEndDate(); $i += 93600) {
+				$i = TTDate::getBeginDayEpoch($i);
+
+				if ( ( $filter_start_date == '' OR $filter_start_date <= $i )
+						AND ( $filter_end_date == '' OR $filter_end_date >= $i ) ) {
+					if ( $include_pay_period_id == TRUE ) {
+						$retarr[TTDate::getAPIDate('DATE', $i)] = $this->getID();
+					} else {
+						$retarr[] = TTDate::getAPIDate('DATE', $i);
+					}
+				} else {
+					Debug::Text('Filter didnt match!', __FILE__, __LINE__, __METHOD__,10);
+				}
+			}
+
+			//Debug::Arr($retarr, 'Pay Period Dates: ', __FILE__, __LINE__, __METHOD__,10);
+
+			return $retarr;
+		}
+
+		return FALSE;
+	}
+
 	function getStartDate( $raw = FALSE ) {
 		if ( isset($this->data['start_date']) ) {
 			if ( $raw === TRUE ) {
@@ -564,15 +593,14 @@ class PayPeriodFactory extends Factory {
 	}
 	function getTimeSheetVerifyWindowStartDate() {
 		if ( is_object( $this->getPayPeriodScheduleObject() ) ) {
-			return (int)$this->getEndDate()-( (int)$this->getPayPeriodScheduleObject()->getTimeSheetVerifyBeforeEndDate()*86400);
+			return (int)$this->getEndDate()-( $this->getPayPeriodScheduleObject()->getTimeSheetVerifyBeforeEndDate()*86400 );
 		}
 
 		return $this->getEndDate();
 	}
 	function getTimeSheetVerifyWindowEndDate() {
 		if ( is_object( $this->getPayPeriodScheduleObject() ) ) {
-			//FIXME: Make this end at midnight, otherwise it defaults to noon. Allow float values for this perhaps, like 2.5days?
-			return (int)$this->getTransactionDate()-( (int)$this->getPayPeriodScheduleObject()->getTimeSheetVerifyBeforeTransactionDate()*86400);
+			return (int)$this->getTransactionDate()-( $this->getPayPeriodScheduleObject()->getTimeSheetVerifyBeforeTransactionDate()*86400 );
 		}
 
 		return $this->getTransactionDate();
@@ -710,6 +738,7 @@ class PayPeriodFactory extends Factory {
 						'exceptions_low' => 0,
 						'exceptions_medium' => 0,
 						'exceptions_high' => 0,
+						'exceptions_critical' => 0,
 						);
 
 		$elf = TTnew( 'ExceptionListFactory' );
@@ -723,10 +752,12 @@ class PayPeriodFactory extends Factory {
 				if ( $e_obj->getColumn('severity_id') == 20 ) {
 					$retarr['exceptions_medium'] = $e_obj->getColumn('count');
 				}
-				if ( $e_obj->getColumn('severity_id') == 30 ) {
+				if ( $e_obj->getColumn('severity_id') == 25 ) {
 					$retarr['exceptions_high']= $e_obj->getColumn('count');
 				}
-
+				if ( $e_obj->getColumn('severity_id') == 30 ) {
+					$retarr['exceptions_critical']= $e_obj->getColumn('count');
+				}
 			}
 		} else {
 			//Debug::Text(' No Exceptions!', __FILE__, __LINE__, __METHOD__,10);
@@ -755,7 +786,8 @@ class PayPeriodFactory extends Factory {
 		$pptsvlf->getByPayPeriodIdAndCompanyId( $this->getID(), $this->getCompany() );
 		if ( $pptsvlf->getRecordCount() > 0 ) {
 			foreach( $pptsvlf as $pptsv_obj ) {
-				if ( $pptsv_obj->getAuthorized() == TRUE ) {
+				//Status is the critical thing to check here due to supervisors authorizing the timesheets before employees.
+				if ( $pptsv_obj->getStatus() == 50 ) {
 					$retarr['verified_timesheets']++;
 				} elseif (  $pptsv_obj->getStatus() == 30 OR $pptsv_obj->getStatus() == 45 ) {
 					$retarr['pending_timesheets']++;
@@ -816,7 +848,7 @@ class PayPeriodFactory extends Factory {
 
 		}
 
-		//Make sure if this a monthly+advanc pay period, advance dates are set.
+		//Make sure if this a monthly+advance pay period, advance dates are set.
         $ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$ppslf->getById( $this->getPayPeriodSchedule() );
 		if ( $ppslf->getRecordCount() == 1 AND is_object($ppslf) ) {
@@ -832,11 +864,13 @@ class PayPeriodFactory extends Factory {
 												FALSE,
 												TTi18n::gettext('Advance transaction date is set') );
 			}
-		} elseif ( $this->getPayPeriodSchedule() == '' ) { // Used to be != for some reason?
+		} elseif ( $this->getStartDate() != '' AND $this->getPayPeriodSchedule() == '' ) {
+			//When mass editing pay periods, we try to validate with no pay period schedule set because it could be editing across multiple pay period schedules.
+			//In this case ignore this check.
 			Debug::text('Pay Period Schedule not found: '. $this->getPayPeriodSchedule(), __FILE__, __LINE__, __METHOD__, 10);
 			$this->Validator->isTrue(		'pay_period_schedule_id',
 											FALSE,
-											TTi18n::gettext('Incorrect Pay Period Schedule') );
+											TTi18n::gettext('Please choose a Pay Period Schedule') );
 		}
 
 		return TRUE;
@@ -960,6 +994,7 @@ class PayPeriodFactory extends Factory {
 								$data[$variable] = $this->$function();
 							}
 							break;
+						case 'exceptions_critical':
 						case 'exceptions_high':
 						case 'exceptions_medium':
 						case 'exceptions_low':
