@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4669 $
- * $Id: PayPeriodListFactory.class.php 4669 2011-05-13 19:30:08Z ipso $
- * $Date: 2011-05-13 12:30:08 -0700 (Fri, 13 May 2011) $
+ * $Revision: 6071 $
+ * $Id: PayPeriodListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -302,6 +302,47 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 		return $this;
 	}
 
+	function getByCompanyIdAndStatusAndTransactionDate($company_id, $status_ids, $transaction_date, $where = NULL, $order = NULL) {
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $status_ids == '' ) {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'a.transaction_date' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$ppsf = new PayPeriodScheduleFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'transaction_date' => $this->db->BindTimeStamp( $transaction_date ),
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $ppsf->getTable() .' as b
+
+					where 	a.pay_period_schedule_id = b.id
+						AND a.company_id = ?
+						AND a.transaction_date <= ?
+						AND a.status_id in ( '. $this->getListSQL($status_ids, $ph) .' )
+						AND ( a.deleted=0 AND b.deleted=0 )
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
 
 	function getByIdAndCompanyId($id, $company_id, $where = NULL, $order = NULL) {
 		if ( $id == '' ) {
@@ -518,6 +559,57 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 		return $this;
 	}
 
+	//Gets all pay periods that start or end between the two dates. Ideal for finding all pay periods that affect a given week.
+	function getByUserIdAndOverlapStartDateAndEndDate($user_id, $start_date, $end_date, $where = NULL, $order = NULL) {
+		if ( $user_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $end_date == '' ) {
+			return FALSE;
+		}
+
+		$ppsuf = new PayPeriodScheduleUserFactory();
+		$ppsf = new PayPeriodScheduleFactory();
+
+		$ph = array(
+					'user_id' => $user_id,
+					'start_date' => $this->db->BindTimeStamp( $start_date ),
+					'end_date' => $this->db->BindTimeStamp( $end_date ),
+					'start_date2' => $this->db->BindTimeStamp( $start_date ),
+					'end_date2' => $this->db->BindTimeStamp( $end_date ),
+					'start_date3' => $this->db->BindTimeStamp( $start_date ),
+					'end_date3' => $this->db->BindTimeStamp( $end_date ),
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $ppsf->getTable() .' as b,
+							'. $ppsuf->getTable() .' as c
+
+					where	a.pay_period_schedule_id = b.id
+						AND a.pay_period_schedule_id = c.pay_period_schedule_id
+						AND	c.user_id = ?
+						AND
+						(
+							( a.start_date >= ? AND a.start_date <= ? )
+							OR
+							( a.end_date >= ? AND a.end_date <= ? )
+							OR
+							( a.start_date <= ? AND a.end_date >= ? )
+						)
+						AND ( a.deleted=0 AND b.deleted=0 )';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		//Debug::Arr($ph, 'Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByUserIdAndEndDate($user_id, $end_date, $where = NULL, $order = NULL) {
 		if ( $user_id == '' ) {
 			return FALSE;
@@ -1236,7 +1328,7 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 		} else {
 			//Always try to order by status first so INACTIVE employees go to the bottom.
 			if ( !isset($order['transaction_date']) ) {
-				$order = Misc::prependArray( array('transaction_date' => 'desc'), $order );
+				$order['transaction_date'] = 'desc';
 			}
 			$strict = TRUE;
 		}
@@ -1268,6 +1360,26 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 					where	a.company_id = ?
 					';
 
+		$query .= ( isset($filter_data['permission_children_ids']) ) ? $this->getWhereClauseSQL( 'a.created_by', $filter_data['permission_children_ids'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['exclude_id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['exclude_id'], 'not_numeric_list', $ph ) : NULL;
+
+		if ( isset($filter_data['status']) AND trim($filter_data['status']) != '' AND !isset($filter_data['status_id']) ) {
+			$filter_data['status_id'] = Option::getByFuzzyValue( $filter_data['status'], $this->getOptions('status') );
+		}
+		$query .= ( isset($filter_data['status_id']) ) ? $this->getWhereClauseSQL( 'a.status_id', $filter_data['status_id'], 'numeric_list', $ph ) : NULL;
+
+		if ( isset($filter_data['type']) AND trim($filter_data['type']) != '' AND !isset($filter_data['type_id']) ) {
+			$filter_data['type_id'] = Option::getByFuzzyValue( $filter_data['type'], $ppsf->getOptions('type') );
+		}
+		$query .= ( isset($filter_data['type_id']) ) ? $this->getWhereClauseSQL( 'b.type_id', $filter_data['type_id'], 'numeric_list', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['pay_period_schedule_id']) ) ? $this->getWhereClauseSQL( 'a.pay_period_schedule_id', $filter_data['pay_period_schedule_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['pay_period_schedule']) ) ? $this->getWhereClauseSQL( 'b.name', $filter_data['pay_period_schedule'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['name']) ) ? $this->getWhereClauseSQL( 'b.name', $filter_data['name'], 'text', $ph ) : NULL;
+
+
+/*
 		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
 		}
@@ -1292,7 +1404,7 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 			$ph[] = strtolower(trim($filter_data['name']));
 			$query  .=	' AND lower(b.name) LIKE ?';
 		}
-
+*/
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
 			$ph[] = $this->db->BindTimeStamp($filter_data['start_date']);
 			$query  .=	' AND a.start_date >= ?';
