@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4556 $
- * $Id: PayPeriodScheduleFactory.class.php 4556 2011-04-20 23:27:04Z ipso $
- * $Date: 2011-04-20 16:27:04 -0700 (Wed, 20 Apr 2011) $
+ * $Revision: 5749 $
+ * $Id: PayPeriodScheduleFactory.class.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 
 /**
@@ -113,11 +113,12 @@ class PayPeriodScheduleFactory extends Factory {
 										'-1010-type' => TTi18n::gettext('Type'),
 										'-1020-name' => TTi18n::gettext('Name'),
 										'-1030-description' => TTi18n::gettext('Description'),
-										'-1030-start_week_day' => TTi18n::gettext('Overtime Week'),
-										'-1040-shift_assigned_day' => TTi18n::gettext('Assign Shifts To'),
-										'-1050-time_zone' => TTi18n::gettext('TimeZone'),
-										'-1060-new_day_trigger_time' => TTi18n::gettext('Minimum Time Off Between Shifts'),
-										'-1070-maximum_shift_time' => TTi18n::gettext('Maximum Shift Time'),
+										'-1040-total_users' => TTi18n::gettext('Employees'),
+										'-1050-start_week_day' => TTi18n::gettext('Overtime Week'),
+										'-1060-shift_assigned_day' => TTi18n::gettext('Assign Shifts To'),
+										'-1070-time_zone' => TTi18n::gettext('TimeZone'),
+										'-1080-new_day_trigger_time' => TTi18n::gettext('Minimum Time Off Between Shifts'),
+										'-1090-maximum_shift_time' => TTi18n::gettext('Maximum Shift Time'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -133,6 +134,7 @@ class PayPeriodScheduleFactory extends Factory {
 								'type',
 								'name',
 								'description',
+								'total_users',
 								);
 				break;
 
@@ -172,8 +174,10 @@ class PayPeriodScheduleFactory extends Factory {
 										'timesheet_verify_type_id' => 'TimeSheetVerifyType',
 										'timesheet_verify_before_end_date' => 'TimeSheetVerifyBeforeEndDate',
 										'timesheet_verify_before_transaction_date' => 'TimeSheetVerifyBeforeTransactionDate',
+										//TimeSheet verification email notices are no longer required, as its handled with exceptions now.
 										//'timesheet_verify_notice_before_transaction_date' => 'TimeSheetVerifyNoticeBeforeTransactionDate',
 										//'timesheet_verify_notice_email' => 'TimeSheetVerifyNoticeEmail',
+										'total_users' => FALSE,
 										'user' => 'User',
 										'deleted' => 'Deleted',
 										);
@@ -757,17 +761,17 @@ class PayPeriodScheduleFactory extends Factory {
 
 	function getTimeSheetVerifyBeforeEndDate() {
 		if ( isset($this->data['timesheet_verify_before_end_date']) ) {
-			return (int)$this->data['timesheet_verify_before_end_date'];
+			return Misc::removeTrailingZeros( round( TTDate::getDays( (int)$this->data['timesheet_verify_before_end_date'] ), 3 ), 0 );
 		}
 		return FALSE;
 	}
 	function setTimeSheetVerifyBeforeEndDate($int) {
-		$int = (int)$int;
+		//$int = (int)$int; // Do not cast to INT, need to support partial days.
 
 		if 	(	$this->Validator->isNumeric(		'timesheet_verify_before_end_date',
 													$int,
 													TTi18n::gettext('Incorrect value for timesheet verification before/after end date')) ) {
-			$this->data['timesheet_verify_before_end_date'] = $int;
+			$this->data['timesheet_verify_before_end_date'] = ($int*86400);
 
 			return TRUE;
 		}
@@ -777,17 +781,17 @@ class PayPeriodScheduleFactory extends Factory {
 
 	function getTimeSheetVerifyBeforeTransactionDate() {
 		if ( isset($this->data['timesheet_verify_before_transaction_date']) ) {
-			return (int)$this->data['timesheet_verify_before_transaction_date'];
+			return Misc::removeTrailingZeros( round( TTDate::getDays( (int)$this->data['timesheet_verify_before_transaction_date'] ), 3 ), 0 );
 		}
 		return FALSE;
 	}
 	function setTimeSheetVerifyBeforeTransactionDate($int) {
-		$int = (int)$int;
+		//$int = $int; // Do not cast to INT, need to support partial days.
 
 		if 	(	$this->Validator->isNumeric(		'timesheet_verify_before_transaction_date',
 													$int,
 													TTi18n::gettext('Incorrect value for timesheet verification before/after transaction date')) ) {
-			$this->data['timesheet_verify_before_transaction_date'] = $int;
+			$this->data['timesheet_verify_before_transaction_date'] = ($int*86400); //Convert to seconds to support partial days. Do not cast to INT!
 
 			return TRUE;
 		}
@@ -795,6 +799,7 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 
+	//Notices are no longer required with TimeSheet not verified exception.
 	function getTimeSheetVerifyNoticeBeforeTransactionDate() {
 		if ( isset($this->data['timesheet_verify_notice_before_transaction_date']) ) {
 			return (int)$this->data['timesheet_verify_notice_before_transaction_date'];
@@ -1460,15 +1465,34 @@ class PayPeriodScheduleFactory extends Factory {
 				//punches in a pair, the remaining punch is ignored and causing punches to jump around between days in some cases.
 				if ( $i > 0 AND isset($shift_data[$shift]['last_out'])
 						AND ( $p_obj->getStatus() == 10 OR $p_obj->getStatus() == $prev_punch_arr['status_id'] )) {
-					//Debug::text('Checking for new shift... This Control ID: '.$p_obj->getPunchControlID() .' Last Out Control ID: '. $shift_data[$shift]['last_out']['punch_control_id'] , __FILE__, __LINE__, __METHOD__, 10);
+					Debug::text('Checking for new shift... This Control ID: '.$p_obj->getPunchControlID() .' Last Out Control ID: '. $shift_data[$shift]['last_out']['punch_control_id'] .' Last Out Time: '. TTDate::getDate('DATE+TIME', $shift_data[$shift]['last_out']['time_stamp']), __FILE__, __LINE__, __METHOD__, 10);
 					//Assume that if two punches are assigned to the same punch_control_id are the same shift, even if the time between
 					//them exceeds the new_shift_trigger_time. This helps fix the bug where you could add a In punch then add a Out
 					//punch BEFORE the In punch as long as it was more than the Maximum Shift Time before the In Punch.
 					//ie: Add: In Punch 10-Dec-09 @ 8:00AM, Add: Out Punch 09-Dec-09 @ 5:00PM.
 					//Basically it just helps the validation checks to determine the error.
-					//If shifts are split at midnight, new_shift_trigger_time must be 0, so the "split" punch can occur at midnight.
+					//
+					//It used to be that if shifts are split at midnight, new_shift_trigger_time must be 0, so the "split" punch can occur at midnight.
+					//However we have since added a check to see if punches span midnight and trigger a new shift based on that, regardless of the new shift trigger time.
+					//As the new_shift_trigger_time of 0 also affected lunch/break automatic detection by Punch Time, since an Out punch and a In punch of any time
+					//would trigger a new shift, and it wouldn't be detected as lunch/break.
+					//
+					//What happens when the employee takes lunch/break over midnight? Lunch out at 11:30PM Lunch IN at 12:30AM
+					//  We need to split those into two lunches, or two breaks? But then that can affect those policies if they are only allowed one break.
+					// 	Or do we not split the shift at all when this occurs? Currently we don't split at all.
 					if ( $p_obj->getPunchControlID() != $shift_data[$shift]['last_out']['punch_control_id']
-							AND ( $p_obj->getTimeStamp() - $shift_data[$shift]['last_out']['time_stamp']) >= $new_shift_trigger_time ) {
+							AND (
+									( $p_obj->getTimeStamp() - $shift_data[$shift]['last_out']['time_stamp'] ) >= $new_shift_trigger_time
+									OR
+									(
+										$this->getShiftAssignedDay() == 40
+										//Only split shifts on NORMAL punches.
+										AND $p_obj->getType() == 10
+										AND $shift_data[$shift]['last_out']['type_id'] == 10
+										AND TTDate::doesRangeSpanMidnight( $shift_data[$shift]['last_out']['time_stamp'], $p_obj->getTimeStamp(), TRUE ) == TRUE
+									)
+								)
+							) {
 						$shift++;
 					}
 				}
@@ -1531,7 +1555,7 @@ class PayPeriodScheduleFactory extends Factory {
 					if ( isset($prev_punch_arr) AND is_array($prev_punch_arr)
 							AND ( $p_obj->getStatus() == 20 AND $prev_punch_arr['status_id'] != 20 )
 							AND TTDate::doesRangeSpanMidnight( $prev_punch_arr['time_stamp'], $p_obj->getTimeStamp() ) == TRUE ) {
-						Debug::text('Punch pair DOES span midnight', __FILE__, __LINE__, __METHOD__, 10);
+						Debug::text('Punch PAIR DOES span midnight', __FILE__, __LINE__, __METHOD__, 10);
 						$shift_data[$shift]['span_midnight'] = TRUE;
 
 						$total_time_for_each_day_arr = TTDate::calculateTimeOnEachDayBetweenRange( $prev_punch_arr['time_stamp'], $p_obj->getTimeStamp() );
@@ -1656,7 +1680,8 @@ class PayPeriodScheduleFactory extends Factory {
 		if ( $this->getShiftAssignedDay() == FALSE ) {
 			$this->setShiftAssignedDay( 10 ); //Day shifts start on
 		} elseif ( $this->getShiftAssignedDay() == 40 ) { //Split at midnight
-			$this->setNewDayTriggerTime( 0 ); //Minimum Time-off between shifts must be 0 in these cases.
+			//We now support a minimum time-off setting when shifts are set to split at midnight.
+			//$this->setNewDayTriggerTime( 0 ); //Minimum Time-off between shifts must be 0 in these cases.
 		}
 
 		if ( $this->getType() != 5 ) { //If schedule is other then manual, automatically calculate annual pay periods
@@ -1707,6 +1732,20 @@ class PayPeriodScheduleFactory extends Factory {
 			}
 		}
 
+		if ( $this->getDeleted() == TRUE ) {
+			//Remove from User Defaults.
+			$udlf = TTnew( 'UserDefaultListFactory' );
+			$udlf->getByCompanyId( $this->getCompany() );
+			if ( $udlf->getRecordCount() > 0 ) {
+				foreach( $udlf as $udf_obj ) {
+					$udf_obj->setPayPeriodSchedule( 0 );
+					if ( $udf_obj->isValid() ) {
+						$udf_obj->Save();
+					}
+				}
+			}
+		}
+
 		$this->CommitTransaction();
 
 		return TRUE;
@@ -1763,6 +1802,9 @@ class PayPeriodScheduleFactory extends Factory {
 
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
+						case 'total_users':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
 						case 'type':
 							$function = 'get'.$variable;
 							if ( method_exists( $this, $function ) ) {
