@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4531 $
- * $Id: PayPeriodTimeSheetVerifyFactory.class.php 4531 2011-04-15 01:35:07Z ipso $
- * $Date: 2011-04-14 18:35:07 -0700 (Thu, 14 Apr 2011) $
+ * $Revision: 5749 $
+ * $Id: PayPeriodTimeSheetVerifyFactory.class.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 
 /**
@@ -348,6 +348,11 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 		return FALSE;
 	}
 
+	//Returns the start and end date of the verification window.
+	function getVerificationWindowDates() {
+		return array( 'start' => $this->getPayPeriodObject()->getTimeSheetVerifyWindowStartDate(), 'end' => $this->getPayPeriodObject()->getTimeSheetVerifyWindowEndDate() );
+	}
+
 	//Determines the color of the verification box.
 	function getVerificationBoxColor() {
 		$retval = FALSE;
@@ -395,7 +400,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 				if ( $pay_period_verify_type_id == 20 OR $pay_period_verify_type_id == 40 ) {
 					$retval = Option::getByKey( 45, $this->getOptions('status') ); //Pending employee verification.
 				} else {
-					$retval = Option::getByKey( 30, $this->getOptions('status') ); //Pending employee verification.
+					$retval = Option::getByKey( 30, $this->getOptions('status') ); //Pending authorization.
 				}
 			} elseif ( $this->isNew() == TRUE ) {
 				//Use Default: Not Verified
@@ -672,7 +677,9 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 		if ( $time_sheet_verification_type_id > 10 ) { //10 = Disabled
 
 			$authorize_timesheet = FALSE;
-			if ( $time_sheet_verification_type_id == 30 ) { //Superior Only
+			if ( $time_sheet_verification_type_id == 20 ) { //Employee Only
+				$authorize_timesheet = TRUE;
+			} elseif ( $time_sheet_verification_type_id == 30 ) { //Superior Only
 				if ( $this->getStatus() == 30 AND $this->getCurrentUser() != FALSE ) { //Check on CurrentUser so we don't loop indefinitely through AuthorizationFactory.
 					Debug::Text(' aAuthorizing TimeSheet as superior...', __FILE__, __LINE__, __METHOD__,10);
 					$authorize_timesheet = TRUE;
@@ -692,7 +699,22 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 				if ( $af->isValid() ) {
 					$af->Save();
 				}
+
+				//Recalculate exceptions on the last day of pay period to remove any TimeSheet Not Verified exceptions.
+				//Get user_date_id.
+				if ( is_object( $this->getPayPeriodObject() ) ) {
+					$udlf = new UserDateListFactory();
+					$udlf->getByUserIdAndDate( $this->getUser(), $this->getPayPeriodObject()->getEndDate() );
+					if ( $udlf->getRecordCount() > 0 ) {
+						Debug::Text('Recalculating exceptions on last day of pay period...', __FILE__, __LINE__, __METHOD__,10);
+						ExceptionPolicyFactory::calcExceptions( $udlf->getCurrent()->getID(), FALSE, FALSE );
+					}
+				} else {
+					Debug::Text('No Pay Period found...', __FILE__, __LINE__, __METHOD__,10);
+				}
 			}
+		} else {
+			Debug::Text('TimeSheet Verification is disabled...', __FILE__, __LINE__, __METHOD__,10);
 		}
 
 		return TRUE;
@@ -768,7 +790,8 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('TimeSheet Verify'), NULL, $this->getTable() );
+		//Should the object_id be the pay period ID instead, that way its easier to find the audit logs?
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('TimeSheet Verify').' - '. TTi18n::getText('Employee') .': '. UserListFactory::getFullNameById( $this->getUser() ) .' '. TTi18n::getText('Pay Period') .': '.  TTDate::getDate('DATE', $this->getPayPeriodObject()->getStartDate() ) .' -> '. TTDate::getDate('DATE', $this->getPayPeriodObject()->getEndDate() ), NULL, $this->getTable() );
 	}
 }
 ?>
