@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: AccrualPolicyFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 6071 $
+ * $Id: AccrualPolicyFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -602,17 +602,21 @@ class AccrualPolicyFactory extends Factory {
 		return $retval;
 	}
 
-	function getWorkedTimeByUserIdAndEndDate( $user_id, $end_date = NULL ) {
+	function getWorkedTimeByUserIdAndEndDate( $user_id, $start_date = NULL, $end_date = NULL ) {
 		if ( $user_id == '' ) {
 			return FALSE;
 		}
 
+		if ( $start_date == '' ) {
+			$start_date = 1; //Default to beginning of time if hire date is not specified.
+		}
+
 		if ( $end_date == '' ) {
 			return FALSE;
 		}
 
 		$udtlf = TTnew( 'UserDateTotalListFactory' );
-		$retval = $udtlf->getWorkedTimeSumByUserIDAndStartDateAndEndDate( $user_id, 1, $end_date );
+		$retval = $udtlf->getWorkedTimeSumByUserIDAndStartDateAndEndDate( $user_id, $start_date, $end_date );
 
 		Debug::Text('Worked Seconds: '. (int)$retval .' Before: '. TTDate::getDate('DATE+TIME', $end_date), __FILE__, __LINE__, __METHOD__,10);
 
@@ -638,12 +642,12 @@ class AccrualPolicyFactory extends Factory {
 			$length_of_service_days = NULL;
 
 			foreach( $apmlf as $apm_obj ) {
-				if ( $apm_obj->getLengthOfServiceUnit() == 50 ) {
+				if ( $apm_obj->getLengthOfServiceUnit() == 50 AND $apm_obj->getLengthOfService() > 0 ) {
 					Debug::Text('&nbsp;&nbsp;MileStone is in Hours...', __FILE__, __LINE__, __METHOD__,10);
 					//Hour based
 					if ( $worked_time == NULL ) {
 						//Get users worked time.
-						$worked_time = TTDate::getHours( $this->getWorkedTimeByUserIdAndEndDate( $u_obj->getId(), $epoch ) );
+						$worked_time = TTDate::getHours( $this->getWorkedTimeByUserIdAndEndDate( $u_obj->getId(), $u_obj->getHireDate(), $epoch ) );
 						Debug::Text('&nbsp;&nbsp;Worked Time: '. $worked_time .'hrs', __FILE__, __LINE__, __METHOD__,10);
 					}
 
@@ -918,7 +922,7 @@ class AccrualPolicyFactory extends Factory {
 
 	function Validate() {
 		if ( $this->getDeleted() == TRUE ){
-			//Check to make sure there are no hours using this OT policy.
+			//Check to make sure there are no hours using this accrual policy.
 			$alf = TTnew( 'AccrualListFactory' );
 			$alf->getByAccrualPolicyId( $this->getId() );
 			if ( $alf->getRecordCount() > 0 ) {
