@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4265 $
- * $Id: AccrualPolicyMilestoneFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
- * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
+ * $Revision: 4897 $
+ * $Id: AccrualPolicyMilestoneFactory.class.php 4897 2011-06-29 00:29:58Z ipso $
+ * $Date: 2011-06-28 17:29:58 -0700 (Tue, 28 Jun 2011) $
  */
 
 /**
@@ -76,6 +76,7 @@ class AccrualPolicyMilestoneFactory extends Factory {
 										'-1020-length_of_service_unit' => TTi18n::gettext('Units'),
 										'-1030-accrual_rate' => TTi18n::gettext('Accrual Rate'),
 										'-1050-maximum_time' => TTi18n::gettext('Maximum Time'),
+										'-1050-rollover_time' => TTi18n::gettext('Rollover Time'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -91,7 +92,8 @@ class AccrualPolicyMilestoneFactory extends Factory {
 								'length_of_service',
 								'length_of_service_unit',
 								'accrual_rate',
-								'maximum_time'
+								'maximum_time',
+								'rollover_time',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -117,6 +119,7 @@ class AccrualPolicyMilestoneFactory extends Factory {
 											'accrual_rate' => 'AccrualRate',
 											'maximum_time' => 'MaximumTime',
 											'minimum_time' => 'MinimumTime',
+											'rollover_time' => 'RolloverTime',
 											'deleted' => 'Deleted',
 											);
 			return $variable_function_map;
