@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4401 $
- * $Id: HolidayPolicyFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
- * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
+ * $Revision: 5610 $
+ * $Id: HolidayPolicyFactory.class.php 5610 2011-11-24 18:25:21Z ipso $
+ * $Date: 2011-11-24 10:25:21 -0800 (Thu, 24 Nov 2011) $
  */
 
 /**
@@ -129,11 +129,12 @@ class HolidayPolicyFactory extends Factory {
 										'minimum_worked_after_days' => 'MinimumWorkedAfterDays',
 										'worked_after_scheduled_days' => 'WorkedAfterScheduledDays',
 										'average_time_days' => 'AverageTimeDays',
+										'average_days' => 'AverageDays',
 										'average_time_worked_days' => 'AverageTimeWorkedDays',
 										'minimum_time' => 'MinimumTime',
 										'maximum_time' => 'MaximumTime',
 										'round_interval_policy_id' => 'RoundIntervalPolicyID',
-										'time' => 'Time',
+										//'time' => 'Time',
 										'paid_absence_as_worked' => 'PaidAbsenceAsWorked',
 										'force_over_time_policy' => 'ForceOverTimePolicy',
 										'include_over_time' => 'IncludeOverTime',
@@ -482,7 +483,7 @@ class HolidayPolicyFactory extends Factory {
 
 		if 	(	$this->Validator->isNumeric(		'average_time_days',
 													$int,
-													TTi18n::gettext('Incorrect Days to Average over')) ) {
+													TTi18n::gettext('Incorrect Days to Total Time over')) ) {
 			$this->data['average_time_days'] = $int;
 
 			return TRUE;
@@ -491,15 +492,41 @@ class HolidayPolicyFactory extends Factory {
 		return FALSE;
 	}
 
+	//This is the divisor in the time averaging formula, as some provinces total time over 30 days and divide by 20 days.
+	function getAverageDays() {
+		if ( isset($this->data['average_days']) ) {
+			return (int)$this->data['average_days'];
+		}
+
+		return FALSE;
+	}
+	function setAverageDays($int) {
+		$int = trim($int);
+
+		if  ( empty($int) ){
+			$int = 0;
+		}
+
+		if 	(	$this->Validator->isNumeric(		'average_days',
+													$int,
+													TTi18n::gettext('Incorrect Days to Average Time over')) ) {
+			$this->data['average_days'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	//If true, uses only worked days to average time over.
-	//If false, always uses the average time days to average time over.
+	//If false, always uses the above average days to average time over.
 	function getAverageTimeWorkedDays() {
 		return $this->fromBool( $this->data['average_time_worked_days'] );
 	}
 	function setAverageTimeWorkedDays($bool) {
 		$this->data['average_time_worked_days'] = $this->toBool($bool);
 
-		return true;
+		return TRUE;
 	}
 
 	function getMinimumTime() {
@@ -582,7 +609,7 @@ class HolidayPolicyFactory extends Factory {
 
 		return FALSE;
 	}
-
+/*
 	function getTime() {
 		if ( isset($this->data['time']) ) {
 			return (int)$this->data['time'];
@@ -607,7 +634,7 @@ class HolidayPolicyFactory extends Factory {
 
 		return FALSE;
 	}
-
+*/
 	//Count all paid absence time as worked time.
 	function getPaidAbsenceAsWorked() {
 		return $this->fromBool( $this->data['paid_absence_as_worked'] );
