@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4401 $
- * $Id: MealPolicyFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
- * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
+ * $Revision: 5477 $
+ * $Id: MealPolicyFactory.class.php 5477 2011-11-08 19:55:40Z ipso $
+ * $Date: 2011-11-08 11:55:40 -0800 (Tue, 08 Nov 2011) $
  */
 
 /**
@@ -441,6 +441,9 @@ class MealPolicyFactory extends Factory {
 	}
 
 	function preSave() {
+		if ( $this->getAutoDetectType() == FALSE ) {
+			$this->setAutoDetectType( 10 );
+		}
 		return TRUE;
 	}
 
