@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4401 $
- * $Id: OverTimePolicyFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
- * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
+ * $Revision: 5132 $
+ * $Id: OverTimePolicyFactory.class.php 5132 2011-08-16 22:53:12Z ipso $
+ * $Date: 2011-08-16 15:53:12 -0700 (Tue, 16 Aug 2011) $
  */
 
 /**
@@ -63,7 +63,7 @@ class OverTimePolicyFactory extends Factory {
 				$retval = array(
 										10 => TTi18n::gettext('Daily'),
 										20 => TTi18n::gettext('Weekly'),
-//										30 => TTi18n::gettext('Bi-Weekly'), //If we do this, we will need to recalculate two weeks ahead, instead of just one.
+										30 => TTi18n::gettext('Bi-Weekly'), //Need to recalculate two weeks ahead, instead of just one.
 										40 => TTi18n::gettext('Sunday'),
 										50 => TTi18n::gettext('Monday'),
 										60 => TTi18n::gettext('Tuesday'),
@@ -86,6 +86,7 @@ class OverTimePolicyFactory extends Factory {
 				$retval = array(
 										10 => 90, //Daily
 										20 => 200, //Weekly
+										30 => 300, //Bi-Weekly
 										40 => 20, //Sunday
 										50 => 30, //Monday
 										60 => 40, //Tuesday
