@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4455 $
- * $Id: PolicyGroupFactory.class.php 4455 2011-03-28 19:18:22Z ipso $
- * $Date: 2011-03-28 12:18:22 -0700 (Mon, 28 Mar 2011) $
+ * $Revision: 4925 $
+ * $Id: PolicyGroupFactory.class.php 4925 2011-07-04 18:43:18Z ipso $
+ * $Date: 2011-07-04 11:43:18 -0700 (Mon, 04 Jul 2011) $
  */
 
 /**
@@ -55,7 +55,7 @@ class PolicyGroupFactory extends Factory {
 			case 'columns':
 				$retval = array(
 										'-1000-name' => TTi18n::gettext('Name'),
-										'-1100-total_users' => TTi18n::gettext('Assigned Employees'),
+										'-1100-total_users' => TTi18n::gettext('Employees'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -369,7 +369,6 @@ class PolicyGroupFactory extends Factory {
 		return FALSE;
 	}
 
-
 	function getObjectAsArray( $include_columns = NULL ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
