@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4401 $
- * $Id: PolicyGroupListFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
- * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
+ * $Revision: 5335 $
+ * $Id: PolicyGroupListFactory.class.php 5335 2011-10-18 00:32:47Z ipso $
+ * $Date: 2011-10-17 17:32:47 -0700 (Mon, 17 Oct 2011) $
  */
 
 /**
@@ -309,6 +309,26 @@ class PolicyGroupListFactory extends PolicyGroupFactory implements IteratorAggre
 		return FALSE;
 	}
 
+	function getArrayByListFactory($lf, $include_blank = TRUE) {
+		if ( !is_object($lf) ) {
+			return FALSE;
+		}
+
+		if ( $include_blank == TRUE ) {
+			$list[0] = '--';
+		}
+
+		foreach ($lf as $obj) {
+			$list[$obj->getID()] = $obj->getName();
+		}
+
+		if ( isset($list) ) {
+			return $list;
+		}
+
+		return FALSE;
+	}
+
 	function getUserToPolicyGroupMapArrayByListFactory( $lf ) {
 		if ( !is_object($lf) ) {
 			return FALSE;
