@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: PunchControlFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5749 $
+ * $Id: PunchControlFactory.class.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 
 /**
@@ -817,8 +817,34 @@ class PunchControlFactory extends Factory {
 			if ( $this->getPunchObject()->getType() == 20 AND $this->getPunchObject()->getStatus() == 10 ) {
 				Debug::text(' bbPrevious Punch to Lunch...', __FILE__, __LINE__, __METHOD__,10);
 
-				$shift_data = $this->getShiftData();
+				//We used to use getShiftData() then pull out the previous punch from that, however that can cause problems
+				//based on the Minimum Time-Off Between Shifts. Either way though that can't be less than the lunch/break autodetection time.
+				$previous_punch_obj = $this->getPunchObject()->getPreviousPunchObject($this->getPunchObject()->getActualTimeStamp() );
+				if ( is_object( $previous_punch_obj ) AND $previous_punch_obj->getType() != 20 ) {
+					Debug::text(' Previous Punch ID: '. $previous_punch_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
 
+					if ( $this->getPunchObject()->inMealPolicyWindow( $this->getPunchObject()->getTimeStamp(), $previous_punch_obj->getTimeStamp(), $previous_punch_obj->getStatus() ) == TRUE ) {
+						Debug::text(' Previous Punch needs to change to Lunch...', __FILE__, __LINE__, __METHOD__,10);
+
+						$plf = TTnew( 'PunchListFactory' );
+						$plf->getById( $previous_punch_obj->getId() );
+						if ( $plf->getRecordCount() == 1 ) {
+							Debug::text(' Modifying previous punch...', __FILE__, __LINE__, __METHOD__,10);
+
+							$pf = $plf->getCurrent();
+							$pf->setType( 20 ); //Lunch
+							//If we start re-rounding this punch we have to recalculate the total for the previous punch_control too.
+							//$p_obj->setTimeStamp( $p_obj->getTimeStamp() ); //Re-round timestamp now that its a lunch punch.
+							if ( $pf->Save( FALSE ) == TRUE ) {
+								Debug::text(' Returning TRUE!', __FILE__, __LINE__, __METHOD__,10);
+
+								return TRUE;
+							}
+						}
+					}
+				}
+				/*
+				$shift_data = $this->getShiftData();
 				if ( isset($shift_data['previous_punch_key'])
 						AND isset($shift_data['punches'][$shift_data['previous_punch_key']])
 						AND $shift_data['punches'][$shift_data['previous_punch_key']]['type_id'] != 20 ) {
@@ -843,17 +869,42 @@ class PunchControlFactory extends Factory {
 
 								return TRUE;
 							}
-
 						}
-
 					}
-
 				}
+				*/
 			} elseif ( $this->getPunchObject()->getType() == 30 AND $this->getPunchObject()->getStatus() == 10 ) {
 				Debug::text(' bbPrevious Punch to Break...', __FILE__, __LINE__, __METHOD__,10);
 
-				$shift_data = $this->getShiftData();
+				//We used to use getShiftData() then pull out the previous punch from that, however that can cause problems
+				//based on the Minimum Time-Off Between Shifts. Either way though that can't be less than the lunch/break autodetection time.
+				$previous_punch_obj = $this->getPunchObject()->getPreviousPunchObject($this->getPunchObject()->getActualTimeStamp() );
+				if ( is_object( $previous_punch_obj ) AND $previous_punch_obj->getType() != 30 ) {
+					Debug::text(' Previous Punch ID: '. $previous_punch_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
 
+					if ( $this->getPunchObject()->inBreakPolicyWindow( $this->getPunchObject()->getTimeStamp(), $previous_punch_obj->getTimeStamp(), $previous_punch_obj->getStatus() ) == TRUE ) {
+						Debug::text(' Previous Punch needs to change to Break...', __FILE__, __LINE__, __METHOD__,10);
+
+						$plf = TTnew( 'PunchListFactory' );
+						$plf->getById( $previous_punch_obj->getId() );
+						if ( $plf->getRecordCount() == 1 ) {
+							Debug::text(' Modifying previous punch...', __FILE__, __LINE__, __METHOD__,10);
+
+							$pf = $plf->getCurrent();
+							$pf->setType( 30 ); //Break
+							//If we start re-rounding this punch we have to recalculate the total for the previous punch_control too.
+							//$p_obj->setTimeStamp( $p_obj->getTimeStamp() ); //Re-round timestamp now that its a lunch punch.
+							if ( $pf->Save( FALSE ) == TRUE ) {
+								Debug::text(' Returning TRUE!', __FILE__, __LINE__, __METHOD__,10);
+
+								return TRUE;
+							}
+						}
+					}
+				}
+
+/*
+				$shift_data = $this->getShiftData();
 				if ( isset($shift_data['previous_punch_key'])
 						AND isset($shift_data['punches'][$shift_data['previous_punch_key']])
 						AND $shift_data['punches'][$shift_data['previous_punch_key']]['type_id'] != 30 ) {
@@ -878,12 +929,10 @@ class PunchControlFactory extends Factory {
 
 								return TRUE;
 							}
-
 						}
-
 					}
-
 				}
+				*/
 			}
 
 		}
@@ -1198,6 +1247,28 @@ class PunchControlFactory extends Factory {
 			$this->findUserDate();
 		}
 
+		//Check to see if timesheet is verified, if so unverify it on modified punch.
+		//Make sure exceptions are calculated *after* this so TimeSheet Not Verified exceptions can be triggered again.
+		if ( is_object( $this->getPayPeriodScheduleObject() )
+				AND $this->getPayPeriodScheduleObject()->getTimeSheetVerifyType() != 10 ) {
+			//Find out if timesheet is verified or not.
+			$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
+			$pptsvlf->getByPayPeriodIdAndUserId( $this->getUserDateObject()->getPayPeriod(), $this->getUser() );
+			if ( $pptsvlf->getRecordCount() > 0 ) {
+				//Pay period is veriferied, delete all records and make log entry.
+				Debug::text('Pay Period is verified, deleting verification records: '. $pptsvlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+				foreach( $pptsvlf as $pptsv_obj ) {
+					if ( is_object( $this->getPunchObject() ) ) {
+						TTLog::addEntry( $pptsv_obj->getId(), 500,  TTi18n::getText('TimeSheet Modified After Verification').': '. UserListFactory::getFullNameById( $this->getUser() ) .' '. TTi18n::getText('Punch').': '. TTDate::getDate('DATE+TIME', $this->getPunchObject()->getTimeStamp() ) , NULL, $pptsvlf->getTable() );
+					}
+					$pptsv_obj->setDeleted( TRUE );
+					if ( $pptsv_obj->isValid() ) {
+						$pptsv_obj->Save();
+					}
+				}
+			}
+		}
+
 		$this->changePreviousPunchType();
 
 		return TRUE;
@@ -1598,7 +1669,6 @@ class PunchControlFactory extends Factory {
 		if ( $this->getEnableCalcSystemTotalTime() == TRUE ) {
 			$this->old_user_date_ids[] = $this->getUserDateID();
 			if ( $this->getUser() > 0 ) {
-				//var_dump($this->old_user_date_ids);
 				UserDateTotalFactory::smartReCalculate( $this->getUser(), $this->old_user_date_ids, $this->getEnableCalcException(), $this->getEnablePreMatureException() );
 			}
 		}
