@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: PunchFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5963 $
+ * $Id: PunchFactory.class.php 5963 2012-01-04 16:31:38Z ipso $
+ * $Date: 2012-01-04 08:31:38 -0800 (Wed, 04 Jan 2012) $
  */
 
 /**
@@ -47,6 +47,7 @@ class PunchFactory extends Factory {
 	protected $pk_sequence_name = 'punch_id_seq'; //PK Sequence name
 
 	var $punch_control_obj = NULL;
+	var $previous_punch_obj = NULL;
 	protected $schedule_obj = NULL;
 	var $tmp_data = NULL;
 
@@ -93,6 +94,11 @@ class PunchFactory extends Factory {
 										'-1210-date_stamp' => TTi18n::gettext('Date'),
 										'-1220-time_stamp' => TTi18n::gettext('Time'),
 
+										'-1310-station_station_id' => TTi18n::gettext('Station ID'),
+										'-1320-station_type' => TTi18n::gettext('Station Type'),
+										'-1330-station_source' => TTi18n::gettext('Station Source'),
+										'-1340-station_description' => TTi18n::gettext('Station Description'),
+
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
@@ -202,22 +208,22 @@ class PunchFactory extends Factory {
 			return FALSE;
 		}
 	}
-/*
-	function getSchedulePolicyObject() {
-		if ( is_object($this->schedule_policy_obj) ) {
-			return $this->schedule_policy_obj;
+
+	function getPreviousPunchObject( $time_stamp ) {
+		if ( is_object($this->previous_punch_obj) ) {
+			return $this->previous_punch_obj;
 		} else {
-			$splf = TTnew( 'SchedulePolicyListFactory' );
-			$splf->getById( $this->getScheduleObject()->getSchedulePolicyID() );
-			if ( $splf->getRecordCount() > 0 ) {
-				$this->schedule_policy_obj = $splf->getCurrent();
-				return $this->schedule_policy_obj;
+			$plf = TTnew( 'PunchListFactory' );
+			$plf->getPreviousPunchByUserIdAndEpoch( $this->getUser(), (int)$time_stamp );
+			if ( $plf->getRecordCount() > 0 ) {
+				$previous_punch_obj = $plf->getCurrent();
+				return $previous_punch_obj;
 			}
 
 			return FALSE;
 		}
 	}
-*/
+
 	function getScheduleObject() {
 		if ( is_object($this->schedule_obj) ) {
 			return $this->schedule_obj;
@@ -321,7 +327,16 @@ class PunchFactory extends Factory {
 
 		return FALSE;
 	}
-	function setTransfer($bool) {
+	function setTransfer($bool, $time_stamp = NULL) {
+		//If a timestamp is passed, check for the previous punch, if one does NOT exist, transfer can not be enabled.
+		if ( $bool == TRUE AND $time_stamp != '' ) {
+			if ( !is_object( $this->getPreviousPunchObject( $time_stamp ) ) ) {
+				Debug::Text('Previous punch does not exist, transfer cannot be enabled. EPOCH: '. $time_stamp , __FILE__, __LINE__, __METHOD__,10);
+				return FALSE;
+			}
+
+		}
+
 		$this->data['transfer'] = $this->toBool($bool);
 
 		return TRUE;
@@ -365,14 +380,43 @@ class PunchFactory extends Factory {
 		return FALSE;
 	}
 
-	function getNextType() {
+	function getNextType( $epoch = NULL ) {
 		if ( $this->getStatus() == 10 ) { //In
-			return 10;
-		} else { //Out
-			return $this->getType();
+			$next_type = 10; //Normal
+		} else { //20 = Out
+			$next_type = $this->getType();
 		}
 
-		return FALSE;
+		//$this object should always be the previous punch.
+		if ( $epoch > 0 AND $this->getUser() > 0 ) {
+			Debug::Text(' Previous Punch Type: '. $this->getType() .' Status: '. $this->getStatus() .' Epoch: '. $epoch .' User ID: '. $this->getUser(), __FILE__, __LINE__, __METHOD__,10);
+
+			//Check for break policy window.
+			//With Time Window auto-detection, ideally we would filter on $this->getStatus() != 20, so we don't try to detect explicit OUT punches.
+			//However with Punch Time auto-detection, ideally we would filter on $this->getStatus() != 10 so we don't try to detect explicity IN punches.
+			//So because of the above, we can't filter based on status at all until we know what the break/lunch policy requires.
+			//Do the filter in inBreakPolicyWindow()/inMealPolicyWindow().
+			//if ( $next_type != 30 AND ( $this->getStatus() != 20 AND $this->getType() != 30 ) ) {
+			if ( $next_type != 30 AND $this->getType() != 30 ) {
+				$this->setScheduleID( $this->findScheduleID( $epoch ) );
+				if ( $this->inBreakPolicyWindow( $epoch, $this->getTimeStamp(), $this->getStatus() ) == TRUE ) {
+					Debug::Text(' Setting Type to Break...', __FILE__, __LINE__, __METHOD__,10);
+					$next_type = 30;
+				}
+			}
+
+			//Check for meal policy window.
+			//if ( $next_type != 20 AND ( $this->getStatus() != 20 AND $this->getType() != 20 ) ) {
+			if ( $next_type != 20 AND $this->getType() != 20 ) {
+				$this->setScheduleID( $this->findScheduleID( $epoch ) );
+				if ( $this->inMealPolicyWindow( $epoch, $this->getTimeStamp(), $this->getStatus() ) == TRUE ) {
+					Debug::Text(' Setting Type to Lunch...', __FILE__, __LINE__, __METHOD__,10);
+					$next_type = 20;
+				}
+			}
+		}
+
+		return $next_type;
 	}
 
 	function getTypeCode() {
@@ -604,9 +648,21 @@ class PunchFactory extends Factory {
 								}
 							}
 
-							Debug::text('bDay Total Time: '. $day_total_time, __FILE__, __LINE__, __METHOD__,10);
+							//Take into account paid meal/breaks when doing day total rounding...
+							$meal_and_break_adjustment = 0;
+							$udtlf = TTnew( 'UserDateTotalListFactory' );
+							$udtlf->getByUserDateIdAndStatusAndType( $plf->getCurrent()->getPunchControlObject()->getUserDateID(), 10, array(100,110) );
+							if ( $udtlf->getRecordCount() > 0 ) {
+								foreach( $udtlf as $udt_obj ) {
+									$meal_and_break_adjustment += $udt_obj->getTotalTime();
+								}
+								Debug::text('Meal and Break Adjustment: '. $meal_and_break_adjustment .' Records: '. $udtlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+							}
+
+							$day_total_time += $meal_and_break_adjustment;
 							$original_day_total_time = $day_total_time;
 
+							Debug::text('cDay Total Time: '. $day_total_time, __FILE__, __LINE__, __METHOD__,10);
 							if ( $day_total_time > 0 ) {
 								//Set the ScheduleID
 								$has_schedule = $this->setScheduleID( $this->findScheduleID( $epoch ) );
@@ -729,7 +785,9 @@ class PunchFactory extends Factory {
 	function setTimeStamp($epoch, $enable_rounding = TRUE) {
 		$epoch = $original_epoch = trim($epoch);
 
-		if ( $enable_rounding == TRUE AND $this->getTransfer() == FALSE ) {
+		//We can't disable rounding if its the first IN punch and no transfer actually needs to occur.
+		//Have setTransfer check to see if there is a previous punch and if not, don't allow it to be set.
+		if ( $enable_rounding == TRUE AND ( $this->getTransfer() == FALSE OR $this->getEnableAutoTransfer() == FALSE ) ) {
 			$epoch = $this->roundTimeStamp($epoch);
 		} else {
 			Debug::text(' Rounding Disabled... ', __FILE__, __LINE__, __METHOD__,10);
@@ -1083,7 +1141,7 @@ class PunchFactory extends Factory {
 	}
 
 	//Run this function on the previous punch object normally.
-	function inMealPolicyWindow( $current_epoch, $previous_epoch ) {
+	function inMealPolicyWindow( $current_epoch, $previous_epoch, $previous_punch_status = NULL ) {
 		Debug::Text(' Checking if we are in meal policy window/punch time...', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $current_epoch == '' ) {
@@ -1104,15 +1162,6 @@ class PunchFactory extends Factory {
 
 			$mp_obj = $this->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject();
 			$start_epoch = $this->getScheduleObject()->getStartTime();
-/*
-			if ( $current_epoch >= ($this->getScheduleObject()->getStartTime() + $this->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow() )
-					AND $current_epoch <= ($this->getScheduleObject()->getStartTime() + $this->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow() + $this->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getWindowLength() ) ) {
-				Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
-				//$next_type = 20;
-
-				return TRUE;
-			}
-*/
 		} else {
 			//Make sure prev punch is a Lunch Out Punch
 			//Check NON-scheduled meal policies
@@ -1121,37 +1170,42 @@ class PunchFactory extends Factory {
 			if ( $mplf->getRecordCount() > 0 ) {
 				$mp_obj = $mplf->getCurrent();
 
-				//FIXME: Start time should be the shift start time, not the previous punch start time.
 				$start_epoch = $previous_epoch;
 				Debug::Text(' Found NON Schedule Meal Policy start Window: '. $mp_obj->getStartWindow(), __FILE__, __LINE__, __METHOD__,10);
-
-/*
-				if ( $current_epoch >= ($previous_epoch + $mp_obj->getStartWindow())
-						AND $current_epoch <= ($previous_epoch + $mp_obj->getStartWindow() + $mp_obj->getWindowLength() ) ) {
-					Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
-					//$next_type = 20;
-					return TRUE;
-				}
-*/
 			} else {
 				Debug::Text(' DID NOT Find NON Schedule Meal Policy start Window: ', __FILE__, __LINE__, __METHOD__,10);
 			}
 			unset($mplf);
 		}
 
+		//Start time should be the shift start time, not the previous punch start time.
+		//Get shift data here.
+		if ( is_object( $this->getPunchControlObject() ) ) {
+			$this->getPunchControlObject()->setPunchObject( $this );
+			$shift_data = $this->getPunchControlObject()->getShiftData();
+			if ( is_array($shift_data) AND isset($shift_data['first_in']) ) {
+				Debug::Text(' Shift First In Punch: '. TTDate::getDate('DATE+TIME', $shift_data['first_in']['time_stamp'] ), __FILE__, __LINE__, __METHOD__,10);
+				$start_epoch = $shift_data['first_in']['time_stamp'];
+			}
+		}
+
 		if ( isset($mp_obj) AND is_object( $mp_obj ) ) {
 			if ( $mp_obj->getAutoDetectType() == 10 ) { //Meal window
 				Debug::Text(' Auto Detect Type: Meal Window...', __FILE__, __LINE__, __METHOD__,10);
 
-				if ( $current_epoch >= ( $start_epoch + $mp_obj->getStartWindow() )
+				//Make we sure ignore meals if the previous punch status was OUT.
+				if ( 	$previous_punch_status != 20
+						AND $current_epoch >= ( $start_epoch + $mp_obj->getStartWindow() )
 						AND $current_epoch <= ( $start_epoch + $mp_obj->getStartWindow() + $mp_obj->getWindowLength() ) ) {
-					Debug::Text(' aPunch is in meal policy window!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' aPunch is in meal policy window! Current Epoch: '. TTDate::getDate('DATE+TIME', $current_epoch), __FILE__, __LINE__, __METHOD__,10);
 
 					return TRUE;
 				}
 			} else { //Punch time.
 				Debug::Text(' Auto Detect Type: Punch Time...', __FILE__, __LINE__, __METHOD__,10);
-				if ( ( $current_epoch - $previous_epoch ) >= $mp_obj->getMinimumPunchTime()
+				//Make we sure ignore meals if the previous punch status was IN.
+				if ( 	$previous_punch_status != 10
+						AND ( $current_epoch - $previous_epoch ) >= $mp_obj->getMinimumPunchTime()
 						AND ( $current_epoch - $previous_epoch ) <= $mp_obj->getMaximumPunchTime() )  {
 					Debug::Text(' bPunch is in meal policy window!', __FILE__, __LINE__, __METHOD__,10);
 
@@ -1166,7 +1220,7 @@ class PunchFactory extends Factory {
 	}
 
 	//Run this function on the previous punch object normally.
-	function inBreakPolicyWindow( $current_epoch, $previous_epoch ) {
+	function inBreakPolicyWindow( $current_epoch, $previous_epoch, $previous_punch_status = NULL ) {
 		Debug::Text(' Checking if we are in break policy window/punch time... Current: '. TTDate::getDate('DATe+TIME', $current_epoch) .' Previous: '. TTDate::getDate('DATe+TIME', $previous_epoch), __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $current_epoch == '' ) {
@@ -1191,38 +1245,54 @@ class PunchFactory extends Factory {
 			}
 			unset($bp_ids, $bp_obj);
 
-			$start_epoch = $this->getScheduleObject()->getStartTime();
+			$start_epoch = $this->getScheduleObject()->getStartTime(); //Keep these here in case PunchControlObject can't be determined.
 		} else {
 			//Make sure prev punch is a Break Out Punch
 			//Check NON-scheduled break policies
 			$bplf = TTnew( 'BreakPolicyListFactory' );
 			$bplf->getByPolicyGroupUserId( $this->getUser() );
 			if ( $bplf->getRecordCount() > 0 ) {
-				$bp_objs[] = $bplf->getCurrent();
+				foreach( $bplf as $bp_obj ) {
+					$bp_objs[] = $bp_obj;
+				}
 
-				//FIXME: Start time should be the shift start time, not the previous punch start time.
-				$start_epoch = $previous_epoch;
+				$start_epoch = $previous_epoch; //Keep these here in case PunchControlObject can't be determined.
 				Debug::Text(' Found NON Schedule Break Policy...', __FILE__, __LINE__, __METHOD__,10);
 			} else {
 				Debug::Text(' DID NOT Find NON Schedule Break Policy...', __FILE__, __LINE__, __METHOD__,10);
 			}
-			unset($mplf);
+			unset($bplf);
+		}
+
+		//Start time should be the shift start time, not the previous punch start time.
+		//Get shift data here.
+		if ( is_object( $this->getPunchControlObject() ) ) {
+			$this->getPunchControlObject()->setPunchObject( $this );
+			$shift_data = $this->getPunchControlObject()->getShiftData();
+			if ( is_array($shift_data) AND isset($shift_data['first_in']) ) {
+				Debug::Text(' Shift First In Punch: '. TTDate::getDate('DATE+TIME', $shift_data['first_in']['time_stamp'] ), __FILE__, __LINE__, __METHOD__,10);
+				$start_epoch = $shift_data['first_in']['time_stamp'];
+			}
 		}
 
 		if ( isset($bp_objs) AND is_array( $bp_objs ) ) {
 			foreach( $bp_objs as $bp_obj ) {
 				if ( $bp_obj->getAutoDetectType() == 10 ) { //Meal window
-					Debug::Text(' Auto Detect Type: Break Window...', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Auto Detect Type: Break Window... Start Epoch: '. TTDate::getDate('DATE+TIME', $start_epoch) , __FILE__, __LINE__, __METHOD__,10);
 
-					if ( $current_epoch >= ( $start_epoch + $bp_obj->getStartWindow() )
+					//Make we sure ignore breaks if the previous punch status was OUT.
+					if ( 	$previous_punch_status != 20
+							AND $current_epoch >= ( $start_epoch + $bp_obj->getStartWindow() )
 							AND $current_epoch <= ( $start_epoch + $bp_obj->getStartWindow() + $bp_obj->getWindowLength() ) ) {
 						Debug::Text(' aPunch is in break policy (ID:'. $bp_obj->getId().') window!', __FILE__, __LINE__, __METHOD__,10);
 
 						return TRUE;
 					}
 				} else { //Punch time.
+					//Make we sure ignore breaks if the previous punch status was IN.
 					Debug::Text(' Auto Detect Type: Punch Time...', __FILE__, __LINE__, __METHOD__,10);
-					if ( ( $current_epoch - $previous_epoch ) >= $bp_obj->getMinimumPunchTime()
+					if ( 	$previous_punch_status != 10
+							AND ( $current_epoch - $previous_epoch ) >= $bp_obj->getMinimumPunchTime()
 							AND ( $current_epoch - $previous_epoch ) <= $bp_obj->getMaximumPunchTime() )  {
 						Debug::Text(' bPunch is in break policy (ID:'. $bp_obj->getId().') window!', __FILE__, __LINE__, __METHOD__,10);
 
@@ -1265,14 +1335,12 @@ class PunchFactory extends Factory {
 
 		if ( $this->getDeleted() == FALSE ) {
 
-			if ( $this->getTransfer() == TRUE AND $this->getEnableAutoTransfer() == TRUE ) {
-				Debug::text(' Transfer is Enabled, automatic punch out of last punch pair: ', __FILE__, __LINE__, __METHOD__,10);
+			if ( $this->isNew() AND $this->getTransfer() == TRUE AND $this->getEnableAutoTransfer() == TRUE ) {
+				Debug::text(' Transfer is Enabled, automatic punch out of last punch pair...', __FILE__, __LINE__, __METHOD__,10);
 
-				//Check to make sure there is an open punch pair.
-				$plf = TTnew( 'PunchListFactory' );
-				$plf->getPreviousPunchByUserIdAndEpoch( $this->getUser(), $this->getTimeStamp() );
-				if ( $plf->getRecordCount() > 0 ) {
-					$p_obj = $plf->getCurrent();
+				//Use actual time stamp, not rounded timestamp. This should only be called on new punches as well, otherwise Actual Time Stamp could be incorrect.
+				$p_obj = $this->getPreviousPunchObject( $this->getActualTimeStamp() );
+				if ( is_object( $p_obj ) ) {
 					Debug::text(' Found Last Punch: ', __FILE__, __LINE__, __METHOD__,10);
 
 					if ( $p_obj->getStatus() == 10 ) {
@@ -1290,7 +1358,9 @@ class PunchFactory extends Factory {
 						$pf->setStatus( 20 ); //Out
 						$pf->setTimeStamp( $this->getTimeStamp(), FALSE ); //Disable rounding.
 						$pf->setActualTimeStamp( $this->getTimeStamp() );
-						$pf->setOriginalTimeStamp( $this->getTimeStamp() );
+						//$pf->setOriginalTimeStamp( $this->getTimeStamp() ); //set in preSave()
+						$pf->setLongitude( $this->getLongitude() );
+						$pf->setLatitude( $this->getLatitude() );
 						if ( $pf->isValid() ) {
 							if ( $pf->Save( FALSE ) == TRUE ) {
 								$p_obj->getPunchControlObject()->setEnableCalcTotalTime( TRUE );
@@ -1312,8 +1382,9 @@ class PunchFactory extends Factory {
 					} else {
 						Debug::text(' Last Punch was out. No Auto Punch ', __FILE__, __LINE__, __METHOD__,10);
 					}
+
 				}
-				unset($plf, $p_obj, $pf);
+				unset($p_obj, $pf);
 			}
 
 			//Split punch at midnight.
@@ -1321,7 +1392,9 @@ class PunchFactory extends Factory {
 			//Check to make sure there is an open punch pair.
 			//Make sure this punch isn't right at midnight either, as no point in splitting a punch at that time.
 			//FIXME: What happens if a supervisor edits a 11:30PM punch and makes it 5:00AM the next day?
-			//		We can't split punches when editing, because we have to split punch_control_ids prior to saving etc...
+			//		We can't split punches when editing existing punches, because we have to split punch_control_ids prior to saving etc...
+			//		But we can split when supervisors are adding new punches.
+			//Debug::text('Split at Midnight Enabled: '. $this->getEnableSplitAtMidnight() .' IsNew: '. $this->isNew() .' Status: '. $this->getStatus() .' TimeStamp: '. $this->getTimeStamp() .' Punch Control ID: '. $this->getPunchControlID(), __FILE__, __LINE__, __METHOD__,10);
 			if ( $this->isNew() == TRUE
 					AND $this->getStatus() == 20
 					AND $this->getEnableSplitAtMidnight() == TRUE
@@ -1346,7 +1419,7 @@ class PunchFactory extends Factory {
 						$this->setStatus(20); //Out
 
 						//Reduce the out punch by 60 seconds, and increase the current punch by 60seconds so no time is lost.
-						$this->setTimeStamp( ($this->getTimeStamp()+60) ); //FIXME: May need to use ActualTimeStamp here so we aren't double rounding.
+						$this->setTimeStamp( $this->getTimeStamp() ); //FIXME: May need to use ActualTimeStamp here so we aren't double rounding.
 
 						//Get new punch control ID for the midnight punch and this one.
 						$new_punch_control_id = $this->getPunchControlObject()->getNextInsertId();
@@ -1373,7 +1446,7 @@ class PunchFactory extends Factory {
 						$pf->setTimeStamp( $before_midnight_timestamp, FALSE ); //Disable rounding.
 
 						$pf->setActualTimeStamp( $before_midnight_timestamp );
-						$pf->setOriginalTimeStamp( $before_midnight_timestamp );
+						//$pf->setOriginalTimeStamp( $before_midnight_timestamp ); //set in preSave()
 
 						$pf->setPunchControlID( $p_obj->getPunchControlID() );
 						if ( $pf->isValid() ) {
@@ -1408,7 +1481,7 @@ class PunchFactory extends Factory {
 						$pf->setTimeStamp( $at_midnight_timestamp, FALSE ); //Disable rounding.
 
 						$pf->setActualTimeStamp( $at_midnight_timestamp );
-						$pf->setOriginalTimeStamp( $at_midnight_timestamp );
+						//$pf->setOriginalTimeStamp( $at_midnight_timestamp ); //set in preSave()
 
 						$pf->setPunchControlID( $new_punch_control_id );
 						if ( $pf->isValid() ) {
@@ -1486,14 +1559,13 @@ class PunchFactory extends Factory {
 			foreach ( $data as $key => $row ) {
 				if ( $row['type_id'] != 10 ) {
 					if ( $row['status_id'] == 20 ) {
-						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev'] = TTDate::strtotime($row['time_stamp']);
+						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev'] = TTDate::parseDateTime($row['time_stamp']);
 					} elseif ( isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) ) {
 						if ( !isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time']) ) {
 							$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = 0;
 						}
 
-						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = bcadd( $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'], bcsub( TTDate::strtotime($row['time_stamp']), $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) );
-
+						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = bcadd( $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'], bcsub( TTDate::parseDateTime($row['time_stamp']), $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) );
 						if ( !isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks']) ) {
 							$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks'] = 0;
 						}
@@ -1515,8 +1587,6 @@ class PunchFactory extends Factory {
 						}
 
 					}
-
-					$date_total_break_ids[] = (int)$row['type_id'];
 				}
 			}
 
@@ -1560,6 +1630,7 @@ class PunchFactory extends Factory {
 			/*
 				ORDER IS EXTREMELY IMPORTANT FOR THIS FUNCTION:
 				1. $pf->setUser();
+				1b. $pf->setTransfer() //include timestamp for this.
 				2. $pf->setType();
 				3. $pf->setStatus();
 				4. $pf->setTimeStamp();
@@ -1568,7 +1639,15 @@ class PunchFactory extends Factory {
 				All these related fields MUST be passed to this function as well, even if they are blank.
 			*/
 
-			$full_time_stamp = NULL;
+			//Parse time stamp above loop so we don't have to do it twice.
+			if ( isset($data['punch_date']) AND $data['punch_date'] != '' AND isset($data['punch_time']) AND $data['punch_time'] != '' ) {
+				$full_time_stamp = TTDate::parseDateTime( $data['punch_date'].' '.$data['punch_time'] );
+				//Debug::text('Setting Punch Time/Date: Date Stamp: '. $data['punch_date'] .' Time Stamp: '. $data['punch_time'] .' Full Time Stamp: '. $data['full_time_stamp'] .' Parsed: '. TTDate::getDate('DATE+TIME', $full_time_stamp ), __FILE__, __LINE__, __METHOD__, 10);
+			} elseif ( isset($data['time_stamp']) AND $data['time_stamp'] != '' ) {
+				$full_time_stamp = TTDate::parseDateTime( $data['time_stamp'] );
+			} else {
+				$full_time_stamp = NULL;
+			}
 
 			$variable_function_map = $this->getVariableToFunctionMap();
 			foreach( $variable_function_map as $key => $function ) {
@@ -1576,6 +1655,9 @@ class PunchFactory extends Factory {
 
 					$function = 'set'.$function;
 					switch( $key ) {
+						case 'transfer':
+							$this->$function( $data[$key], $full_time_stamp ); //Assume time_stamp contains date as well.
+							break;
 						case 'time_stamp':
 							if ( method_exists( $this, $function ) ) {
 								if ( isset($data['disable_rounding']) AND $data['disable_rounding'] == TRUE ) {
@@ -1584,13 +1666,6 @@ class PunchFactory extends Factory {
 									$enable_rounding = TRUE;
 								}
 
-								if ( isset($data['punch_date']) AND $data['punch_date'] != '' AND isset($data['punch_time']) AND $data['punch_time'] != '' ) {
-									$full_time_stamp = TTDate::parseDateTime( $data['punch_date'].' '.$data['punch_time'] );
-									//Debug::text('Setting Punch Time/Date: Date Stamp: '. $data['punch_date'] .' Time Stamp: '. $data['punch_time'] .' Full Time Stamp: '. $data['full_time_stamp'] .' Parsed: '. TTDate::getDate('DATE+TIME', $full_time_stamp ), __FILE__, __LINE__, __METHOD__, 10);
-								} elseif ( isset($data['time_stamp']) AND $data['time_stamp'] != '' ) {
-									$full_time_stamp = TTDate::parseDateTime( $data['time_stamp'] );
-								}
-
 								$this->$function( $full_time_stamp, $enable_rounding ); //Assume time_stamp contains date as well.
 							}
 							break;
@@ -1620,7 +1695,7 @@ class PunchFactory extends Factory {
 			if ( $this->isNew() == TRUE AND $full_time_stamp != NULL ) {
 				Debug::text('Setting actual/original timestamp: '. $full_time_stamp, __FILE__, __LINE__, __METHOD__, 10);
 				$this->setActualTimeStamp( $full_time_stamp );
-				$this->setOriginalTimeStamp( $this->getTimeStamp() );
+				//$this->setOriginalTimeStamp( $this->getTimeStamp() ); //set in preSave()
 			} else {
 				Debug::text('NOT setting actual/original timestamp...', __FILE__, __LINE__, __METHOD__, 10);
 			}
@@ -1703,6 +1778,9 @@ class PunchFactory extends Factory {
 						case 'actual_time_stamp':
 							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( 'actual_time_stamp' ) ) );
 							break;
+						case 'actual_time':
+							$data[$variable] = TTDate::getAPIDate( 'TIME', TTDate::strtotime( $this->getColumn( 'actual_time_stamp' ) ) );
+							break;
 						case 'station_type':
 							$data[$variable] = Option::getByKey( $this->getColumn( 'station_type_id' ), $sf->getOptions( 'type' ) );
 							break;
