@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: PunchListFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 6071 $
+ * $Id: PunchListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -779,11 +779,14 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 
 		$ph = array(
 					'user_id' => $user_id,
+					'date_stamp1' => $this->db->BindDate( TTDate::getMiddleDayEpoch($epoch)-86400 ),
+					'date_stamp2' => $this->db->BindDate( TTDate::getMiddleDayEpoch($epoch)+86400 ),
 					'status_id' => $status_id,
 					'type_id' => $type_id,
 					'time_stamp' => $this->db->BindTimeStamp($epoch),
 					);
 
+		//Narrow down the c.date_stamp column to speed this query up, as sometimes it can be so slow that connections timeout.
 		//Status order matters, because if its a.status_id desc, OUT comes first, but if the last
 		//punch doesn't have OUT yet, it defaults to IN
 		// with a.status_id asc...
@@ -795,6 +798,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					where	a.punch_control_id = b.id
 						AND b.user_date_id = c.id
 						AND c.user_id = ?
+						AND ( c.date_stamp >= ? AND c.date_stamp <= ? )
 						AND a.status_id = ?
 						AND a.type_id = ?
 						AND a.time_stamp <= ?
@@ -804,6 +808,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					';
 		$query .= $this->getSortSQL( $order );
 
+		//Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -1632,7 +1638,9 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$jf = new JobFactory();
+			$jgf = new JobGroupFactory();
 			$jif = new JobItemFactory();
+			$jigf = new JobItemGroupFactory();
 		}
 
 		$ph = array( 'company_id' => $company_id );
@@ -1647,6 +1655,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							a.status_id as status_id,
 							a.time_stamp as punch_time_stamp,
 							a.actual_time_stamp as punch_actual_time_stamp,
+							a.created_date as punch_created_date,
+							a.updated_date as punch_updated_date,
 
 							pcf.user_date_id as user_date_id,
 							pcf.branch_id as branch_id,
@@ -1681,13 +1691,39 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							z.id as user_wage_id,
 							z.effective_date as user_wage_effective_date,
 							z.hourly_rate as hourly_rate,
+							z.labor_burden_percent as labor_burden_percent,
 
 							sf.type_id as station_type_id,
 							sf.station_id as station_station_id,
 							sf.source as station_source,
-							sf.description as station_description
+							sf.description as station_description';
 
-					from	'. $this->getTable() .' as a
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= ',
+						jf.name as job,
+						jf.description as job_description,
+						jf.status_id as job_status_id,
+						jf.manual_id as job_manual_id,
+						jf.branch_id as job_branch_id,
+						jbf.name as job_branch,
+						jf.department_id as job_department_id,
+						jdf.name as job_department,
+						jf.group_id as job_group_id,
+						jgf.name as job_group,
+						jf.other_id1 as job_other_id1,
+						jf.other_id2 as job_other_id2,
+						jf.other_id3 as job_other_id3,
+						jf.other_id4 as job_other_id4,
+						jf.other_id5 as job_other_id5,
+						jif.name as job_item,
+						jif.description as job_item_description,
+						jif.manual_id as job_item_manual_id,
+						jif.group_id as job_item_group_id,
+						jigf.name as job_item_group
+						';
+		}
+
+		$query .= ' from	'. $this->getTable() .' as a
 					LEFT JOIN '. $pcf->getTable() .' as pcf ON a.punch_control_id = pcf.id
 					LEFT JOIN '. $udf->getTable() .' as b ON pcf.user_date_id = b.id
 					LEFT JOIN '. $ppf_b->getTable() .' as ppf ON b.pay_period_id = ppf.id
@@ -1704,8 +1740,19 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 																			and z.effective_date <= b.date_stamp
 																			and z.wage_group_id = 0
 																			and z.deleted = 0
-																			order by z.effective_date desc limit 1)
-					where 	uf.company_id = ? ';
+																			order by z.effective_date desc limit 1) ';
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= '	LEFT JOIN '. $jf->getTable() .' as jf ON pcf.job_id = jf.id
+						LEFT JOIN '. $jif->getTable() .' as jif ON pcf.job_item_id = jif.id
+						LEFT JOIN '. $bf->getTable() .' as jbf ON jf.branch_id = jbf.id
+						LEFT JOIN '. $df->getTable() .' as jdf ON jf.department_id = jdf.id
+						LEFT JOIN '. $jgf->getTable() .' as jgf ON jf.group_id = jgf.id
+						LEFT JOIN '. $jigf->getTable() .' as jigf ON jif.group_id = jigf.id
+						';
+		}
+
+		$query .= ' where 	uf.company_id = ? ';
 
 		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
 			$query  .=	' AND uf.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
@@ -1912,7 +1959,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							d.last_name as last_name,
 							d.status_id as user_status_id,
 							d.group_id as group_id,
-							g.name as group,
+							g.name as "group",
 							d.title_id as title_id,
 							h.name as title,
 							d.default_branch_id as default_branch_id,
@@ -2122,6 +2169,12 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$sort_column_aliases = array(
 									 'status' => 'status_id',
 									 'type' => 'type_id',
+									 'first_name' => 'd.first_name',
+									 'last_name' => 'd.last_name',
+									 'station_station_id' => 'l.station_id',
+									 'station_type' => 'l.type_id',
+									 'station_source' => 'l.source',
+									 'station_description' => 'l.description',
 									 );
 
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
@@ -2167,6 +2220,11 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		if ( isset($filter_data['punch_department_ids']) ) {
 			$filter_data['punch_department_id'] = $filter_data['punch_department_ids'];
 		}
+
+		if ( isset($filter_data['pay_period_ids']) ) {
+			$filter_data['pay_period_id'] = $filter_data['pay_period_ids'];
+		}
+
 /*
 		if ( isset($filter_data['exclude_job_ids']) ) {
 			$filter_data['exclude_id'] = $filter_data['exclude_job_ids'];
@@ -2221,9 +2279,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							b.department_id as department_id,
 							k.name as department,
 							b.job_id as job_id,
-							r.name as job,
 							b.job_item_id as job_item_id,
-							s.name as job_item,
 							b.quantity as quantity_id,
 							b.bad_quantity as bad_quantity_id,
 							b.total_time as total_time,
@@ -2244,7 +2300,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							d.last_name as last_name,
 							d.status_id as user_status_id,
 							d.group_id as group_id,
-							g.name as group,
+							g.name as "group",
 							d.title_id as title_id,
 							h.name as title,
 							d.default_branch_id as default_branch_id,
@@ -2253,6 +2309,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							f.name as default_department,
 							d.created_by as user_created_by,
 
+							l.id as station_id,
 							l.type_id as station_type_id,
 							l.station_id as station_station_id,
 							l.source as station_source,
@@ -2271,12 +2328,14 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= ',
+						r.name as job,
 						r.name as job_name,
 						r.status_id as job_status_id,
 						r.manual_id as job_manual_id,
 						r.branch_id as job_branch_id,
 						r.department_id as job_department_id,
-						r.group_id as job_group_id';
+						r.group_id as job_group_id,
+						s.name as job_item';
 		}
 
 		$query .= '
@@ -2293,7 +2352,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							LEFT JOIN '. $bf->getTable() .' as j ON ( b.branch_id = j.id AND j.deleted = 0)
 							LEFT JOIN '. $df->getTable() .' as k ON ( b.department_id = k.id AND k.deleted = 0)
 
-							LEFT JOIN '. $sf->getTable() .' as l ON a.station_id = l.id
+							LEFT JOIN '. $sf->getTable() .' as l ON ( a.station_id = l.id AND l.deleted = 0 )
 
 							LEFT JOIN '. $uwf->getTable() .' as w ON w.id = (select w.id
 																		from '. $uwf->getTable() .' as w
@@ -2356,8 +2415,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
 			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
 		}
-		if ( isset($filter_data['pay_period_ids']) AND isset($filter_data['pay_period_ids'][0]) AND !in_array(-1, (array)$filter_data['pay_period_ids']) ) {
-			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
+		if ( isset($filter_data['pay_period_id']) AND isset($filter_data['pay_period_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_id']) ) {
+			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_id'], $ph) .') ';
 		}
 
 
@@ -2396,6 +2455,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		//Debug::Arr($ph, 'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
