@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -76,6 +76,7 @@ class PayrollExportReport extends TimesheetSummaryReport {
 								'millenium' 		=> TTi18n::gettext('Millenium'),
 								'quickbooks' 		=> TTi18n::gettext('QuickBooks Pro'),
 								'surepayroll' 		=> TTi18n::gettext('SurePayroll'),
+								'chris21' 			=> TTi18n::gettext('Chris21'),
 								'csv' 				=> TTi18n::gettext('Generic Excel/CSV'),
 								//'other' 			=> TTi18n::gettext('-- Other --'),
 								);
@@ -180,12 +181,48 @@ class PayrollExportReport extends TimesheetSummaryReport {
 				break;
 			case 'adp_hour_column_options':
 				$retval['adp_hour_column_options'][0] = TTi18n::gettext('-- DO NOT EXPORT --');
-				$retval['adp_hour_column_options']['regular_time'] = TTi18n::gettext('Regular Time');
-				$retval['adp_hour_column_options']['overtime'] = TTi18n::gettext('Overtime');
+				$retval['adp_hour_column_options']['-0010-regular_time'] = TTi18n::gettext('Regular Time');
+				$retval['adp_hour_column_options']['-0020-overtime'] = TTi18n::gettext('Overtime');
 				for ( $i=3; $i <= 4; $i++ ) {
-					$retval['adp_hour_column_options'][$i] = TTi18n::gettext('Hours') .' '. $i;
+					$retval['adp_hour_column_options']['-003'.$i.'-'.$i] = TTi18n::gettext('Hours') .' '. $i;
 				}
 				break;
+			case 'adp_company_code_options':
+			case 'adp_batch_options':
+			case 'adp_temp_dept_options':
+				$retval = array(
+								0 => TTi18n::gettext('-- Custom --'),
+								'-0010-default_branch_manual_id' => TTi18n::gettext('Default Branch: Code'),
+								'-0020-default_department_manual_id' => TTi18n::gettext('Default Department: Code'),
+								'-0030-branch_manual_id' => TTi18n::gettext('Branch: Code'),
+								'-0040-department_manual_id' => TTi18n::gettext('Department: Code'),
+								);
+
+				$oflf = TTnew( 'OtherFieldListFactory' );
+
+				//Put a colon or underscore in the name, thats how we know it needs to be replaced.
+
+				//Get Branch other fields.
+				$default_branch_options = $oflf->getByCompanyIdAndTypeIdArray( $this->getUserObject()->getCompany(), 4, '-1000-default_branch_', TTi18n::getText('Default Branch').': ' );
+				if (  !is_array($default_branch_options) ) {
+					$default_branch_options = array();
+				}
+				$default_department_options = $oflf->getByCompanyIdAndTypeIdArray( $this->getUserObject()->getCompany(), 5, '-2000-default_department_', TTi18n::getText('Default Department').': ' );
+				if (  !is_array($default_department_options) ) {
+					$default_department_options = array();
+				}
+
+				$branch_options = $oflf->getByCompanyIdAndTypeIdArray( $this->getUserObject()->getCompany(), 4, '-3000-branch_', TTi18n::getText('Branch').': ' );
+				if ( !is_array($branch_options) ) {
+					$branch_options = array();
+				}
+				$department_options = $oflf->getByCompanyIdAndTypeIdArray( $this->getUserObject()->getCompany(), 5, '-4000-department_', TTi18n::getText('Department').': ' );
+				if ( !is_array($department_options) ) {
+					$department_options = array();
+				}
+
+				$retval = array_merge( $retval, (array)$default_branch_options, (array)$default_department_options, $branch_options, $department_options );
+				break;
 			case 'quickbooks_proj_options':
 				$retval = array(
 								0 => TTi18n::gettext('-- NONE --'),
@@ -214,10 +251,51 @@ class PayrollExportReport extends TimesheetSummaryReport {
 
 				switch( strtolower($export_type) ) {
 					case 'adp':
+						//$setup_data = $this->getFormConfig(); //get setup data to determine PROJ field.
+						$setup_data = $config['form']; //get setup data to determine custom formats...
+
+						$config['columns'][] = 'default_branch_id';
+						$config['columns'][] = 'default_department_id';
+
+						if ( isset($setup_data['adp']['company_code']) AND strpos( $setup_data['adp']['company_code'], '_' ) !== FALSE ) {
+							$config['columns'][] = Misc::trimSortPrefix( $setup_data['adp']['company_code'] );
+						}
+						if ( isset($setup_data['adp']['batch_id']) AND strpos( $setup_data['adp']['batch_id'], '_' ) !== FALSE ) {
+							$config['columns'][] = Misc::trimSortPrefix( $setup_data['adp']['batch_id'] );
+						}
+						if ( isset($setup_data['adp']['temp_dept']) AND strpos( $setup_data['adp']['temp_dept'], '_' ) !== FALSE ) {
+							$config['columns'][] = Misc::trimSortPrefix( $setup_data['adp']['temp_dept'] );
+						}
+						$config['columns'][] = 'employee_number';
+						$config['columns'] += Misc::trimSortPrefix( $this->getOptions('dynamic_columns') );
+
+						$config['group'][] = 'default_branch_id';
+						$config['group'][] = 'default_department_id';
+						if ( isset($setup_data['adp']['company_code']) AND strpos( $setup_data['adp']['company_code'], '_' ) !== FALSE ) {
+							$config['group'][] = Misc::trimSortPrefix( $setup_data['adp']['company_code'] );
+						}
+						if ( isset($setup_data['adp']['batch_id']) AND strpos( $setup_data['adp']['batch_id'], '_' ) !== FALSE ) {
+							$config['group'][] = Misc::trimSortPrefix( $setup_data['adp']['batch_id'] );
+						}
+						if ( isset($setup_data['adp']['temp_dept']) AND strpos( $setup_data['adp']['temp_dept'], '_' ) !== FALSE ) {
+							$config['group'][] = Misc::trimSortPrefix( $setup_data['adp']['temp_dept'] );
+						}
+						$config['group'][] = 'employee_number';
+
+						if ( isset($setup_data['adp']['company_code']) AND strpos( $setup_data['adp']['company_code'], '_' ) !== FALSE ) {
+							$config['sort'][] = array( Misc::trimSortPrefix( $setup_data['adp']['company_code'] ) => 'asc' );
+						}
+						if ( isset($setup_data['adp']['batch_id']) AND strpos( $setup_data['adp']['batch_id'], '_' ) !== FALSE ) {
+							$config['sort'][] = array( Misc::trimSortPrefix( $setup_data['adp']['batch_id'] ) => 'asc' );
+						}
+						if ( isset($setup_data['adp']['temp_dept']) AND strpos( $setup_data['adp']['temp_dept'], '_' ) !== FALSE ) {
+							$config['sort'][] = array( Misc::trimSortPrefix( $setup_data['adp']['temp_dept'] ) => 'asc' );
+						}
+						$config['sort'][] = array('employee_number' => 'asc' );
+						break;
 					case 'paychex_preview':
 					case 'paychex_online':
 					case 'millenium':
-					case 'quickbooks':
 					case 'ceridian_insync':
 						$config['columns'][] = 'employee_number';
 						$config['columns'] += Misc::trimSortPrefix( $this->getOptions('dynamic_columns') );
@@ -226,6 +304,35 @@ class PayrollExportReport extends TimesheetSummaryReport {
 
 						$config['sort'][] = array('employee_number' => 'asc');
 						break;
+					case 'quickbooks':
+						$setup_data = $this->getFormConfig(); //get setup data to determine PROJ field.
+
+						$config['columns'][] = 'pay_period_end_date';
+						$config['columns'][] = 'employee_number';
+						$config['columns'][] = 'last_name';
+						$config['columns'][] = 'first_name';
+						$config['columns'][] = 'middle_name';
+
+						//Support custom group based on PROJ field
+						if ( isset($setup_data['quickbooks']['proj']) ) {
+							$config['columns'][] = $setup_data['quickbooks']['proj'];
+						}
+
+						$config['columns'] += Misc::trimSortPrefix( $this->getOptions('dynamic_columns') );
+
+						$config['group'][] = 'pay_period_end_date';
+						$config['group'][] = 'employee_number';
+						$config['group'][] = 'last_name';
+						$config['group'][] = 'first_name';
+						$config['group'][] = 'middle_name';
+
+						//Support custom group based on PROJ field
+						if ( isset($setup_data['quickbooks']['proj']) ) {
+							$config['group'][] = $setup_data['quickbooks']['proj'];
+						}
+
+						$config['sort'][] = array('pay_period_end_date' => 'asc', 'employee_number' => 'asc', 'last_name' => 'asc', 'first_name' => 'asc');
+						break;
 					case 'surepayroll':
 						$config['columns'][] = 'pay_period_end_date';
 						$config['columns'][] = 'employee_number';
@@ -240,7 +347,18 @@ class PayrollExportReport extends TimesheetSummaryReport {
 
 						$config['sort'][] = array('pay_period_end_date' => 'asc', 'employee_number' => 'asc', 'last_name' => 'asc', 'first_name' => 'asc');
 						break;
+					case 'chris21':
+						$config['columns'][] = 'pay_period_end_date';
+						$config['columns'][] = 'employee_number';
+						$config['columns'] += Misc::trimSortPrefix( $this->getOptions('dynamic_columns') );
+
+						$config['group'][] = 'pay_period_end_date';
+						$config['group'][] = 'employee_number';
+
+						$config['sort'][] = array('pay_period_end_date' => 'asc', 'employee_number' => 'asc');
+						break;
 					case 'csv':
+						//If this needs to be customized, they can just export any regular report. This could probably be removed completely except for the Hour Code mapping...
 						$config['columns'][] = 'full_name';
 						$config['columns'][] = 'employee_number';
 						$config['columns'][] = 'default_branch';
@@ -286,7 +404,7 @@ class PayrollExportReport extends TimesheetSummaryReport {
 			Debug::Text('No Export Type defined!', __FILE__, __LINE__, __METHOD__,10);
 			return FALSE;
 		}
-
+		Debug::Arr($setup_data, 'Setup Data: ', __FILE__, __LINE__, __METHOD__,10);
 		$rows = $this->data;
 		Debug::Arr($rows, 'PreData: ', __FILE__, __LINE__, __METHOD__,10);
 
@@ -296,6 +414,90 @@ class PayrollExportReport extends TimesheetSummaryReport {
 
 		switch( strtolower(trim($setup_data['export_type'])) ) {
 			case 'adp': //ADP export format.
+				//File format supports multiple rows per employee (file #) all using the same columns. No need to jump through nasty hoops to fit everything on row.
+				$export_column_map = array(
+										'company_code' => 'Co Code',
+										'batch_id' => 'Batch ID',
+										'temp_dept' => 'Temp Dept',
+										'employee_number' =>  'File #',
+										'regular_time' => 'Reg Hours',
+										'overtime' => 'O/T Hours',
+										'3_code' => 'Hours 3 Code',
+										'3_amount' => 'Hours 3 Amount',
+										'4_code' => 'Hours 4 Code',
+										'4_amount' => 'Hours 4 Amount',
+										);
+
+				ksort($setup_data['adp']['columns']);
+				$setup_data['adp']['columns'] = Misc::trimSortPrefix( $setup_data['adp']['columns'] );
+
+				foreach( $setup_data['adp']['columns'] as $column_id => $column_data ) {
+					$column_name = NULL;
+					if ( $column_data['hour_column'] == 'regular_time' ) {
+						$export_data_map[$column_id] = 'regular_time';
+					} elseif ($column_data['hour_column'] == 'overtime' ) {
+						$export_data_map[$column_id] = 'overtime';
+					} elseif ( $column_data['hour_column'] >= 3 ) {
+						$export_data_map[$column_id] = $column_data;
+					}
+				}
+
+				if ( !isset($setup_data['adp']['company_code_value']) ) {
+					$setup_data['adp']['company_code_value'] = NULL;
+				}
+				if ( !isset($setup_data['adp']['batch_id_value']) ) {
+					$setup_data['adp']['batch_id_value'] = NULL;
+				}
+				if ( !isset($setup_data['adp']['temp_dept_value']) ) {
+					$setup_data['adp']['temp_dept_value'] = NULL;
+				}
+
+				$company_code_column = Misc::trimSortPrefix( $setup_data['adp']['company_code'] );
+				$batch_id_column = Misc::trimSortPrefix( $setup_data['adp']['batch_id'] );
+				$temp_dept_column = Misc::trimSortPrefix( $setup_data['adp']['temp_dept'] );
+				foreach($rows as $row) {
+					$static_columns = array(
+										'company_code' => ( isset($row[$company_code_column]) ) ? $row[$company_code_column] : $setup_data['adp']['company_code_value'],
+										'batch_id' => ( isset($row[$batch_id_column]) ) ? $row[$batch_id_column] : $setup_data['adp']['batch_id_value'],
+										'temp_dept' => ( isset($row[$temp_dept_column]) ) ? $row[$temp_dept_column] : $setup_data['adp']['temp_dept_value'],
+										'employee_number' => str_pad( $row['employee_number'], 6, 0, STR_PAD_LEFT), //ADP employee numbers should always be 6 digits.
+										);
+
+					foreach( $setup_data['adp']['columns'] as $column_id => $column_data ) {
+						$column_data = Misc::trimSortPrefix( $column_data, TRUE );
+						Debug::Text('ADP Column ID: '. $column_id .' Hour Column: '. $column_data['hour_column'] .' Code: '. $column_data['hour_code'], __FILE__, __LINE__, __METHOD__,10);
+						if ( isset( $row[$column_id] ) AND $column_data['hour_column'] != '0' ) {
+							foreach( $export_column_map as $export_column_id => $export_column_name ) {
+								Debug::Arr($row, 'Row: Column ID: '. $column_id .' Export Column ID: '. $export_column_id .' Name: '. $export_column_name, __FILE__, __LINE__, __METHOD__,10);
+
+								if ( ( $column_data['hour_column'] == $export_column_id OR $column_data['hour_column'].'_code' == $export_column_id )
+										AND !in_array( $export_column_id, array('company_code','batch_id','temp_dept', 'employee_number')) ) {
+									if ( (int)substr( $export_column_id, 0, 1 ) > 0 ) {
+										$tmp_row[$column_data['hour_column'].'_code'] = $column_data['hour_code'];
+										$tmp_row[$column_data['hour_column'].'_amount'] = TTDate::getTimeUnit( $row[$column_id], 20 );
+									} else {
+										$tmp_row[$export_column_id] = TTDate::getTimeUnit( $row[$column_id], 20 );
+									}
+
+									//Break out every column onto its own row, that way its easier to handle multiple columns of the same type.
+									$tmp_rows[] = array_merge( $static_columns, $tmp_row );
+									unset($tmp_row);
+								}
+							}
+						}
+					}
+				}
+
+				$file_name = 'EPI000000.csv';
+				if ( isset( $tmp_rows) ) {
+					//File format supports multiple entries per employee (file #) all using the same columns. No need to jump through nasty hoops to fit everyone one row.
+					$file_name = 'EPI'. $tmp_rows[0]['company_code'] . $tmp_rows[0]['batch_id'] .'.csv';
+
+					$data = Misc::Array2CSV( $tmp_rows, $export_column_map, FALSE );
+				}
+				unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
+				break;
+			case 'adp_old': //ADP export format.
 				$file_name = 'EPI'. $setup_data['adp']['company_code'] . $setup_data['adp']['batch_id'] .'.csv';
 
 				$export_column_map = array();
@@ -488,24 +690,31 @@ class PayrollExportReport extends TimesheetSummaryReport {
 				unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
 				break;
 
-			case 'ceridian_insync': //Ceridian InSync export format.
+			case 'ceridian_insync': //Ceridian InSync export format. Needs to be .IMP to import? DOS line endings?
+				if ( !isset($setup_data['ceridian_insync']['employer_number']) OR $setup_data['ceridian_insync']['employer_number'] == '' ) {
+					$setup_data['ceridian_insync']['employer_number'] = '0001';
+				}
+
+				$file_name = strtolower(trim($setup_data['export_type'])).'_'. $setup_data['ceridian_insync']['employer_number'] .'_'. date('Y_m_d').'.imp';
+
 				ksort($setup_data['ceridian_insync']['columns']);
 				$setup_data['ceridian_insync']['columns'] = Misc::trimSortPrefix( $setup_data['ceridian_insync']['columns'] );
 
-				$export_column_map = array(	'employee_number' => '', 'import_type_id' => '', 'employee_number_b' => '', 'check_type' => '',
+				$export_column_map = array(	'employer_number' => '', 'import_type_id' => '', 'employee_number' => '', 'check_type' => '',
 											'hour_code' => '', 'value' => '', 'distribution' => '', 'rate' => '', 'premium' => '', 'day' => '', 'pay_period' => '');
 				foreach($rows as $row) {
 					foreach( $setup_data['ceridian_insync']['columns'] as $column_id => $column_data ) {
 						if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
 							$tmp_rows[] = array(
-												'employee_number' => $row['employee_number'],
-												'import_type_id' => 'COSTING',
-												'employee_number_b' => str_pad( $row['employee_number'], 9, '0', STR_PAD_LEFT),
+												'employer_number' => $setup_data['ceridian_insync']['employer_number'], //Employer No./Payroll Number
+												'import_type_id' => 'COSTING', //This can change, must be configurable.
+												'employee_number' => str_pad( $row['employee_number'], 9, '0', STR_PAD_LEFT),
 												'check_type' => 'REG',
 												'hour_code' => trim($column_data['hour_code']),
 												'value' => TTDate::getTimeUnit( $row[$column_id], 20 ),
 												'distribution' => NULL,
-												'rate' => ( isset($row[$column_id.'_hourly_rate']) ) ? $row[$column_id.'_hourly_rate'] : NULL,
+												'rate' => NULL, //This overrides whats in ceridian and seems to cause problems.
+												//'rate' => ( isset($row[$column_id.'_hourly_rate']) ) ? $row[$column_id.'_hourly_rate'] : NULL,
 												'premium' => NULL,
 												'day' => NULL,
 												'pay_period' => NULL,
@@ -515,7 +724,7 @@ class PayrollExportReport extends TimesheetSummaryReport {
 				}
 
 				if ( isset( $tmp_rows) ) {
-					$data = Misc::Array2CSV( $tmp_rows, $export_column_map, FALSE, FALSE );
+					$data = Misc::Array2CSV( $tmp_rows, $export_column_map, FALSE, FALSE, "\r\n" ); //Use DOS line endings only.
 				}
 				unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
 
@@ -601,7 +810,37 @@ class PayrollExportReport extends TimesheetSummaryReport {
 				unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
 				break;
 
-			case 'csv': //Generic CSV
+			case 'chris21': //Chris21 Export format.
+				//Columns required: Employee_number (2), Date (10), ADJUSTMENT_CODE (12), HOURS (13), SIGNED_HOURS(15)[?]
+				//Use SIGNED_HOURS only, as it provides more space?
+				ksort($setup_data['chris21']['columns']);
+				$setup_data['chris21']['columns'] = Misc::trimSortPrefix( $setup_data['chris21']['columns'] );
+
+				$data = '';
+				foreach($rows as $row) {
+					foreach( $setup_data['chris21']['columns'] as $column_id => $column_data ) {
+
+						if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
+							//Debug::Arr($column_data,'Output2', __FILE__, __LINE__, __METHOD__,10);
+							$data .= str_repeat(' ', 8); 															//8 digits Blank
+							$data .= str_pad( substr( $row['employee_number'], 0, 7), 7, ' ', STR_PAD_RIGHT); 		//7 digits
+							$data .= str_repeat(' ', 11); 															//14 digits Blank
+							$data .= date('dmy', $row['pay_period_end_date']);										//4 digits Date
+							$data .= str_repeat(' ', 4); 															//4 digits Blank
+							$data .= str_pad( substr( trim($column_data['hour_code']), 0, 4), 4, ' ', STR_PAD_RIGHT);//4 digits
+							$data .= '0000'; 																		//4 digits HOURS field, always be 0, use SIGNED_HOURS instead.
+							$data .= str_repeat(' ', 4); 															//4 digits Blank
+							$data .= str_pad( str_replace('.','', TTDate::getTimeUnit( $row[$column_id], 20 ) ), 6, 0, STR_PAD_LEFT); //Hours without decimal padded to 6 digits.
+							$data .= '+000000000'; 																	//Filler
+							$data .= "\n";
+						}
+					}
+				}
+				unset($tmp_rows, $column_id, $column_data, $rows, $row);
+				break;
+
+			case 'csv': //Generic CSV.
+				//If this needs to be customized, they can just export any regular report. This could probably be removed completely except for the Hour Code mapping...
 				ksort($setup_data['csv']['columns']);
 				$setup_data['csv']['columns'] = Misc::trimSortPrefix( $setup_data['csv']['columns'] );
 
@@ -658,7 +897,7 @@ class PayrollExportReport extends TimesheetSummaryReport {
 				break;
 		}
 
-		Debug::Arr($data, 'Export Data: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($data, 'Export Data: ', __FILE__, __LINE__, __METHOD__,10);
 		return array( 'file_name' => $file_name, 'mime_type' => $mime_type, 'data' => $data );
 	}
 
