@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -50,20 +50,24 @@ class Report {
 
 	protected $config = array(
 								'other' => array(
+												'report_name' => '', //Name to be displayed on the report.
 												'disable_grand_total' => FALSE,
 												//'output_format' => 'pdf', //PDF, PDF_PRINT, PDF_FORM(Tax Form), PDF_FORM_PRINT(Print Tax Form), HTML, EMAIL
 												'page_orientation' => 'P', //Portrait
 												'page_format' => 'Letter', //Letter/Legal
 												'default_font' => 'freeserif',
 												'font_size' => 0, //+5, +4, .., +1, 0, -1, ..., -4, -5 (adjusts relative font size)
-												'top_margin' => 5, //Allow the user to adjust the left/top margins for different prints.
+												'table_header_font_size' => 10,
+												'table_row_font_size' => 8,
+												'top_margin' => 5, //Allow the user to adjust the left/top margins for different printers.
 												'left_margin' => 5,
 												'right_margin' => 5,
 												'adjust_horizontal_position' => 0, //We may need these for government forms/check printing, for on-page adjustments.
 												'adjust_vertical_position' => 0,
-												'show_blank_values' => FALSE, //Uses "- -" in place of a blank value.
+												'show_blank_values' => TRUE, //Uses "- -" in place of a blank value.
+												'blank_value_placeholder' => '-', //Used to replace blank values with. Was '- -'
 												'show_duplicate_values' => FALSE, //Hides duplicate values in the same columns.
-												'duplicate_value_placeholder' => '', //Used to replace duplicate values with.
+												'duplicate_value_placeholder' => ' ', //Used to replace duplicate values with. Can't be '' as that represents a blank value.
 												),
 								'chart' => array(
 												'enable' => FALSE,
@@ -81,6 +85,7 @@ class Report {
 	protected $tmp_data = NULL;
 	public $data = NULL;
 	protected $total_row = NULL;
+	protected $data_column_widths = NULL;
 	public $pdf = NULL;
 
 	protected $chart_images = array();
@@ -137,6 +142,43 @@ class Report {
 								30 => TTi18n::getText('Chart Only'), //'chart_only'
 							   );
 				break;
+
+			//
+			//Metadata options...
+			//
+			case 'metadata_columns':
+				$options = array(
+								'columns' => array( 'format' => TTi18n::getText('Format'), 'format2' => TTi18n::getText('SubFormat') ),
+								'group_by' => array( 'aggregate' => TTi18n::getText('Aggregate') ),
+								'sub_total_by' => array( 'aggregate' => TTi18n::getText('Aggregate') ),
+								'sort_order' =>	array( 'sort_order' => TTi18n::getText('Sort') )
+							);
+				if ( isset($params) AND $params != '' AND isset($options[$params]) ) {
+					$retval = $options[$params];
+				} else {
+					$retval = $options;
+				}
+
+				break;
+			case 'metadata_column_options':
+				$options = array(
+								'text' => array(),
+								//'time_stamp' => array( 'HH:mm' => 'Hours:Minutes', 'HH' => 'Hours', 'HH:mm:ss' => 'Hours:Min:Sec' )
+								//'date_stamp' => array( 'DD-MM-YY' => 'Day-Month-Year', 'MM-YY' => 'Month-Year' )
+								//'currency' => array( 1 => 'Include dollar sign' 0 => 'Exclude Dollar Sign' )
+								//'precision' => array( 1 => '1 Decimal Place', 1 => '2 Decimal Places',  )
+								//'numeric' => array( 0 => 'w/Seperator', 1 => 'w/o Seperator' )
+								//'full_name' = array( 0 => 'First Name', 1 => 'Last Name', 2 => 'First & Last Name', 3 => 'Last & First Name' ),
+								'aggregate' => array( FALSE => TTi18n::getText('Group By'), 'min' => TTi18n::getText('Min'), 'avg' => TTi18n::getText('Avg'), 'max' => TTi18n::getText('Max'), 'sum' => TTi18n::getText('Sum'), 'count' => TTi18n::getText('Count') ),
+								'sort' => array( 'ASC' => TTi18n::getText('ASC'), 'DESC' => TTi18n::getText('DESC') )
+							);
+				if ( isset($params) AND $params != '' AND isset($options[$params]) ) {
+					$retval = $options[$params];
+				} else {
+					$retval = $options;
+				}
+				break;
+
 		}
 
 		return $retval;
@@ -323,7 +365,7 @@ class Report {
 
 			//Convert time_period into start/end date, with pay_period_schedule_ids if necessary.
 			if ( isset($data['time_period']) AND isset($data['time_period']['time_period'])
-					AND ( $data['time_period']['time_period'] == 'custom_date' ) OR $data['time_period']['time_period'] == 'custom_time' ) {
+					AND ( $data['time_period']['time_period'] == 'custom_date' OR $data['time_period']['time_period'] == 'custom_time' ) ) {
 				Debug::Text('Found Custom dates...', __FILE__, __LINE__, __METHOD__,10);
 				if ( isset($data['time_period']['start_date']) ) {
 					$data['start_date'] = TTDate::parseDateTime( $data['time_period']['start_date'] );
@@ -331,7 +373,7 @@ class Report {
 				if ( isset($data['time_period']['end_date']) ) {
 					$data['end_date'] = TTDate::parseDateTime( $data['time_period']['end_date'] );
 				}
-			} else {
+			} elseif ( isset($data['time_period']) )  {
 				$params = array();
 				if ( isset($data['time_period']['pay_period_schedule_id']) ) {
 					$params = array('pay_period_schedule_id' => $data['time_period']['pay_period_schedule_id'] );
@@ -339,6 +381,11 @@ class Report {
 					$params = array('pay_period_id' => $data['time_period']['pay_period_id'] );
 				}
 
+				if ( !isset($data['time_period']['time_period']) ) {
+					Debug::Text('ERROR: Time Period idenfier not specified!', __FILE__, __LINE__, __METHOD__,10);
+					$data['time_period']['time_period'] = NULL;
+				}
+
 				$time_period_dates = TTDate::getTimePeriodDates($data['time_period']['time_period'], NULL, $this->getUserObject(), $params );
 				if ( $time_period_dates != FALSE ) {
 					if ( isset($time_period_dates['start_date']) ) {
@@ -351,6 +398,8 @@ class Report {
 						$data['pay_period_id'] = $time_period_dates['pay_period_id'];
 					}
 				}
+			} else {
+				Debug::Text('Invalid TimePeriod filter...', __FILE__, __LINE__, __METHOD__,10);
 			}
 		}
 
@@ -367,11 +416,47 @@ class Report {
 		return FALSE;
 	}
 
+	//Used for converting $test[] = blah, or $test[] = array( 'col' => blah ) to $test['col'] => $blah.
+	//Mainly for multi-dimension awesomebox group by, sub_total by, sorting...
+	function convertArrayNumericKeysToString( $arr ) {
+		foreach( $arr as $key => $value ) {
+			if ( is_array($value) ) {
+				foreach( $value as $key2 => $value2 ) {
+					$retarr[$key2] = $value2;
+				}
+			} else {
+				$retarr[$key] = $value;
+			}
+		}
+
+		if (isset($retarr) ) {
+			return $retarr;
+		}
+
+		return FALSE;
+	}
 	function formatGroupConfig() {
-		if ( is_array( $this->getGroupConfig() ) ) {
-			//Merge passed group array with default aggregates from sub-class
-			$group_data = array_merge( array_flip( $this->getGroupConfig() ), $this->getOptions('aggregates') );
-			//Debug::Arr($group_data, 'Final Group Data: ', __FILE__, __LINE__, __METHOD__,10);
+		$group_config = $this->getGroupConfig();
+
+		if ( is_array( $group_config ) ) {
+			$metadata = $this->getOptions('group_by_metadata');
+			if ( is_array($metadata) ) {
+				$aggregates = $metadata['aggregate'];
+			} else {
+				$aggregates = $this->getOptions('aggregates');
+			}
+			//Debug::Arr($aggregates, 'Aggregates: ', __FILE__, __LINE__, __METHOD__,10);
+
+			if ( isset($group_config[0]) AND is_array( $group_config[0] ) ) {
+				$group_data = array_merge( $aggregates, $this->convertArrayNumericKeysToString( $group_config ) );
+			} elseif ( isset($group_config[0]) AND $group_config[0] !== FALSE )  {
+				//Merge passed group array with default aggregates from sub-class
+				$group_data = array_merge( array_flip( $group_config ), $aggregates );
+				//Debug::Arr($group_data, 'Final Group Data: ', __FILE__, __LINE__, __METHOD__,10);
+			} else {
+				Debug::Text('ERROR: Group data cannot be determined!', __FILE__, __LINE__, __METHOD__,10);
+				$group_data = FALSE;
+			}
 
 			return $group_data;
 		}
@@ -425,23 +510,39 @@ class Report {
 	// When multiple columns are selected for sub-totaling, we need to multiply the sub-total passes,
 	// ie: pay_period,branch,department would need to sub-total on pay_period.branch.department, pay_period.branch, pay_period
 	function formatSubTotalConfig() {
-		$data = $this->getSubTotalConfig();
+		$sub_total_config = $this->getSubTotalConfig();
 
-		//Multiple sub-total config into each iteration. Order of the columns matters.
-		//Reverse the array then
-		for( $i=0; $i < count($data); $i++ ) {
-			$n=count($data)-1;
-			foreach( $data as $column ) {
-				if ( $n >= $i ) {
-					$sub_total_data[$i][] = $column;
-				}
-				$n--;
+		if ( is_array( $sub_total_config ) AND count($sub_total_config) > 0 ) {
+			$metadata = $this->getOptions('sub_total_by_metadata');
+			if ( is_array($metadata) ) {
+				$aggregates = $metadata['aggregate'];
+			} else {
+				$aggregates = $this->getOptions('aggregates');
 			}
-			$sub_total_data[$i] = array_merge( array_flip( $sub_total_data[$i] ), $this->getOptions('aggregates') );
-		}
-		//Debug::Arr($sub_total_data, 'Final SubTotal Data: ', __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Arr($aggregates, 'Aggregates: ', __FILE__, __LINE__, __METHOD__,10);
 
-		return $sub_total_data;
+			if ( isset($sub_total_config[0]) ) {
+				$sub_total_config = $this->convertArrayNumericKeysToString( $sub_total_config );
+			}
+
+			//Multiple sub-total config into each iteration. Order of the columns matters.
+			//Reverse the array then
+			for( $i=0; $i < count($sub_total_config); $i++ ) {
+				$n=count($sub_total_config)-1;
+				foreach( $sub_total_config as $column ) {
+					if ( $n >= $i ) {
+						$sub_total_data[$i][] = $column;
+					}
+					$n--;
+				}
+				$sub_total_data[$i] = array_merge( array_flip( $sub_total_data[$i] ), $aggregates );
+			}
+			//Debug::Arr($sub_total_data, 'Final SubTotal Data: ', __FILE__, __LINE__, __METHOD__,10);
+
+			return $sub_total_data;
+		}
+
+		return FALSE;
 	}
 
 	//Sub-Total options - If grouping is being used, we can only sub-total based on grouped columns.
@@ -490,8 +591,10 @@ class Report {
 		if ( isset( $data[0] ) ) {
 			//Allow alternative format of: array( 0 => array('col1' => 'asc'), 1 => array('col2' => 'desc') ) so Flex can use the array key to maintain order
 			foreach( $data as $key => $sort_arr ) {
-				foreach( $sort_arr as $sort_col => $sort_dir ) {
-					$formatted_data[$sort_col] = $sort_dir;
+				if ( is_array($sort_arr) ) {
+					foreach( $sort_arr as $sort_col => $sort_dir ) {
+						$formatted_data[$sort_col] = $sort_dir;
+					}
 				}
 			}
 		} else {
@@ -672,13 +775,13 @@ class Report {
 	function group() {
 		$this->profiler->startTimer( 'group' );
 
-
 		if ( is_array( $this->formatGroupConfig() ) AND count( $this->formatGroupConfig() ) > 0 ) {
 			$this->getProgressBarObject()->start( $this->getAMFMessageID(), count($this->data), NULL, TTi18n::getText('Grouping Data...') );
 
 			$this->data = Group::GroupBy( $this->data, $this->formatGroupConfig() );
 
 			$this->getProgressBarObject()->set( $this->getAMFMessageID(), count($this->data) );
+			//Debug::Arr($this->formatGroupConfig(), 'Group Config: ', __FILE__, __LINE__, __METHOD__,10);
 			//Debug::Arr($this->data, 'Group Data: ', __FILE__, __LINE__, __METHOD__,10);
 		}
 
@@ -711,9 +814,18 @@ class Report {
 
 		$other_config = $this->getOtherConfig();
 		if ( !isset($other_config['disable_grand_total']) OR $other_config['disable_grand_total'] == FALSE ) {
+
+			$metadata = $this->getOptions('grand_total_metadata');
+			if ( is_array($metadata) ) {
+				$aggregates = $metadata['aggregate'];
+			} else {
+				$aggregates = $this->getOptions('aggregates');
+			}
+			//Debug::Arr($aggregates, 'Aggregates: ', __FILE__, __LINE__, __METHOD__,10);
+
 			//Use Group By , so we utilize the proper aggregates when totalling the entire report.
 			//Add '_total' = TRUE as metadata.
-			$total = Group::GroupBy( $this->data, $this->getOptions('aggregates'), 2 ); //2 = Total
+			$total = Group::GroupBy( $this->data, $aggregates, 2 ); //2 = Total
 			$total[0]['_total'] = TRUE;
 			$this->total_row = $total[0];
 			//Debug::Arr($this->total_row, ' Total Row: ', __FILE__, __LINE__, __METHOD__,10);
@@ -746,7 +858,8 @@ class Report {
 						if ( isset($sub_total_data[$key]) ) {
 							//Find non-conflicting key that preserves ordering.
 							$new_key = $key;
-							for($i=0; $i <= count($sub_total_data); $i++ ) {
+							$sub_total_data_count = count($sub_total_data);
+							for($i=0; $i <= $sub_total_data_count; $i++ ) {
 								$new_key .= '_';
 								//Stop the loop if the new key isn't also a duplicate.
 								if ( !isset($sub_total_data[$new_key]) ) {
@@ -771,7 +884,7 @@ class Report {
 			unset($sub_total_data, $k, $key, $data, $tmp_sub_total_data);
 
 			uksort($this->data, 'strnatcasecmp');
-			$this->data = array_values($this->data); //Reindex all rows after sorting.
+			//$this->data = array_values($this->data); //Reindex all rows after sorting.
 			//Debug::Arr($this->data, ' SubTotal Data: ', __FILE__, __LINE__, __METHOD__,10);
 		}
 
@@ -818,36 +931,79 @@ class Report {
 		return TRUE;
 	}
 
-	function columnFormatter( $type, $column, $value ) {
+	function columnFormatter( $type, $column, $value, $format = NULL ) {
 		if ( is_array($value) AND isset($value['display']) ) { //Found sorting array, use display column.
 			return $value['display'];
 		} else {
 			$retval = $value;
 
-			switch ( $type ) {
-				case 'report_date':
-					$retval = TTDate::getReportDates( $column, $value, TRUE, $this->getUserObject() );
-					break;
-				case 'currency':
-					$retval = TTi18n::formatCurrency( $value );
-					break;
-				case 'percent':
-					$retval = TTi18n::formatNumber( $value, TRUE ).'%';
-					break;
-				case 'numeric':
-					$retval = TTi18n::formatNumber( $value, TRUE );
-					break;
-				case 'time_unit':
-					$retval = TTDate::getTimeUnit( $value );
-					break;
-				case 'date_stamp':
-					$retval = TTDate::getDate('DATE', $value );
-					break;
-				case 'time_stamp':
-					$retval = TTDate::getDate('DATE+TIME', $value );
-					break;
-				default:
-					break;
+			if ( $format == 'csv' OR $format == 'raw' ) { //Force specific field formats for exporting to CSV format.
+				switch ( $type ) {
+					case 'report_date':
+						$retval = TTDate::getReportDates( $column, $value, TRUE, $this->getUserObject() );
+						break;
+					case 'currency':
+					case 'percent':
+					case 'numeric':
+						//Don't format above types.
+						break;
+					case 'time_unit':
+						$retval = TTDate::getHours( $value ); //Force to hours always.
+						break;
+					case 'date_stamp':
+						$retval = TTDate::getDate('DATE', $value );
+						break;
+					case 'time':
+						$retval = TTDate::getDate('TIME', $value );
+						break;
+					case 'time_stamp':
+						$retval = TTDate::getDate('DATE+TIME', $value );
+						break;
+					case 'boolean':
+						if ( $value == TRUE ) {
+							$retval = TTi18n::getText('Yes');
+						} else {
+							$retval = TTi18n::getText('No');
+						}
+					default:
+						break;
+				}
+			} else {
+				switch ( $type ) {
+					case 'report_date':
+						$retval = TTDate::getReportDates( $column, $value, TRUE, $this->getUserObject() );
+						break;
+					case 'currency':
+						$retval = TTi18n::formatCurrency( $value );
+						break;
+					case 'percent':
+						$retval = TTi18n::formatNumber( $value, TRUE ).'%';
+						break;
+					case 'numeric':
+						$retval = TTi18n::formatNumber( $value, TRUE );
+						break;
+					case 'time_unit':
+						$retval = TTDate::getTimeUnit( $value );
+						break;
+					case 'date_stamp':
+						$retval = TTDate::getDate('DATE', $value );
+						break;
+					case 'time':
+						$retval = TTDate::getDate('TIME', $value );
+						break;
+					case 'time_stamp':
+						$retval = TTDate::getDate('DATE+TIME', $value );
+						break;
+					case 'boolean':
+						if ( $value == TRUE ) {
+							$retval = TTi18n::getText('Yes');
+						} else {
+							$retval = TTi18n::getText('No');
+						}
+						break;
+					default:
+						break;
+				}
 			}
 
 			//Debug::Text('Column: '. $column .' Value: '. $value .' Retval: '. $retval, __FILE__, __LINE__, __METHOD__,10);
@@ -873,7 +1029,7 @@ class Report {
 		return $this->getTimePeriodFormatOptions( Misc::trimSortPrefix( $this->getOptions('column_format') ) );
 	}
 
-	function _postProcess() {
+	function _postProcess( $format = NULL ) {
 		if ( is_array($this->data) AND count($this->data) > 0 ) {
 			$this->getProgressBarObject()->start( $this->getAMFMessageID(), count($this->data), NULL, TTi18n::getText('Post-Processing Data...') );
 
@@ -886,7 +1042,7 @@ class Report {
 					foreach( $row as $column => $value ) {
 						//Debug::Arr($row, ' Row: ', __FILE__, __LINE__, __METHOD__,10);
 						if ( isset($column_format_config[$column]) ) {
-							$this->data[$key][$column] = $this->columnFormatter( $column_format_config[$column], $column, $value );
+							$this->data[$key][$column] = $this->columnFormatter( $column_format_config[$column], $column, $value, $format );
 						} else {
 							if ( is_array($row[$column]) AND isset($row[$column]['display']) ) { //Found sorting array, use display column.
 								$this->data[$key][$column] = $row[$column]['display'];
@@ -914,6 +1070,12 @@ class Report {
 		//$body = TTI18n::getText('Report').': '. $this->title."\n\n";
 		$body = '';
 
+		//Report Name
+		$report_name = $this->getDescription('report_name');
+		if ( $report_name != '' ) {
+			$body .= TTi18n::getText('Name').': '. $report_name."\n";
+		}
+
 		//Time Period: start/end date, or pay period.
 		$description = $this->getDescription('time_period', array( 'relative_time_period' => $relative_time_period ) );
 		if ( $description != '' ) {
@@ -1007,8 +1169,13 @@ class Report {
 
 				}
 				break;
+			case 'report_name':
+				$config = $this->getOtherConfig();
+				if ( isset($config['report_name']) AND $config['report_name'] != '' ) {
+					$retval = $config['report_name'];
+				}
+				break;
 			case 'filter':
-
 			case 'group':
 			case 'sub_total':
 			case 'sort':
@@ -1020,13 +1187,29 @@ class Report {
 						$columns = Misc::trimSortPrefix( $this->getOptions('setup_fields') );
 						break;
 					case 'group':
-						$config = (array)$this->getGroupConfig();
-						$filter_columns = array_values($config);
+						$config = (array)$this->formatGroupConfig();
+						$filter_columns = array();
+						foreach( $config as $key => $val ){
+							if ( $val == '' OR is_int($val) ) {
+								$filter_columns[] = $key;
+							}
+						}
+						unset($key, $val);
 						$columns = Misc::trimSortPrefix( $this->getOptions('columns') );
 						break;
 					case 'sub_total':
-						$config = (array)$this->getSubTotalConfig();
-						$filter_columns = array_values($config);
+						$config = (array)$this->formatSubTotalConfig();
+						$filter_columns = array();
+
+						if ( is_array($config) AND isset($config[0]) AND is_array($config[0]) ) {
+							$config = $config[0];
+							foreach( $config as $key => $val ){
+								if ( $val == '' OR is_int($val) ) {
+									$filter_columns[] = $key;
+								}
+							}
+						}
+						unset($key, $val);
 						$columns = Misc::trimSortPrefix( $this->getOptions('columns') );
 						break;
 					case 'sort':
@@ -1040,9 +1223,8 @@ class Report {
 				if ( is_array( $filter_columns ) AND count($filter_columns) > 0 ) {
 					foreach( $filter_columns as $column ) {
 						//Debug::Text(' Column: '. $column, __FILE__, __LINE__, __METHOD__,10);
-
 						if ( isset($columns[$column]) ) {
-							$retval[] = Option::getByKey( $column, $columns );
+							$retval[] = trim( Option::getByKey( $column, $columns ) );
 						}
 					}
 
@@ -1057,7 +1239,7 @@ class Report {
 				break;
 		}
 
-		Debug::Text('Getting description for label: '. $label .' Description: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text('Getting description for label: '. $label .' Description: '. $retval, __FILE__, __LINE__, __METHOD__,10);
 
 		return $retval;
 	}
@@ -1094,8 +1276,14 @@ class Report {
 		$this->preProcess( $format );
 		$this->group();
 		$this->sort(); //Sort needs to come before subTotal, as subTotal will need to re-sort the data in order to fit the sub-totals in.
-		$this->Total();
-		$this->subTotal();
+		if ( $format != 'csv' ) { //Exclude total/sub-totals for CSV format
+			$this->Total();
+			$this->subTotal();
+		}
+
+		//Rekey data array starting at 0 sequentially.
+		//This prevents the progress bar from jumping all over or moving in reverse.
+		$this->data = array_values((array)$this->data);
 
 		//We need to generate the charts before postProcess runs.
 		$this->_pdf_Initialize();
@@ -1112,7 +1300,8 @@ class Report {
 		$this->getProgressBarObject()->stop( $this->getAMFMessageID() );
 
 		Debug::Text(' Format: '. $format .' Total Time: '. (microtime(TRUE)-$this->start_time) .' Memory Usage: Current: '. memory_get_usage() .' Peak: '. memory_get_peak_usage() , __FILE__, __LINE__, __METHOD__,10);
-
+		Debug::Arr( Debug::profileTimers( $this->profiler ), ' Profile Timers: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr( $retval, ' Report Data...', __FILE__, __LINE__, __METHOD__,10);
 		if ( $format != 'raw' AND ( !is_array($retval) OR !isset($retval['file_name']) OR !isset($retval['mime_type']) ) ) {
 			return array(
 						 'data' => $retval,
@@ -1132,11 +1321,16 @@ class Report {
 		Debug::Text('Format: '. $format, __FILE__, __LINE__, __METHOD__,10);
 		if ( $format == 'raw' ) {
 			//Should we rekey this array so the order can be presevered, which is critical to outputting it properly?
-			return array_values( $this->data );
+			return $this->data;
 		} elseif ( $format == 'csv' ) {
-			$column_config = $this->getColumnConfig();
-			foreach( $column_config as $column_name => $column_data ) {
-				$columns[$column_name] = $column_name;
+			//Make sure we use the full readable column name when exporting to CSV.
+			$column_options = (array)Misc::trimSortPrefix( $this->getOptions('columns') );
+			$column_config = (array)$this->getReportColumns();
+			$columns = array();
+			foreach( $column_config as $column => $tmp ) {
+				if ( isset($column_options[$column]) ) {
+					$columns[$column] = $column_options[$column];
+				}
 			}
 			//Debug::Arr($columns, 'Columns:  '. $format, __FILE__, __LINE__, __METHOD__,10);
 			return array(
@@ -1156,7 +1350,7 @@ class Report {
 		return TRUE;
 	}
 
-	function email( $output ) {
+	function email( $output, $report_schedule_obj = NULL ) {
 		Debug::Text('Emailing report...', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( is_array($output) AND isset($output['data']) AND $output['data'] != ''
@@ -1165,24 +1359,37 @@ class Report {
 
 			if ( $this->getUserObject()->getWorkEmail() != FALSE ) {
 				$primary_email = $this->getUserObject()->getWorkEmail();
-				if ( $this->getUserObject()->getHomeEmail() != FALSE ) {
-					$secondary_email = $this->getUserObject()->getHomeEmail();
-				} else {
-					$secondary_email = NULL;
+
+				$secondary_email = NULL;
+				if ( is_object( $report_schedule_obj ) AND $report_schedule_obj->getEnableHomeEmail() == TRUE AND $this->getUserObject()->getHomeEmail() != FALSE ) {
+					$secondary_email .= $this->getUserObject()->getHomeEmail();
+				}
+
+				if ( is_object( $report_schedule_obj ) AND $report_schedule_obj->getOtherEmail() != '' ) {
+					$secondary_email .= ' '. $report_schedule_obj->getOtherEmail();
 				}
 			} else {
 				$primary_email = $this->getUserObject()->getHomeEmail();
 				$secondary_email = NULL;
 			}
 
-			Debug::Text('Emailing report to: '. $primary_email, __FILE__, __LINE__, __METHOD__,10);
+			Debug::Text('Emailing report to: '. $primary_email .' CC: '. $secondary_email, __FILE__, __LINE__, __METHOD__,10);
 
-			$subject = APPLICATION_NAME .' '. $this->title;
+			$subject = APPLICATION_NAME .' ';
+			$other_config = $this->getOtherConfig();
+			if ( isset($other_config['report_name']) AND $other_config['report_name'] != '' ) {
+				$subject .= $other_config['report_name'] .' (';
+			}
+			$subject .= $this->title;
+			if ( isset($other_config['report_name']) AND $other_config['report_name'] != '' ) {
+				$subject .= ')';
+			}
 
 			$body = '<html><body>';
 			$body .= TTI18n::getText('Report').': '. $this->title.'<br><br>';
 			$body .= $this->getDescriptionBlock( TRUE );
 			$body .= '</body></html>';
+			//Debug::Text('Email Subject: '. $subject, __FILE__, __LINE__, __METHOD__,10);
 			//Debug::Text('Email Body: '. $body, __FILE__, __LINE__, __METHOD__,10);
 
 			TTLog::addEntry( 0, 500, TTi18n::getText('Emailing Report').': '. $this->title .' '. TTi18n::getText('To') .': '. $primary_email, NULL, $this->getTable() );
@@ -1202,23 +1409,33 @@ class Report {
 			$mail->getMIMEObject()->addAttachment($output['data'], $output['mime_type'], $output['file_name'], FALSE, 'base64');
 
 			$mail->setBody( $mail->getMIMEObject()->get( $mail->default_mime_config ) );
-			$retval = $mail->Send();
+			return $mail->Send();
 		}
 
 		Debug::Text('No report data to email!', __FILE__, __LINE__, __METHOD__,10);
 		return FALSE;
 	}
 
-	function _pdf_detectPageSize( $text, $layout ) {
+	function _pdf_detectPageSize( $column_options, $columns ) {
 		$min_dimensions = array(216, 279); //Letter size, in mm
 
-		if ( !is_array($text) ) {
-			$text[] = $text;
-		}
+		//Compare size of table header with larger bold font compared to table data with smaller font.
+		$this->pdf->SetFont($this->config['other']['default_font'],'B', $this->_pdf_fontSize( $this->config['other']['table_header_font_size'] ) );
+		$table_column_name_widths = $this->_pdf_getTableColumnWidths( array_intersect_key($column_options, (array)$columns), $this->config['other']['layout']['header'] ); //Table header column names
+
+		$this->pdf->SetFont($this->config['other']['default_font'],'', $this->_pdf_fontSize( $this->config['other']['table_row_font_size'] ) );
+		$table_data_column_widths = $this->_pdf_getTableColumnWidths( $this->getLargestColumnData( array_intersect_key($column_options, (array)$columns) ), $this->config['other']['layout']['header'] ); //Table largest column data
 
 		$width = 0;
-		foreach( $text as $k => $str ) {
-			$width += $this->_pdf_getColumnWidth( $str, $layout );
+		foreach( $table_column_name_widths as $column => $column_width ) {
+			if (  $column_width > $table_data_column_widths[$column] ) {
+				$tmp_width = $column_width;
+			} else {
+				$tmp_width = $table_data_column_widths[$column];
+			}
+
+			$this->data_column_widths[$column] = $tmp_width;
+			$width += $tmp_width;
 		}
 
 		$margins = $this->pdf->getMargins();
@@ -1232,6 +1449,41 @@ class Report {
 		return $this->_pdf_getPageSizeDimensionsFromWidth( $width );
 	}
 
+
+	//Return the string from each column that is the largest, so we can base the column widths on these.
+	function getLargestColumnData( $columns ) {
+		//Cache the widths so all data doesn't need to be searched each time.
+		$this->profiler->startTimer( 'getLargestColumnData' );
+
+		$retarr = array();
+		$widths = array();
+		foreach( $columns as $key => $text ) {
+			$retarr[$key] = $text;
+			$widths[$key] = strlen( $text );
+			//Make sure we include the length of the column header in this as well.
+			if ( is_array($this->data) ) {
+				foreach( $this->data as $row => $data_arr ) {
+					if ( isset($data_arr[$key]) ) {
+						if ( is_array($data_arr[$key]) AND isset($data_arr[$key]['display']) ) {
+							$tmp_len = strlen($data_arr[$key]['display']);
+							$data_arr[$key] = $data_arr[$key]['display'];
+						} else {
+							$tmp_len = strlen($data_arr[$key]);
+						}
+						if ( $tmp_len > $widths[$key] ) {
+							$retarr[$key] = $data_arr[$key];
+							$widths[$key] = $tmp_len;
+						}
+					}
+				}
+			}
+		}
+
+		$this->profiler->stopTimer( 'getLargestColumnData' );
+
+		return $retarr;
+	}
+
 	function _pdf_getColumnWidth( $text, $layout ) {
 		$max_width = 0;
 		$cell_padding = 0;
@@ -1242,7 +1494,7 @@ class Report {
 			$cell_padding = $layout['cell_padding'];
 		}
 
-		$string_width = ceil($this->pdf->getStringWidth($text) + $cell_padding);
+		$string_width = ceil( $this->pdf->getStringWidth($text) + $cell_padding );
 
 		if ( $max_width > 0 AND $string_width > $max_width ) {
 			$string_width = $max_width;
@@ -1303,8 +1555,20 @@ class Report {
 		return $retval;
 	}
 
-	function _pdf_getPageSizeDimensionsFromWidth( $width ) {
-		return array( $width, $width*1.2739726027397260274 );
+	function _pdf_getPageSizeDimensionsFromWidth( $min_width ) {
+		//Handle portrait/landscape modes properly
+		if ( $this->config['other']['page_orientation'] == 'L' ) {
+			//Landscape
+			$width = $min_width;
+			$height = $min_width*0.784946236559;
+		} else {
+			//Portrait
+			$width = $min_width;
+			$height = $min_width*1.2739726027397260274;
+		}
+		//Debug::Text(' Orientation: '. $this->config['other']['page_orientation'] .' Width: '. $width .' Height: '. $height, __FILE__, __LINE__, __METHOD__,10);
+		//return array( $width, $width*1.2739726027397260274 );
+		return array( $width, $height );
 	}
 
 	function _pdf_drawLine( $width = 3 ) {
@@ -1364,6 +1628,14 @@ class Report {
 			//Set font to small for report filter description
 			$this->pdf->SetFont($this->config['other']['default_font'], '', $this->_pdf_fontSize(6) );
 
+			//Report Name
+			$report_name = $this->getDescription('report_name');
+			if ( $report_name != '' ) {
+				$this->pdf->Cell(15, $this->_pdf_fontSize(3), TTi18n::getText('Name').':' , 0, 0, 'L', 0, '', 1);
+				$this->pdf->Cell(100, $this->_pdf_fontSize(3), $report_name, 0, 0, 'L', 0, '', 1);
+				$this->pdf->Ln();
+			}
+
 			//Time Period: start/end date, or pay period.
 			$description = $this->getDescription('time_period');
 			if ( $description != '' ) {
@@ -1421,6 +1693,23 @@ class Report {
 		return FALSE;
 	}
 
+	function _pdf_getMaximumNumLinesFromArray( $columns, $column_options, $column_widths ) {
+		$max_num_lines = 1;
+		foreach( $columns as $column => $tmp ) {
+			if ( isset($column_options[$column]) AND isset($column_widths[$column]) ) {
+				$num_lines = $this->pdf->getNumLines($column_options[$column], $column_widths[$column] );
+				if ( $num_lines > $max_num_lines ) {
+					$max_num_lines = $num_lines;
+				}
+			}
+		}
+
+		if ( $max_num_lines > 1 ) {
+			return ($max_num_lines/1.5); //For some reason getNumLines returns 2 when 1.5 will do, so adjust for that here.
+		}
+		return $max_num_lines;
+	}
+
 	function _pdf_Header() {
 		$column_options = Misc::trimSortPrefix( $this->getOptions('columns') );
 		$columns = $this->getReportColumns();
@@ -1434,12 +1723,13 @@ class Report {
 		}
 
 		if ( is_array($columns) AND count($columns) > 0 ) {
-			$this->pdf->SetFont($this->config['other']['default_font'],'B', $this->_pdf_fontSize(10) );
+			$this->pdf->SetFont($this->config['other']['default_font'],'B', $this->_pdf_fontSize( $this->config['other']['table_header_font_size'] ) );
 			$this->pdf->setTextColor(0);
 			$this->pdf->setDrawColor(0);
 			$this->pdf->setFillColor(240); //Grayscale only.
 
-			$column_widths = $this->_pdf_getTableColumnWidths( array_intersect_key($column_options, $columns), $header_layout );
+			$column_widths = $this->data_column_widths;
+			$cell_height = $this->_pdf_getMaximumNumLinesFromArray( $columns, $column_options, $column_widths ) * $this->_pdf_fontSize( $header_layout['height'] );
 			foreach( $columns as $column => $tmp ) {
 				if ( isset($column_options[$column]) AND isset($column_widths[$column]) ) {
 					$cell_width = $column_widths[$column];
@@ -1448,11 +1738,15 @@ class Report {
 						$this->pdf->Ln();
 					}
 					$this->pdf->Cell( $cell_width, $this->_pdf_fontSize( $header_layout['height'] ), $column_options[$column], $header_layout['border'], 0, $header_layout['align'], $header_layout['fill'], '', $header_layout['stretch'] );
+					//Wrapping shouldn't be needed as the cell widths should expand to at least fit the header. Wrapping may be needed on regular rows though.
+					//$this->pdf->MultiCell( $cell_width, $cell_height, $column_options[$column], 0, $header_layout['align'], $header_layout['fill'], 0 );
 				} else {
 					Debug::Text(' Invalid Column: '. $column, __FILE__, __LINE__, __METHOD__,10);
 				}
 			}
 			$this->pdf->Ln();
+			//$this->pdf->Ln( $cell_height ); //Used for multi-cell wrapping
+
 			$this->_pdf_drawLine( 0.75 ); //Slightly smaller than first/last lines.
 		}
 
@@ -1570,7 +1864,7 @@ class Report {
 		//Table Header - Start
 		//
 		$this->config['other']['layout']['header'] = array(
-																	'max_width' => 30,
+																	'max_width' => 500,
 																	'cell_padding' => 2,
 																	'height' => 8,
 																	'align' => 'R',
@@ -1579,7 +1873,7 @@ class Report {
 																	'stretch' => 1 );
 
 		//Determine how large the page needs to be, and change its format as necessary.
-		$page_size = $this->_pdf_detectPageSize( array_intersect_key($column_options, (array)$columns), $this->config['other']['layout']['header'] );
+		$page_size = $this->_pdf_detectPageSize( $column_options, $columns );
 		$this->pdf->AddPage( $this->config['other']['page_orientation'], $page_size );
 
 		$this->profiler->stopTimer( 'PDF' );
@@ -1618,6 +1912,27 @@ class Report {
 		return FALSE;
 	}
 
+	function _pdf_getSubTotalColumnLabelPosition( $row, $columns, $sub_total_columns ) {
+		$sub_total_column_position = FALSE;
+		if ( count( $sub_total_columns ) > 0 ) {
+			$tmp_columns = array_keys( $columns );
+			$tmp_sub_total_columns = array_reverse($sub_total_columns);
+			foreach( $tmp_sub_total_columns as $sub_total_column  ) {
+				if ( isset($row[$sub_total_column]) ) {
+					//Find which position this sub_total column is in.
+					$sub_total_column_position = array_search( $sub_total_column, $tmp_columns )-1;
+					break;
+				}
+			}
+		}
+
+		if ( $sub_total_column_position < 0 ) {
+			$sub_total_column_position = FALSE;
+		}
+
+		return $sub_total_column_position;
+	}
+
 	//Generate PDF.
 	function _pdf_Table() {
 		$this->profiler->startTimer( 'PDF Table' );
@@ -1646,7 +1961,8 @@ class Report {
 								'border' => 0,
 								'fill' => 1,
 								'stretch' => 1 );
-		$column_widths = $this->_pdf_getTableColumnWidths( array_intersect_key($column_options, (array)$columns), $this->config['other']['layout']['header'] );
+
+		$column_widths = $this->data_column_widths;
 
 		$prev_row = array();
 		$r=0;
@@ -1665,7 +1981,7 @@ class Report {
 				$new_page = $this->_pdf_checkPageBreak( $page_break_row_height,  TRUE );
 
 				//Reset all styles/fills after page break.
-				$this->pdf->SetFont($this->config['other']['default_font'],'', $this->_pdf_fontSize(8) );
+				$this->pdf->SetFont($this->config['other']['default_font'],'', $this->_pdf_fontSize( $this->config['other']['table_row_font_size'] ) );
 				$this->pdf->SetTextColor(0);
 				$this->pdf->SetDrawColor(0);
 				if ( $r % 2 == 0 ) {
@@ -1695,6 +2011,9 @@ class Report {
 								$total_row_sub_total_columns++;
 							}
 						}
+
+						//Make sure we only run this once per sub_total row.
+						$sub_total_column_label_position = $this->_pdf_getSubTotalColumnLabelPosition( $row, $columns, $sub_total_columns );
 					}
 
 					foreach( $columns as $column => $tmp ) {
@@ -1710,17 +2029,22 @@ class Report {
 
 						//Bold total and sub-total rows, add lines above each cell.
 						if ( ( isset($row['_subtotal']) AND $row['_subtotal'] == TRUE ) OR ( isset($row['_total']) AND $row['_total'] == TRUE ) ) {
-							$this->pdf->SetFont($this->config['other']['default_font'], 'B', $this->_pdf_fontSize(8) );
+							$this->pdf->SetFont($this->config['other']['default_font'], 'B', $this->_pdf_fontSize( $this->config['other']['table_row_font_size'] ) );
 
 							if ( ( isset($row['_subtotal']) AND $row['_subtotal'] == TRUE ) ) {
-								//Debug::Text(' SubTotal Row... SI: '. $sub_total_columns_count .' C: '. $c .' Row SI: '. $total_row_sub_total_columns, __FILE__, __LINE__, __METHOD__,10);
-								if ( $c == $sub_total_columns_count ) {
+								Debug::Text(' SubTotal Row... SI: '. $sub_total_columns_count .' Pos: '. $sub_total_column_label_position .' C: '. $c .' Row SI: '. $total_row_sub_total_columns, __FILE__, __LINE__, __METHOD__,10);
+								//Need to display "SubTotal" before the column that is being sub-totaled.
+								//if ( $c == $sub_total_columns_count ) {
+								if ( $sub_total_column_label_position !== FALSE AND $c == $sub_total_column_label_position ) {
 									$value = TTi18n::getText('SubTotal').'['. $sub_total_rows[$total_row_sub_total_columns] .']:';
 								} elseif ( $c < ($total_row_sub_total_columns-1) ) {
 									$value = '';
+								} elseif ( $c == 0 AND $sub_total_column_label_position === FALSE ) {
+									$value = '['. $sub_total_rows[$total_row_sub_total_columns] .'] '. $value;
 								}
 							} else {
 								//Debug::Text(' C: '. $c .' Row SI: '. $sub_total_columns_count, __FILE__, __LINE__, __METHOD__,10);
+								//Display "Grand Total" immediately before all the columns that are totaled, or on the last static column.
 								if ( $c == $sub_total_columns_count ) {
 									$value = TTi18n::getText('Grand Total').'['. $total_rows .']:';
 								}
@@ -1740,14 +2064,19 @@ class Report {
 							//Don't show duplicate data in cells that are next to one another. But always show data after a sub-total.
 							//Only do this for static columns as well.
 							//Make sure we don't remove duplicate values in pay stub reports, so if the value is a FLOAT then never replace it.
-							if ( $this->config['other']['show_duplicate_values'] == FALSE AND $new_page == FALSE AND !isset($prev_row['_subtotal']) AND isset($prev_row[$column]) AND isset($row[$column]) AND !is_float($row[$column]) AND $prev_row[$column] === $row[$column] AND isset($static_column_options[$column]) ) {
+							//Make sure we don't replace duplicate values if the duplicates are blank value placeholders.
+							if ( $this->config['other']['show_duplicate_values'] == FALSE AND $new_page == FALSE AND !isset($prev_row['_subtotal'])
+									AND isset($prev_row[$column]) AND isset($row[$column]) AND !is_float($row[$column]) AND $prev_row[$column] === $row[$column]
+									AND isset($static_column_options[$column])
+									AND $prev_row[$column] !== $this->config['other']['blank_value_placeholder'] ) {
 								//This needs to be a space otherwise cell background colors won't be shown.
 								$value = ( $this->config['other']['duplicate_value_placeholder'] != '' ) ? $this->config['other']['duplicate_value_placeholder'] : ' ';
 							}
 						}
 
 						if ( $this->config['other']['show_blank_values'] == TRUE AND $value == '' ) {
-							$value = '- -';
+							//Update $row[$column] so the blank value gets put into the prev_row variable so we can check for it in the next loop.
+							$value = $row[$column] = $this->config['other']['blank_value_placeholder'];
 						}
 
 						if ( !isset($row['_total']) AND $blank_row == TRUE AND $value == '' ) {
@@ -1784,8 +2113,8 @@ class Report {
 
 				//UnBold after sub-total rows, but NOT grand total row.
 				if ( ( isset($row['_subtotal']) AND $row['_subtotal'] == TRUE ) ) {
-					$this->pdf->SetFont($this->config['other']['default_font'], '', $this->_pdf_fontSize(8) );
-					$this->pdf->Ln(3);
+					$this->pdf->SetFont($this->config['other']['default_font'], '', $this->_pdf_fontSize( $this->config['other']['table_row_font_size'] ) );
+					$this->pdf->Ln(10);
 				}
 
 				if ( $blank_row == TRUE ) {
