@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -100,7 +100,7 @@ class ScheduleSummaryReport extends Report {
 				$retval = TTDate::getTimePeriodOptions();
 				break;
 			case 'date_columns':
-				$retval = TTDate::getReportDateOptions( NULL, TTi18n::getText('Date'), 15, FALSE );
+				$retval = TTDate::getReportDateOptions( NULL, TTi18n::getText('Date'), 15, TRUE );
 				break;
 			case 'static_columns':
 				$retval = array(
@@ -123,7 +123,8 @@ class ScheduleSummaryReport extends Report {
 										'-1210-pay_period_schedule' => TTi18n::gettext('Pay Period Schedule'),
 										'-1220-policy_group' => TTi18n::gettext('Policy Group'),
 
-										'-1230-pay_period' => TTi18n::gettext('Pay Period'),
+										//Handled in date_columns above.
+										//'-1230-pay_period' => TTi18n::gettext('Pay Period'),
 
 										'-1600-branch' => TTi18n::gettext('Branch'),
 										'-1610-department' => TTi18n::gettext('Department'),
@@ -161,7 +162,7 @@ class ScheduleSummaryReport extends Report {
 				$columns = $this->getOptions('dynamic_columns');
 				if ( is_array($columns) ) {
 					foreach($columns as $column => $name ) {
-						if ( strpos($column, '_wage') !== FALSE OR strpos($column, '_hourly_rate') !== FALSE ) {
+						if ( strpos($column, '_wage') !== FALSE OR strpos($column, '_hourly_rate') !== FALSE OR strpos($column, 'hourly_rate') !== FALSE ) {
 							$retval[$column] = 'currency';
 						} elseif ( strpos($column, '_time') OR strpos($column, '_policy') ) {
 							$retval[$column] = 'time_unit';
@@ -176,7 +177,7 @@ class ScheduleSummaryReport extends Report {
 					foreach( $dynamic_columns as $column ) {
 						switch ( $column ) {
 							default:
-								if ( strpos($column, '_hourly_rate') !== FALSE ) {
+								if ( strpos($column, '_hourly_rate') !== FALSE OR strpos($column, 'hourly_rate') !== FALSE ) {
 									$retval[$column] = 'avg';
 								} else {
 									$retval[$column] = 'sum';
@@ -209,7 +210,8 @@ class ScheduleSummaryReport extends Report {
 										'-1430-by_department_by_pay_period+work+total_time+total_time_wage' => TTi18n::gettext('Work Time+Wage by Department/Pay Period'),
 										'-1440-by_branch_by_department_by_pay_period+work+total_time+total_time_wage' => TTi18n::gettext('Work Time+Wage by Branch/Department/Pay Period'),
 
-										'-1510-by_title_by_start_time+work+total_time+total_time_wage' => TTi18n::gettext('Work Time+Wage+Total Shifts by Title/Start Time'),
+										'-1510-by_title_by_start_time+work+total_time+total_time_wage+total_shift' => TTi18n::gettext('Work Time+Wage+Total Shifts by Title/Start Time'),
+										'-1520-by_date_by_title+work+total_time+total_time_wage+total_shift' => TTi18n::gettext('Work Time+Wage+Total Shifts by Date/Title'),
 
 										'-2010-by_employee+absence+total_time' => TTi18n::gettext('Absence Time by Employee'),
 										'-2020-by_employee+absence+total_time+total_time_wage' => TTi18n::gettext('Absence Time+Wage by Employee'),
@@ -271,6 +273,9 @@ class ScheduleSummaryReport extends Report {
 										case 'absence':
 											$retval['filter']['status_id'] = array(20);
 											break;
+										case 'total_shift':
+											$retval['columns'][] = 'total_shift';
+											break;
 
 										//Group By
 										//SubTotal
@@ -444,6 +449,18 @@ class ScheduleSummaryReport extends Report {
 											$retval['sort'][] = array('date_stamp' => 'asc');
 											$retval['sort'][] = array('full_name' => 'asc');
 											break;
+										case 'by_date_by_title':
+											$retval['columns'][] = 'date_stamp';
+											$retval['columns'][] = 'title';
+
+											$retval['group'][] = 'date_stamp';
+											$retval['group'][] = 'title';
+
+											$retval['sub_total'][] = 'date_stamp';
+
+											$retval['sort'][] = array('date_stamp' => 'asc');
+											$retval['sort'][] = array('title' => 'asc');
+											break;
 										case 'by_full_name_by_date':
 											$retval['columns'][] = 'full_name';
 											$retval['columns'][] = 'date_stamp';
@@ -571,7 +588,7 @@ class ScheduleSummaryReport extends Report {
 		if ( $slf->getRecordCount() > 0 ) {
 			foreach ( $slf as $key => $s_obj ) {
 				$hourly_rate = 0;
-				if ( $wage_permission_children_ids === TRUE OR in_array( $user_id, $wage_permission_children_ids) ) {
+				if ( $wage_permission_children_ids === TRUE OR in_array( $s_obj->getColumn('user_id'), $wage_permission_children_ids) ) {
 					$hourly_rate = $s_obj->getColumn( 'user_wage_hourly_rate' );
 				}
 
@@ -656,9 +673,9 @@ class ScheduleSummaryReport extends Report {
 			foreach( $this->tmp_data['schedule'] as $user_id => $level_1 ) {
 				if ( isset($this->tmp_data['user'][$user_id]) ) {
 					foreach( $level_1 as $key => $row ) {
-					$date_columns = TTDate::getReportDates( NULL, $row['date_stamp'], FALSE, $this->getUserObject() );
+					$date_columns = TTDate::getReportDates( NULL, $row['date_stamp'], FALSE, $this->getUserObject(), array('pay_period_start_date' => $row['pay_period_start_date'], 'pay_period_end_date' => $row['pay_period_end_date'], 'pay_period_transaction_date' => $row['pay_period_transaction_date']) );
 					$processed_data  = array(
-											'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
+											//'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
 											);
 
 					$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
