@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -88,6 +88,9 @@ class TimesheetSummaryReport extends Report {
 										'-2080-punch_branch_id' => TTi18n::gettext('Punch Branch'),
 										'-2090-punch_department_id' => TTi18n::gettext('Punch Department'),
 
+										'-4010-pay_period_time_sheet_verify_status_id' => TTi18n::gettext('TimeSheet Verification'),
+										'-4020-include_no_data_rows' => TTi18n::gettext('Include Blank Records'),
+
 										'-5000-columns' => TTi18n::gettext('Display Columns'),
 										'-5010-group' => TTi18n::gettext('Group By'),
 										'-5020-sub_total' => TTi18n::gettext('SubTotal By'),
@@ -98,7 +101,7 @@ class TimesheetSummaryReport extends Report {
 				$retval = TTDate::getTimePeriodOptions();
 				break;
 			case 'date_columns':
-				$retval = TTDate::getReportDateOptions( NULL, TTi18n::getText('Date'), 13, FALSE );
+				$retval = TTDate::getReportDateOptions( NULL, TTi18n::getText('Date'), 13, TRUE );
 				break;
 			case 'static_columns':
 				$retval = array(
@@ -125,10 +128,11 @@ class TimesheetSummaryReport extends Report {
 										'-1410-pay_period_schedule' => TTi18n::gettext('Pay Period Schedule'),
 										'-1420-policy_group' => TTi18n::gettext('Policy Group'),
 
-										'-1430-branch' => TTi18n::gettext('Branch'),
-										'-1440-department' => TTi18n::gettext('Department'),
+										'-1430-branch_name' => TTi18n::gettext('Branch'),
+										'-1440-department_name' => TTi18n::gettext('Department'),
 
-										'-1450-pay_period' => TTi18n::gettext('Pay Period'),
+										//Handled in date_columns above.
+										//'-1450-pay_period' => TTi18n::gettext('Pay Period'),
 
 										'-1510-verified_time_sheet' => TTi18n::gettext('Verified TimeSheet'),
 										'-1515-verified_time_sheet_date' => TTi18n::gettext('Verified TimeSheet Date'),
@@ -148,7 +152,7 @@ class TimesheetSummaryReport extends Report {
 										//'-2080-schedule_absence' => TTi18n::gettext('Scheduled Absence'),
 
 										//'-2085-worked_days' => TTi18n::gettext('Worked Days'), //Doesn't work for this report.
-										//'-2090-worked_time' => TTi18n::gettext('Worked Time'),
+										'-2090-worked_time' => TTi18n::gettext('Worked Time'),
 										//'-2100-actual_time' => TTi18n::gettext('Actual Time'),
 										//'-2110-actual_time_diff' => TTi18n::gettext('Actual Time Difference'),
 										//'-2130-paid_time' => TTi18n::gettext('Paid Time'),
@@ -258,15 +262,15 @@ class TimesheetSummaryReport extends Report {
 										'-1100-by_employee+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Employee'),
 
 										'-1110-by_date_by_full_name+regular+regular_wage' => TTi18n::gettext('Regular Time+Wage by Date/Employee'),
-										'-1120-by_date_by_full_name+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Pay Date/Employee'),
-										'-1130-by_date_by_full_name+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Pay Date/Employee'),
-										'-1140-by_date_by_full_name+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Pay Date/Employee'),
+										'-1120-by_date_by_full_name+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Date/Employee'),
+										'-1130-by_date_by_full_name+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Date/Employee'),
+										'-1140-by_date_by_full_name+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Date/Employee'),
 										'-1150-by_date_by_full_name+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Date/Employee'),
 
 										'-1160-by_full_name_by_date+regular+regular_wage' => TTi18n::gettext('Regular Time+Wage by Employee/Date'),
-										'-1170-by_full_name_by_date+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Pay Employee/Date'),
-										'-1180-by_full_name_by_date+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Pay Employee/Date'),
-										'-1190-by_full_name_by_date+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Pay Employee/Date'),
+										'-1170-by_full_name_by_date+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Employee/Date'),
+										'-1180-by_full_name_by_date+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Employee/Date'),
+										'-1190-by_full_name_by_date+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Employee/Date'),
 										'-1200-by_full_name_by_date+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Employee/Date'),
 
 										'-1210-by_branch+regular+regular_wage' => TTi18n::gettext('Regular Time+Wage by Branch'),
@@ -342,6 +346,7 @@ class TimesheetSummaryReport extends Report {
 										'-1900-by_branch_by_department_by_pay_period+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Branch/Department/Pay Period'),
 
 										'-3000-by_pay_period_by_employee+verified_time_sheet' => TTi18n::gettext('Timesheet Verification by Pay Period/Employee'),
+										'-3010-by_verified_time_sheet_by_pay_period_by_employee+verified_time_sheet' => TTi18n::gettext('Timesheet Verification by Verification/Pay Period/Employee'),
 							   );
 
 				break;
@@ -366,6 +371,25 @@ class TimesheetSummaryReport extends Report {
 							$retval['sort'][] = array('verified_time_sheet' => 'desc');
 							$retval['sort'][] = array('verified_time_sheet_date' => 'asc');
 							break;
+						case 'by_verified_time_sheet_by_pay_period_by_employee+verified_time_sheet':
+							$retval['-1010-time_period']['time_period'] = 'last_pay_period';
+
+							$retval['columns'][] = 'verified_time_sheet';
+							$retval['columns'][] = 'pay_period';
+							$retval['columns'][] = 'first_name';
+							$retval['columns'][] = 'last_name';
+							$retval['columns'][] = 'verified_time_sheet_date';
+
+							$retval['group'][] = 'verified_time_sheet';
+							$retval['group'][] = 'pay_period';
+							$retval['group'][] = 'first_name';
+							$retval['group'][] = 'last_name';
+
+							$retval['sort'][] = array('verified_time_sheet' => 'desc');
+							$retval['sort'][] = array('pay_period' => 'asc');
+							$retval['sort'][] = array('verified_time_sheet_date' => 'asc');
+							break;
+
 						default:
 							Debug::Text(' Parsing template name: '. $template, __FILE__, __LINE__, __METHOD__,10);
 							$retval['-1010-time_period']['time_period'] = 'last_pay_period';
@@ -379,6 +403,7 @@ class TimesheetSummaryReport extends Report {
 									switch( $template_keyword ) {
 										//Columns
 										case 'regular':
+											$retval['columns'][] = 'worked_time';
 											$retval['columns'][] = 'regular_time';
 											break;
 										case 'overtime':
@@ -424,30 +449,30 @@ class TimesheetSummaryReport extends Report {
 											$retval['sort'][] = array('first_name' => 'asc');
 											break;
 										case 'by_branch':
-											$retval['columns'][] = 'branch';
+											$retval['columns'][] = 'branch_name';
 
-											$retval['group'][] = 'branch';
+											$retval['group'][] = 'branch_name';
 
-											$retval['sort'][] = array('branch' => 'asc');
+											$retval['sort'][] = array('branch_name' => 'asc');
 											break;
 										case 'by_department':
-											$retval['columns'][] = 'department';
+											$retval['columns'][] = 'department_name';
 
-											$retval['group'][] = 'department';
+											$retval['group'][] = 'department_name';
 
-											$retval['sort'][] = array('department' => 'asc');
+											$retval['sort'][] = array('department_name' => 'asc');
 											break;
 										case 'by_branch_by_department':
-											$retval['columns'][] = 'branch';
-											$retval['columns'][] = 'department';
+											$retval['columns'][] = 'branch_name';
+											$retval['columns'][] = 'department_name';
 
-											$retval['group'][] = 'branch';
-											$retval['group'][] = 'department';
+											$retval['group'][] = 'branch_name';
+											$retval['group'][] = 'department_name';
 
-											$retval['sub_total'][] = 'branch';
+											$retval['sub_total'][] = 'branch_name';
 
-											$retval['sort'][] = array('branch' => 'asc');
-											$retval['sort'][] = array('department' => 'asc');
+											$retval['sort'][] = array('branch_name' => 'asc');
+											$retval['sort'][] = array('department_name' => 'asc');
 											break;
 										case 'by_pay_period':
 											$retval['columns'][] = 'pay_period';
@@ -473,43 +498,43 @@ class TimesheetSummaryReport extends Report {
 											break;
 										case 'by_pay_period_by_branch':
 											$retval['columns'][] = 'pay_period';
-											$retval['columns'][] = 'branch';
+											$retval['columns'][] = 'branch_name';
 
 											$retval['group'][] = 'pay_period';
-											$retval['group'][] = 'branch';
+											$retval['group'][] = 'branch_name';
 
 											$retval['sub_total'][] = 'pay_period';
 
 											$retval['sort'][] = array('pay_period' => 'asc');
-											$retval['sort'][] = array('branch' => 'asc');
+											$retval['sort'][] = array('branch_name' => 'asc');
 											break;
 										case 'by_pay_period_by_department':
 											$retval['columns'][] = 'pay_period';
-											$retval['columns'][] = 'department';
+											$retval['columns'][] = 'department_name';
 
 											$retval['group'][] = 'pay_period';
-											$retval['group'][] = 'department';
+											$retval['group'][] = 'department_name';
 
 											$retval['sub_total'][] = 'pay_period';
 
 											$retval['sort'][] = array('pay_period' => 'asc');
-											$retval['sort'][] = array('department' => 'asc');
+											$retval['sort'][] = array('department_name' => 'asc');
 											break;
 										case 'by_pay_period_by_branch_by_department':
 											$retval['columns'][] = 'pay_period';
-											$retval['columns'][] = 'branch';
-											$retval['columns'][] = 'department';
+											$retval['columns'][] = 'branch_name';
+											$retval['columns'][] = 'department_name';
 
 											$retval['group'][] = 'pay_period';
-											$retval['group'][] = 'branch';
-											$retval['group'][] = 'department';
+											$retval['group'][] = 'branch_name';
+											$retval['group'][] = 'department_name';
 
 											$retval['sub_total'][] = 'pay_period';
-											$retval['sub_total'][] = 'branch';
+											$retval['sub_total'][] = 'branch_name';
 
 											$retval['sort'][] = array('pay_period' => 'asc');
-											$retval['sort'][] = array('branch' => 'asc');
-											$retval['sort'][] = array('department' => 'asc');
+											$retval['sort'][] = array('branch_name' => 'asc');
+											$retval['sort'][] = array('department_name' => 'asc');
 											break;
 										case 'by_employee_by_pay_period':
 											$retval['columns'][] = 'full_name';
@@ -524,43 +549,43 @@ class TimesheetSummaryReport extends Report {
 											$retval['sort'][] = array('pay_period' => 'asc');
 											break;
 										case 'by_branch_by_pay_period':
-											$retval['columns'][] = 'branch';
+											$retval['columns'][] = 'branch_name';
 											$retval['columns'][] = 'pay_period';
 
-											$retval['group'][] = 'branch';
+											$retval['group'][] = 'branch_name';
 											$retval['group'][] = 'pay_period';
 
-											$retval['sub_total'][] = 'branch';
+											$retval['sub_total'][] = 'branch_name';
 
-											$retval['sort'][] = array('branch' => 'asc');
+											$retval['sort'][] = array('branch_name' => 'asc');
 											$retval['sort'][] = array('pay_period' => 'asc');
 											break;
 										case 'by_department_by_pay_period':
-											$retval['columns'][] = 'department';
+											$retval['columns'][] = 'department_name';
 											$retval['columns'][] = 'pay_period';
 
-											$retval['group'][] = 'department';
+											$retval['group'][] = 'department_name';
 											$retval['group'][] = 'pay_period';
 
-											$retval['sub_total'][] = 'department';
+											$retval['sub_total'][] = 'department_name';
 
-											$retval['sort'][] = array('department' => 'asc');
+											$retval['sort'][] = array('department_name' => 'asc');
 											$retval['sort'][] = array('pay_period' => 'asc');
 											break;
 										case 'by_branch_by_department_by_pay_period':
-											$retval['columns'][] = 'branch';
-											$retval['columns'][] = 'department';
+											$retval['columns'][] = 'branch_name';
+											$retval['columns'][] = 'department_name';
 											$retval['columns'][] = 'pay_period';
 
-											$retval['group'][] = 'branch';
-											$retval['group'][] = 'department';
+											$retval['group'][] = 'branch_name';
+											$retval['group'][] = 'department_name';
 											$retval['group'][] = 'pay_period';
 
-											$retval['sub_total'][] = 'branch';
-											$retval['sub_total'][] = 'department';
+											$retval['sub_total'][] = 'branch_name';
+											$retval['sub_total'][] = 'department_name';
 
-											$retval['sort'][] = array('branch' => 'asc');
-											$retval['sort'][] = array('department' => 'asc');
+											$retval['sort'][] = array('branch_name' => 'asc');
+											$retval['sort'][] = array('department_name' => 'asc');
 											$retval['sort'][] = array('pay_period' => 'asc');
 											break;
 										case 'by_date_by_full_name':
@@ -658,11 +683,7 @@ class TimesheetSummaryReport extends Report {
 		$aplf->getByCompanyId( $this->getUserObject()->getCompany() );
 		if ( $aplf->getRecordCount() > 0 ) {
 			foreach( $aplf as $ap_obj ) {
-				if ( $ap_obj->getType() == 10 ) {
-					$policy_rates['absence_policy-'.$ap_obj->getId()] = $ap_obj;
-				} else {
-					$policy_rates['absence_policy-'.$ap_obj->getId()] = FALSE;
-				}
+				$policy_rates['absence_policy-'.$ap_obj->getId()] = $ap_obj;
 			}
 		}
 
@@ -671,7 +692,7 @@ class TimesheetSummaryReport extends Report {
 
 	//Get raw data for report
 	function _getData( $format = NULL ) {
-		$this->tmp_data = array('user_date_total' => array(), 'user' => array(), 'verified_timesheet' => array() );
+		$this->tmp_data = array('user_date_total' => array(), 'user' => array(), 'default_branch' => array(), 'default_department' => array(), 'branch' => array(), 'department' => array(), 'verified_timesheet' => array() );
 
 		$columns = $this->getColumnConfig();
 		$filter_data = $this->getFilterConfig();
@@ -680,7 +701,7 @@ class TimesheetSummaryReport extends Report {
 		if ( $this->getPermissionObject()->Check('punch','view') == FALSE OR $this->getPermissionObject()->Check('wage','view') == FALSE ) {
 			$hlf = TTnew( 'HierarchyListFactory' );
 			$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID() );
-			Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 		} else {
 			//Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 			$permission_children_ids = array();
@@ -724,72 +745,75 @@ class TimesheetSummaryReport extends Report {
 				$user_id = $udt_obj->getColumn('user_id');
 
 				$date_stamp = TTDate::strtotime( $udt_obj->getColumn('date_stamp') );
+				$branch_id = $udt_obj->getColumn('branch_id');
+				$department_id = $udt_obj->getColumn('department_id');
 				$status_id = $udt_obj->getColumn('status_id');
 				$type_id = $udt_obj->getColumn('type_id');
 
-				$branch = $udt_obj->getColumn('branch');
-				$department = $udt_obj->getColumn('department');
-
 				//Can we get rid of Worked and Paid time to simplify things? People have a hard time figuring out what these are anyways for reports.
 				//Paid time doesn't belong to a branch/department, so if we try to group by branch/department there will
 				//always be a blank line showing just the paid time. So if they don't want to display paid time, just exclude it completely.
 				$column = $udt_obj->getTimeCategory();
-				if ( $column == 'paid_time' OR $column == 'worked_time' ) {
+				//Worked_time includes paid lunch/break time as well.
+				if ( $column == 'paid_time' ) {
 					$column = NULL;
 				}
 
-
 				//Debug::Text('Column: '. $column .' Total Time: '. $udt_obj->getColumn('total_time') .' Status: '. $status_id .' Type: '. $type_id .' Rate: '. $udt_obj->getColumn( 'hourly_rate' ), __FILE__, __LINE__, __METHOD__,10);
-				if ( ( isset($filter_data['include_no_data_users']) AND $filter_data['include_no_data_users'] == 1 )
-						OR ( !isset($filter_data['include_no_data_users']) AND $date_stamp != '' AND $column != '' AND $udt_obj->getColumn('total_time') > 0 )  ) {
+				if ( ( isset($filter_data['include_no_data_rows']) AND $filter_data['include_no_data_rows'] == 1 )
+						OR ( $date_stamp != '' AND $column != '' AND $udt_obj->getColumn('total_time') != 0 )  ) {
 
 					$hourly_rate = 0;
 					if ( $wage_permission_children_ids === TRUE OR in_array( $user_id, $wage_permission_children_ids) ) {
 						$hourly_rate = $udt_obj->getColumn( 'hourly_rate' );
 					}
 					if ( isset($policy_hourly_rates[$column]) AND is_object($policy_hourly_rates[$column]) ) {
-						$hourly_rate = $policy_hourly_rates[$column]->getHourlyRate( $udt_obj->getColumn( 'hourly_rate' ) );
+						$hourly_rate = $policy_hourly_rates[$column]->getHourlyRate( $hourly_rate );
 					}
 
-					if ( isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department]) ) {
-						//Add time/wage and calculate average hourly rate.
-						if ( isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column]) ) {
-							$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column] += $udt_obj->getColumn('total_time');
-						} else {
-							$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column] = $udt_obj->getColumn('total_time');
-						}
-
-						if ( isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_wage']) ) {
-							$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_wage'] += bcmul( bcdiv($udt_obj->getColumn('total_time'), 3600), $hourly_rate );
-						} else {
-							$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_wage'] = bcmul( bcdiv($udt_obj->getColumn('total_time'), 3600), $hourly_rate );
-						}
-
-						if ( $this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column] > 0 ) {
-							$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_hourly_rate'] = bcdiv($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_wage'], bcdiv($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column], 3600) );
-						} else {
-							$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_hourly_rate'] = $hourly_rate;
-						}
-					} else {
-						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department] = array(
+					//Split time by user,date,branch,department as that is the lowest level we can split time.
+					//We always need to split time as much as possible as it can always be combined together by grouping.
+					//Unless we never add columns together that would ever span a single row is of course
+					if ( !isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id]) ) {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id] = array(
+															'branch_id' => $udt_obj->getColumn('branch_id'),
+															'department_id' => $udt_obj->getColumn('department_id'),
+															//'branch' => $udt_obj->getColumn('branch'),
+															//'department' => $udt_obj->getColumn('department'),
 															'pay_period_start_date' => strtotime( $udt_obj->getColumn('pay_period_start_date') ),
 															'pay_period_end_date' => strtotime( $udt_obj->getColumn('pay_period_end_date') ),
 															'pay_period_transaction_date' => strtotime( $udt_obj->getColumn('pay_period_transaction_date') ),
 															'pay_period' => strtotime( $udt_obj->getColumn('pay_period_transaction_date') ),
 															'pay_period_id' => $udt_obj->getColumn('pay_period_id'),
-
-															$column => $udt_obj->getColumn('total_time'),
-															$column.'_hourly_rate' => $hourly_rate,
-															$column.'_wage' => bcmul( bcdiv($udt_obj->getColumn('total_time'), 3600), $hourly_rate )
 															);
 					}
 
-					if ( isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department]['gross_wage']) ) {
-						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department]['gross_wage'] += $this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_wage'];
+					//Add time/wage and calculate average hourly rate.
+					$udt_total_time_wage = bcmul( bcdiv($udt_obj->getColumn('total_time'), 3600), $hourly_rate );
+
+					if ( isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column]) ) {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column] += $udt_obj->getColumn('total_time');
 					} else {
-						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department]['gross_wage'] = $this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch][$department][$column.'_wage'];
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column] = $udt_obj->getColumn('total_time');
 					}
 
+					if ( isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column.'_wage']) ) {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column.'_wage'] += $udt_total_time_wage;
+					} else {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column.'_wage'] = $udt_total_time_wage;
+					}
+
+					if ( $this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column] != 0 ) {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column.'_hourly_rate'] = bcdiv($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column.'_wage'], bcdiv($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column], 3600) );
+					} else {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id][$column.'_hourly_rate'] = $hourly_rate;
+					}
+
+					if ( isset($this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id]['gross_wage']) ) {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id]['gross_wage'] += $udt_total_time_wage;
+					} else {
+						$this->tmp_data['user_date_total'][$user_id][$date_stamp][$branch_id][$department_id]['gross_wage'] = $udt_total_time_wage;
+					}
 					unset($hourly_rate);
 				}
 
@@ -809,6 +833,28 @@ class TimesheetSummaryReport extends Report {
 		}
 		//Debug::Arr($this->tmp_data['user'], 'User Raw Data: ', __FILE__, __LINE__, __METHOD__,10);
 
+		$blf = TTnew( 'BranchListFactory' );
+		$blf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
+		Debug::Text(' Branch Total Rows: '. $blf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $blf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
+		foreach ( $blf as $key => $b_obj ) {
+			$this->tmp_data['default_branch'][$b_obj->getId()] = Misc::addKeyPrefix( 'default_branch_', (array)$b_obj->getObjectAsArray( array('id' => TRUE, 'name' => TRUE, 'manual_id' => TRUE, 'other_id1' => TRUE, 'other_id2' => TRUE, 'other_id3' => TRUE, 'other_id4' => TRUE, 'other_id5' => TRUE ) ) );
+			$this->tmp_data['branch'][$b_obj->getId()] = Misc::addKeyPrefix( 'branch_', (array)$b_obj->getObjectAsArray( array('id' => TRUE, 'name' => TRUE, 'manual_id' => TRUE, 'other_id1' => TRUE, 'other_id2' => TRUE, 'other_id3' => TRUE, 'other_id4' => TRUE, 'other_id5' => TRUE ) ) );
+			$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
+		}
+		//Debug::Arr($this->tmp_data['default_branch'], 'Default Branch Raw Data: ', __FILE__, __LINE__, __METHOD__,10);
+
+		$dlf = TTnew( 'DepartmentListFactory' );
+		$dlf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
+		Debug::Text(' Department Total Rows: '. $blf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $dlf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
+		foreach ( $dlf as $key => $d_obj ) {
+			$this->tmp_data['default_department'][$d_obj->getId()] = Misc::addKeyPrefix( 'default_department_', (array)$d_obj->getObjectAsArray( array('id' => TRUE, 'name' => TRUE, 'manual_id' => TRUE, 'other_id1' => TRUE, 'other_id2' => TRUE, 'other_id3' => TRUE, 'other_id4' => TRUE, 'other_id5' => TRUE ) ) );
+			$this->tmp_data['department'][$d_obj->getId()] = Misc::addKeyPrefix( 'department_', (array)$d_obj->getObjectAsArray( array('id' => TRUE, 'name' => TRUE, 'manual_id' => TRUE, 'other_id1' => TRUE, 'other_id2' => TRUE, 'other_id3' => TRUE, 'other_id4' => TRUE, 'other_id5' => TRUE ) ) );
+			$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
+		}
+		//Debug::Arr($this->tmp_data['default_department'], 'Default Department Raw Data: ', __FILE__, __LINE__, __METHOD__,10);
+
 		//Get verified timesheets for all pay periods considered in report.
 		$pay_period_ids = array_keys( $pay_period_ids );
 		if ( isset($pay_period_ids) AND count($pay_period_ids) > 0 ) {
@@ -840,11 +886,12 @@ class TimesheetSummaryReport extends Report {
 					foreach( $level_1 as $date_stamp => $level_2 ) {
 						foreach( $level_2 as $branch => $level_3 ) {
 							foreach( $level_3 as $department => $row ) {
-								$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject() );
+
+								$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject(), array('pay_period_start_date' => $row['pay_period_start_date'], 'pay_period_end_date' => $row['pay_period_end_date'], 'pay_period_transaction_date' => $row['pay_period_transaction_date']) );
 								$processed_data  = array(
-														'branch' => $branch,
-														'department' => $department,
-														'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
+														//'branch_id' => $branch_id,
+														//'department_id' => $department_id,
+														//'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
 														);
 
 								if ( isset( $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]) ) {
@@ -855,7 +902,29 @@ class TimesheetSummaryReport extends Report {
 									$processed_data['verified_time_sheet_date'] = FALSE;
 								}
 
-								$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
+								if ( isset($this->tmp_data['user'][$user_id]['default_branch_id']) AND isset($this->tmp_data['default_branch'][$this->tmp_data['user'][$user_id]['default_branch_id']]) ) {
+									$tmp_default_branch = $this->tmp_data['default_branch'][$this->tmp_data['user'][$user_id]['default_branch_id']];
+								} else {
+									$tmp_default_branch = array();
+								}
+								if ( isset($this->tmp_data['user'][$user_id]['default_department_id']) AND isset($this->tmp_data['default_department'][$this->tmp_data['user'][$user_id]['default_department_id']]) ) {
+									$tmp_default_department = $this->tmp_data['default_department'][$this->tmp_data['user'][$user_id]['default_department_id']];
+								} else {
+									$tmp_default_department = array();
+								}
+
+								if ( isset($this->tmp_data['branch'][$row['branch_id']]) ) {
+									$tmp_branch = $this->tmp_data['branch'][$row['branch_id']];
+								} else {
+									$tmp_branch = array();
+								}
+								if ( isset($this->tmp_data['department'][$row['department_id']]) ) {
+									$tmp_department = $this->tmp_data['department'][$row['department_id']];
+								} else {
+									$tmp_department = array();
+								}
+
+								$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $tmp_default_branch, $tmp_default_department, $tmp_branch, $tmp_department, $row, $date_columns, $processed_data );
 
 								$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
 								$key++;
@@ -866,7 +935,7 @@ class TimesheetSummaryReport extends Report {
 			}
 			unset($this->tmp_data, $row, $date_columns, $processed_data, $level_1, $level_2, $level_3);
 		}
-		//Debug::Arr($this->data, 'preProcess Data: ', __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($this->data, 'preProcess Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		return TRUE;
 	}
