@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -145,6 +145,9 @@ class UserSummaryReport extends Report {
 										'-1480-sin' => TTi18n::gettext('SIN/SSN'),
 										'-1490-note' => TTi18n::gettext('Note'),
 
+										'-1495-tag' => TTi18n::gettext('Tags'),
+										'-1499-hierarchy_control_display' => TTi18n::gettext('Hierarchy'),
+
 										//Date columns handles these.
 										//'-1500-hire_date' => TTi18n::gettext('Hire Date'),
 										//'-1600-termination_date' => TTi18n::gettext('Termination Date'),
@@ -707,15 +710,20 @@ class UserSummaryReport extends Report {
 		//Debug::Arr($permission_children_ids, 'Permission Children: '. count($permission_children_ids), __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($wage_permission_children_ids, 'Wage Children: '. count($wage_permission_children_ids), __FILE__, __LINE__, __METHOD__,10);
 
+		//Always include date columns, because 'hire-date_stamp' is not recognized by the UserFactory.
+		$columns['hire_date'] = $columns['termination_date'] = $columns['birth_date'] = TRUE;
+
 		//Get user data for joining.
 		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Rows: '. $ulf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $ulf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
 		foreach ( $ulf as $key => $u_obj ) {
-			//$this->tmp_data['user'][$u_obj->getId()] = (array)$u_obj->getObjectAsArray( $this->getColumnConfig() );
-			$this->tmp_data['user'][$u_obj->getId()] = (array)$u_obj->data;
-			$this->tmp_data['user'][$u_obj->getId()]['status'] = Option::getByKey( $u_obj->getStatus(), $u_obj->getOptions( 'status' ) );
+			//We used to just get return the entire $u_obj->data array, but this wouldn't include tags and other columns that required some additional processing.
+			//Not sure why this was done that way... I think because we had problems with the multiple date fields (Hire Date/Termination Date/Birth Date, etc...)
+			$this->tmp_data['user'][$u_obj->getId()] = (array)$u_obj->getObjectAsArray( $columns );
+			//$this->tmp_data['user'][$u_obj->getId()] = (array)$u_obj->data;
+			//$this->tmp_data['user'][$u_obj->getId()]['status'] = Option::getByKey( $u_obj->getStatus(), $u_obj->getOptions( 'status' ) );
 
 			$this->tmp_data['user_preference'][$u_obj->getId()] = array();
 			$this->tmp_data['user_wage'][$u_obj->getId()] = array();
@@ -724,7 +732,7 @@ class UserSummaryReport extends Report {
 
 			$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
 		}
-
+		//Debug::Arr($this->tmp_data['user'], 'TMP User Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		//Get user preference data for joining.
 		$uplf = TTnew( 'UserPreferenceListFactory' );
@@ -732,7 +740,7 @@ class UserSummaryReport extends Report {
 		Debug::Text(' User Preference Rows: '. $ulf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $uplf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
 		foreach ( $uplf as $key => $up_obj ) {
-			$this->tmp_data['user_preference'][$up_obj->getUser()] = (array)$up_obj->getObjectAsArray( $this->getColumnConfig() );
+			$this->tmp_data['user_preference'][$up_obj->getUser()] = (array)$up_obj->getObjectAsArray( $columns );
 			$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
 		}
 
@@ -744,7 +752,7 @@ class UserSummaryReport extends Report {
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $ulf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
 		foreach ( $uwlf as $key => $uw_obj ) {
 			if ( $wage_permission_children_ids === TRUE OR in_array( $uw_obj->getUser(), $wage_permission_children_ids) ) {
-				$this->tmp_data['user_wage'][$uw_obj->getUser()] = (array)$uw_obj->getObjectAsArray( $this->getColumnConfig() );
+				$this->tmp_data['user_wage'][$uw_obj->getUser()] = (array)$uw_obj->getObjectAsArray( $columns );
 			}
 			$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
 		}
@@ -756,11 +764,11 @@ class UserSummaryReport extends Report {
 		Debug::Text(' User Bank Rows: '. $balf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $balf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
 		foreach ( $balf as $key => $ba_obj ) {
-			$this->tmp_data['user_bank'][$ba_obj->getUser()] = (array)$ba_obj->getObjectAsArray( $this->getColumnConfig() );
+			$this->tmp_data['user_bank'][$ba_obj->getUser()] = (array)$ba_obj->getObjectAsArray( $columns );
 			$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
 		}
 
-		Debug::Arr($this->tmp_data['user_preference'], 'TMP Data: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($this->tmp_data['user_preference'], 'TMP Data: ', __FILE__, __LINE__, __METHOD__,10);
 		return TRUE;
 	}
 
@@ -772,18 +780,18 @@ class UserSummaryReport extends Report {
 		if ( isset($this->tmp_data['user']) ) {
 			foreach( $this->tmp_data['user'] as $user_id => $row ) {
 				if ( isset($row['hire_date']) ) {
-					$hire_date_columns = TTDate::getReportDates( 'hire', $row['hire_date'], FALSE, $this->getUserObject() );
+					$hire_date_columns = TTDate::getReportDates( 'hire', TTDate::parseDateTime( $row['hire_date'] ), FALSE, $this->getUserObject() );
 				} else {
 					$hire_date_columns = array();
 				}
 
 				if ( isset($row['termination_date']) ) {
-					$termination_date_columns = TTDate::getReportDates( 'termination', $row['termination_date'], FALSE, $this->getUserObject() );
+					$termination_date_columns = TTDate::getReportDates( 'termination', TTDate::parseDateTime( $row['termination_date'] ), FALSE, $this->getUserObject() );
 				} else {
 					$termination_date_columns = array();
 				}
 				if ( isset($row['birth_date']) ) {
-					$birth_date_columns = TTDate::getReportDates( 'birth', $row['birth_date'], FALSE, $this->getUserObject() );
+					$birth_date_columns = TTDate::getReportDates( 'birth', TTDate::parseDateTime( $row['birth_date'] ), FALSE, $this->getUserObject() );
 				} else {
 					$birth_date_columns = array();
 				}
@@ -807,7 +815,7 @@ class UserSummaryReport extends Report {
 			unset($this->tmp_data, $row, $date_columns, $user_id, $hire_date_columns, $termination_date_columns, $birth_date_columns, $processed_data );
 		}
 		//Debug::Arr($this->data, 'preProcess Data: ', __FILE__, __LINE__, __METHOD__,10);
-		
+
 		return TRUE;
 	}
 }
