@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4356 $
- * $Id: RequestFactory.class.php 4356 2011-03-10 20:02:15Z ipso $
- * $Date: 2011-03-10 12:02:15 -0800 (Thu, 10 Mar 2011) $
+ * $Revision: 5749 $
+ * $Id: RequestFactory.class.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 
 /**
@@ -66,10 +66,10 @@ class RequestFactory extends Factory {
 				$retval = array(
 										10 => TTi18n::gettext('INCOMPLETE'),
 										20 => TTi18n::gettext('OPEN'),
-										30 => TTi18n::gettext('PENDING AUTHORIZATION'),
+										30 => TTi18n::gettext('PENDING'), //Used to be "Pending Authorizion"
 										40 => TTi18n::gettext('AUTHORIZATION OPEN'),
-										50 => TTi18n::gettext('ACTIVE'),
-										55 => TTi18n::gettext('AUTHORIZATION DECLINED'),
+										50 => TTi18n::gettext('AUTHORIZED'), //Used to be "Active"
+										55 => TTi18n::gettext('DECLINED'), //Used to be "AUTHORIZATION DECLINED"
 										60 => TTi18n::gettext('DISABLED')
 									);
 				break;
@@ -369,21 +369,23 @@ class RequestFactory extends Factory {
 											TTi18n::gettext('Invalid message length') );
 		}
 
-		if ( $this->getUserDateID() == FALSE ) {
+		if ( $this->getUserDateID() == FALSE OR !is_object( $this->getUserObject() ) ) {
 			$this->Validator->isTRUE(		'user_date',
 											FALSE,
 											TTi18n::gettext('Date/Time is incorrect or pay period does not exist for this date. Please create a pay period schedule if you have not done so already') );
 		}
 
 		//Check to make sure this user has superiors to send a request too, otherwise we can't save the request.
-		$hlf = TTnew( 'HierarchyListFactory' );
-		$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), $this->getHierarchyTypeId(), TRUE, FALSE ); //Request - Immediate parents only.
-		Debug::Arr($request_parent_level_user_ids, 'Check for Superiors: ', __FILE__, __LINE__, __METHOD__,10);
+		if ( is_object( $this->getUserObject() ) ) {
+			$hlf = TTnew( 'HierarchyListFactory' );
+			$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), $this->getHierarchyTypeId(), TRUE, FALSE ); //Request - Immediate parents only.
+			Debug::Arr($request_parent_level_user_ids, 'Check for Superiors: ', __FILE__, __LINE__, __METHOD__,10);
 
-		if ( !is_array($request_parent_level_user_ids) OR count($request_parent_level_user_ids) == 0 ) {
-			$this->Validator->isTRUE(		'message',
-											FALSE,
-											TTi18n::gettext('No supervisors are assigned to you at this time, please try again later') );
+			if ( !is_array($request_parent_level_user_ids) OR count($request_parent_level_user_ids) == 0 ) {
+				$this->Validator->isTRUE(		'message',
+												FALSE,
+												TTi18n::gettext('No supervisors are assigned to you at this time, please try again later') );
+			}
 		}
 
 		return TRUE;
@@ -392,11 +394,14 @@ class RequestFactory extends Factory {
 	function preSave() {
 		//If this is a new request, find the current authorization level to assign to it.
 		if ( $this->isNew() == TRUE ) {
-			$hlf = TTnew( 'HierarchyListFactory' );
-			$hierarchy_arr = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID(), $this->getHierarchyTypeId(), FALSE);
+
+			if ( is_object( $this->getUserObject() ) ) {
+				$hlf = TTnew( 'HierarchyListFactory' );
+				$hierarchy_arr = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID(), $this->getHierarchyTypeId(), FALSE);
+			}
 
 			$hierarchy_highest_level = 99;
-			if ( is_array( $hierarchy_arr ) ) {
+			if ( isset($hierarchy_arr) AND is_array( $hierarchy_arr ) ) {
 				Debug::Arr($hierarchy_arr, ' Hierarchy Array: ', __FILE__, __LINE__, __METHOD__,10);
 				$hierarchy_highest_level = end( array_keys( $hierarchy_arr ) ) ;
 				Debug::Text(' Setting hierarchy level to: '. $hierarchy_highest_level, __FILE__, __LINE__, __METHOD__,10);
