@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4356 $
- * $Id: RequestListFactory.class.php 4356 2011-03-10 20:02:15Z ipso $
- * $Date: 2011-03-10 12:02:15 -0800 (Thu, 10 Mar 2011) $
+ * $Revision: 5891 $
+ * $Id: RequestListFactory.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -864,6 +864,15 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 			$query  .= ' AND  huf.id = -1 '; //Make sure the user maps to a hierarchy.
 		}
 
+		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+			$ph[] = $this->db->BindDate( TTDate::parseDateTime( $filter_data['start_date'] ) );
+			$query  .=	' AND udf.date_stamp >= ?';
+		}
+		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+			$ph[] = $this->db->BindDate( TTDate::parseDateTime( $filter_data['end_date'] ) );
+			$query  .=	' AND udf.date_stamp <= ?';
+		}
+
 		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
 		}
