@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4670 $
- * $Id: RecurringScheduleTemplateFactory.class.php 4670 2011-05-13 19:32:19Z ipso $
- * $Date: 2011-05-13 12:32:19 -0700 (Fri, 13 May 2011) $
+ * $Revision: 5891 $
+ * $Id: RecurringScheduleTemplateFactory.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -695,6 +695,8 @@ class RecurringScheduleTemplateFactory extends Factory {
 														//'department' =>  Option::getByKey($this->getColumn('schedule_department_id'), $department_options, NULL ),
 
 														'created_by_id' => $this->getColumn('recurring_schedule_control_created_by'), //Whoever created the recurring schedule control object is consider the owner.
+														'created_date' => $this->getCreatedDate(),
+														'updated_date' => $this->getUpdatedDate(),
 														);
 					$shifts_index[$iso_date_stamp][$this->getColumn('user_id')][] = $this->getColumn('user_id').$start_time;
 
