@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4550 $
- * $Id: RecurringScheduleTemplateListFactory.class.php 4550 2011-04-19 19:09:38Z ipso $
- * $Date: 2011-04-19 12:09:38 -0700 (Tue, 19 Apr 2011) $
+ * $Revision: 4993 $
+ * $Id: RecurringScheduleTemplateListFactory.class.php 4993 2011-07-15 23:32:11Z ipso $
+ * $Date: 2011-07-15 16:32:11 -0700 (Fri, 15 Jul 2011) $
  */
 
 /**
@@ -254,7 +254,7 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 							d.title_id as title_id,
 							utf.name as title,
 							d.group_id as group_id,
-							ugf.name as group,
+							ugf.name as "group",
 							d.created_by as user_created_by,
 							d.hire_date as hire_date,
 							d.termination_date as termination_date,
