@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4670 $
- * $Id: ScheduleFactory.class.php 4670 2011-05-13 19:32:19Z ipso $
- * $Date: 2011-05-13 12:32:19 -0700 (Fri, 13 May 2011) $
+ * $Revision: 6071 $
+ * $Id: ScheduleFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -63,7 +63,10 @@ class ScheduleFactory extends Factory {
 			case 'status':
 				$retval = array(
 										10 => TTi18n::gettext('Working'),
-										20 => TTi18n::gettext('Absent')
+										20 => TTi18n::gettext('Absent'),
+										//Not displayed on schedules, used to overwrite recurring schedule if we want to change a 8AM-5PM recurring schedule
+										//with a 6PM-11PM schedule? Although this can be done with an absence shift as well...
+										//90 => TTi18n::gettext('Hidden'),
 									);
 				break;
 			case 'columns':
@@ -115,7 +118,7 @@ class ScheduleFactory extends Factory {
 				$retval = array(
 								);
 				break;
-			case 'group_columns': //Columns that are displayed by default.
+			case 'group_columns': //Columns available for grouping on the schedule.
 				$retval = array(
 								'title',
 								'group',
@@ -182,47 +185,15 @@ class ScheduleFactory extends Factory {
 	 }
 
 	function getSchedulePolicyObject() {
-		if ( is_object($this->schedule_policy_obj) ) {
-			return $this->schedule_policy_obj;
-		} else {
-			$splf = TTnew( 'SchedulePolicyListFactory' );
-			$splf->getById( $this->getSchedulePolicyID() );
-			if ( $splf->getRecordCount() > 0 ) {
-				$this->schedule_policy_obj = $splf->getCurrent();
-				return $this->schedule_policy_obj;
-			}
-
-			return FALSE;
-		}
+		return $this->getGenericObject( 'SchedulePolicyListFactory', $this->getSchedulePolicyID(), 'schedule_policy_obj' );
 	}
 
 	function getAbsencePolicyObject() {
-		if ( is_object($this->absence_policy_obj) ) {
-			return $this->absence_policy_obj;
-		} else {
-			$aplf = TTnew( 'AbsencePolicyListFactory' );
-			$aplf->getById( $this->getAbsencePolicyID() );
-			if ( $aplf->getRecordCount() > 0 ) {
-				$this->absence_policy_obj = $aplf->getCurrent();
-			}
-
-			return $this->absence_policy_obj;
-		}
+		return $this->getGenericObject( 'AbsencePolicyListFactory', $this->getAbsencePolicyID(), 'absence_policy_obj' );
 	}
 
 	function getUserDateObject() {
-		if ( is_object($this->user_date_obj) ) {
-			return $this->user_date_obj;
-		} else {
-			$udlf = TTnew( 'UserDateListFactory' );
-			$udlf->getById( $this->getUserDateID() );
-			if ( $udlf->getRecordCount() > 0 ) {
-				$this->user_date_obj = $udlf->getCurrent();
-				return $this->user_date_obj;
-			}
-
-			return FALSE;
-		}
+		return $this->getGenericObject( 'UserDateListFactory', $this->getUserDateID(), 'user_date_obj' );
 	}
 
 	function getUser() {
@@ -249,32 +220,6 @@ class ScheduleFactory extends Factory {
 	}
 
 	function findUserDate($user_id, $epoch) {
-		//Get pay period start/continuous time
-		//FIXME: Add proper schedule support for new_day_trigger_time.
-		/*
-		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
-		$ppslf->getByUserId( $user_id );
-		if ( $ppslf->getRecordCount() == 1 ) {
-			$pps_obj = $ppslf->getCurrent();
-			Debug::Text(' Pay Period Schedule Maximum Shift Time: '. $pps_obj->getMaximumShiftTime(), __FILE__, __LINE__, __METHOD__,10);
-
-			$plf = TTnew( 'PunchListFactory' );
-			$plf->getFirstPunchByUserIDAndEpoch( $user_id, $epoch, $pps_obj->getMaximumShiftTime() );
-
-			if ( $plf->getRecordCount() > 0 ) {
-				$p_obj = $plf->getCurrent();
-				if ( ( $epoch - $p_obj->getTimeStamp() ) <= $pps_obj->getMaximumShiftTime() ) {
-					$user_date_id = $p_obj->getPunchControlObject()->getUserDateID();
-					Debug::text(' User Date ID found: '. $user_date_id, __FILE__, __LINE__, __METHOD__,10);
-
-					$this->setUserDateID( $user_date_id, TRUE );
-					return TRUE;
-				}
-			}
-
-		}
-		*/
-
 		return $this->setUserDate( $user_id, $epoch );
 	}
 
@@ -400,24 +345,38 @@ class ScheduleFactory extends Factory {
 
 
 	function calcTotalTime() {
-		if ( $this->getSchedulePolicyObject() != FALSE ) {
-			if ( $this->getSchedulePolicyObject()->getMealPolicyObject() != FALSE ) {
-				if ( $this->getSchedulePolicyObject()->getMealPolicyObject()->getType() == 10
-						OR $this->getSchedulePolicyObject()->getMealPolicyObject()->getType() == 20 ) {
-					$total_time = ( $this->getEndTime() - $this->getStartTime() );
+		if ( $this->getStartTime() > 0 AND $this->getEndTime() > 0 ) {
+			$total_time = ( $this->getEndTime() - $this->getStartTime() );
 
-					if ( $total_time > $this->getSchedulePolicyObject()->getMealPolicyObject()->getTriggerTime() ) {
-						$total_time -= $this->getSchedulePolicyObject()->getMealPolicyObject()->getAmount();
+			if ( $this->getSchedulePolicyObject() != FALSE ) {
+				if ( $this->getSchedulePolicyObject()->getMealPolicyObject() != FALSE ) {
+					if ( $this->getSchedulePolicyObject()->getMealPolicyObject()->getType() == 10 OR $this->getSchedulePolicyObject()->getMealPolicyObject()->getType() == 20 ) {
+						if ( $total_time > $this->getSchedulePolicyObject()->getMealPolicyObject()->getTriggerTime() ) {
+							$total_time -= $this->getSchedulePolicyObject()->getMealPolicyObject()->getAmount();
+						}
 					}
-
-					return $total_time;
 				}
+
+				$break_policy_ids = $this->getSchedulePolicyObject()->getBreakPolicy();
+				if ( is_array($break_policy_ids) ) {
+					foreach( $break_policy_ids as $break_policy_id ) {
+						if ( $break_policy_id > 0 ) {
+							$break_policy_obj = $this->getSchedulePolicyObject()->getBreakPolicyObject( $break_policy_id );
+							if ( is_object($break_policy_obj) AND ( $break_policy_obj->getType() == 10 OR $break_policy_obj->getType() == 20 ) ) {
+								if ( $total_time > $break_policy_obj->getTriggerTime() ) {
+									$total_time -= $break_policy_obj->getAmount();
+								}
+							}
+						}
+					}
+				}
+				unset($break_policy_ids, $break_policy_id, $break_policy_obj);
 			}
+
+			return $total_time;
 		}
 
-		$total_time = ( $this->getEndTime() - $this->getStartTime() );
-
-		return $total_time;
+		return FALSE;
 	}
 
 	function getTotalTime() {
@@ -623,7 +582,7 @@ class ScheduleFactory extends Factory {
 			Debug::text('aWithin Schedule: '. $epoch, __FILE__, __LINE__, __METHOD__,10);
 
 			return TRUE;
-		} elseif ( $this->inStartWindow( $epoch ) OR $this->inStopWindow( $epoch) )  {
+		} elseif ( $this->inStartWindow( $epoch ) OR $this->inStopWindow( $epoch ) )  {
 			Debug::text('bWithin Schedule: '. $epoch, __FILE__, __LINE__, __METHOD__,10);
 
 			return TRUE;
@@ -840,6 +799,8 @@ class ScheduleFactory extends Factory {
 													//'department' => Option::getByKey($s_obj->getDepartment(), $department_options, NULL ),
 
 													'created_by_id' => $s_obj->getCreatedBy(),
+													'created_date' => $s_obj->getCreatedDate(),
+													'updated_date' => $s_obj->getUpdatedDate(),
 												);
 				$schedule_shifts_index[$iso_date_stamp][$s_obj->getColumn('user_id')][] = $s_obj->getColumn('user_id').$s_obj->getStartTime();
 				unset($absence_policy_name);
@@ -938,7 +899,8 @@ class ScheduleFactory extends Factory {
 		Debug::Arr($this->getEndTime(), 'End Time: '. TTDate::getDate('DATE+TIME', $this->getEndTime()), __FILE__, __LINE__, __METHOD__, 10);
 
 		//This used to be done in Validate, but needs to be done in preSave too.
-		if ( $this->getEndTime() < $this->getStartTime() ) {
+		//Allow 12:00AM to 12:00AM schedules for a total of 24hrs.
+		if ( $this->getEndTime() <= $this->getStartTime() ) {
 			Debug::Text('EndTime spans midnight boundary! Increase by 24hrs ', __FILE__, __LINE__, __METHOD__,10);
 			$this->setEndTime( $this->getEndTime() + 86400 ); //End time spans midnight, add 24hrs.
 		}
@@ -1146,7 +1108,7 @@ class ScheduleFactory extends Factory {
 			unset($tmp_schedule_shifts);
 			//Debug::Arr($raw_schedule_shifts, 'Raw Schedule Shifts: ', __FILE__, __LINE__, __METHOD__,10);
 
-			if ( is_array($raw_schedule_shifts) ) {
+			if ( isset($raw_schedule_shifts) AND is_array($raw_schedule_shifts) ) {
 				foreach( $raw_schedule_shifts as $user_id => $day_schedule_shifts ) {
 
 					foreach( $day_schedule_shifts as $day_epoch => $day_schedule_shifts ) {
@@ -1508,6 +1470,8 @@ class ScheduleFactory extends Factory {
 
 		if ( $this->getStatus() == 10 ) {
 			$this->setAbsencePolicyID( NULL );
+		} elseif ( $this->getStatus() == FALSE ) {
+			$this->setStatus( 10 ); //Default to working.
 		}
 
 		if ( $this->getEnableOverwrite() == TRUE AND $this->isNew() == TRUE ) {
@@ -1533,6 +1497,28 @@ class ScheduleFactory extends Factory {
 	}
 
 	function postSave() {
+		//Check to see if schedule is verified, if so unverify it on modified punch.
+		//Make sure exceptions are calculated *after* this so TimeSheet Not Verified exceptions can be triggered again.
+		if ( is_object( $this->getUserDateObject() )
+				AND is_object( $this->getUserDateObject()->getPayPeriodObject() )
+				AND is_object( $this->getUserDateObject()->getPayPeriodObject()->getPayPeriodScheduleObject() )
+				AND $this->getUserDateObject()->getPayPeriodObject()->getPayPeriodScheduleObject()->getTimeSheetVerifyType() != 10 ) {
+			//Find out if timesheet is verified or not.
+			$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
+			$pptsvlf->getByPayPeriodIdAndUserId(  $this->getUserDateObject()->getPayPeriod(), $this->getUserDateObject()->getUser() );
+			if ( $pptsvlf->getRecordCount() > 0 ) {
+				//Pay period is veriferied, delete all records and make log entry.
+				Debug::text('Pay Period is verified, deleting verification records: '. $pptsvlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+				foreach( $pptsvlf as $pptsv_obj ) {
+					TTLog::addEntry( $pptsv_obj->getId(), 500,  TTi18n::getText('Schedule Modified After Verification').': '. UserListFactory::getFullNameById( $this->getUserDateObject()->getUser() ) .' '. TTi18n::getText('Schedule').': '. TTDate::getDate('DATE', $this->getStartTime() ), NULL, $pptsvlf->getTable() );
+					$pptsv_obj->setDeleted( TRUE );
+					if ( $pptsv_obj->isValid() ) {
+						$pptsv_obj->Save();
+					}
+				}
+			}
+		}
+
 		if ( $this->getEnableReCalculateDay() == TRUE ) {
 			//Calculate total time. Mainly for docked.
 			//Calculate entire week as Over Schedule (Weekly) OT policy needs to be reapplied if the schedule changes.
