@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4673 $
- * $Id: ScheduleListFactory.class.php 4673 2011-05-13 21:18:06Z ipso $
- * $Date: 2011-05-13 14:18:06 -0700 (Fri, 13 May 2011) $
+ * $Revision: 6071 $
+ * $Id: ScheduleListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -696,6 +696,9 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							a.absence_policy_id as absence_policy_id,
 							apf.type_id as absence_policy_type_id,
 
+							a.created_date as created_date,
+							a.updated_date as updated_date,
+
 							bf.name as default_branch,
 							df.name as default_department,
 							ugf.name as "group",
@@ -832,7 +835,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
@@ -1079,6 +1082,8 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		$additional_order_fields = array('schedule_policy_id', 'schedule_policy', 'first_name', 'last_name', 'user_status_id', 'group_id', 'group', 'title_id', 'title', 'default_branch_id', 'default_branch', 'default_department_id', 'default_department', 'total_time', 'date_stamp', 'pay_period_id', );
 
 		$sort_column_aliases = array(
+									 'first_name' => 'd.first_name',
+									 'last_name' => 'd.last_name',
 									 'updated_date' => 'a.updated_date',
 									 'created_date' => 'a.created_date',
 									 );
