@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4306 $
- * $Id: TimeTrexSoapClient.class.php 4306 2011-02-27 21:48:28Z ipso $
- * $Date: 2011-02-27 13:48:28 -0800 (Sun, 27 Feb 2011) $
+ * $Revision: 5208 $
+ * $Id: TimeTrexSoapClient.class.php 5208 2011-09-08 16:48:53Z ipso $
+ * $Date: 2011-09-08 09:48:53 -0700 (Thu, 08 Sep 2011) $
  */
 
 /**
@@ -147,13 +147,21 @@ class TimeTrexSoapClient {
 	}
 
 	function getLocalRegistrationKey() {
+		$key = FALSE;
+
 		$sslf = TTnew( 'SystemSettingListFactory' );
 		$sslf->getByName('registration_key');
 		if ( $sslf->getRecordCount() == 1 ) {
-			return $sslf->getCurrent()->getValue();
+			$key = $sslf->getCurrent()->getValue();
 		}
 
-		return FALSE;
+		//If key is invalid, attempt to obtain a new one.
+		if ( $key == '' ) {
+			$this->saveRegistrationKey();
+			return FALSE;
+		}
+
+		return $key;
 	}
 	function getRegistrationKey() {
 		return $this->getSoapObject()->generateRegistrationKey();
@@ -167,10 +175,9 @@ class TimeTrexSoapClient {
 			$key = $this->getRegistrationKey();
 			Debug::Text('Registration Key from server: '. $key, __FILE__, __LINE__, __METHOD__,10);
 
-			if ( $key != '' ) {
+			if ( $key == '' ) {
 				$key = md5( uniqid() );
-			} else {
-				Debug::Text('Failed getting registration key...', __FILE__, __LINE__, __METHOD__,10);
+				Debug::Text('Failed getting registration key from server...', __FILE__, __LINE__, __METHOD__,10);
 			}
 
 			$sslf->setName('registration_key');
@@ -180,6 +187,11 @@ class TimeTrexSoapClient {
 			}
 
 			return TRUE;
+		} elseif ( $sslf->getRecordCount() > 1 ) {
+			Debug::Text('Too many registration keys, removing them...', __FILE__, __LINE__, __METHOD__,10);
+			foreach( $sslf as $ss_obj ) {
+				$ss_obj->Delete();
+			}
 		} else {
 			Debug::Text('Registration key is already set, skipping...', __FILE__, __LINE__, __METHOD__,10);
 		}
@@ -491,5 +503,45 @@ class TimeTrexSoapClient {
 
 		return FALSE;
 	}
+
+	function getGeoCodeByAddress( $address1, $address2, $city, $province, $country, $postal_code ) {
+		global $config_vars;
+
+		if ( !isset( $config_vars['other']['primary_company_id'] ) ) {
+			$config_vars['other']['primary_company_id'] = 1;
+		}
+
+		try {
+			$clf = TTnew( 'CompanyListFactory' );
+			$clf->getById( $config_vars['other']['primary_company_id'] );
+			if ( $clf->getRecordCount() > 0 ) {
+				foreach( $clf as $c_obj ) {
+					$company_data = array(
+											'system_version' => APPLICATION_VERSION,
+											'registration_key' => $this->getLocalRegistrationKey(),
+											'product_edition_id' => $c_obj->getProductEdition(),
+											'product_edition_available' => getTTProductEdition(),
+											'name' => $c_obj->getName(),
+											'short_name' => $c_obj->getShortName(),
+											'work_phone' => $c_obj->getWorkPhone(),
+											'city' => $c_obj->getCity(),
+											'country' => $c_obj->getCountry(),
+											'province' => $c_obj->getProvince(),
+											'postal_code' => $c_obj->getPostalCode(),
+										  );
+				}
+			}
+		} catch( Exception $e ) {
+			Debug::Text('ERROR: Cant get company data for geocoding, database is likely down...', __FILE__, __LINE__, __METHOD__,10);
+			$company_data = NULL;
+		}
+
+		if ( isset($company_data) AND $city != '' AND $country != '' ) {
+			return $this->getSoapObject()->getGeoCodeByAddress( $address1, $address2, $city, $province, $country, $postal_code, $company_data );
+		}
+
+		return NULL; //Return NULL when no data available, and FALSE to try again later.
+	}
+
 }
 ?>
