@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4674 $
- * $Id: UserDefaultFactory.class.php 4674 2011-05-13 21:19:07Z ipso $
- * $Date: 2011-05-13 14:19:07 -0700 (Fri, 13 May 2011) $
+ * $Revision: 5523 $
+ * $Id: UserDefaultFactory.class.php 5523 2011-11-16 00:54:14Z ipso $
+ * $Date: 2011-11-15 16:54:14 -0800 (Tue, 15 Nov 2011) $
  */
 
 /**
@@ -391,6 +391,31 @@ class UserDefaultFactory extends Factory {
 		return FALSE;
 	}
 
+	function getCountry() {
+		if ( isset($this->data['country']) ) {
+			return $this->data['country'];
+		}
+
+		return FALSE;
+	}
+	function setCountry($country) {
+		$country = trim($country);
+
+		$cf = TTnew( 'CompanyFactory' );
+
+		if ( $this->Validator->inArrayKey(		'country',
+												$country,
+												TTi18n::gettext('Invalid Country'),
+												$cf->getOptions('country') ) ) {
+
+			$this->data['country'] = $country;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getProvince() {
 		if ( isset($this->data['province']) ) {
 			return $this->data['province'];
@@ -412,9 +437,12 @@ class UserDefaultFactory extends Factory {
 			$options = array();
 		}
 
-		if ( $this->Validator->inArrayKey(		'province',
+		//If country isn't set yet, accept the value and re-validate on save.
+		if ( $this->getCountry() == FALSE
+				OR
+				$this->Validator->inArrayKey(	'province',
 												$province,
-												TTi18n::gettext('Invalid Province'),
+												TTi18n::gettext('Invalid Province/State'),
 												$options ) ) {
 
 			$this->data['province'] = $province;
@@ -425,31 +453,6 @@ class UserDefaultFactory extends Factory {
 		return FALSE;
 	}
 
-	function getCountry() {
-		if ( isset($this->data['country']) ) {
-			return $this->data['country'];
-		}
-
-		return FALSE;
-	}
-	function setCountry($country) {
-		$country = trim($country);
-
-		$cf = TTnew( 'CompanyFactory' );
-
-		if ( $this->Validator->inArrayKey(		'country',
-												$country,
-												TTi18n::gettext('Invalid Country'),
-												$cf->getOptions('country') ) ) {
-
-			$this->data['country'] = $country;
-
-			return TRUE;
-		}
-
-		return FALSE;
-	}
-
 	function getWorkPhone() {
 		if ( isset($this->data['work_phone']) ) {
 			return $this->data['work_phone'];
@@ -650,7 +653,7 @@ class UserDefaultFactory extends Factory {
 		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
 		$upf = TTnew( 'UserPreferenceFactory' );
-		
+
 		if ( $this->Validator->inArrayKey(	'time_zone',
 											$time_zone,
 											TTi18n::gettext('Incorrect time zone'),
