@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: UserFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 6071 $
+ * $Id: UserFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -68,6 +68,8 @@ class UserFactory extends Factory {
 		switch( $name ) {
 			case 'status':
 				$retval = array(
+										//Add System users (for APIs and reseller admin accounts)
+										//Add "New Hire" status for employees going through the onboarding process or newly imported employees.
 										10 => TTi18n::gettext('Active'),
 										12 => TTi18n::gettext('Leave - Illness/Injury'),
 										14 => TTi18n::gettext('Leave - Maternity/Parental'),
@@ -88,14 +90,14 @@ class UserFactory extends Factory {
 										'-1010-employee_number' => TTi18n::gettext('Employee #'),
 										'-1020-status' => TTi18n::gettext('Status'),
 										'-1030-user_name' => TTi18n::gettext('User Name'),
-										'-1040-phone_id' => TTi18n::gettext('PIN/Phone ID'),
+										'-1040-phone_id' => TTi18n::gettext('Quick Punch ID'),
 
 										'-1060-first_name' => TTi18n::gettext('First Name'),
 										'-1070-middle_name' => TTi18n::gettext('Middle Name'),
 										'-1080-last_name' => TTi18n::gettext('Last Name'),
 
 										'-1090-title' => TTi18n::gettext('Title'),
-										'-1099-user_group' => TTi18n::gettext('Group'),
+										'-1099-user_group' => TTi18n::gettext('Group'), //Update ImportUser class if sort order is changed for this.
 										'-1100-default_branch' => TTi18n::gettext('Branch'),
 										'-1110-default_department' => TTi18n::gettext('Department'),
 										'-1110-currency' => TTi18n::gettext('Currency'),
@@ -125,6 +127,8 @@ class UserFactory extends Factory {
 										'-1270-termination_date' => TTi18n::gettext('Termination Date'),
 										'-1280-sin' => TTi18n::gettext('SIN/SSN'),
 										'-1290-note' => TTi18n::gettext('Note'),
+										'-1300-tag' => TTi18n::gettext('Tags'),
+										'-1400-hierarchy_control_display' => TTi18n::gettext('Hierarchy'),
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
@@ -225,65 +229,38 @@ class UserFactory extends Factory {
 										'note' => 'Note',
 										'password_reset_key' => 'PasswordResetKey',
 										'password_reset_date' => 'PasswordResetDate',
+										'tag' => 'Tag',
+										'hierarchy_control_display' => FALSE,
 										'deleted' => 'Deleted',
  										);
 		return $variable_function_map;
 	}
 
 	function getUserPreferenceObject() {
-		if ( is_object($this->user_preference_obj) ) {
-			return $this->user_preference_obj;
-		} else {
-			$uplf = TTnew( 'UserPreferenceListFactory' );
-			$this->user_preference_obj = $uplf->getByUserId( $this->getId() )->getCurrent();
+		$retval = $this->getGenericObject( 'UserPreferenceListFactory', $this->getID(), 'user_preference_obj', 'getByUserId', 'getUser' );
+
+		//Always bootstrap the user preferences if none exist.
+		if ( !is_object( $retval ) ) {
+			Debug::Text('NO PREFERENCES SET FOR USER ID: '. $this->getID() .' Using Defaults...', __FILE__, __LINE__, __METHOD__,10);
+			$this->user_preference_obj = TTnew( 'UserPreferenceFactory' );
+			$this->user_preference_obj->setUser( $this->getID() );
 
 			return $this->user_preference_obj;
 		}
+
+		return $retval;
 	}
 
 	function getCompanyObject() {
-		if ( is_object($this->company_obj) ) {
-			return $this->company_obj;
-		} else {
-			$clf = TTnew( 'CompanyListFactory' );
-			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
-
-			return $this->company_obj;
-		}
+		return $this->getGenericObject( 'CompanyListFactory', $this->getCompany(), 'company_obj' );
 	}
 
 	function getTitleObject() {
-		if ( is_object($this->title_obj) ) {
-			return $this->title_obj;
-		} else {
-
-			$utlf = TTnew( 'UserTitleListFactory' );
-			$utlf->getById( $this->getTitle() );
-
-			if ( $utlf->getRecordCount() == 1 ) {
-				$this->title_obj = $utlf->getCurrent();
-
-				return $this->title_obj;
-			}
-
-			return FALSE;
-		}
+		return $this->getGenericObject( 'UserTitleListFactory', $this->getTitle(), 'title_obj' );
 	}
 
 	function getCurrencyObject() {
-		if ( is_object($this->currency_obj) ) {
-			return $this->currency_obj;
-		} else {
-			$clf = TTnew( 'CurrencyListFactory' );
-
-			$clf->getById( $this->getCurrency() );
-			if ( $clf->getRecordCount() == 1 ) {
-				$this->currency_obj = $clf->getCurrent();
-				return $this->currency_obj;
-			}
-		}
-
-		return FALSE;
+		return $this->getGenericObject( 'CurrencyListFactory', $this->getCurrency(), 'currency_obj' );
 	}
 
 	function getCompany() {
@@ -350,9 +327,7 @@ class UserFactory extends Factory {
 	function setGroup($id) {
 		$id = (int)trim($id);
 
-		Debug::Text('Group ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$uglf = TTnew( 'UserGroupListFactory' );
-
 		if (	$id == 0
 				OR
 				$this->Validator->isResultSetWithRows(	'group',
@@ -504,6 +479,26 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 
+	//Display each hierarchy that the employee is assigned too.
+	function getHierarchyControlDisplay() {
+		$hclf = TTnew( 'HierarchyControlListFactory' );
+		$hclf->getObjectTypeAppendedListByCompanyIDAndUserID( $this->getCompany(), $this->getID() );
+		$data = $hclf->getArrayByListFactory( $hclf, FALSE, FALSE, TRUE );
+
+		if ( is_array($data) ) {
+			$retval = array();
+			foreach( $data as $id => $name ) {
+				$retval[] = $name;
+			}
+
+			sort($retval); //Maintain consistent order.
+
+			return implode(',', $retval );
+		}
+
+		return FALSE;
+	}
+
 	function getHierarchyControl() {
 		//Check to see if any temporary data is set for the hierarchy, if not, make a call to the database instead.
 		//postSave() needs to get the tmp_data.
@@ -525,9 +520,11 @@ class UserFactory extends Factory {
 		//array passed in is hierarchy_object_type_id => hierarchy_control_id
 		if ( is_array($data) ) {
 			$hclf = TTnew( 'HierarchyControlListFactory' );
-			Debug::Arr($data,'Hiearchy Control Data: ', __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Arr($data,'Hierarchy Control Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 			foreach( $data as $hierarchy_object_type_id => $hierarchy_control_id ) {
+				$hierarchy_control_id = Misc::trimSortPrefix( $hierarchy_control_id );
+
 				if (	$hierarchy_control_id == 0
 						OR
 						$this->Validator->isResultSetWithRows(		'hierarchy_control_id',
@@ -548,7 +545,7 @@ class UserFactory extends Factory {
 
 	function isUniqueUserName($user_name) {
 		$ph = array(
-					'user_name' => $user_name,
+					'user_name' => trim(strtolower($user_name)),
 					);
 
 		$query = 'select id from '. $this->getTable() .' where user_name = ? AND deleted=0';
@@ -616,7 +613,7 @@ class UserFactory extends Factory {
 
 		return $encrypted_password;
 	}
-	function checkPassword($password) {
+	function checkPassword($password, $check_password_policy = TRUE ) {
 		global $config_vars;
 
 		$password = html_entity_decode( $password );
@@ -629,7 +626,7 @@ class UserFactory extends Factory {
 			if ( is_object($this->getCompanyObject()) ) {
 				$ldap_authentication_type_id = $this->getCompanyObject()->getLDAPAuthenticationType();
 				if ( $ldap_authentication_type_id > 0 ) {
-					$ldap = new TTLDAP();
+					$ldap = TTnew('TTLDAP');
 					$ldap->setHost( $this->getCompanyObject()->getLDAPHost() );
 					$ldap->setPort( $this->getCompanyObject()->getLDAPPort() );
 					$ldap->setBindUserName( $this->getCompanyObject()->getLDAPBindUserName() );
@@ -657,7 +654,14 @@ class UserFactory extends Factory {
 
 		//Don't check local TT passwords if LDAP Only authentication is enabled. Still accept override passwords though.
 		if ( $ldap_authentication_type_id != 2 AND $password == $this->getPassword() ) {
-			return TRUE;
+			//If the passwords match, confirm that the password hasn't exceeded its maximum age.
+			//Allow override passwords always.
+			if ( $check_password_policy == TRUE AND $this->checkPasswordAge() == FALSE ) {
+				Debug::Text('Password Policy: Password exceeds maximum age, denying access...', __FILE__, __LINE__, __METHOD__,10);
+				return FALSE;
+			} else {
+				return TRUE; //Password accepted.
+			}
 		} elseif ( isset($config_vars['other']['override_password_prefix'])
 						AND $config_vars['other']['override_password_prefix'] != '' ) {
 			//Check override password
@@ -687,7 +691,87 @@ class UserFactory extends Factory {
 												4,
 												64) ) {
 
-			$this->data['password'] = $this->encryptPassword( $password );
+			$update_password = TRUE;
+
+			//When changing the password, we need to check if a Password Policy is defined.
+			$c_obj = $this->getCompanyObject();
+			if ( is_object( $c_obj ) AND $c_obj->getPasswordPolicyType() == 1 AND $this->getPermissionLevel() >= $c_obj->getPasswordMinimumPermissionLevel() AND $c_obj->getProductEdition() > 10 ) {
+				Debug::Text('Password Policy: Minimum Length: '. $c_obj->getPasswordMinimumLength() .' Min. Strength: '. $c_obj->getPasswordMinimumStrength() .' ('.  Misc::getPasswordStrength( $password ) .') Age: '. $c_obj->getPasswordMinimumAge(), __FILE__, __LINE__, __METHOD__,10);
+
+				if ( strlen( $password ) < $c_obj->getPasswordMinimumLength() ) {
+					$update_password = FALSE;
+					$this->Validator->isTrue(		'password',
+													FALSE,
+													TTi18n::gettext('Password is too short') );
+				}
+
+				if ( Misc::getPasswordStrength( $password ) <= $c_obj->getPasswordMinimumStrength() ) {
+					$update_password = FALSE;
+					$this->Validator->isTrue(		'password',
+													FALSE,
+													TTi18n::gettext('Password is too weak, add additional numbers or special characters') );
+				}
+
+				if ( $this->getPasswordUpdatedDate() != '' AND $this->getPasswordUpdatedDate() >= time()-($c_obj->getPasswordMinimumAge()*86400) ) {
+					$update_password = FALSE;
+					$this->Validator->isTrue(		'password',
+													FALSE,
+													TTi18n::gettext('Password must reach its minimum age before it can be changed again') );
+				}
+
+				if ( $this->getId() > 0 ) {
+					$uilf = TTnew( 'UserIdentificationListFactory' );
+					$uilf->getByUserIdAndTypeIdAndValue( $this->getId(), 5, $this->encryptPassword( $password ) );
+					if ( $uilf->getRecordCount() > 0 ) {
+						$update_password = FALSE;
+						$this->Validator->isTrue(		'password',
+														FALSE,
+														TTi18n::gettext('Password has already been used in the past, please choose a new one') );
+					}
+					unset($uilf);
+				}
+			} else {
+				//Debug::Text('Password Policy disabled or does not apply to this user.', __FILE__, __LINE__, __METHOD__,10);
+			}
+
+			if ( $update_password === TRUE ) {
+				$this->data['password'] = $this->encryptPassword( $password );
+				$this->setPasswordUpdatedDate( time() );
+			}
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function checkPasswordAge() {
+		$c_obj = $this->getCompanyObject();
+		if ( is_object( $c_obj ) AND $c_obj->getPasswordPolicyType() == 1 AND $this->getPasswordUpdatedDate() > 0 AND $this->getPasswordUpdatedDate() < ( time()-($c_obj->getPasswordMaximumAge()*86400) ) AND $c_obj->getProductEdition() > 10 ) {
+			Debug::Text('Password Policy: Password exceeds maximum age, denying access... Current Age: '. TTDate::getDays( (time()-$this->getPasswordUpdatedDate()) ) .' Maximum Age: '. $c_obj->getPasswordMaximumAge() .' days', __FILE__, __LINE__, __METHOD__,10);
+			return FALSE;
+		}
+		return TRUE;
+	}
+	function getPasswordUpdatedDate() {
+		if ( isset($this->data['password_updated_date']) ) {
+			return $this->data['password_updated_date'];
+		}
+
+		return FALSE;
+	}
+	function setPasswordUpdatedDate($epoch) {
+		if ( empty($epoch) ) {
+			$epoch = NULL;
+		}
+
+		if 	(	$epoch == ''
+				OR
+				$this->Validator->isDate(		'password_updated_date',
+												$epoch,
+												TTi18n::gettext('Password updated date is invalid')) ) {
+
+			$this->data['password_updated_date'] = $epoch;
 
 			return TRUE;
 		}
@@ -772,6 +856,8 @@ class UserFactory extends Factory {
 	function setPhonePassword($phone_password) {
 		$phone_password = trim($phone_password);
 
+		//Phone passwords are now displayed the administrators to make things easier.
+		//NOTE: Phone passwords are used for passwords on the timeclock as well, and need to be able to be cleared sometimes.
 		//Limit phone password to max of 9 digits so we don't overflow an integer on the timeclocks. (10 digits, but maxes out at 2billion)
 		if 	(	$phone_password == ''
 				OR (
@@ -1107,7 +1193,7 @@ class UserFactory extends Factory {
 		}
 
 		$ph = array(
-					'manual_id' => $id,
+					'manual_id' => (int)$id, //Make sure cast this to an int so we can handle overflows above PHP_MAX_INT properly.
 					'company_id' =>  $this->getCompany(),
 					);
 
@@ -1156,8 +1242,8 @@ class UserFactory extends Factory {
 													TTi18n::gettext('Employee number must only be digits'))
 					AND
 					$this->Validator->isTrue(		'employee_number',
-														$this->isUniqueEmployeeNumber($value),
-														TTi18n::gettext('Employee number is already in use, please enter a different one'))
+													$this->isUniqueEmployeeNumber($value),
+													TTi18n::gettext('Employee number is already in use, please enter a different one'))
 				)
 												) {
 			if ( $value != '' AND $value >= 0 ) {
@@ -1278,9 +1364,7 @@ class UserFactory extends Factory {
 	function setTitle($id) {
 		$id = (int)trim($id);
 
-		Debug::Text('Title ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$utlf = TTnew( 'UserTitleListFactory' );
-
 		if (
 				$id == 0
 				OR
@@ -1307,9 +1391,7 @@ class UserFactory extends Factory {
 	function setDefaultBranch($id) {
 		$id = (int)trim($id);
 
-		Debug::Text('Branch ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$blf = TTnew( 'BranchListFactory' );
-
 		if (
 				$id == 0
 				OR
@@ -1336,9 +1418,7 @@ class UserFactory extends Factory {
 	function setDefaultDepartment($id) {
 		$id = (int)trim($id);
 
-		Debug::Text('Department ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$dlf = TTnew( 'DepartmentListFactory' );
-
 		if (
 				$id == 0
 				OR
@@ -1381,12 +1461,33 @@ class UserFactory extends Factory {
 													50) ) {
 
 			$this->data['first_name'] = $first_name;
+			$this->setFirstNameMetaphone( $first_name );
 
 			return TRUE;
 		}
 
 		return FALSE;
 	}
+	function getFirstNameMetaphone() {
+		if ( isset($this->data['first_name_metaphone']) ) {
+			return $this->data['first_name_metaphone'];
+		}
+
+		return FALSE;
+	}
+	function setFirstNameMetaphone($first_name) {
+		$first_name = metaphone( trim($first_name) );
+
+		if 	(	$first_name != '' ) {
+
+			$this->data['first_name_metaphone'] = $first_name;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 
 	function getMiddleInitial() {
 		if ( $this->getMiddleName() != '' ) {
@@ -1454,6 +1555,26 @@ class UserFactory extends Factory {
 													50) ) {
 
 			$this->data['last_name'] = $last_name;
+			$this->setLastNameMetaphone( $last_name );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+	function getLastNameMetaphone() {
+		if ( isset($this->data['last_name_metaphone']) ) {
+			return $this->data['last_name_metaphone'];
+		}
+
+		return FALSE;
+	}
+	function setLastNameMetaphone($last_name) {
+		$last_name = metaphone( trim($last_name) );
+
+		if 	( $last_name != '' ) {
+
+			$this->data['last_name_metaphone'] = $last_name;
 
 			return TRUE;
 		}
@@ -1509,7 +1630,7 @@ class UserFactory extends Factory {
 
 		if ( $this->Validator->inArrayKey(	'sex',
 											$sex,
-											TTi18n::gettext('Invalid gender type'),
+											TTi18n::gettext('Invalid gender'),
 											$this->getOptions('sex') ) ) {
 
 			$this->data['sex_id'] = $sex;
@@ -1658,7 +1779,7 @@ class UserFactory extends Factory {
 	function setProvince($province) {
 		$province = trim($province);
 
-		Debug::Text('Country: '. $this->getCountry() .' Province: '. $province, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text('Country: '. $this->getCountry() .' Province: '. $province, __FILE__, __LINE__, __METHOD__,10);
 
 		$cf = TTnew( 'CompanyFactory' );
 
@@ -1720,6 +1841,54 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getLongitude() {
+		if ( isset($this->data['longitude']) ) {
+			return (float)$this->data['longitude'];
+		}
+
+		return FALSE;
+	}
+	function setLongitude($value) {
+		$value = trim((float)$value);
+
+		if (	$value == 0
+				OR
+				$this->Validator->isFloat(	'longitude',
+											$value,
+											TTi18n::gettext('Longitude is invalid')
+											) ) {
+			$this->data['longitude'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLatitude() {
+		if ( isset($this->data['latitude']) ) {
+			return (float)$this->data['latitude'];
+		}
+
+		return FALSE;
+	}
+	function setLatitude($value) {
+		$value = trim((float)$value);
+
+		if (	$value == 0
+				OR
+				$this->Validator->isFloat(	'latitude',
+											$value,
+											TTi18n::gettext('Latitude is invalid')
+											) ) {
+			$this->data['latitude'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getWorkPhone() {
 		if ( isset($this->data['work_phone']) ) {
 			return $this->data['work_phone'];
@@ -1851,10 +2020,15 @@ class UserFactory extends Factory {
 	function setHomeEmail($home_email) {
 		$home_email = trim($home_email);
 
+		$error_threshold = 7; //No DNS checks.
+		if ( DEPLOYMENT_ON_DEMAND === TRUE ) {
+			$error_threshold = 0; //DNS checks on email address.
+		}
 		if 	(	$home_email == ''
-					OR $this->Validator->isEmail(	'home_email',
+					OR $this->Validator->isEmailAdvanced(	'home_email',
 													$home_email,
-													TTi18n::gettext('Home Email address is invalid')) ) {
+													TTi18n::gettext('Home Email address is invalid'),
+													$error_threshold ) ) {
 
 			$this->data['home_email'] = $home_email;
 
@@ -1874,10 +2048,15 @@ class UserFactory extends Factory {
 	function setWorkEmail($work_email) {
 		$work_email = trim($work_email);
 
+		$error_threshold = 7; //No DNS checks.
+		if ( DEPLOYMENT_ON_DEMAND === TRUE ) {
+			$error_threshold = 0; //DNS checks on email address.
+		}
 		if 	(	$work_email == ''
-					OR	$this->Validator->isEmail(	'work_email',
+					OR	$this->Validator->isEmailAdvanced(	'work_email',
 													$work_email,
-													TTi18n::gettext('Work Email address is invalid')) ) {
+													TTi18n::gettext('Work Email address is invalid'),
+													$error_threshold) ) {
 
 			$this->data['work_email'] = $work_email;
 
@@ -1899,13 +2078,13 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setBirthDate($epoch) {
-		$epoch = trim($epoch);
-
-		if 	(	$this->Validator->isDate(		'birth_date',
+		if 	(	( $epoch !== FALSE AND $epoch == '' )
+				OR $this->Validator->isDate(	'birth_date',
 												$epoch,
 												TTi18n::gettext('Birth date is invalid, try specifying the year with four digits.')) ) {
 
-			$this->data['birth_date'] = TTDate::getMiddleDayEpoch( $epoch );
+			//Allow for negative epochs, for birthdates less than 1960's
+			$this->data['birth_date'] = ( $epoch != 0 AND $epoch != '' ) ? TTDate::getMiddleDayEpoch( $epoch ) : '' ; //Allow blank birthdate.
 
 			return TRUE;
 		}
@@ -1921,11 +2100,8 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setHireDate($epoch) {
-		if ( empty($epoch) ) {
-			$epoch = NULL;
-		}
-
-		if 	(	$epoch == ''
+		//( $epoch !== FALSE AND $epoch == '' ) //Check for strict FALSE causes data from UserDefault to fail if its not set.
+		if 	(	( $epoch == '' )
 				OR
 				$this->Validator->isDate(		'hire_date',
 												$epoch,
@@ -1948,16 +2124,15 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setTerminationDate($epoch) {
-		if ( empty($epoch) ) {
-			$epoch = NULL;
-		}
-
-		if 	(	$epoch == ''
+		if 	(	( $epoch == '' )
 				OR
 				$this->Validator->isDate(		'termination_date',
 												$epoch,
 												TTi18n::gettext('Termination date is invalid')) ) {
 
+			if ( $epoch == '' ) {
+				$epoch = NULL; //Force to NULL if no termination date is set, this prevents "0" from being entered and causing problems with "is NULL" SQL queries.
+			}
 			$this->data['termination_date'] = $epoch;
 
 			return TRUE;
@@ -1982,7 +2157,7 @@ class UserFactory extends Factory {
 		if (
 				$this->Validator->isResultSetWithRows(	'currency_id',
 														$culf->getByID($id),
-														TTi18n::gettext('Invalid Currency')
+														TTi18n::gettext('Invalid currency')
 													) ) {
 
 			$this->data['currency_id'] = $id;
@@ -2317,6 +2492,26 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getTag() {
+		//Check to see if any temporary data is set for the tags, if not, make a call to the database instead.
+		//postSave() needs to get the tmp_data.
+		if ( isset($this->tmp_data['tags']) ) {
+			return $this->tmp_data['tags'];
+		} elseif ( $this->getCompany() > 0 AND $this->getID() > 0 ) {
+			return CompanyGenericTagMapListFactory::getStringByCompanyIDAndObjectTypeIDAndObjectID( $this->getCompany(), 200, $this->getID() );
+		}
+
+		return FALSE;
+	}
+	function setTag( $tags ) {
+		$tags = trim($tags);
+
+		//Save the tags in temporary memory to be committed in postSave()
+		$this->tmp_data['tags'] = $tags;
+
+		return TRUE;
+	}
+
 	function isInformationComplete() {
 		//Make sure the users information is all complete.
 		//No longer check for SIN, as employees can't change it anyways.
@@ -2333,6 +2528,13 @@ class UserFactory extends Factory {
 	}
 
 	function Validate() {
+		//When doing a mass edit of employees, user name is never specified, so we need to avoid this validation issue.
+		if ( $this->getUserName() == '' ) {
+			$this->Validator->isTrue(		'user_name',
+											FALSE,
+											TTi18n::gettext('User name not specified'));
+		}
+
 		//Re-validate the province just in case the country was set AFTER the province.
 		$this->setProvince( $this->getProvince() );
 
@@ -2342,6 +2544,12 @@ class UserFactory extends Factory {
 											TTi18n::gettext('Company is invalid'));
 		}
 
+		if ( $this->getCurrency() == FALSE ) {
+			$this->Validator->isTrue(		'currency_id',
+											FALSE,
+											TTi18n::gettext('Invalid currency'));
+		}
+
 		//Need to require password on new employees as the database column is NOT NULL.
 		//However when mass editing, no IDs are set so this always fails during the only validation phase.
 		if ( $this->validate_only == FALSE AND $this->isNew() == TRUE AND ( $this->getPassword() == FALSE OR $this->getPassword() == '' ) ) {
@@ -2371,6 +2579,10 @@ class UserFactory extends Factory {
 			$this->setStatus( 10 ); //Active
 		}
 
+		if ( $this->getSex() == FALSE ) {
+			$this->setSex( 5 ); //UnSpecified
+		}
+
 		//Remember if this is a new user for postSave()
 		if ( $this->isNew() ) {
 			$this->is_new = TRUE;
@@ -2379,7 +2591,7 @@ class UserFactory extends Factory {
 		return TRUE;
 	}
 
-	function postSave() {
+	function postSave( $data_diff = NULL ) {
 		$this->removeCache( $this->getId() );
 
 		if ( $this->getDeleted() == FALSE AND $this->getPermissionControl() !== FALSE ) {
@@ -2435,7 +2647,9 @@ class UserFactory extends Factory {
 		}
 
 		if ( $this->getDeleted() == FALSE AND $this->getPayPeriodSchedule() !== FALSE ) {
-			Debug::text('Pay Period Schedule is set...', __FILE__, __LINE__, __METHOD__, 10);
+			Debug::text('Pay Period Schedule is set: '. $this->getPayPeriodSchedule(), __FILE__, __LINE__, __METHOD__, 10);
+
+			$add_pay_period_schedule = FALSE;
 
 			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$ppslf->getByUserId( $this->getId() );
@@ -2460,7 +2674,7 @@ class UserFactory extends Factory {
 					}
 					$add_pay_period_schedule = TRUE;
 				}
-			} else {
+			} elseif ( $this->getPayPeriodSchedule() > 0 ) {
 				Debug::text('Not assigned to ANY Pay Period Schedule...', __FILE__, __LINE__, __METHOD__, 10);
 				$add_pay_period_schedule = TRUE;
 			}
@@ -2573,6 +2787,32 @@ class UserFactory extends Factory {
 			}
 		}
 
+		if ( $this->getDeleted() == FALSE AND $this->getPasswordUpdatedDate() >= (time()-10) ) { //If the password was updated in the last 10 seconds.
+			Debug::text('Password changed, saving it for historical purposes... Password: '. $this->getPassword(), __FILE__, __LINE__, __METHOD__, 10);
+
+			$uif = TTnew( 'UserIdentificationFactory' );
+			$uif->setUser( $this->getID() );
+			$uif->setType( 5 ); //Password History
+			$uif->setNumber( 0 );
+			$uif->setValue( $this->getPassword() );
+			if ( $uif->isValid() ) {
+				$uif->Save();
+			}
+			unset($uif);
+		}
+
+		if ( $this->getDeleted() == FALSE ) {
+			Debug::text('Setting Tags...', __FILE__, __LINE__, __METHOD__, 10);
+			CompanyGenericTagMapFactory::setTags( $this->getCompany(), 200, $this->getID(), $this->getTag() );
+
+			if ( is_array($data_diff) AND ( isset($data_diff['address1']) OR isset($data_diff['address2']) OR isset($data_diff['city']) OR isset($data_diff['province']) OR isset($data_diff['country']) OR isset($data_diff['postal_code']) ) ) {
+				//Run a separate custom query to clear the geocordinates. Do we really want to do this for so many objects though...
+				Debug::text('Address has changed, clear geocordinates!', __FILE__, __LINE__, __METHOD__, 10);
+				$query = 'UPDATE '. $this->getTable() .' SET longitude = NULL, latitude = NULL where id = ?';
+				$this->db->Execute( $query, array( 'id' => $this->getID() ) );
+			}
+		}
+
 		if ( isset($this->is_new) AND $this->is_new == TRUE ) {
 			$udlf = TTnew( 'UserDefaultListFactory' );
 			$udlf->getByCompanyId( $this->getCompany() );
@@ -2616,7 +2856,6 @@ class UserFactory extends Factory {
 					$upf->Save();
 				}
 			}
-
 		}
 
 		if ( $this->getDeleted() == TRUE ) {
@@ -2807,6 +3046,12 @@ class UserFactory extends Factory {
 						case 'hierarchy_control':
 							$data[$variable] = $this->getHierarchyControl();
 							break;
+						case 'hierarchy_control_display':
+							//These functions are slow to obtain, so make sure the column is requested explicitly before we include it.
+							if ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) {
+								$data[$variable] = $this->getHierarchyControlDisplay();
+							}
+							break;
 						case 'password': //Don't return password
 							break;
 						case 'sin':
