@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4644 $
- * $Id: UserListFactory.class.php 4644 2011-05-05 23:54:00Z ipso $
- * $Date: 2011-05-05 16:54:00 -0700 (Thu, 05 May 2011) $
+ * $Revision: 6071 $
+ * $Id: UserListFactory.class.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 
 /**
@@ -651,6 +651,7 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		$sdf = new StationDepartmentFactory();
 		$siuf = new StationIncludeUserFactory();
 		$seuf = new StationExcludeUserFactory();
+		$uif = new UserIdentificationFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
@@ -660,10 +661,15 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 					//'date2' => $date,
 					);
 
+		//Also include users with user_identifcation rows that have been *created* after the given date
+		//so the first supervisor/admin enrolled on a timeclock is properly updated to lock the menu.
+		//Make sure we return distinct user rows so there aren't duplicates.
 		$query = '
-					select 	a.*
-					from 	'. $this->getTable() .' as a,
-							'. $sf->getTable() .' as z
+					select 	distinct a.*
+					from 	'. $this->getTable() .' as a
+
+					LEFT JOIN '. $sf->getTable() .' as z ON (1=1)
+					LEFT JOIN '. $uif->getTable() .' as uif ON ( a.id = uif.user_id )
 					where	a.company_id = ?
 						AND z.id = ?
 						AND a.status_id = ?
@@ -700,7 +706,8 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 			//Append the same date twice for created and updated.
 			$ph[] = (int)$date;
 			$ph[] = (int)$date;
-			$query  .=	' 		AND ( a.created_date >= ? OR a.updated_date >= ? )
+			$ph[] = (int)$date;
+			$query  .=	' 		AND ( a.created_date >= ? OR a.updated_date >= ? OR uif.created_date >= ? )
 								)';
 		} else {
 				$query  .=	'   )';
@@ -725,6 +732,100 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByCompanyIDAndStationIDAndStatusAndEmployeeNumber($company_id, $station_id, $status_id, $employee_number, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( $station_id == '') {
+			return FALSE;
+		}
+
+		if ( $status_id == '') {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'a.id' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$sf = new StationFactory();
+		$sugf = new StationUserGroupFactory();
+		$sbf = new StationBranchFactory();
+		$sdf = new StationDepartmentFactory();
+		$siuf = new StationIncludeUserFactory();
+		$seuf = new StationExcludeUserFactory();
+		$uif = new UserIdentificationFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'station_id' => $station_id,
+					'status_id' => $status_id,
+					'employee_number' => $employee_number,
+					//'date' => $date,
+					//'date2' => $date,
+					);
+
+		//Also include users with user_identifcation rows that have been *created* after the given date
+		//so the first supervisor/admin enrolled on a timeclock is properly updated to lock the menu.
+		$query = '
+					select 	a.*
+					from 	'. $this->getTable() .' as a
+
+					LEFT JOIN '. $sf->getTable() .' as z ON (1=1)
+					where	a.company_id = ?
+						AND z.id = ?
+						AND a.status_id = ?
+						AND a.employee_number = ?
+						AND
+							(
+								(
+									(
+										(
+											(
+												z.user_group_selection_type_id = 10
+													OR ( z.user_group_selection_type_id = 20 AND a.group_id in ( select b.group_id from '. $sugf->getTable() .' as b WHERE z.id = b.station_id ) )
+													OR ( z.user_group_selection_type_id = 30 AND a.group_id not in ( select b.group_id from '. $sugf->getTable() .' as b WHERE z.id = b.station_id ) )
+											)
+											AND
+											(
+												z.branch_selection_type_id = 10
+													OR ( z.branch_selection_type_id = 20 AND a.default_branch_id in ( select c.branch_id from '. $sbf->getTable() .' as c WHERE z.id = c.station_id ) )
+													OR ( z.branch_selection_type_id = 30 AND a.default_branch_id not in ( select c.branch_id from '. $sbf->getTable() .' as c WHERE z.id = c.station_id ) )
+											)
+											AND
+											(
+												z.department_selection_type_id = 10
+													OR ( z.department_selection_type_id = 20 AND a.default_department_id in ( select d.department_id from '. $sdf->getTable() .' as d WHERE z.id = d.station_id ) )
+													OR ( z.department_selection_type_id = 30 AND a.default_department_id not in ( select d.department_id from '. $sdf->getTable() .' as d WHERE z.id = d.station_id ) )
+											)
+											AND a.id not in ( select f.user_id from '. $seuf->getTable() .' as f WHERE z.id = f.station_id )
+										)
+										OR a.id in ( select e.user_id from '. $siuf->getTable() .' as e WHERE z.id = e.station_id )
+									)
+								)
+							)
+							';
+
+		$query .= '	AND ( a.deleted = 0 AND z.deleted = 0 )';
+
+		//Debug::Arr($ph, 'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getByCompanyId($company_id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
 		if ( $company_id == '') {
 			return FALSE;
@@ -758,6 +859,44 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByCompanyIdAndLongitudeAndLatitude($company_id, $longitude, $latitude, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'longitude' => 'asc', 'latitude' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	*
+					from 	'. $this->getTable() .'
+					where	company_id = ? ';
+
+		//isset() returns false on NULL.
+		$query .= $this->getWhereClauseSQL( 'longitude', $longitude, 'numeric', $ph );
+		$query .= $this->getWhereClauseSQL( 'latitude', $latitude, 'numeric', $ph );
+		$query .= '	AND deleted = 0';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getByCompanyIdArray($company_id, $include_blank = TRUE, $include_disabled = TRUE, $last_name_first = TRUE ) {
 
 		$ulf = new UserListFactory();
@@ -871,16 +1010,22 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 					'company_id' => $company_id,
 					'created_date' => $date,
 					'updated_date' => $date,
+					'uif_created_date' => $date,
 					);
 
+		$uif = new UserIdentificationFactory();
+
 		//INCLUDE Deleted rows in this query.
+		//Also include users with user_identifcation rows that have been *created* after the given date
+		//so the first supervisor/admin enrolled on a timeclock is properly updated to lock the menu.
 		$query = '
-					select 	*
-					from	'. $this->getTable() .'
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $uif->getTable() .' as uif ON ( a.id = uif.user_id )
 					where
-							company_id = ?
+							a.company_id = ?
 						AND
-							( created_date >= ? OR updated_date >= ? )
+							( a.created_date >= ? OR a.updated_date >= ? OR uif.created_date >= ? )
 					';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
@@ -1569,6 +1714,10 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 			}
 		}
 
+		if ( isset($filter_data['user_status_id']) ) {
+			$filter_data['status_id'] = $filter_data['user_status_id'];
+		}
+
 		if ( isset($filter_data['include_user_id']) ) {
 			$filter_data['id'] = $filter_data['include_user_id'];
 		}
@@ -1576,6 +1725,10 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 			$filter_data['exclude_id'] = $filter_data['exclude_user_id'];
 		}
 
+		if ( isset($filter_data['group_id']) ) {
+			$filter_data['user_group_id'] = $filter_data['group_id'];
+		}
+
 		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
 		$additional_order_fields = array(	'default_branch',
 											'default_department',
@@ -1615,7 +1768,7 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 			}
 			$strict = TRUE;
 		}
-		Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		$compf = new CompanyFactory();
@@ -1636,7 +1789,8 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 					);
 
 		$query = '
-					select 	a.*,
+					select
+							a.*,
 							compf.name as company,
 							b.name as default_branch,
 							c.name as default_department,
@@ -1680,135 +1834,88 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 							SELECT i2.*, i1.user_id
 							FROM '. $pguf->getTable() .' as i1, '. $pgf->getTable() .' as i2
 							WHERE ( i1.policy_group_id = i2.id AND i2.deleted = 0)
-						) as i ON ( a.id = i.user_id )
+						) as i ON ( a.id = i.user_id ) ';
 
+		$query .= '
 						LEFT JOIN '. $this->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
 						LEFT JOIN '. $this->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
 					where	a.company_id = ?
 					';
 
-		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
-			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
-		}
-		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
-			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
-		}
-		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
-			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
-			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
-			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
-				$uglf = new UserGroupListFactory();
-				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
-			}
-			$query  .=	' AND a.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['user_group']) AND trim($filter_data['user_group']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['user_group']));
-			$query  .=	' AND lower(d.name) LIKE ?';
-		}
+		//if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+		//	$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		//}
 
-		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
-			$query  .=	' AND a.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['default_branch']) AND trim($filter_data['default_branch']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['default_branch']));
-			$query  .=	' AND lower(b.name) LIKE ?';
-		}
+		//if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+		//	$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		//}
 
-		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
-			$query  .=	' AND a.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['default_department']) AND trim($filter_data['default_department']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['default_department']));
-			$query  .=	' AND lower(c.name) LIKE ?';
-		}
+		//if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+		//	$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		//}
 
-		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
-			$query  .=	' AND a.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['title']) AND trim($filter_data['title']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['title']));
-			$query  .=	' AND lower(e.name) LIKE ?';
-		}
+		$query .= ( isset($filter_data['permission_children_ids']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['permission_children_ids'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['exclude_id']) ) ? $this->getWhereClauseSQL( 'a.id', $filter_data['exclude_id'], 'not_numeric_list', $ph ) : NULL;
 
-		if ( isset($filter_data['currency_id']) AND isset($filter_data['currency_id'][0]) AND !in_array(-1, (array)$filter_data['currency_id']) ) {
-			$query  .=	' AND a.currency_id in ('. $this->getListSQL($filter_data['currency_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['currency']) AND trim($filter_data['currency']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['currency']));
-			$query  .=	' AND lower(f.name) LIKE ?';
+		if ( isset($filter_data['status']) AND trim($filter_data['status']) != '' AND !isset($filter_data['status_id']) ) {
+			$filter_data['status_id'] = Option::getByFuzzyValue( $filter_data['status'], $this->getOptions('status') );
 		}
+		$query .= ( isset($filter_data['status_id']) ) ? $this->getWhereClauseSQL( 'a.status_id', $filter_data['status_id'], 'numeric_list', $ph ) : NULL;
 
-		if ( isset($filter_data['permission_control_id']) AND isset($filter_data['permission_control_id'][0]) AND !in_array(-1, (array)$filter_data['permission_control_id']) ) {
-			$query  .=	' AND g.permission_control_id in ('. $this->getListSQL($filter_data['permission_control_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['permission_control']) AND trim($filter_data['permission_control']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['permission_control']));
-			$query  .=	' AND lower(g.name) LIKE ?';
+		if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+			$uglf = new UserGroupListFactory();
+			$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
 		}
+		$query .= ( isset($filter_data['user_group_id']) ) ? $this->getWhereClauseSQL( 'a.group_id', $filter_data['user_group_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['user_group']) ) ? $this->getWhereClauseSQL( 'd.name', $filter_data['user_group'], 'text', $ph ) : NULL;
 
-		if ( isset($filter_data['pay_period_schedule_id']) AND isset($filter_data['pay_period_schedule_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_schedule_id']) ) {
-			$query  .=	' AND i.pay_period_schedule_id in ('. $this->getListSQL($filter_data['pay_period_schedule_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['pay_period_schedule']) AND trim($filter_data['pay_period_schedule']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['pay_period_schedule']));
-			$query  .=	' AND lower(h.name) LIKE ?';
-		}
+		$query .= ( isset($filter_data['default_branch_id']) ) ? $this->getWhereClauseSQL( 'a.default_branch_id', $filter_data['default_branch_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['default_branch']) ) ? $this->getWhereClauseSQL( 'b.name', $filter_data['default_branch'], 'text', $ph ) : NULL;
 
-		if ( isset($filter_data['policy_group_id']) AND isset($filter_data['policy_group_id'][0]) AND !in_array(-1, (array)$filter_data['policy_group_id']) ) {
-			$query  .=	' AND k.policy_group_id in ('. $this->getListSQL($filter_data['policy_group_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['policy_group']) AND trim($filter_data['policy_group']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['policy_group']));
-			$query  .=	' AND lower(i.name) LIKE ?';
-		}
+		$query .= ( isset($filter_data['default_department_id']) ) ? $this->getWhereClauseSQL( 'a.default_department_id', $filter_data['default_department_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['default_department']) ) ? $this->getWhereClauseSQL( 'c.name', $filter_data['default_department'], 'text', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['title_id']) ) ? $this->getWhereClauseSQL( 'a.title_id', $filter_data['title_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['title']) ) ? $this->getWhereClauseSQL( 'e.name', $filter_data['title'], 'text', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['currency_id']) ) ? $this->getWhereClauseSQL( 'a.currency_id', $filter_data['currency_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['currency']) ) ? $this->getWhereClauseSQL( 'f.name', $filter_data['currency'], 'text', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['permission_control_id']) ) ? $this->getWhereClauseSQL( 'g.permission_control_id', $filter_data['permission_control_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['permission_control']) ) ? $this->getWhereClauseSQL( 'g.name', $filter_data['permission_control'], 'text', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['pay_period_schedule_id']) ) ? $this->getWhereClauseSQL( 'i.pay_period_schedule_id', $filter_data['pay_period_schedule_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['pay_period_schedule']) ) ? $this->getWhereClauseSQL( 'h.name', $filter_data['pay_period_schedule'], 'text', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['policy_group_id']) ) ? $this->getWhereClauseSQL( 'k.policy_group_id', $filter_data['policy_group_id'], 'numeric_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['policy_group']) ) ? $this->getWhereClauseSQL( 'i.name', $filter_data['policy_group'], 'text', $ph ) : NULL;
 
 		if ( isset($filter_data['sex']) AND trim($filter_data['sex']) != '' AND !isset($filter_data['sex_id']) ) {
 			$filter_data['sex_id'] = Option::getByFuzzyValue( $filter_data['sex'], $this->getOptions('sex') );
 		}
-		if ( isset($filter_data['sex_id']) AND isset($filter_data['sex_id'][0]) AND !in_array(-1, (array)$filter_data['sex_id']) ) {
-			$query  .=	' AND a.sex_id in ('. $this->getListSQL($filter_data['sex_id'], $ph) .') ';
-		}
+		$query .= ( isset($filter_data['sex_id']) ) ?$this->getWhereClauseSQL( 'a.sex_id', $filter_data['sex_id'], 'text_list', $ph ) : NULL;
 
-		if ( isset($filter_data['country']) AND isset($filter_data['country'][0]) AND !in_array(-1, (array)$filter_data['country']) ) {
-			$query  .=	' AND a.country in ('. $this->getListSQL($filter_data['country'], $ph) .') ';
-		}
-		if ( isset($filter_data['province']) AND isset($filter_data['province'][0]) AND !in_array( -1, (array)$filter_data['province']) AND !in_array( '00', (array)$filter_data['province']) ) {
-			$query  .=	' AND a.province in ('. $this->getListSQL($filter_data['province'], $ph) .') ';
-		}
-		if ( isset($filter_data['city']) AND trim($filter_data['city']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['city']));
-			$query  .=	' AND lower(a.city) LIKE ?';
-		}
-		if ( isset($filter_data['first_name']) AND trim($filter_data['first_name']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['first_name']));
-			$query  .=	' AND lower(a.first_name) LIKE ?';
-		}
-		if ( isset($filter_data['last_name']) AND trim($filter_data['last_name']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['last_name']));
-			$query  .=	' AND lower(a.last_name) LIKE ?';
-		}
+		$query .= ( isset($filter_data['first_name']) ) ? $this->getWhereClauseSQL( 'a.first_name', $filter_data['first_name'], 'text_metaphone', $ph ) : NULL;
+		$query .= ( isset($filter_data['last_name']) ) ? $this->getWhereClauseSQL( 'a.last_name', $filter_data['last_name'], 'text_metaphone', $ph ) : NULL;
+		$query .= ( isset($filter_data['home_phone']) ) ? $this->getWhereClauseSQL( 'a.home_phone', $filter_data['home_phone'], 'phone', $ph ) : NULL;
+		$query .= ( isset($filter_data['work_phone']) ) ? $this->getWhereClauseSQL( 'a.work_phone', $filter_data['work_phone'], 'phone', $ph ) : NULL;
+		$query .= ( isset($filter_data['country']) ) ?$this->getWhereClauseSQL( 'a.country', $filter_data['country'], 'upper_text_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['province']) ) ? $this->getWhereClauseSQL( 'a.province', $filter_data['province'], 'upper_text_list', $ph ) : NULL;
+		$query .= ( isset($filter_data['city']) ) ? $this->getWhereClauseSQL( 'a.city', $filter_data['city'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['address1']) ) ? $this->getWhereClauseSQL( 'a.address1', $filter_data['address1'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['address2']) ) ? $this->getWhereClauseSQL( 'a.address2', $filter_data['address2'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['postal_code']) ) ? $this->getWhereClauseSQL( 'a.postal_code', $filter_data['postal_code'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['employee_number']) ) ? $this->getWhereClauseSQL( 'a.employee_number', $filter_data['employee_number'], 'numeric', $ph ) : NULL;
+		$query .= ( isset($filter_data['user_name']) ) ? $this->getWhereClauseSQL( 'a.user_name', $filter_data['user_name'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['sin']) ) ? $this->getWhereClauseSQL( 'a.sin', $filter_data['sin'], 'numeric', $ph ) : NULL;
 
-		if ( isset($filter_data['home_phone']) AND trim($filter_data['home_phone']) != '' ) {
-			$ph[] = trim($filter_data['home_phone']);
-			$query  .=	' AND a.home_phone LIKE ?';
-		}
-		if ( isset($filter_data['employee_number']) AND trim($filter_data['employee_number']) != '' ) {
-			$ph[] = trim($filter_data['employee_number']);
-			$query  .=	' AND a.employee_number LIKE ?';
-		}
-		if ( isset($filter_data['user_name']) AND trim($filter_data['user_name']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['user_name']));
-			$query  .=	' AND lower(a.user_name) LIKE ?';
-		}
-		if ( isset($filter_data['sin']) AND trim($filter_data['sin']) != '' ) {
-			$ph[] = trim($filter_data['sin']);
-			$query  .=	' AND a.sin LIKE ?';
-		}
+		$query .= ( isset($filter_data['work_email']) ) ? $this->getWhereClauseSQL( 'a.work_email', $filter_data['work_email'], 'text', $ph ) : NULL;
+		$query .= ( isset($filter_data['home_email']) ) ? $this->getWhereClauseSQL( 'a.home_email', $filter_data['home_email'], 'text', $ph ) : NULL;
+
+		$query .= ( isset($filter_data['tag']) ) ? $this->getWhereClauseSQL( '', array( 'company_id' => $company_id, 'object_type_id' => 200, 'tag' => $filter_data['tag'] ), 'tag', $ph ) : NULL;
+
+		//$query .= ( isset($filter_data['longitude']) ) ? $this->getWhereClauseSQL( 'a.longitude', $filter_data['longitude'], 'numeric', $ph ) : NULL;
 
 		if ( isset($filter_data['created_date']) AND trim($filter_data['created_date']) != '' ) {
 			$date_filter = $this->getDateRangeSQL( $filter_data['created_date'], 'a.created_date' );
@@ -1841,6 +1948,8 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		//Debug::Arr($ph, 'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
