@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: UserPreferenceListFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 4884 $
+ * $Id: UserPreferenceListFactory.class.php 4884 2011-06-26 00:52:55Z ipso $
+ * $Date: 2011-06-25 17:52:55 -0700 (Sat, 25 Jun 2011) $
  */
 
 /**
@@ -210,7 +210,7 @@ class UserPreferenceListFactory extends UserPreferenceFactory implements Iterato
 			$filter_data['exclude_id'] = $filter_data['exclude_user_id'];
 		}
 
-		$additional_order_fields = array('user_status_id','last_name', 'first_name', 'default_branch', 'default_department', 'user_group', 'title' );
+		$additional_order_fields = array('user_status_id','last_name', 'first_name', 'default_branch', 'default_department', 'user_group', 'title', 'city', 'province', 'country' );
 
 		$sort_column_aliases = array(
 									'user_status' => 'user_status_id',
@@ -261,6 +261,10 @@ class UserPreferenceListFactory extends UserPreferenceFactory implements Iterato
 							b.title_id as title_id,
 							utf.name as title,
 
+							b.city as city,
+							b.province as province,
+							b.country as country,
+
 							y.first_name as created_by_first_name,
 							y.middle_name as created_by_middle_name,
 							y.last_name as created_by_last_name,
