@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -384,7 +384,7 @@ class UserReportDataListFactory extends UserReportDataFactory implements Iterato
 
 		$additional_order_fields = array();
 		if ( $order == NULL ) {
-			$order = array();
+			$order = array('a.name' => 'asc');
 			$strict = FALSE;
 		} else {
 			$strict = TRUE;
