@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: UserWageFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5457 $
+ * $Id: UserWageFactory.class.php 5457 2011-11-04 20:49:58Z ipso $
+ * $Date: 2011-11-04 13:49:58 -0700 (Fri, 04 Nov 2011) $
  */
 
 /**
@@ -179,7 +179,11 @@ class UserWageFactory extends Factory {
 	}
 
 	function getUser() {
-		return $this->data['user_id'];
+		if ( isset($this->data['user_id']) ) {
+			return $this->data['user_id'];
+		}
+
+		return FALSE;
 	}
 	function setUser($id) {
 		$id = trim($id);
@@ -276,7 +280,26 @@ class UserWageFactory extends Factory {
 				AND
 				$this->Validator->isFloat(	'wage',
 											$wage,
-											TTi18n::gettext('Incorrect Wage')) ) {
+											TTi18n::gettext('Incorrect Wage'))
+				AND
+				$this->Validator->isLength(	'wage',
+											$wage,
+											TTi18n::gettext('Wage has too many digits'),
+											0,
+											21) //Need to include decimal.
+				AND
+				$this->Validator->isLengthBeforeDecimal(	'wage',
+											$wage,
+											TTi18n::gettext('Wage has too many digits before the decimal'),
+											0,
+											16)
+				AND
+				$this->Validator->isLengthAfterDecimal(	'wage',
+											$wage,
+											TTi18n::gettext('Wage has too many digits after the decimal'),
+											0,
+											4)
+				) {
 
 			$this->data['wage'] = $wage;
 
