@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4046 $
- * $Id: CA.class.php 4046 2010-12-21 00:56:06Z ipso $
- * $Date: 2010-12-20 16:56:06 -0800 (Mon, 20 Dec 2010) $
+ * $Revision: 5891 $
+ * $Id: CA.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -371,18 +371,7 @@ class PayrollDeduction_CA extends PayrollDeduction_CA_Data {
 		*/
 
 		$tmp1_K4 = bcmul( $this->getData()->getFederalLowestRate(), $this->getAnnualTaxableIncome() );
-
-		if ( $this->getDate() >= strtotime('01-Jan-2010') ) {
-			$tmp2_K4 = bcmul( $this->getData()->getFederalLowestRate(), 1051 );
-		} elseif ( $this->getDate() >= strtotime('01-Jan-2009') ) {
-			$tmp2_K4 = bcmul( $this->getData()->getFederalLowestRate(), 1044 );
-		} elseif ( $this->getDate() >= strtotime('01-Jan-2008') ) {
-			$tmp2_K4 = bcmul( $this->getData()->getFederalLowestRate(), 1019 );
-		} elseif ( $this->getDate() >= strtotime('01-Jan-2007') ) {
-			$tmp2_K4 = bcmul( $this->getData()->getFederalLowestRate(), 1000 );
-		} else {
-			$tmp2_K4 = bcmul( $this->getData()->getFederalLowestRate(), 500 );
-		}
+		$tmp2_K4 = bcmul( $this->getData()->getFederalLowestRate(), $this->getData()->getFederalEmploymentCreditAmount() );
 
 		if ( $tmp2_K4 < $tmp1_K4 ) {
 			$K4 = $tmp2_K4;
