@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4046 $
- * $Id: BC.class.php 4046 2010-12-21 00:56:06Z ipso $
- * $Date: 2010-12-20 16:56:06 -0800 (Mon, 20 Dec 2010) $
+ * $Revision: 5891 $
+ * $Id: BC.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -52,8 +52,54 @@ class PayrollDeduction_CA_BC extends PayrollDeduction_CA {
 		$S = 0;
 
 		Debug::text('BC Specific - Province: '. $this->getProvince(), __FILE__, __LINE__, __METHOD__,10);
-		if ( $this->getDate() >= strtotime('01-Jan-2011') ) {
-			//Calculate S after Jan 1st 2009.
+		$tax_reduction_data = $this->getProvincialTaxReductionData( $this->getDate() , $this->getProvince() );
+		if ( is_array($tax_reduction_data) ) {
+			if ( $A <= $tax_reduction_data['income1'] ) {
+				Debug::text('S: Annual Income less than: '. $tax_reduction_data['income1'], __FILE__, __LINE__, __METHOD__,10);
+				if ( $T4 > $tax_reduction_data['amount'] ) {
+					$S = $tax_reduction_data['amount'];
+				} else {
+					$S = $T4;
+				}
+			} elseif ( $A > $tax_reduction_data['income1'] AND $A <= $tax_reduction_data['income2'] ) {
+				Debug::text('S: Annual Income less than '. $tax_reduction_data['income2'], __FILE__, __LINE__, __METHOD__,10);
+
+				$tmp_S = bcsub( $tax_reduction_data['amount'], bcmul( bcsub( $A, $tax_reduction_data['income1'] ), $tax_reduction_data['rate'] ) );
+				Debug::text('Tmp_S: '. $tmp_S, __FILE__, __LINE__, __METHOD__,10);
+
+				if ( $T4 > $tmp_S ) {
+					$S = $tmp_S;
+				} else {
+					$S = $T4;
+				}
+				unset($tmp_S);
+			}
+		}
+/*
+		if ( $this->getDate() >= strtotime('01-Jan-2012') ) {
+			//Calculate S after Jan 1st 2012.
+			if ( $A <= 17913 ) {
+				Debug::text('S: Annual Income less than 17913', __FILE__, __LINE__, __METHOD__,10);
+				if ( $T4 > 403 ) {
+					$S = 403;
+				} else {
+					$S = $T4;
+				}
+			} elseif ( $A > 17913 AND $A <= 30506.75) {
+				Debug::text('S: Annual Income less than 30506.75', __FILE__, __LINE__, __METHOD__,10);
+
+				$tmp_S = bcsub( 403, bcmul( bcsub( $A, 17913 ), 0.032 ) );
+				Debug::text('Tmp_S: '. $tmp_S, __FILE__, __LINE__, __METHOD__,10);
+
+				if ( $T4 > $tmp_S ) {
+					$S = $tmp_S;
+				} else {
+					$S = $T4;
+				}
+				unset($tmp_S);
+			}
+		} elseif ( $this->getDate() >= strtotime('01-Jan-2011') ) {
+			//Calculate S after Jan 1st 2011.
 			if ( $A <= 17493 ) {
 				Debug::text('S: Annual Income less than 17493', __FILE__, __LINE__, __METHOD__,10);
 				if ( $T4 > 394 ) {
@@ -75,7 +121,7 @@ class PayrollDeduction_CA_BC extends PayrollDeduction_CA {
 				unset($tmp_S);
 			}
 		} elseif ( $this->getDate() >= strtotime('01-Jan-2010') ) {
-			//Calculate S after Jan 1st 2009.
+			//Calculate S after Jan 1st 2010.
 			if ( $A <= 17354 ) {
 				Debug::text('S: Annual Income less than 17354', __FILE__, __LINE__, __METHOD__,10);
 				if ( $T4 > 390 ) {
@@ -231,7 +277,7 @@ class PayrollDeduction_CA_BC extends PayrollDeduction_CA {
 				unset($tmp_S);
 			}
 		}
-
+ */
 		Debug::text('aS: '. $S, __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $S < 0 ) {
