@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: Data.class.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5891 $
+ * $Id: Data.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -52,6 +52,22 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		Claim Code Basic Amounts
 	*/
 	var $basic_claim_code_options = array(
+							1325404800 => array( //01-Jan-2012:
+										'CA' => 10822, //Federal
+										'BC' => 11354,
+										'AB' => 17282,
+										'SK' => 14942,
+										'MB' => 8634,
+										'QC' => 0,
+										'ON' => 9405,
+										'NL' => 8237,
+										'NB' => 9203,
+										'NS' => 8481,
+										'PE' => 7708,
+										'NT' => 13280,
+										'YT' => 10822,
+										'NU' => 12211,
+										),
 							1309503600 => array( //01-Jul-2011: Some of these are only changed for the last 6mths in the year.
 										'CA' => 10527, //Federal
 										'BC' => 11088,
@@ -218,11 +234,17 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		CPP settings
 	*/
 	var $cpp_options = array(
+							1325404800 => array( //2012
+										'maximum_pensionable_earnings' => 50100,
+										'basic_exemption' => 3500,
+										'employee_rate' => 0.0495,
+										'employee_maximum_contribution' => 2306.70
+										),
 							1293868800 => array( //2011
 										'maximum_pensionable_earnings' => 48300,
 										'basic_exemption' => 3500,
 										'employee_rate' => 0.0495,
-										'employee_maximum_contribution' => 2163.15
+										'employee_maximum_contribution' => 2217.60
 										),
 							1262332800 => array( //2010
 										'maximum_pensionable_earnings' => 47200,
@@ -272,6 +294,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		EI settings
 	*/
 	var $ei_options = array(
+							1325404800 => array( //2012
+										'maximum_insurable_earnings' => 45900,
+										'employee_rate' => 0.0183,
+										'employee_maximum_contribution' => 839.97,
+										'employer_rate' => 1.4
+										),
 							1293868800 => array( //2011
 										'maximum_insurable_earnings' => 44200,
 										'employee_rate' => 0.0178,
@@ -322,6 +350,168 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										),
 							);
 
+	/*
+		Federal employment credit
+	*/
+	var $federal_employment_credit_options = array(
+							1325404800 => array( //2012
+										'credit' => 1095,
+										),
+							1293868800 => array( //2011
+										'credit' => 1065,
+										),
+							1262332800 => array( //2010
+										'credit' => 1051,
+										),
+							1230796800 => array( //2009
+										'credit' => 1044,
+										),
+							1199174400 => array( //2008
+										'credit' => 1019,
+										),
+							1167638400 => array( //2007
+										'credit' => 1000,
+										),
+							1136102400 => array( //2006
+										'credit' => 500,
+										),
+							);
+
+	/*
+		Provincial tax reduction
+	*/
+	var $provincial_tax_reduction_options = array(
+							'BC' => array(
+									1325404800 => array( //2012
+														'income1' => 17913,
+														'income2' => 30506.75,
+														'amount' => 403,
+														'rate' => 0.032,
+														),
+									1293868800 => array( //2011
+														'income1' => 17493,
+														'income2' => 29805.50,
+														'amount' => 394,
+														'rate' => 0.032,
+												),
+									1262332800 => array( //2010
+														'income1' => 17354,
+														'income2' => 29541.50,
+														'amount' => 390,
+														'rate' => 0.032,
+												),
+									1230796800 => array( //2009
+														'income1' => 17285,
+														'income2' => 29441.25,
+														'amount' => 389,
+														'rate' => 0.032,
+												),
+									1199174400 => array( //2008
+														'income1' => 16946,
+														'income2' => 28852.25,
+														'amount' => 381,
+														'rate' => 0.032,
+												),
+									1183273200 => array( //2007 (July)
+														'income1' => 16646,
+														'income2' => 28364.75,
+														'amount' => 375,
+														'rate' => 0.032,
+												),
+									1167638400	=> array( //2007 (Jan)
+														'income1' => 16646,
+														'income2' => 27062.67,
+														'amount' => 375,
+														'rate' => 0.032,
+												),
+									1136102400 => array( //2006
+														'income1' => 16336,
+														'income2' => 26558.22,
+														'amount' => 368,
+														'rate' => 0.032,
+												),
+									1104566400 => array( //2005
+														'income1' => 16000,
+														'income2' => 26000,
+														'amount' => 360,
+														'rate' => 0.032,
+												),
+									),
+							'ON' => array(
+									1325404800 => array( //2012
+														'amount' => 217,
+														),
+									1293868800 => array( //2011
+														'amount' => 210,
+												),
+									1262332800 => array( //2010
+														'amount' => 206,
+												),
+									1230796800 => array( //2009
+														'amount' => 205,
+												),
+									1199174400 => array( //2008
+														'amount' => 201,
+												),
+									1167638400	=> array( //2007
+														'amount' => 198,
+												),
+									1136102400 => array( //2006
+														'amount' => 194,
+												),
+									),
+							);
+
+	/*
+		Provincial surtax
+	*/
+	var $provincial_surtax_options = array(
+							'ON' => array(
+									1325404800 => array( //2012
+														'income1' => 4213,
+														'income2' => 5392,
+														'rate1' => 0.20,
+														'rate2' => 0.36,
+														),
+									1293868800 => array( //2011
+														'income1' => 4078,
+														'income2' => 5219,
+														'rate1' => 0.20,
+														'rate2' => 0.36,
+												),
+									1262332800 => array( //2010
+														'income1' => 4006,
+														'income2' => 5127,
+														'rate1' => 0.20,
+														'rate2' => 0.36,
+												),
+									1230796800 => array( //2009
+														'income1' => 4257,
+														'income2' => 5370,
+														'rate1' => 0.20,
+														'rate2' => 0.36,
+												),
+									1199174400 => array( //2008
+														'income1' => 4162,
+														'income2' => 5249,
+														'rate1' => 0.20,
+														'rate2' => 0.36,
+												),
+									1167638400	=> array( //2007
+														'income1' => 4100,
+														'income2' => 5172,
+														'rate1' => 0.20,
+														'rate2' => 0.36,
+												),
+									1136102400 => array( //2006
+														'income1' => 4016,
+														'income2' => 5065,
+														'rate1' => 0.20,
+														'rate2' => 0.36,
+												),
+									),
+							);
+
 	function __construct() {
 		global $db;
 
@@ -362,6 +552,51 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		return FALSE;
 	}
 
+	/*
+		Provincial tax/surtax reduction functions
+	*/
+	function getProvincialTaxReductionData( $date, $province ) {
+		if ( isset($this->provincial_tax_reduction_options[$province]) ) {
+			foreach( $this->provincial_tax_reduction_options[$province] as $effective_date => $data ) {
+				if ( $date >= $effective_date ) {
+					return $data;
+				}
+			}
+		}
+
+		return FALSE;
+	}
+	function getProvincialSurTaxData( $date, $province ) {
+		if ( isset($this->provincial_surtax_options[$province]) ) {
+			foreach( $this->provincial_surtax_options[$province] as $effective_date => $data ) {
+				if ( $date >= $effective_date ) {
+					return $data;
+				}
+			}
+		}
+
+		return FALSE;
+	}
+
+	/*
+		Federal Employment Credit functions
+	*/
+	function getFederalEmploymentCreditData( $date ) {
+		foreach( $this->federal_employment_credit_options as $effective_date => $data ) {
+			if ( $date >= $effective_date ) {
+				return $data;
+			}
+		}
+
+		return FALSE;
+	}
+	function getFederalEmploymentCreditAmount() {
+		$data = $this->getFederalEmploymentCreditData( $this->getDate() );
+
+		Debug::text('Date: '. $this->getDate() .' Credit: '. $data['credit'], __FILE__, __LINE__, __METHOD__,10);
+		return $data['credit'];
+	}
+
 	/*
 		CPP functions
 	*/
