@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4055 $
- * $Id: CA.class.php 4055 2010-12-23 01:12:06Z ipso $
- * $Date: 2010-12-22 17:12:06 -0800 (Wed, 22 Dec 2010) $
+ * $Revision: 5891 $
+ * $Id: CA.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -51,6 +51,28 @@ class PayrollDeduction_US_CA extends PayrollDeduction_US {
 */
 
 	var $state_options = array(
+								1325404800 => array( //01-Jan-12
+													'standard_deduction' => array(
+																				//First entry is 0,1 allowance, second is for 2 or more.
+																				'10' => array(3769.00, 3769.00),
+																				'20' => array(3769.00, 3769.00),
+																				'30' => array(3769.00, 7538.00),
+																				'40' => array(7538.00, 7538.00),
+																				),
+													'allowance' => array(
+																				'10' => 112.20,
+																				'20' => 112.20,
+																				'30' => 112.20,
+																				'40' => 112.20,
+																				),
+                                                    'minimum_income' => array(
+                                                                                //First entry is 0,1 allowance, 2nd is 2 or more.
+																				'10' => array(12527.00, 12527.00),
+																				'20' => array(12527.00, 12527.00),
+																				'30' => array(12527.00, 25054.00),
+																				'40' => array(25054.00, 25054.00),
+																				),
+													),
 								1293868800 => array( //01-Jan-11
 													'standard_deduction' => array(
 																				//First entry is 0,1 allowance, second is for 2 or more.
@@ -163,6 +185,26 @@ class PayrollDeduction_US_CA extends PayrollDeduction_US {
 	}
 
 	function getStateAnnualTaxableIncome() {
+		$retarr = $this->getDataFromRateArray($this->getDate(), $this->state_options);
+		if ( $retarr == FALSE ) {
+			return FALSE;
+
+		}
+
+        $minimum_income = 0;
+        if ( isset($retarr['minimum_income']) AND isset($retarr['minimum_income'][$this->getStateFilingStatus()]) ) {
+            $minimum_income_arr = $retarr['minimum_income'][$this->getStateFilingStatus()];
+            if ( $this->getStateAllowance() == 0 OR $this->getStateAllowance() == 1 ) {
+                $minimum_income = $minimum_income_arr[0];
+            } elseif ( $this->getStateAllowance() >= 2 ) {
+                $minimum_income = $minimum_income_arr[1];
+            }
+        }
+
+        if ( $this->getAnnualTaxableIncome() <= $minimum_income ) {
+            return 0; //Below minimum income threshold, no withholding.
+        }
+
 		return bcsub( $this->getAnnualTaxableIncome(), $this->getStateStandardDeduction() );
 	}
 
