@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4063 $
- * $Id: MO.class.php 4063 2010-12-24 20:15:06Z ipso $
- * $Date: 2010-12-24 12:15:06 -0800 (Fri, 24 Dec 2010) $
+ * $Revision: 5891 $
+ * $Id: MO.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -51,6 +51,26 @@ class PayrollDeduction_US_MO extends PayrollDeduction_US {
 */
 
 	var $state_options = array(
+								1325404800 => array( //01-Jan-12
+													'standard_deduction' => array(
+																				'10' => 5800.00,
+																				'20' => 5800.00,
+																				'30' => 11600.00,
+																				'40' => 8500.00,
+																				),
+													'allowance' => array(
+																				'10' => array( 2100.00, 1200.00, 1200.00 ),
+																				'20' => array( 2100.00, 1200.00, 1200.00 ),
+																				'30' => array( 2100.00, 2100.00, 1200.00 ),
+																				'40' => array( 3500.00, 1200.00, 1200.00 ),
+																				),
+													'federal_tax_maximum' => array(
+																				'10' => 5000.00,
+																				'20' => 5000.00,
+																				'30' => 10000.00,
+																				'40' => 5000.00
+																				)
+													),
 								1230796800 => array( //01-Jan-09
 													'standard_deduction' => array(
 																				'10' => 5700.00,
