@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4055 $
- * $Id: ND.class.php 4055 2010-12-23 01:12:06Z ipso $
- * $Date: 2010-12-22 17:12:06 -0800 (Wed, 22 Dec 2010) $
+ * $Revision: 5891 $
+ * $Id: ND.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -45,6 +45,9 @@
 class PayrollDeduction_US_ND extends PayrollDeduction_US {
 
 	var $state_options = array(
+								1325404800 => array( //01-Jan-12
+													'allowance' => 3800
+													),
 								1293868800 => array( //01-Jan-11
 													'allowance' => 3700
 													),
