@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3657 $
- * $Id: OR.class.php 3657 2010-06-11 21:20:32Z ipso $
- * $Date: 2010-06-11 14:20:32 -0700 (Fri, 11 Jun 2010) $
+ * $Revision: 5891 $
+ * $Id: OR.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -45,6 +45,34 @@
 class PayrollDeduction_US_OR extends PayrollDeduction_US {
 	var $original_filing_status = NULL;
 	var $state_options = array(
+								1325404800 => array( //01-Jan-10
+												'standard_deduction' => array(
+																			'10' => 2025,
+																			'20' => 4055,
+																			),
+												'allowance' => 183,
+												'federal_tax_maximum' => 6100,
+												'phase_out' => array(
+																		'10' => array(
+																						50000 =>  6100,
+																						125000 => 6100,
+																						130000 => 4850,
+																						135000 => 3650,
+																						140000 => 2400,
+																						145000 => 1200,
+																						145000 => 0,
+																					 ),
+																		'20' => array(
+																						50000 =>  6100,
+																						250000 => 6100,
+																						260000 => 4850,
+																						270000 => 3650,
+																						280000 => 2400,
+																						290000 => 1200,
+																						290000 => 0,
+																					 ),
+																	),
+												),
 								1262332800 => array( //01-Jan-10
 												'standard_deduction' => array(
 																			'10' => 1950,
@@ -79,6 +107,33 @@ class PayrollDeduction_US_OR extends PayrollDeduction_US {
 													)
 								);
 
+	private function getStateRateArray($input_arr, $income) {
+		if ( !is_array($input_arr) ) {
+			return 0;
+		}
+
+		$total_rates = count($input_arr) - 1;
+		$prev_bracket=0;
+		$i=0;
+		foreach( $input_arr as $bracket => $value ) {
+			Debug::text('Bracket: '. $bracket .' Value: '.$value, __FILE__, __LINE__, __METHOD__,10);
+
+			if ($income >= $prev_bracket AND $income < $bracket) {
+				Debug::text('Found Bracket: '. $bracket  .' Returning: '. $value, __FILE__, __LINE__, __METHOD__,10);
+
+				return $value;
+			} elseif ($i == $total_rates) {
+				Debug::text('Found Last Bracket: '. $bracket .' Returning: '. $value, __FILE__, __LINE__, __METHOD__,10);
+				return $value;
+			}
+
+			$prev_bracket = $bracket;
+			$i++;
+		}
+
+		return FALSE;
+	}
+
 	function getStatePayPeriodDeductions() {
 		//IF exemptions are 3 or more, change filing status to married.
 		$this->original_filing_status = $this->getStateFilingStatus();
@@ -113,6 +168,15 @@ class PayrollDeduction_US_OR extends PayrollDeduction_US {
 
 		$maximum = $retarr['federal_tax_maximum'];
 
+		if ( isset($retarr['phase_out'][$this->getStateFilingStatus()]) ) {
+			$phase_out_arr = $retarr['phase_out'][$this->getStateFilingStatus()];
+			$phase_out_maximum = $this->getStateRateArray($phase_out_arr, $this->getAnnualTaxableIncome() );
+			if ( $maximum > $phase_out_maximum ) {
+				Debug::text('Maximum allowed Federal Tax exceeded phase out maximum of: '. $phase_out_maximum, __FILE__, __LINE__, __METHOD__,10);
+				$maximum = $phase_out_maximum;
+			}
+		}
+
 		Debug::text('Maximum State allowed Federal Tax: '. $maximum, __FILE__, __LINE__, __METHOD__,10);
 
 		return $maximum;
@@ -122,16 +186,14 @@ class PayrollDeduction_US_OR extends PayrollDeduction_US {
 		$retarr = $this->getDataFromRateArray($this->getDate(), $this->state_options);
 		if ( $retarr == FALSE ) {
 			return FALSE;
-
 		}
 
-		if ( $this->original_filing_status == $this->getStateFilingStatus() ) {
+		if ( $this->original_filing_status == $this->getStateFilingStatus() AND isset($retarr['standard_deduction'][$this->getStateFilingStatus()]) ) {
 			$deduction = $retarr['standard_deduction'][$this->getStateFilingStatus()];
 		} else {
 			$deduction = $retarr['standard_deduction'][10];
 		}
 
-
 		Debug::text('Standard Deduction: '. $deduction, __FILE__, __LINE__, __METHOD__,10);
 
 		return $deduction;
