@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3284 $
- * $Id: UT.class.php 3284 2010-01-19 00:25:29Z ipso $
- * $Date: 2010-01-18 16:25:29 -0800 (Mon, 18 Jan 2010) $
+ * $Revision: 5891 $
+ * $Id: UT.class.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 
 /**
@@ -92,8 +92,10 @@ class PayrollDeduction_US_UT extends PayrollDeduction_US {
 			return FALSE;
 		}
 
-		$retval = $retarr['base_allowance'][$this->getStateFilingStatus()];
-
+		$retval = 0;
+		if ( isset($retarr['base_allowance'][$this->getStateFilingStatus()]) ) {
+			$retval = $retarr['base_allowance'][$this->getStateFilingStatus()];
+		}
 		Debug::text('State Base Allowance Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
 
 		return $retval;
@@ -105,7 +107,10 @@ class PayrollDeduction_US_UT extends PayrollDeduction_US {
 			return FALSE;
 		}
 
-		$allowance_reduction_amount = $retarr['allowance_reduction'][$this->getStateFilingStatus()];
+		$allowance_reduction_amount = 0;
+		if ( isset($retarr['allowance_reduction'][$this->getStateFilingStatus()]) ) {
+			$allowance_reduction_amount = $retarr['allowance_reduction'][$this->getStateFilingStatus()];
+		}
 
 		$adjusted_taxable_income = bcsub( $this->getStateAnnualTaxableIncome(), $allowance_reduction_amount );
 		if ( $adjusted_taxable_income > 0 )  {
