@@ -117,7 +117,7 @@ class Payment_Process {
         $class = "Payment_Process_".$type;
         if (include_once "Payment/Process/{$type}.php") {
             if (class_exists($class)) {
-                $object = & new $class($options);
+                $object = new $class($options);
                 return $object;
             }
         }
