@@ -552,10 +552,11 @@ class fileupload {
 	private function clean_filename($name='') 
 	{
 		$name = strtolower($name);
-		$name = str_replace(" ", "_", str_replace("%20", "_", $name) );
-		$name = ereg_replace("[^a-z0-9._]", "", $name);
+		$name = str_replace(' ', '_', str_replace("%20", '_', $name) );
+		//$name = ereg_replace('[^a-z0-9._]', '', $name);
+		$name = preg_replace('/[^a-z0-9._]/', '', $name);	
 		if ($name[0] == '.') { // first char is dot
-			$name = "_".$name;
+			$name = '_'.$name;
 		}
 		if (!strlen($name)) { // if all chars were stripped out by regex
 			$name = 'uploaded_file';
