@@ -12,6 +12,7 @@ $global_class_map = array(
     'APILogDetail' => 'api/core/APILogDetail.class.php',
 	'APIBranch' => 'api/company/APIBranch.class.php',
 	'APICompany' => 'api/company/APICompany.class.php',
+    'APICompanyGenericTag' => 'api/company/APICompanyGenericTag.class.php',
     'APIOtherField' => 'api/core/APIOtherField.class.php',
 	'APIWageGroup' => 'api/company/APIWageGroup.class.php',
     'APICompanyDeduction' => 'api/company/APICompanyDeduction.class.php',
@@ -26,6 +27,7 @@ $global_class_map = array(
     'APIUserDateTotal' => 'api/core/APIUserDateTotal.class.php',
 	'APIException' => 'api/core/APIException.class.php',
     'APITest' => 'api/core/APITest.class.php',
+    'APINotification' => 'api/core/APINotification.class.php',
 	'APIDepartment' => 'api/department/APIDepartment.class.php',
 	'APIRecurringHoliday' => 'api/holiday/APIRecurringHoliday.class.php',
 	'APIPayStubEntryAccount' => 'api/pay_stub/APIPayStubEntryAccount.class.php',
@@ -97,15 +99,30 @@ $global_class_map = array(
     'APIInvoiceTransactionSummaryReport' => 'api/report/APIInvoiceTransactionSummaryReport.class.php',
     'APIPayrollExportReport' => 'api/report/APIPayrollExportReport.class.php',
     'APIForm941Report' => 'api/report/APIForm941Report.class.php',
+    'APIForm940Report' => 'api/report/APIForm940Report.class.php',
+    'APIFormW2Report' => 'api/report/APIFormW2Report.class.php',
+    'APIForm1099MiscReport' => 'api/report/APIForm1099MiscReport.class.php',
+    'APIRemittanceSummaryReport' => 'api/report/APIRemittanceSummaryReport.class.php',
+    'APIT4SummaryReport' => 'api/report/APIT4SummaryReport.class.php',
+    'APIJobDetailReport' => 'api/report/APIJobDetailReport.class.php',
+    'APIJobSummaryReport' => 'api/report/APIJobSummaryReport.class.php',
     'APITimeClockUnAuthenticated' => 'api/time_clock/APITimeClockUnAuthenticated.class.php',
     'APITimeClockUnAuthenticated_TTA8' => 'api/time_clock/APITimeClockUnAuthenticated_TTA8.class.php',
     'APITimeClockUnAuthenticated_TTUS100' => 'api/time_clock/APITimeClockUnAuthenticated_TTUS100.class.php',
     'APIInvoiceDistrict' => 'api/invoice/APIInvoiceDistrict.class.php',
+    'APIInvoice' => 'api/invoice/APIInvoice.class.php',
+    'APITransaction' => 'api/invoice/APITransaction.class.php',
     'APIAreaPolicy' => 'api/invoice_policy/APIAreaPolicy.class.php',
     'APITaxPolicy' => 'api/invoice_policy/APITaxPolicy.class.php',
     'APIShippingPolicy' => 'api/invoice_policy/APIShippingPolicy.class.php',
     'APIProduct' => 'api/product/APIProduct.class.php',
     'APIProductPrice' => 'api/product/APIProductPrice.class.php',
+    'APIImport' => 'api/import/APIImport.class.php',
+    'APIImportUser' => 'api/import/APIImportUser.class.php',
+    'APIImportBranch' => 'api/import/APIImportBranch.class.php',
+    'APIImportDepartment' => 'api/import/APIImportDepartment.class.php',
+    'APIImportUserWage' => 'api/import/APIImportUserWage.class.php',
+    'APIImportClient' => 'api/import/APIImportClient.class.php',
 	'ClientAuthentication' => 'client/ClientAuthentication.class.php',
 	'ClientBalanceFactory' => 'client/ClientBalanceFactory.class.php',
 	'ClientBalanceListFactory' => 'client/ClientBalanceListFactory.class.php',
@@ -126,6 +143,10 @@ $global_class_map = array(
 	'CompanyFactory' => 'company/CompanyFactory.class.php',
 	'CompanyGenericMapFactory' => 'company/CompanyGenericMapFactory.class.php',
 	'CompanyGenericMapListFactory' => 'company/CompanyGenericMapListFactory.class.php',
+	'CompanyGenericTagFactory' => 'company/CompanyGenericTagFactory.class.php',
+	'CompanyGenericTagListFactory' => 'company/CompanyGenericTagListFactory.class.php',
+	'CompanyGenericTagMapFactory' => 'company/CompanyGenericTagMapFactory.class.php',
+	'CompanyGenericTagMapListFactory' => 'company/CompanyGenericTagMapListFactory.class.php',
 	'CompanyListFactory' => 'company/CompanyListFactory.class.php',
 	'CompanyUserCountFactory' => 'company/CompanyUserCountFactory.class.php',
 	'CompanyUserCountListFactory' => 'company/CompanyUserCountListFactory.class.php',
@@ -141,6 +162,7 @@ $global_class_map = array(
 	'CurrencyFactory' => 'core/CurrencyFactory.class.php',
 	'CurrencyListFactory' => 'core/CurrencyListFactory.class.php',
 	'Debug' => 'core/Debug.class.php',
+    'RateLimit' => 'core/RateLimit.class.php',
 	'DependencyTree' => 'core/DependencyTree.class.php',
 	'Environment' => 'core/Environment.class.php',
 	'Exception' => 'core/Exception.class.php',
@@ -156,6 +178,7 @@ $global_class_map = array(
 	'LogListFactory' => 'core/LogListFactory.class.php',
     'LogDetailFactory' => 'core/LogDetailFactory.class.php',
     'LogDetailListFactory' => 'core/LogDetailListFactory.class.php',
+    'LogDetailDisplay' => 'core/LogDetailDisplay.class.php',
 	'LogRotate' => 'core/LogRotate.class.php',
 	'Misc' => 'core/Misc.class.php',
 	'Option' => 'core/Option.class.php',
@@ -170,6 +193,7 @@ $global_class_map = array(
 	'PermissionListFactory' => 'core/PermissionListFactory.class.php',
 	'PermissionUserFactory' => 'core/PermissionUserFactory.class.php',
 	'PermissionUserListFactory' => 'core/PermissionUserListFactory.class.php',
+    'PurgeDatabase' => 'core/PurgeDatabase.class.php',
 	'Profiler' => 'core/Profiler.class.php',
 	'ProgressBar' => 'core/ProgressBar.class.php',
 	'Redirect' => 'core/Redirect.class.php',
@@ -191,6 +215,13 @@ $global_class_map = array(
     'InvoiceTransactionSummaryReport' => 'report/InvoiceTransactionSummaryReport.class.php',
     'PayrollExportReport' => 'report/PayrollExportReport.class.php',
     'Form941Report' => 'report/Form941Report.class.php',
+    'Form940Report' => 'report/Form940Report.class.php',
+    'FormW2Report' => 'report/FormW2Report.class.php',
+    'Form1099MiscReport' => 'report/Form1099MiscReport.class.php',
+    'RemittanceSummaryReport' => 'report/RemittanceSummaryReport.class.php',
+    'T4SummaryReport' => 'report/T4SummaryReport.class.php',
+    'JobDetailReport' => 'report/JobDetailReport.class.php',
+    'JobSummaryReport' => 'report/JobSummaryReport.class.php',
 	'StationBranchFactory' => 'core/StationBranchFactory.class.php',
 	'StationBranchListFactory' => 'core/StationBranchListFactory.class.php',
 	'StationDepartmentFactory' => 'core/StationDepartmentFactory.class.php',
@@ -456,5 +487,11 @@ $global_class_map = array(
 	'UserTitleListFactory' => 'users/UserTitleListFactory.class.php',
 	'UserWageFactory' => 'users/UserWageFactory.class.php',
 	'UserWageListFactory' => 'users/UserWageListFactory.class.php',
+    'Import' => 'import/Import.class.php',
+    'ImportUser' => 'import/ImportUser.class.php',
+    'ImportBranch' => 'import/ImportBranch.class.php',
+    'ImportDepartment' => 'import/ImportDepartment.class.php',
+    'ImportUserWage' => 'import/ImportUserWage.class.php',
+    'ImportClient' => 'import/ImportClient.class.php',
 );
 ?>
