@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4312 $
- * $Id: Interface.inc.php 4312 2011-02-28 00:42:55Z ipso $
- * $Date: 2011-02-27 16:42:55 -0800 (Sun, 27 Feb 2011) $
+ * $Revision: 5891 $
+ * $Id: Interface.inc.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 if ( !isset($disable_cache_control) ) {
 	//Turn caching off.
@@ -62,14 +62,19 @@ $clf = new CompanyListFactory();
 if ( ( !isset($disable_database_connection) OR ( isset($disable_database_connection) AND $disable_database_connection != TRUE ) )
 		AND ( !isset($config_vars['other']['installer_enabled']) OR ( isset($config_vars['other']['installer_enabled']) AND $config_vars['other']['installer_enabled'] != TRUE ) )) {
 	//Get all system settings, so they can be used even if the user isn't logged in, such as the login page.
-	$sslf = new SystemSettingListFactory();
-	$system_settings = $sslf->getAllArray();
-	unset($sslf);
+	try {
+		$sslf = new SystemSettingListFactory();
+		$system_settings = $sslf->getAllArray();
+		unset($sslf);
 
-	//Get primary company data needs to be used when user isn't logged in as well.
-	$clf->getByID( PRIMARY_COMPANY_ID );
-	if ( $clf->getRecordCount() == 1 ) {
-		$primary_company = $clf->getCurrent();
+		//Get primary company data needs to be used when user isn't logged in as well.
+		$clf->getByID( PRIMARY_COMPANY_ID );
+		if ( $clf->getRecordCount() == 1 ) {
+			$primary_company = $clf->getCurrent();
+		}
+	} catch (Exception $e) {
+		//Database not initialized, or some error, redirect to Install page.
+		throw new DBError($e, 'DBInitialize');
 	}
 }
 
@@ -195,7 +200,7 @@ if ( isset($authenticate) AND $authenticate === FALSE ) {
 
 		$profiler->stopTimer( 'Interface.inc - Post-Authentication' );
 	} else {
-		Debug::text('User NOT! Authenticated', __FILE__, __LINE__, __METHOD__, 10);
+		Debug::text('User NOT Authenticated!', __FILE__, __LINE__, __METHOD__, 10);
 
 		if ( isset($enable_wap) AND $enable_wap == TRUE ) {
 			Redirect::Page( URLBuilder::getURL(NULL, Environment::GetBaseURL().'wap/wap_login.php') );
@@ -322,7 +327,6 @@ if ( isset($current_station) ) {
 }
 
 $smarty->assign('BASE_URL', Environment::getBaseURL() );
-$smarty->assign('global_script_start_time', $global_script_start_time );
 $smarty->assign('profiler', $profiler );
 $smarty->assign_by_ref('permission', $permission );
 
