@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,11 +34,15 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: global.inc.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 6071 $
+ * $Id: global.inc.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
-$global_script_start_time = microtime(true);
+//PHP v5.1.0 introduced $_SERVER['REQUEST_TIME'], but it doesn't i nclude microseconds until v5.4.0.
+if ( version_compare(PHP_VERSION, '5.4.0', '<') == TRUE ) {
+	//$global_script_start_time = microtime( TRUE );
+	$_SERVER['REQUEST_TIME'] = microtime( TRUE );
+}
 
 //BUG in PHP 5.2.2 that causes $HTTP_RAW_POST_DATA not to be set. Work around it.
 if ( strpos( phpversion(), '5.2.2') !== FALSE ) {
@@ -56,7 +60,7 @@ ini_set( 'max_execution_time', 1800 );
 //Check: http://ca3.php.net/manual/en/security.magicquotes.php#61188 for disabling magic_quotes_gpc
 ini_set( 'magic_quotes_runtime', 0 );
 
-define('APPLICATION_VERSION', '3.5.1' );
+define('APPLICATION_VERSION', '5.0.3' );
 
 /*
 	Config file inside webroot.
@@ -113,7 +117,7 @@ if ( isset($config_vars['other']['primary_company_id']) AND $config_vars['other'
 //Try to dynamically load required PHP extensions if they aren't already.
 //This saves people from having to modify php.ini if possible.
 //v5.3 of PHP deprecates DL().
-if ( version_compare(PHP_VERSION, '5.3.0', '<') AND (bool)ini_get( 'enable_dl' ) == TRUE AND (bool)ini_get( 'safe_mode' ) == FALSE ) {
+if ( version_compare(PHP_VERSION, '5.3.0', '<') AND function_exists('dl') == TRUE AND (bool)ini_get( 'enable_dl' ) == TRUE AND (bool)ini_get( 'safe_mode' ) == FALSE ) {
 	$prefix = (PHP_SHLIB_SUFFIX === 'dll') ? 'php_' : '';
 
 	//This quite possibly breaks PEAR's Cache_Lite <= v1.7.2 because
@@ -183,6 +187,16 @@ if ( !isset($_SERVER['REQUEST_URI']) ) {
 	}
 }
 
+//HTTP Basic authentication doesn't work properly with CGI/FCGI unless we decode it this way.
+if ( ( PHP_SAPI == 'cgi' OR PHP_SAPI == 'cgi-fcgi' ) AND isset($_SERVER['HTTP_AUTHORIZATION']) ) {
+	//<IfModule mod_rewrite.c>
+	//RewriteEngine on
+	//RewriteRule .* - [E=HTTP_AUTHORIZATION:%{HTTP:Authorization},L]
+	//</IfModule>
+	list($_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW']) = explode(':', base64_decode( substr( $_SERVER['HTTP_AUTHORIZATION'], 6) ) );
+}
+
+
 require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR .'ClassMap.inc.php');
 function __autoload( $name ) {
 	global $global_class_map, $profiler;
@@ -215,6 +229,7 @@ function __autoload( $name ) {
 
 	return TRUE;
 }
+spl_autoload_register('__autoload'); //Registers the autoloader mainly for use with PHPUnit
 
 //The basis for the plugin system, instantiate all classes through this, allowing the class to be overloaded on the fly by a class in the plugin directory.
 //ie: $uf = TTNew( 'UserFactory' ); OR $uf = TTNew( 'UserFactory', $arg1, $arg2, $arg3 );
@@ -307,9 +322,9 @@ define('TT_PRODUCT_PROFESSIONAL', 20 );
 define('TT_PRODUCT_BUSINESS', 15 );
 define('TT_PRODUCT_STANDARD', 10 );
 function getTTProductEdition() {
-	if ( file_exists(Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'job'. DIRECTORY_SEPARATOR .'JobFactory.class.php') ) {
+	if ( file_exists( Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'job'. DIRECTORY_SEPARATOR .'JobFactory.class.php') ) {
 		return TT_PRODUCT_PROFESSIONAL;
-	} elseif ( file_exists(Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'time_clock'. DIRECTORY_SEPARATOR .'TimeClock.class.php') ) {
+	} elseif ( file_exists( Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'time_clock'. DIRECTORY_SEPARATOR .'TimeClock.class.php') ) {
 		return TT_PRODUCT_BUSINESS;
 	}
 
@@ -337,7 +352,6 @@ require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARAT
 require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'core'. DIRECTORY_SEPARATOR .'Profiler.class.php');
 $profiler = new Profiler( true );
 
-//clearstatcache();
 set_include_path(
 					'.' . PATH_SEPARATOR .
 					Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'core' .
