@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: ForgotPassword.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 6071 $
+ * $Id: ForgotPassword.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 require_once('../includes/global.inc.php');
 
@@ -92,7 +92,7 @@ switch ($action) {
 
 			} else {
 
-				$validator->isTrue('password',FALSE, 'Passwords do not match');
+				$validator->isTrue('password',FALSE, TTi18n::getText('Passwords do not match') );
 			}
 
 		} else {
@@ -126,18 +126,22 @@ switch ($action) {
 		$ulf->getByHomeEmailOrWorkEmail( $email );
 		if ( $ulf->getRecordCount() == 1 ) {
 			$user_obj = $ulf->getCurrent();
-			$user_obj->sendPasswordResetEmail();
-			Debug::Text('Found USER! ', __FILE__, __LINE__, __METHOD__,10);
 
-			Redirect::Page( URLBuilder::getURL( array('email_sent' => 1, 'email' => $email ), 'ForgotPassword.php' ) );
+			//Check if company is using LDAP authentication, if so deny password reset.
+			if ( $user_obj->getCompanyObject()->getLDAPAuthenticationType() == 0 ) {
+				$user_obj->sendPasswordResetEmail();
+				Debug::Text('Found USER! ', __FILE__, __LINE__, __METHOD__,10);
+
+				Redirect::Page( URLBuilder::getURL( array('email_sent' => 1, 'email' => $email ), 'ForgotPassword.php' ) );
+			} else {
+				Debug::Text('LDAP Authentication is enabled, password reset is disabled! ', __FILE__, __LINE__, __METHOD__,10);
+				$validator->isTrue('email', FALSE, TTi18n::getText('Please contact your administrator for instructions on changing your password.'). ' (LDAP)' );
+			}
 		} else {
 			//Error
 			Debug::Text('DID NOT FIND USER! ', __FILE__, __LINE__, __METHOD__,10);
-			$validator->isTrue('email',FALSE, 'Email address was not found in our database');
+			$validator->isTrue('email', FALSE, TTi18n::getText('Email address was not found in our database') );
 		}
-/*
-		$validator->isTrue('user_name',FALSE, 'User Name or Password is incorrect');
-*/
 		break;
 	default:
 		break;
