@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: EditBankAccount.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5391 $
+ * $Id: EditBankAccount.php 5391 2011-10-25 19:53:15Z ipso $
+ * $Date: 2011-10-25 12:53:15 -0700 (Tue, 25 Oct 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -76,10 +76,22 @@ switch ($action) {
 		Debug::Text('User ID: '. $bank_data['user_id'] .' Company ID: '. $bank_data['company_id'], __FILE__, __LINE__, __METHOD__,10);
 
 		$balf = TTnew( 'BankAccountListFactory' );
-		if ( isset($user_id) AND $user_id != '' ) {
+
+		if ( ( $bank_data['user_id'] != '' AND $bank_data['user_id'] == $current_user->getId() ) AND $bank_data['company_id'] == '' AND $permission->Check('user','edit_own_bank') ) {
+			Debug::Text('Current User/Company', __FILE__, __LINE__, __METHOD__,10);
+			$balf->GetUserAccountByCompanyIdAndUserId( $current_company->getId(), $current_user->getId() );
+			$redirect_arr = array('data_saved' => TRUE );
+		} elseif ( $bank_data['user_id'] != '' AND $bank_data['company_id'] == '' AND $permission->Check('user','edit_bank') ) {
+			Debug::Text('Specified User', __FILE__, __LINE__, __METHOD__,10);
 			$balf->GetUserAccountByCompanyIdAndUserId( $current_company->getId(), $user_id );
-		} elseif ( isset($company_id) AND $company_id != '' ) {
+			$redirect_arr = array('user_id' => $user_id, 'company_id' => $company_id, 'data_saved' => TRUE );
+		} elseif ( $bank_data['company_id'] != '' AND $bank_data['user_id'] == '' AND $permission->Check('company','edit_own_bank') ) {
+			Debug::Text('Specified Company', __FILE__, __LINE__, __METHOD__,10);
+			//Company bank.
 			$balf->GetCompanyAccountByCompanyId( $current_company->getId() );
+			$redirect_arr = array('company_id' => $company_id, 'data_saved' => TRUE );
+		} else {
+			$permission->Redirect( FALSE );
 		}
 
 		Debug::Text('Found Records: '. $balf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
@@ -88,33 +100,36 @@ switch ($action) {
 			$b_obj->setDeleted(TRUE);
 			$b_obj->Save();
 
-			Redirect::Page( URLBuilder::getURL( array('user_id' => $user_id, 'company_id' => $company_id ), Environment::getBaseURL().'/bank_account/EditBankAccount.php') );
+			Redirect::Page( URLBuilder::getURL( $redirect_arr, Environment::getBaseURL().'/bank_account/EditBankAccount.php') );
 		}
 
 		break;
 	case 'submit':
 		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);
 		Debug::Text('User ID: '. $bank_data['user_id'] .' Company ID: '. $bank_data['company_id'], __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($bank_data, 'Bank Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( !empty($bank_data['id']) ) {
 			$baf->setId( $bank_data['id'] );
 		}
 
-		if ( $bank_data['user_id'] == '' AND $bank_data['company_id'] == '' AND $permission->Check('user','edit_own_bank') ) {
+		if ( ( $bank_data['user_id'] != '' AND $bank_data['user_id'] == $current_user->getId() ) AND $bank_data['company_id'] == '' AND $permission->Check('user','edit_own_bank') ) {
 			Debug::Text('Current User/Company', __FILE__, __LINE__, __METHOD__,10);
-
 			//Current user
 			$baf->setCompany( $current_company->getId() );
 			$baf->setUser( $current_user->getId() );
+			$redirect_arr = array('data_saved' => TRUE );
 		} elseif ( $bank_data['user_id'] != '' AND $bank_data['company_id'] == '' AND $permission->Check('user','edit_bank') ) {
 			Debug::Text('Specified User', __FILE__, __LINE__, __METHOD__,10);
 			//Specified User
 			$baf->setCompany( $current_company->getId() );
 			$baf->setUser( $bank_data['user_id'] );
+			$redirect_arr = array('user_id' => $user_id, 'company_id' => $company_id, 'data_saved' => TRUE );
 		} elseif ( $bank_data['company_id'] != '' AND $bank_data['user_id'] == '' AND $permission->Check('company','edit_own_bank') ) {
 			Debug::Text('Specified Company', __FILE__, __LINE__, __METHOD__,10);
 			//Company bank.
 			$baf->setCompany( $bank_data['company_id'] );
+			$redirect_arr = array('company_id' => $company_id, 'data_saved' => TRUE );
 		} else {
 			$permission->Redirect( FALSE );
 		}
@@ -128,15 +143,18 @@ switch ($action) {
 		if ( $baf->isValid() ) {
 			$baf->Save();
 
-			Redirect::Page( URLBuilder::getURL( array('user_id' => $user_id, 'company_id' => $company_id, 'data_saved' => TRUE ), Environment::getBaseURL().'/bank_account/EditBankAccount.php') );
+			Redirect::Page( URLBuilder::getURL( $redirect_arr, Environment::getBaseURL().'/bank_account/EditBankAccount.php') );
 
 			break;
+		} else {
+			Debug::Text('Invalid bank data...', __FILE__, __LINE__, __METHOD__,10);
 		}
 	default:
 		$balf = TTnew( 'BankAccountListFactory' );
 		$ulf = TTnew( 'UserListFactory' );
 
-		if ( $user_id == '' AND $company_id == '' AND $permission->Check('user','edit_own_bank') ) {
+		$country = NULL;
+		if ( ( $user_id == '' OR $user_id == $current_user->getId() ) AND $company_id == '' AND $permission->Check('user','edit_own_bank') ) {
 			//Current user
 			$balf->getUserAccountByCompanyIdAndUserId( $current_company->getId(), $current_user->getId() );
 			$user_id = $current_user->getId();
@@ -169,7 +187,7 @@ switch ($action) {
 									'country' => strtolower($country),
 									'institution' => $bank_account->getInstitution(),
 									'transit' => $bank_account->getTransit(),
-									'account' => $bank_account->getAccount(),
+									'account' => $bank_account->getSecureAccount(),
 									'created_date' => $bank_account->getCreatedDate(),
 									'created_by' => $bank_account->getCreatedBy(),
 									'updated_date' => $bank_account->getUpdatedDate(),
