@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4219 $
- * $Id: EditCompany.php 4219 2011-02-08 23:44:01Z ipso $
- * $Date: 2011-02-08 15:44:01 -0800 (Tue, 08 Feb 2011) $
+ * $Revision: 5290 $
+ * $Id: EditCompany.php 5290 2011-10-06 21:54:39Z ipso $
+ * $Date: 2011-10-06 14:54:39 -0700 (Thu, 06 Oct 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -105,6 +105,22 @@ switch ($action) {
 			$cf->setEnableSecondLastName( FALSE );
 		}
 
+		if ( isset($company_data['other_id1']) ) {
+			$cf->setOtherID1( $company_data['other_id1'] );
+		}
+		if ( isset($company_data['other_id2']) ) {
+			$cf->setOtherID2( $company_data['other_id2'] );
+		}
+		if ( isset($company_data['other_id3']) ) {
+			$cf->setOtherID3( $company_data['other_id3'] );
+		}
+		if ( isset($company_data['other_id4']) ) {
+			$cf->setOtherID4( $company_data['other_id4'] );
+		}
+		if ( isset($company_data['other_id5']) ) {
+			$cf->setOtherID5( $company_data['other_id5'] );
+		}
+
 		$cf->setLDAPAuthenticationType($company_data['ldap_authentication_type_id']);
 		$cf->setLDAPHost($company_data['ldap_host']);
 		$cf->setLDAPPort($company_data['ldap_port']);
@@ -178,7 +194,11 @@ switch ($action) {
 									'support_contact' => $company->getSupportContact(),
 									'logo_file_name' => $company->getLogoFileName( NULL, FALSE ),
 									'enable_second_last_name' => $company->getEnableSecondLastName(),
-
+									'other_id1' => $company->getOtherID1(),
+									'other_id2' => $company->getOtherID2(),
+									'other_id3' => $company->getOtherID3(),
+									'other_id4' => $company->getOtherID4(),
+									'other_id5' => $company->getOtherID5(),
 									'ldap_authentication_type_id' => $company->getLDAPAuthenticationType(),
 									'ldap_host' => $company->getLDAPHost(),
 									'ldap_port' => $company->getLDAPPort(),
@@ -197,6 +217,10 @@ switch ($action) {
 									'deleted_by' => $company->getDeletedBy(),
 								);
 			}
+		} elseif ( $action != 'submit' ) {
+			$company_data = array(
+								  'parent' => $current_company->getId(),
+								  );
 		}
 
 		//Select box options;
@@ -208,6 +232,10 @@ switch ($action) {
 		$company_data['company_list_options'] = CompanyListFactory::getAllArray();
 		$company_data['product_edition_options'] = $cf->getOptions('product_edition');
 
+		//Get other field names
+		$oflf = TTnew( 'OtherFieldListFactory' );
+		$company_data['other_field_names'] = $oflf->getByCompanyIdAndTypeIdArray( $current_company->getID(), 2 );
+
 		$company_data['ldap_authentication_type_options'] = $cf->getOptions('ldap_authentication_type');
 
 		if (!isset($id) AND isset($company_data['id']) ) {
