@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: EditCompanyDeduction.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5459 $
+ * $Id: EditCompanyDeduction.php 5459 2011-11-04 21:40:55Z ipso $
+ * $Date: 2011-11-04 14:40:55 -0700 (Fri, 04 Nov 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -158,6 +158,13 @@ switch ($action) {
 			$cdf->setMaximumLengthOfServiceUnit( $data['maximum_length_of_service_unit_id'] );
 		}
 
+		if ( isset($data['minimum_user_age']) ) {
+			$cdf->setMinimumUserAge( $data['minimum_user_age'] );
+		}
+		if ( isset($data['maximum_user_age']) ) {
+			$cdf->setMaximumUserAge( $data['maximum_user_age'] );
+		}
+
 		if ( isset($data['include_account_amount_type_id']) ) {
 			$cdf->setIncludeAccountAmountType( $data['include_account_amount_type_id'] );
 		}
@@ -205,22 +212,6 @@ switch ($action) {
 			foreach ($cdlf as $cd_obj) {
 				//Debug::Arr($station,'Department', __FILE__, __LINE__, __METHOD__,10);
 
-				//Get all users assigned to this deduction.
-				/*
-				$udlf = TTnew( 'UserDeductionListFactory' );
-				$udlf->getByCompanyIdAndCompanyDeductionId( $current_company->getId(), $cd_obj->getId() );
-				if ( $udlf->getRecordCount() > 0 ) {
-					Debug::Text('Found users assigned to this deduction!', __FILE__, __LINE__, __METHOD__,10);
-
-					foreach( $udlf as $ud_obj ) {
-						$user_ids[] = $ud_obj->getUser();
-					}
-				} else {
-					$user_ids = array();
-				}
-				unset($udlf, $ud_obj);
-				*/
-
 				$data = array(
 									'id' => $cd_obj->getId(),
 									'company_id' => $cd_obj->getCompany(),
@@ -235,6 +226,8 @@ switch ($action) {
 									'minimum_length_of_service_unit_id' => $cd_obj->getMinimumLengthOfServiceUnit(),
 									'maximum_length_of_service' => $cd_obj->getMaximumLengthOfService(),
 									'maximum_length_of_service_unit_id' => $cd_obj->getMaximumLengthOfServiceUnit(),
+									'minimum_user_age' => $cd_obj->getMinimumUserAge(),
+									'maximum_user_age' => $cd_obj->getMaximumUserAge(),
 
 									'calculation_id' => $cd_obj->getCalculation(),
 									'calculation_order' => $cd_obj->getCalculationOrder(),
@@ -303,6 +296,8 @@ switch ($action) {
 						'user_value10' => 0,
 						'minimum_length_of_service' => 0,
 						'maximum_length_of_service' => 0,
+						'minimum_user_age' => 0,
+						'maximum_user_age' => 0,
 						'calculation_order' => 100,
 						);
 		}
