@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: DatabaseSchema.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5166 $
+ * $Id: DatabaseSchema.php 5166 2011-08-26 23:01:36Z ipso $
+ * $Date: 2011-08-26 16:01:36 -0700 (Fri, 26 Aug 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once('HTML/Progress.php');
@@ -155,12 +155,14 @@ switch ($action) {
 		//exists and Database.inc.php has made a connection.
 		//Otherwise we can't use objects yet.
 		//Debug::setVerbosity(11);
+		//Debug::setBufferOutput(FALSE);
 		Debug::Text('Install Schema', __FILE__, __LINE__, __METHOD__,10);
 
 		InitProgressBar();
 		$progress_bar->setValue(1);
 		$progress_bar->display();
 
+		//$install_obj->getDatabaseConnection()->StartTrans(); //Used for debugging only.
 		if ( $install_obj->checkDatabaseExists( $config_vars['database']['database_name'] ) == TRUE ) {
 			//Create SQL, always try to install every schema version, as
 			//installSchema() will check if its already been installed or not.
@@ -171,6 +173,7 @@ switch ($action) {
 		} else {
 			Debug::Text('bDatabase does not exist.', __FILE__, __LINE__, __METHOD__,10);
 		}
+		//$install_obj->getDatabaseConnection()->FailTrans(); //Used for debugging only.
 
 		$progress_bar->setValue( 100 );
 		$progress_bar->display();
@@ -201,7 +204,7 @@ switch ($action) {
 				$next_page = URLBuilder::getURL( array('external_installer' => $external_installer), 'SystemSettings.php');
 			}
 		}
-
+		Debug::writeToLog();
 		if ( Debug::getVerbosity() >= 11 ) {
 			Debug::Display();
 		} else {
