@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4852 $
- * $Id: User.php 4852 2011-06-21 19:19:32Z ipso $
- * $Date: 2011-06-21 12:19:32 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5428 $
+ * $Id: User.php 5428 2011-10-31 18:13:21Z ipso $
+ * $Date: 2011-10-31 11:13:21 -0700 (Mon, 31 Oct 2011) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -101,12 +101,15 @@ switch ($action) {
 			$uf->setPostalCode( $uf->getCompanyObject()->getPostalCode() );
 			$uf->setWorkPhone( $uf->getCompanyObject()->getWorkPhone() );
 			$uf->setHomePhone( $uf->getCompanyObject()->getWorkPhone() );
+
+			if ( is_object( $uf->getCompanyObject()->getUserDefaultObject() ) ) {
+				$uf->setCurrency( $uf->getCompanyObject()->getUserDefaultObject()->getCurrency() );
+			}
 		}
 
-		//Get Permission Control with highest ID, assume its for Administrators
-		//and use it.
+		//Get Permission Control with highest level, assume its for Administrators and use it.
 		$pclf = TTnew( 'PermissionControlListFactory' );
-		$pclf->getByCompanyId( $user_data['company_id'], NULL, NULL, NULL, array('id' => 'desc' ) );
+		$pclf->getByCompanyId( $user_data['company_id'], NULL, NULL, NULL, array('level' => 'desc' ) );
 		if ( $pclf->getRecordCount() > 0 ) {
 			$pc_obj = $pclf->getCurrent();
 			if ( is_object($pc_obj) ) {
