@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: EditPayPeriodSchedule.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5178 $
+ * $Id: EditPayPeriodSchedule.php 5178 2011-08-30 21:13:34Z ipso $
+ * $Date: 2011-08-30 14:13:34 -0700 (Tue, 30 Aug 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -203,9 +203,9 @@ switch ($action) {
 													'maximum_shift_time' => $pay_period_schedule->getMaximumShiftTime(),
 													'shift_assigned_day_id' => $pay_period_schedule->getShiftAssignedDay(),
 
-													'timesheet_verify_type_id' => (int)$pay_period_schedule->getTimeSheetVerifyType(),
-													'timesheet_verify_before_end_date' => (int)$pay_period_schedule->getTimeSheetVerifyBeforeEndDate(),
-													'timesheet_verify_before_transaction_date' => (int)$pay_period_schedule->getTimeSheetVerifyBeforeTransactionDate(),
+													'timesheet_verify_type_id' => $pay_period_schedule->getTimeSheetVerifyType(),
+													'timesheet_verify_before_end_date' => $pay_period_schedule->getTimeSheetVerifyBeforeEndDate(),
+													'timesheet_verify_before_transaction_date' => $pay_period_schedule->getTimeSheetVerifyBeforeTransactionDate(),
 													'timesheet_verify_notice_before_transaction_date' => $pay_period_schedule->getTimeSheetVerifyNoticeBeforeTransactionDate(),
 													'timesheet_verify_notice_email' => $pay_period_schedule->getTimeSheetVerifyNoticeEmail(),
 
