@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: ViewPayPeriod.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5387 $
+ * $Id: ViewPayPeriod.php 5387 2011-10-25 16:23:28Z ipso $
+ * $Date: 2011-10-25 09:23:28 -0700 (Tue, 25 Oct 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -169,6 +169,7 @@ switch ($action) {
 								'low' => 0,
 								'med' => 0,
 								'high' => 0,
+								'critical' => 0,
 								);
 			if ( $elf->getRecordCount() > 0 ) {
 				Debug::Text(' Found Exceptions: '. $elf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
@@ -179,9 +180,12 @@ switch ($action) {
 					if ( $e_obj->getColumn('severity_id') == 20 ) {
 						$exceptions['med'] = $e_obj->getColumn('count');
 					}
-					if ( $e_obj->getColumn('severity_id') == 30 ) {
+					if ( $e_obj->getColumn('severity_id') == 25 ) {
 						$exceptions['high'] = $e_obj->getColumn('count');
 					}
+					if ( $e_obj->getColumn('severity_id') == 30 ) {
+						$exceptions['critical'] = $e_obj->getColumn('count');
+					}
 
 				}
 			} else {
