@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: ProgressBar.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5218 $
+ * $Id: ProgressBar.php 5218 2011-09-09 18:57:24Z ipso $
+ * $Date: 2011-09-09 11:57:24 -0700 (Fri, 09 Sep 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -171,22 +171,21 @@ switch ($action) {
 
 					Debug::text('Found days to re-calculate: '.$udlf->getRecordCount() , __FILE__, __LINE__, __METHOD__, 10);
 
-					$udlf->StartTransaction();
+
 
 					$x=1;
 					foreach($udlf as $ud_obj ) {
 						//Debug::text($x .' / '. $udlf->getRecordCount() .' - User Date Id: '. $ud_obj->getId() .' Date: '.$ud_obj->getDateStamp(TRUE) .' User ID: '. $ud_obj->getUser() , __FILE__, __LINE__, __METHOD__, 10);
 
+						$udlf->StartTransaction(); //If a transaction wraps the entire recalculation process, a deadlock is likely to occur for large batches.
 						UserDateTotalFactory::reCalculateDay( $ud_obj->getId(), TRUE );
+						$udlf->CommitTransaction();
 
 						$progress_bar->setValue( Misc::calculatePercent( $x, $udlf->getRecordCount() ) );
 						$progress_bar->display();
 
 						$x++;
 					}
-
-					$udlf->CommitTransaction();
-
 				} else {
 					Debug::text('No User Date rows to calculate!', __FILE__, __LINE__, __METHOD__, 10);
 				}
