@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: EditPunch.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5963 $
+ * $Id: EditPunch.php 5963 2012-01-04 16:31:38Z ipso $
+ * $Date: 2012-01-04 08:31:38 -0800 (Wed, 04 Jan 2012) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -91,7 +91,6 @@ $ulf = TTnew( 'UserListFactory' );
 $action = Misc::findSubmitButton();
 switch ($action) {
 	case 'delete':
-		//Debug::setVerbosity(11);
 		Debug::Text('Delete!', __FILE__, __LINE__, __METHOD__,10);
 
 		$plf = TTnew( 'PunchListFactory' );
@@ -107,7 +106,9 @@ switch ($action) {
 				$p_obj->setEnableCalcWeeklySystemTotalTime( TRUE );
 				$p_obj->setEnableCalcUserDateTotal( TRUE );
 				$p_obj->setEnableCalcException( TRUE );
-				$p_obj->Save();
+				if (  $p_obj->isValid() ) {
+					$p_obj->Save();
+				}
 			}
 		}
 
@@ -148,7 +149,7 @@ switch ($action) {
 				$pf->setId( $pc_data['punch_id'] );
 			}
 			if ( isset($data['transfer']) ) {
-				$pf->setTransfer( TRUE );
+				$pf->setTransfer( TRUE, $time_stamp ); //Include timestamp so we can tell if its the first punch or not.
 			}
 
 			$pf->setType( $pc_data['type_id'] );
@@ -171,7 +172,7 @@ switch ($action) {
 
 			if ( $pf->isNew() ) {
 				$pf->setActualTimeStamp( $time_stamp );
-				$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
+				//$pf->setOriginalTimeStamp( $pf->getTimeStamp() ); //set in preSave()
 			}
 
 			if ( $pf->isValid() == TRUE ) {
