@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: Punch.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5749 $
+ * $Id: Punch.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -91,7 +91,7 @@ switch ($action) {
 		if ( isset($data['transfer']) ) {
 			$data['type_id'] = 10;
 			$data['status_id'] = 10;
-			$pf->setTransfer( TRUE );
+			$pf->setTransfer( TRUE, $data['punch_full_time_stamp'] ); //Include timestamp so we can tell if its the first punch or not.
 		}
 
 		$pf->setType( $data['type_id'] );
@@ -108,7 +108,7 @@ switch ($action) {
 
 		if ( $pf->isNew() ) {
 			$pf->setActualTimeStamp( $data['punch_full_time_stamp'] );
-			$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
+			//$pf->setOriginalTimeStamp( $pf->getTimeStamp() ); //set in preSave()
 		}
 
 		if ( $pf->isValid() == TRUE ) {
@@ -197,6 +197,7 @@ switch ($action) {
 			$plf->getPreviousPunchByUserIDAndEpoch( $current_user->getId(), $epoch );
 			if ($plf->getRecordCount() > 0 ) {
 				$prev_punch_obj = $plf->getCurrent();
+				$prev_punch_obj->setUser( $current_user->getId() );
 				Debug::Text(' Found Previous Punch within Continuous Time from now: '. TTDate::getDate('DATe+TIME', $prev_punch_obj->getTimeStamp() ), __FILE__, __LINE__, __METHOD__,10);
 
 				$branch_id = $prev_punch_obj->getPunchControlObject()->getBranch();
@@ -245,27 +246,7 @@ switch ($action) {
 					}
 				}
 
-				$next_type = $prev_punch_obj->getNextType();
-
-				//Check for break policy window.
-				if ( $next_type != 30 AND ( $prev_punch_obj->getStatus() != 30 AND $prev_punch_obj->getType() != 30 ) ) {
-					$prev_punch_obj->setUser( $current_user->getId() );
-					$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $epoch ) );
-					if ( $prev_punch_obj->inBreakPolicyWindow( $epoch, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
-						Debug::Text(' Setting Type to Break: ', __FILE__, __LINE__, __METHOD__,10);
-						$next_type = 30;
-					}
-				}
-
-				//Check for meal policy window.
-				if ( $next_type != 20 AND ( $prev_punch_obj->getStatus() != 20 AND $prev_punch_obj->getType() != 20 ) ) {
-					$prev_punch_obj->setUser( $current_user->getId() );
-					$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $epoch ) );
-					if ( $prev_punch_obj->inMealPolicyWindow( $epoch, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
-						Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
-						$next_type = 20;
-					}
-				}
+				$next_type = $prev_punch_obj->getNextType( $epoch ); //Detects breaks/lunches too.
 
 				if ( $prev_punch_obj->getNextStatus() == 10 ) {
 					//In punch - Carry over just certain data
