@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: GeneralLedgerSummary.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5749 $
+ * $Id: GeneralLedgerSummary.php 5749 2011-12-12 18:19:44Z ipso $
+ * $Date: 2011-12-12 10:19:44 -0800 (Mon, 12 Dec 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -51,8 +51,23 @@ $smarty->assign('title', TTi18n::gettext($title = 'General Ledger Summary Report
 function replaceGLAccountVariables( $subject, $replace_arr = NULL) {
 	$search_arr = array(
 						'#default_branch#',
+						'#default_branch_other_id1#',
+						'#default_branch_other_id2#',
+						'#default_branch_other_id3#',
+						'#default_branch_other_id4#',
+						'#default_branch_other_id5#',
 						'#default_department#',
-						'#employee_number#'
+						'#default_department_other_id1#',
+						'#default_department_other_id2#',
+						'#default_department_other_id3#',
+						'#default_department_other_id4#',
+						'#default_department_other_id5#',
+						'#employee_number#',
+						'#employee_other_id1#',
+						'#employee_other_id2#',
+						'#employee_other_id3#',
+						'#employee_other_id4#',
+						'#employee_other_id5#',
 						);
 
 	if ( $subject != '' AND is_array($replace_arr) ) {
@@ -169,9 +184,7 @@ switch ($action) {
 
 				//Get all pay stubs.
 				$pslf = TTnew( 'PayStubListFactory' );
-				//$pslf->getByUserIdAndCompanyIdAndPayPeriodId( $filter_data['user_ids'], $current_company->getId(), $filter_data['pay_period_ids'] );
 				$pslf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
-
 				if ( $pslf->getRecordCount() > 0 ) {
 					$ulf = TTnew( 'UserListFactory' );
 
@@ -183,7 +196,8 @@ switch ($action) {
 					$blf->getByCompanyId( $current_company->getId() );
 					if ( $blf->getRecordCount() > 0 ) {
 						foreach( $blf as $b_obj ) {
-							$branch_code_map[$b_obj->getId()] = $b_obj->getManualID();
+							//$branch_code_map[$b_obj->getId()] = $b_obj->getManualID();
+							$branch_code_map[$b_obj->getId()] = $b_obj;
 						}
 					}
 
@@ -195,7 +209,8 @@ switch ($action) {
 					$dlf->getByCompanyId( $current_company->getId() );
 					if ( $dlf->getRecordCount() > 0 ) {
 						foreach( $dlf as $d_obj ) {
-							$department_code_map[$d_obj->getId()] = $d_obj->getManualID();
+							//$department_code_map[$d_obj->getId()] = $d_obj->getManualID();
+							$department_code_map[$d_obj->getId()] = $d_obj;
 						}
 					}
 
@@ -221,13 +236,31 @@ switch ($action) {
 					foreach( $pslf as $ps_obj ) {
 						$user_obj = $ulf->getById( $ps_obj->getUser() )->getCurrent();
 
-						$replace_arr = array( $branch_code_map[(int)$user_obj->getDefaultBranch()], $department_code_map[(int)$user_obj->getDefaultDepartment()], $user_obj->getEmployeeNumber() );
+						$replace_arr = array(
+												( is_object($branch_code_map[(int)$user_obj->getDefaultBranch()]) ) ? $branch_code_map[(int)$user_obj->getDefaultBranch()]->getManualID() : NULL,
+												( is_object($branch_code_map[(int)$user_obj->getDefaultBranch()]) ) ? $branch_code_map[(int)$user_obj->getDefaultBranch()]->getOtherID1() : NULL,
+												( is_object($branch_code_map[(int)$user_obj->getDefaultBranch()]) ) ? $branch_code_map[(int)$user_obj->getDefaultBranch()]->getOtherID2() : NULL,
+												( is_object($branch_code_map[(int)$user_obj->getDefaultBranch()]) ) ? $branch_code_map[(int)$user_obj->getDefaultBranch()]->getOtherID3() : NULL,
+												( is_object($branch_code_map[(int)$user_obj->getDefaultBranch()]) ) ? $branch_code_map[(int)$user_obj->getDefaultBranch()]->getOtherID4() : NULL,
+												( is_object($branch_code_map[(int)$user_obj->getDefaultBranch()]) ) ? $branch_code_map[(int)$user_obj->getDefaultBranch()]->getOtherID5() : NULL,
+												( is_object($department_code_map[(int)$user_obj->getDefaultDepartment()]) ) ? $department_code_map[(int)$user_obj->getDefaultDepartment()]->getManualID() : NULL,
+												( is_object($department_code_map[(int)$user_obj->getDefaultDepartment()]) ) ? $department_code_map[(int)$user_obj->getDefaultDepartment()]->getOtherID1() : NULL,
+												( is_object($department_code_map[(int)$user_obj->getDefaultDepartment()]) ) ? $department_code_map[(int)$user_obj->getDefaultDepartment()]->getOtherID2() : NULL,
+												( is_object($department_code_map[(int)$user_obj->getDefaultDepartment()]) ) ? $department_code_map[(int)$user_obj->getDefaultDepartment()]->getOtherID3() : NULL,
+												( is_object($department_code_map[(int)$user_obj->getDefaultDepartment()]) ) ? $department_code_map[(int)$user_obj->getDefaultDepartment()]->getOtherID4() : NULL,
+												( is_object($department_code_map[(int)$user_obj->getDefaultDepartment()]) ) ? $department_code_map[(int)$user_obj->getDefaultDepartment()]->getOtherID5() : NULL,
+												$user_obj->getEmployeeNumber(),
+												$user_obj->getOtherID1(),
+												$user_obj->getOtherID2(),
+												$user_obj->getOtherID3(),
+												$user_obj->getOtherID4(),
+												$user_obj->getOtherID5()
+											);
 
 						$je_records = NULL;
 
 						//Get all PS Entries for this pay stub.
 						$pself = TTnew( 'PayStubEntryListFactory' );
-						//$pself->getByPayStubId( $ps_obj->getId() );
 						$pself->getByPayStubIdAndYTDAdjustment( $ps_obj->getId(), FALSE ); //Skip any YTD adjustments, as they aren't needed in the GL
 						if ( $pself->getRecordCount() > 0 ) {
 							Debug::Text('Found Pay Stub Entries for PS ID:'. $ps_obj->getId() , __FILE__, __LINE__, __METHOD__,10);
@@ -325,7 +358,7 @@ switch ($action) {
 														'amount' => $je_record['amount'],
 														);
 
-									if ( $je_record['type'] == 'total' ) {
+									if ( $je_record['type'] == 'total' AND isset($je_record['debit']) AND isset($je_record['credit']) ) {
 										$tmp_arr['total_debits'] = Misc::MoneyFormat( $je_record['debit'], FALSE);
 										$tmp_arr['total_credits'] = Misc::MoneyFormat( $je_record['credit'], FALSE);
 										$tmp_arr['total_diff'] = Misc::MoneyFormat( $je_record['diff'], FALSE);
