@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: UserBarcode.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5891 $
+ * $Id: UserBarcode.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -71,7 +71,7 @@ URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
 $columns = array(
 											'-1010-employee_number' => TTi18n::gettext('Employee #'),
 											'-1030-user_name' => TTi18n::gettext('User Name'),
-											'-1040-phone_id' => TTi18n::gettext('Phone ID'),
+											'-1040-phone_id' => TTi18n::gettext('Quick Punch ID'),
 
 											'-1060-first_name' => TTi18n::gettext('First Name'),
 											'-1070-middle_name' => TTi18n::gettext('Middle Name'),
