@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: UserInformation.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5891 $
+ * $Id: UserInformation.php 5891 2011-12-30 16:24:54Z ipso $
+ * $Date: 2011-12-30 08:24:54 -0800 (Fri, 30 Dec 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -76,8 +76,8 @@ URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
 $columns = array(						'-1010-employee_number' => TTi18n::gettext('Employee #'),
 										'-1020-status' => TTi18n::gettext('Status'),
 										'-1030-user_name' => TTi18n::gettext('User Name'),
-										'-1040-phone_id' => TTi18n::gettext('Phone ID'),
-										'-1050-ibutton_id' => TTi18n::gettext('iButton'),
+										'-1040-phone_id' => TTi18n::gettext('Quick Punch ID'),
+										//'-1050-ibutton_id' => TTi18n::gettext('iButton'),
 
 										'-1060-first_name' => TTi18n::gettext('First Name'),
 										'-1070-middle_name' => TTi18n::gettext('Middle Name'),
@@ -104,6 +104,7 @@ $columns = array(						'-1010-employee_number' => TTi18n::gettext('Employee #'),
 										'-1170-country' => TTi18n::gettext('Country'),
 										'-1180-postal_code' => TTi18n::gettext('Postal Code'),
 										'-1190-work_phone' => TTi18n::gettext('Work Phone'),
+                                        '-1191-work_phone_ext' => TTi18n::gettext('Work Phone Ext'),
 										'-1200-home_phone' => TTi18n::gettext('Home Phone'),
 										'-1210-mobile_phone' => TTi18n::gettext('Mobile Phone'),
 										'-1220-fax_phone' => TTi18n::gettext('Fax Phone'),
@@ -217,6 +218,8 @@ switch ($action) {
 		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data, 'Filter Data', __FILE__, __LINE__, __METHOD__,10);
 
+        $bf = new BankAccountFactory();
+
 		//Get all employees that match the criteria:
 		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
@@ -456,6 +459,7 @@ switch ($action) {
 									'country' => $u_obj->getCountry(),
 									'postal_code' => $u_obj->getPostalCode(),
 									'work_phone' => $u_obj->getWorkPhone(),
+                                    'work_phone_ext' => $u_obj->getWorkPhoneExt(),
 									'home_phone' => $u_obj->getHomePhone(),
 									'mobile_phone' => $u_obj->getMobilePhone(),
 									'fax_phone' => $u_obj->getFaxPhone(),
@@ -483,7 +487,7 @@ switch ($action) {
 									//Bank Info
 									'institution' => $u_obj->getColumn('institution'),
 									'transit' => $u_obj->getColumn('transit'),
-									'account' => $u_obj->getColumn('account'),
+									'account' => $bf->getSecureAccount( $u_obj->getColumn('account') ),
 
 									//Wage info
 									'currency' => Option::getByKey($u_obj->getCurrency(), $currency_options ),
