@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: WagesPayableSummary.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 6071 $
+ * $Id: WagesPayableSummary.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -154,7 +154,7 @@ if ( $aplf->getRecordCount() > 0 ) {
 	foreach ($aplf as $ap_obj ) {
 		$ap_columns['absence_policy-'.$ap_obj->getId()] = $ap_obj->getName();
 		if ( $ap_obj->getType() == 10 ) {
-			$policy_rates['absence_policy-'.$ap_obj->getId()] = 1;
+			$policy_rates['absence_policy-'.$ap_obj->getId()] = $ap_obj->getRate();
 			$ap_columns['absence_policy-'.$ap_obj->getId().'_wage'] = $ap_obj->getName().' Wage';
 		} else {
 			$policy_rates['absence_policy-'.$ap_obj->getId()] = 0;
@@ -334,7 +334,7 @@ switch ($action) {
 				} elseif ($status_id == 30 AND $type_id == 10) {
 					$column = 'absence_policy-'. $udt_obj->getColumn('absence_policy_id');
 					$wage_column = 'absence_policy_wage_id';
-				} elseif ( ($status_id == 20 AND $type_id == 10 ) OR ($status_id == 10 AND $type_id == 100 ) ) {
+				} elseif ( ($status_id == 20 AND $type_id == 10 ) OR ($status_id == 10 AND $type_id == 100 ) OR ($status_id == 10 AND $type_id == 110 ) ) {
 					$column = 'worked_time';
 					$wage_column = 'user_wage_id';
 				} else {
@@ -342,7 +342,7 @@ switch ($action) {
 					$wage_column = NULL;
 				}
 
-				Debug::Text('Column: '. $column .' Total Time: '. $udt_obj->getColumn('total_time'), __FILE__, __LINE__, __METHOD__,10);
+				//Debug::Text('Column: '. $column .' Total Time: '. $udt_obj->getColumn('total_time'), __FILE__, __LINE__, __METHOD__,10);
 				if ( ( isset($filter_data['include_no_data_users']) AND $filter_data['include_no_data_users'] == 1 )
 						OR ( !isset($filter_data['include_no_data_users']) AND $date_stamp != '' AND $column != '' AND $udt_obj->getColumn('total_time') > 0 )  ) {
 
