@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -58,6 +58,7 @@ extract	(FormVariables::GetVariables(
 $object_type = strtolower($object_type);
 Debug::Text('Object Type: '. $object_type .' ID: '. $object_id .' Parent ID: '. $parent_id, __FILE__, __LINE__, __METHOD__,10);
 
+$upload = new fileupload();
 switch ($object_type) {
 	case 'document_revision':
 		Debug::Text('Document...', __FILE__, __LINE__, __METHOD__,10);
@@ -66,7 +67,6 @@ switch ($object_type) {
 		$drf = TTnew( 'DocumentRevisionFactory' );
 
 		//Debug::setVerbosity(11);
-		$upload = new fileupload();
 		$upload->set_max_filesize(128000000); //128mb or less, though I'm not 100% sure this is even working.
 		$upload->set_overwrite_mode(3); //Do nothing
 
@@ -111,19 +111,94 @@ switch ($object_type) {
 	case 'company_logo':
 		Debug::Text('Company Logo...', __FILE__, __LINE__, __METHOD__,10);
 
+		$upload->set_max_filesize(1000000); //1mb or less
+		//Flex isn't sending proper MIME types?
+		//$upload->set_acceptable_types( array('image/jpg', 'image/jpeg', 'image/pjpeg', 'image/png') ); // comma separated string, or array
+		$upload->set_overwrite_mode(1);
+
+		$cf = TTnew( 'CompanyFactory' );
+		$cf->cleanStoragePath( $current_company->getId() );
+
+		$dir = $cf->getStoragePath( $current_company->getId() );
+		Debug::Text('Storage Path: '. $dir, __FILE__, __LINE__, __METHOD__,10);
+		if ( isset($dir) ) {
+			@mkdir($dir, 0700, TRUE);
+
+			//$upload_result = $upload->upload("userfile", $dir);
+			$upload_result = $upload->upload('filedata', $dir); //'filedata' is case sensitive
+			//var_dump($upload ); //file data
+			if ($upload_result) {
+				$success = $upload_result .' '. TTi18n::gettext('Successfully Uploaded');
+			} else {
+				$error = $upload->get_error();
+			}
+		}
+		Debug::Text('cUpload... Object Type: '. $object_type, __FILE__, __LINE__, __METHOD__,10);
+
+		Debug::Text('Post Upload Operation...', __FILE__, __LINE__, __METHOD__,10);
+		if ( isset($success) AND $success != '' ) {
+			Debug::Text('Rename', __FILE__, __LINE__, __METHOD__,10);
+			//Submit filename to db.
+			//Rename file to just "logo" so its always consistent.
+
+			//Don't resize image, because we use so many different sizes (paystub,logo,etc...) that we can't pick a good size, so just leave as original.
+			$file_data_arr = $upload->get_file();
+			rename( $dir.'/'.$upload_result, $dir.'/logo'. $file_data_arr['extension'] );
+		} else {
+			Debug::Text('bUpload Failed!: '. $upload->get_error(), __FILE__, __LINE__, __METHOD__,10);
+		}
+
 		break;
 	case 'user_picture':
 		break;
 	case 'license':
 		break;
+	case 'import':
+		$import = TTnew( 'Import' );
+		$import->company_id = $current_company->getId();
+		$import->user_id = $current_user->getId();
+
+		//Debug::setVerbosity(11);
+		$upload->set_max_filesize(128000000); //128mb or less, though I'm not 100% sure this is even working.
+		$upload->set_overwrite_mode(1); //Overwrite
+
+		$dir = $import->getStoragePath();
+		Debug::Text('Storage Path: '. $dir, __FILE__, __LINE__, __METHOD__,10);
+		if ( isset($dir) ) {
+			@mkdir($dir, 0700, TRUE);
+
+			$upload_result = $upload->upload('filedata', $dir); //'filedata' is case sensitive
+			//Debug::Arr($_FILES, 'FILES Vars: ', __FILE__, __LINE__, __METHOD__,10);
+			if ($upload_result) {
+				Debug::Text('Upload Success: '. $upload_result, __FILE__, __LINE__, __METHOD__,10);
+				$success = $upload_result . TTi18n::gettext(' Successfully Uploaded');
+				$upload_file_arr = $upload->get_file();
+			} else {
+				Debug::Text('Upload Failed!: '. $upload->get_error(), __FILE__, __LINE__, __METHOD__,10);
+				$error = $upload->get_error();
+			}
+		}
+
+		if ( isset($success) ) {
+			$import->setRemoteFileName( $upload_file_arr['name'] );
+			$import->renameLocalFile();
+		} else {
+			Debug::Text('bUpload Failed!: '. $upload->get_error(), __FILE__, __LINE__, __METHOD__,10);
+		}
+		break;
 	default:
+		$error = 'Invalid object_type';
 		break;
 }
 
 if ( isset($success) ) {
 	echo 'TRUE';
 } else {
-	echo $error;
+	if ( isset($error) ) {
+		echo $error;
+	} else {
+		echo 'Generic Error!';
+	}
 }
 Debug::writeToLog();
 ?>
\ No newline at end of file
