@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4845 $
- * $Id: EditUser.php 4845 2011-06-21 16:23:18Z ipso $
- * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
+ * $Revision: 5453 $
+ * $Id: EditUser.php 5453 2011-11-03 20:30:28Z ipso $
+ * $Date: 2011-11-03 13:30:28 -0700 (Thu, 03 Nov 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -100,12 +100,24 @@ $action = Misc::findSubmitButton();
 switch ($action) {
 	case 'login':
 		if ( $permission->Check('company','view') AND $permission->Check('company','login_other_user') ) {
+
 			Debug::Text('Login as different user: '. $id, __FILE__, __LINE__, __METHOD__,10);
-			$authentication->changeObject( $id );
+			//Get record for other user so we can check to make sure its not a primary company.
+			$ulf = TTNew('UserListFactory');
+			$ulf->getById( $id );
+			if ( $ulf->getRecordCount() > 0 ) {
+				if ( isset($config_vars['other']['primary_company_id']) AND $config_vars['other']['primary_company_id'] != $ulf->getCurrent()->getCompany() ) {
+					$authentication->changeObject( $id );
 
-			TTLog::addEntry( $current_user->getID(), 'Login',  TTi18n::getText('Switch User').': '. TTi18n::getText('SourceIP').': '. $authentication->getIPAddress() .' '. TTi18n::getText('SessionID') .': '.$authentication->getSessionID() .' '.  TTi18n::getText('UserID').': '. $id, $current_user->getId(), 'authentication');
+					TTLog::addEntry( $current_user->getID(), 'Login',  TTi18n::getText('Switch User').': '. TTi18n::getText('SourceIP').': '. $authentication->getIPAddress() .' '. TTi18n::getText('SessionID') .': '.$authentication->getSessionID() .' '.  TTi18n::getText('UserID').': '. $id, $current_user->getId(), 'authentication');
 
-			Redirect::Page( URLBuilder::getURL( NULL, '../index.php') );
+					Redirect::Page( URLBuilder::getURL( NULL, '../index.php') );
+				} else {
+					$permission->Redirect( FALSE ); //Redirect
+				}
+			}
+		} else {
+			$permission->Redirect( FALSE ); //Redirect
 		}
 		break;
 	case 'submit':
@@ -438,7 +450,7 @@ switch ($action) {
 										'title' => $user_title,
 	//									'password' => $user->getPassword(),
 										'phone_id' => $user->getPhoneId(),
-	//									'phone_password' => $user->getPhonePassword(),
+										'phone_password' => $user->getPhonePassword(),
 										'ibutton_id' => $user->getIbuttonId(),
 										'employee_number' => $user->getEmployeeNumber(),
 										'first_name' => $user->getFirstName(),
