@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,15 +34,15 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: EditUserPassword.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5166 $
+ * $Id: EditUserPassword.php 5166 2011-08-26 23:01:36Z ipso $
+ * $Date: 2011-08-26 16:01:36 -0700 (Fri, 26 Aug 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
 
 if ( !$permission->Check('user','enabled')
-		OR !( $permission->Check('user','edit') OR $permission->Check('user','edit_own') ) ) {
+		OR !( $permission->Check('user','edit') OR $permission->Check('user','edit_own_password') ) ) {
 	$permission->Redirect( FALSE ); //Redirect
 }
 
