@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4104 $
- * $Id: UserWageList.php 4104 2011-01-04 19:04:05Z ipso $
- * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
+ * $Revision: 5457 $
+ * $Id: UserWageList.php 5457 2011-11-04 20:49:58Z ipso $
+ * $Date: 2011-11-04 13:49:58 -0700 (Fri, 04 Nov 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -152,7 +152,7 @@ switch ($action) {
 										'wage_group_id' => $wage->getWageGroup(),
 										'wage_group' => Option::getByKey($wage->getWageGroup(), $wage_group_options ),
 										'type' => Option::getByKey($wage->getType(), $wage->getOptions('type') ),
-										'wage' => Misc::removeTrailingZeros($wage->getWage()),
+										'wage' => Misc::MoneyFormat( Misc::removeTrailingZeros($wage->getWage()), TRUE ),
 										'currency_symbol' => $currency_symbol,
 										'effective_date' => TTDate::getDate( 'DATE', $wage->getEffectiveDate() ),
 										'is_owner' => $is_owner,
