@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4495 $
- * $Id: import_users.php 4495 2011-04-04 23:23:53Z ipso $
- * $Date: 2011-04-04 16:23:53 -0700 (Mon, 04 Apr 2011) $
+ * $Revision: 5284 $
+ * $Id: import_users.php 5284 2011-10-03 19:02:20Z ipso $
+ * $Date: 2011-10-03 12:02:20 -0700 (Mon, 03 Oct 2011) $
  */
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'global.inc.php');
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'CLI.inc.php');
@@ -64,6 +64,12 @@ function parse_status_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 	} elseif ( strtolower( $input ) == 't'
 			OR strtolower( $input ) == 'terminated' ) {
 		$retval = 20;
+	} elseif ( strtolower( $input ) == 'l'
+			OR strtolower( $input ) == 'leave' ) {
+		$retval = 16; //Leave - Other
+	} elseif ( strtolower( $input ) == 'i'
+			OR strtolower( $input ) == 'injury' OR strtolower( $input ) == 'illness' ) {
+		$retval = 12; //Leave - Injury
 	} else {
 		$retval = (int)$input;
 	}
@@ -89,7 +95,7 @@ function parse_title_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 
 function parse_default_branch_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 	global $branch_options, $branch_manual_id_options, $fuzzy_match;
-
+	//echo "Parse Branch: Input: ". $input ."\n";
 	if ( !is_numeric( $input ) ) {
 		if ( $fuzzy_match == TRUE ) {
 			$retval = Misc::findClosestMatch( $input, $branch_options, 50 );
@@ -109,7 +115,7 @@ function parse_default_branch_id( $input, $default_value = NULL, $parse_hint = N
 
 function parse_default_department_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 	global $department_options, $department_manual_id_options, $fuzzy_match;
-
+	//echo "Parse Department: Input: ". $input ."\n";
 	if ( !is_numeric( $input ) ) {
 		if ( $fuzzy_match == TRUE ) {
 			$retval = Misc::findClosestMatch( $input, $department_options, 50 );
@@ -133,7 +139,7 @@ function parse_group_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 	if ( !is_numeric( $input ) ) {
 		if ( $fuzzy_match == TRUE ) {
 			$retval = Misc::findClosestMatch( $input, $group_options, 50 );
-			echo "\nFuzzy Group - Search For: ". $input ." Found: ". @$group_options[$retval] ."\n";
+			//echo "\nFuzzy Group - Search For: ". $input ." Found: ". @$group_options[$retval] ."\n";
 			return $retval;
 		} else {
 			return array_search( $input, $group_options );
@@ -144,12 +150,26 @@ function parse_group_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 }
 
 function parse_first_name( $input, $default_value = NULL, $parse_hint = NULL ) {
-	if ( strpos($input, ',') === FALSE ) {
+	if ( stripos( $parse_hint, 'first' ) !== FALSE ) {
+		$offset = 0;
+	} elseif ( stripos( $parse_hint, 'last' ) !== FALSE ) {
+		$offset = 1;
+	} else {
+		$offset = 1; //Last name, First name
+	}
+
+	$parse_hint = str_ireplace( array('first','last'), '', $parse_hint );
+
+	if ( $parse_hint == '' OR strpos($input, $parse_hint) === FALSE ) {
 		return $input;
 	}
 
-	$split_full_name = explode(',', $input);
-	$first_name = $split_full_name[1];
+	if ( $parse_hint == '' ) {
+		$parse_hint = ',';
+	}
+
+	$split_full_name = explode( $parse_hint, $input);
+	$first_name = $split_full_name[$offset];
 
 	if ( strpos( $first_name, ' ') !== FALSE ) {
 		$first_name = substr( $first_name, 0, strlen( $first_name )-2);
@@ -159,12 +179,26 @@ function parse_first_name( $input, $default_value = NULL, $parse_hint = NULL ) {
 }
 
 function parse_last_name( $input, $default_value = NULL, $parse_hint = NULL ) {
-	if ( strpos($input, ',') === FALSE ) {
+	if ( stripos( $parse_hint, 'first' ) !== FALSE ) {
+		$offset = 0;
+	} elseif ( stripos( $parse_hint, 'last' ) !== FALSE ) {
+		$offset = 1;
+	} else {
+		$offset = 1; //Last name, First name
+	}
+
+	$parse_hint = str_ireplace( array('first','last'), '', $parse_hint );
+
+	if ( $parse_hint == '' OR strpos($input, $parse_hint) === FALSE ) {
 		return $input;
 	}
 
-	$split_full_name = explode(',', $input);
-	$last_name = $split_full_name[0];
+	if ( $parse_hint == '' ) {
+		$parse_hint = ',';
+	}
+
+	$split_full_name = explode( $parse_hint, $input);
+	$last_name = $split_full_name[$offset];
 
 	return $last_name;
 }
@@ -212,33 +246,37 @@ function parse_phone_password( $input, $default_value = NULL, $parse_hint = NULL
 function parse_birth_date( $input, $default_value = NULL, $parse_hint = NULL ) {
 	if ( isset($parse_hint) AND $parse_hint != '' ) {
 		TTDate::setDateFormat( $parse_hint );
+		return TTDate::getMiddleDayEpoch( TTDate::parseDateTime( $input ) );
+	} else {
+		return TTDate::getMiddleDayEpoch( TTDate::strtotime( $input ) );
 	}
-
-	return TTDate::getMiddleDayEpoch( TTDate::parseDateTime( $input ) );
 }
 
 function parse_hire_date( $input, $default_value = NULL, $parse_hint = NULL ) {
 	if ( isset($parse_hint) AND $parse_hint != '' ) {
 		TTDate::setDateFormat( $parse_hint );
+		return TTDate::getMiddleDayEpoch( TTDate::parseDateTime( $input ) );
+	} else {
+		return TTDate::getMiddleDayEpoch( TTDate::strtotime( $input ) );
 	}
-
-	return TTDate::getMiddleDayEpoch( TTDate::parseDateTime( $input ) );
 }
 
 function parse_termination_date( $input, $default_value = NULL, $parse_hint = NULL ) {
 	if ( isset($parse_hint) AND $parse_hint != '' ) {
 		TTDate::setDateFormat( $parse_hint );
+		return TTDate::parseDateTime( $input );
+	} else {
+		return TTDate::strtotime( $input );
 	}
-
-	return TTDate::parseDateTime( $input );
 }
 
 function parse_wage_effective_date( $input, $default_value = NULL, $parse_hint = NULL ) {
 	if ( isset($parse_hint) AND $parse_hint != '' ) {
 		TTDate::setDateFormat( $parse_hint );
+		return TTDate::parseDateTime( $input );
+	} else {
+		return TTDate::strtotime( $input );
 	}
-
-	return TTDate::parseDateTime( $input );
 }
 
 function parse_wage_type_id( $input, $default_value = NULL, $parse_hint = NULL ) {
@@ -505,6 +543,18 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 		foreach( $import_arr as $tmp_import_arr ) {
 			$mapped_row = Misc::importApplyColumnMap( $filtered_import_map, $tmp_import_arr );
 
+			if ( $i == 1 AND $mapped_row['company_id'] > 0 ) {
+				$clf = new CompanyListFactory();
+				$clf->getById( $mapped_row['company_id'] );
+				if ( $clf->getRecordCount() > 0 ) {
+					echo 'Company: '. $clf->getCurrent()->getName() ."\n";
+					ob_flush();
+					flush();
+					sleep(2);
+				}
+				unset( $clf );
+			}
+
 			$uf = new UserFactory();
 
 			//Start with user default values.
@@ -551,7 +601,7 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 				echo "  Looking up User By: $update_column (". $mapped_row[$update_column] .") - ". str_pad( $mapped_row['first_name'] ." ". $mapped_row['last_name'] , 20, '.', STR_PAD_RIGHT)."... ";
 
 				$ulf = new UserListFactory();
-				$ulf->getSearchByCompanyIdAndArrayCriteria( $mapped_row['company_id'], array( $update_column => $mapped_row[$update_column] ) );
+				$ulf->getSearchByCompanyIdAndArrayCriteria( $mapped_row['company_id'], array( $update_column => $ulf->Validator->stripSpaces( $mapped_row[$update_column] ) ) );
 				if ( $ulf->getRecordCount() == 1 ) {
 					echo " Found 1 User\n";
 					$uf = $ulf->getCurrent();
@@ -608,26 +658,6 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 				$uf->setCompany( Misc::importCallInputParseFunction( 'company_id', $mapped_row['company_id'], $filtered_import_map['company_id']['default_value'], $filtered_import_map['company_id']['parse_hint'] ) );
 			}
 
-			if ( isset($mapped_row['user_name']) AND $mapped_row['user_name'] != '' ) {
-				$uf->setUserName($mapped_row['user_name']);
-			} elseif ( isset($mapped_row['first_name']) AND $mapped_row['first_name'] != ''
-						AND isset($mapped_row['last_name']) AND $mapped_row['last_name'] != '' ) {
-
-				//Get rid of special chars
-				$tmp_first_name = $uf->Validator->stripNonAlphaNumeric( Misc::importCallInputParseFunction( 'first_name', $mapped_row['first_name'], $filtered_import_map['first_name']['default_value'], $filtered_import_map['first_name']['parse_hint'] ) );
-				$tmp_last_name = $uf->Validator->stripNonAlphaNumeric( Misc::importCallInputParseFunction( 'last_name', $mapped_row['last_name'], $filtered_import_map['last_name']['default_value'], $filtered_import_map['last_name']['parse_hint'] ) );
-
-				$tmp_user_name = strtolower($tmp_first_name.'.'.$tmp_last_name);
-				//Make sure user name is unique
-				if ( $uf->isUniqueUserName( $tmp_user_name ) == FALSE ) {
-					$tmp_user_name = strtolower($tmp_first_name.'.'.$tmp_last_name.rand(1,99) );
-				}
-
-				$uf->setUserName( $tmp_user_name );
-
-				unset($tmp_user_name, $tmp_first_name, $tmp_middle_name, $tmp_last_name);
-			}
-
 			if ( isset($mapped_row['status_id']) AND $mapped_row['status_id'] != '' ) {
 				$uf->setStatus( Misc::importCallInputParseFunction( 'status_id', $mapped_row['status_id'], $filtered_import_map['status_id']['default_value'], $filtered_import_map['status_id']['parse_hint'] ) );
 			}
@@ -657,6 +687,7 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 			}
 
 			if ( isset($mapped_row['default_branch_id']) AND $mapped_row['default_branch_id'] != '' ) {
+				$tmp_branch = Misc::importCallInputParseFunction( 'default_branch_id', $mapped_row['default_branch_id'], $filtered_import_map['default_branch_id']['default_value'], $filtered_import_map['default_branch_id']['parse_hint'] );
 				if ( $create_branch === TRUE ) {
 					//Check to see if branch exists or not.
 					if ( array_search( parse_default_branch_id( $mapped_row['default_branch_id'] ), $branch_options ) === FALSE ) {
@@ -664,11 +695,18 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 						$bf = new BranchFactory();
 						$bf->setCompany( $mapped_row['company_id'] );
 						$bf->setStatus( 10 );
-						$bf->setName( $mapped_row['default_branch_id'] );
-						if ( strtolower($filtered_import_map['default_branch_id']['parse_hint']) == 'manual_id' ) {
+
+						if ( strtolower($filtered_import_map['default_branch_id']['parse_hint']) == 'parse_manual_id' ) {
+							//Parse out any digits from the branch name and use them as the manual_id.
+							$bf->setName( $bf->Validator->stripNumeric( $mapped_row['default_branch_id'] ) );
+							$bf->setManualId( $bf->Validator->stripNonNumeric( $mapped_row['default_branch_id'] ) );
+							$tmp_branch = $bf->getName();
+						} elseif ( strtolower($filtered_import_map['default_branch_id']['parse_hint']) == 'manual_id' ) {
+							$bf->setName( $mapped_row['default_branch_id'] );
 							$bf->setManualId( $mapped_row['default_branch_id'] );
 						} else {
 							$next_available_manual_id = BranchListFactory::getNextAvailableManualId( $mapped_row['company_id'] );
+							$bf->setName( $mapped_row['default_branch_id'] );
 							$bf->setManualId( $next_available_manual_id );
 						}
 						$bf->setCity( 'NA' );
@@ -682,10 +720,12 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 					}
 				}
 
-				$uf->setDefaultBranch( Misc::importCallInputParseFunction( 'default_branch_id', $mapped_row['default_branch_id'], $filtered_import_map['default_branch_id']['default_value'], $filtered_import_map['default_branch_id']['parse_hint'] ) );
+				$uf->setDefaultBranch( $tmp_branch );
+				unset($tmp_branch);
 			}
 
 			if ( isset($mapped_row['default_department_id']) AND $mapped_row['default_department_id'] != '' ) {
+				$tmp_department = Misc::importCallInputParseFunction( 'default_department_id', $mapped_row['default_department_id'], $filtered_import_map['default_department_id']['default_value'], $filtered_import_map['default_department_id']['parse_hint'] );
 				if ( $create_department === TRUE ) {
 					//Check to see if department exists or not.
 					if ( array_search( parse_default_department_id( $mapped_row['default_department_id'] ), $department_options ) === FALSE ) {
@@ -693,11 +733,18 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 						$df = new DepartmentFactory();
 						$df->setCompany( $mapped_row['company_id'] );
 						$df->setStatus( 10 );
-						$df->setName( $mapped_row['default_department_id'] );
-						if ( strtolower($filtered_import_map['default_department_id']['parse_hint']) == 'manual_id' ) {
+
+						if ( strtolower($filtered_import_map['default_department_id']['parse_hint']) == 'parse_manual_id' ) {
+							//Parse out any digits from the department name and use them as the manual_id.
+							$df->setName( $df->Validator->stripNumeric(  $mapped_row['default_department_id'] ) );
+							$df->setManualId( $df->Validator->stripNonNumeric( $mapped_row['default_department_id'] ) );
+							$tmp_department = $df->getName();
+						} elseif ( strtolower($filtered_import_map['default_department_id']['parse_hint']) == 'manual_id' ) {
+							$df->setName( $mapped_row['default_department_id'] );
 							$df->setManualId( $mapped_row['default_department_id'] );
 						} else {
 							$next_available_manual_id = DepartmentListFactory::getNextAvailableManualId( $mapped_row['company_id'] );
+							$df->setName( $mapped_row['default_department_id'] );
 							$df->setManualId( $next_available_manual_id );
 						}
 						if ( $df->isValid() ) {
@@ -710,7 +757,8 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 					}
 				}
 
-				$uf->setDefaultDepartment( Misc::importCallInputParseFunction( 'default_department_id', $mapped_row['default_department_id'], $filtered_import_map['default_department_id']['default_value'], $filtered_import_map['default_department_id']['parse_hint'] ) );
+				$uf->setDefaultDepartment( $tmp_department );
+				unset($tmp_department);
 			}
 
 			if ( isset($mapped_row['group_id']) AND $mapped_row['group_id'] != '' ) {
@@ -777,6 +825,35 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 				$uf->setLastName( Misc::importCallInputParseFunction( 'last_name', $mapped_row['last_name'], $filtered_import_map['last_name']['default_value'], $filtered_import_map['last_name']['parse_hint'] ) );
 			}
 
+			//This must go below setting First/Last name in the object.
+			if ( isset($mapped_row['user_name']) AND $mapped_row['user_name'] != '' ) {
+				//If duplicate username, automatically append random number to the end.
+				if ( $uf->isUniqueUserName( $mapped_row['user_name'] ) == FALSE ) {
+					$tmp_user_name = $mapped_row['user_name'].rand(10,9999);
+					echo " Duplicate username, fixing: $tmp_user_name";
+				} else {
+					$tmp_user_name = $mapped_row['user_name'];
+				}
+				$uf->setUserName( $tmp_user_name );
+				unset($tmp_user_name);
+			} elseif ( $uf->getFirstName() != '' AND $uf->getLastName() != '' ) {
+				//Get rid of special chars
+				$tmp_first_name = $uf->Validator->stripNonAlphaNumeric( $uf->getFirstName() );
+				$tmp_last_name = $uf->Validator->stripNonAlphaNumeric( $uf->getLastName() );
+
+				$tmp_user_name = strtolower($tmp_first_name.'.'.$tmp_last_name);
+				//Make sure user name is unique
+				if ( $uf->isUniqueUserName( $tmp_user_name ) == FALSE ) {
+					$tmp_user_name = strtolower($tmp_first_name.'.'.$tmp_last_name.rand(10,9999) );
+				}
+
+				$uf->setUserName( $tmp_user_name );
+
+				unset($tmp_user_name, $tmp_first_name, $tmp_middle_name, $tmp_last_name);
+			} else {
+				//-
+			}
+
 			if ( isset($mapped_row['sex']) AND $mapped_row['sex'] != '' ) {
 				$uf->setSex( Misc::importCallInputParseFunction( 'sex', $mapped_row['sex'], $filtered_import_map['sex']['default_value'], $filtered_import_map['sex']['parse_hint'] ) );
 			} else {
@@ -860,12 +937,15 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 					echo " \t\t\tSuccess!\n";
 
 					if ( isset($mapped_row['wage_type_id']) AND $mapped_row['wage_type_id'] != ''
-							AND isset($mapped_row['wage']) AND $mapped_row['wage'] != ''
-							AND isset($mapped_row['wage_effective_date']) AND $mapped_row['wage_effective_date'] != '') {
+							AND isset($mapped_row['wage']) AND $mapped_row['wage'] != '' ) {
 						echo "    Importing User Wage Information...";
 
 						//Import Salary information
-						$wage_effective_date = Misc::importCallInputParseFunction( 'wage_effective_date', $mapped_row['wage_effective_date'], $filtered_import_map['wage_effective_date']['default_value'], $filtered_import_map['wage_effective_date']['parse_hint'] );
+						if ( isset($mapped_row['wage_effective_date'])) {
+							$wage_effective_date = Misc::importCallInputParseFunction( 'wage_effective_date', $mapped_row['wage_effective_date'], $filtered_import_map['wage_effective_date']['default_value'], $filtered_import_map['wage_effective_date']['parse_hint'] );
+						} else {
+							$wage_effective_date = $uf->getHireDate();
+						}
 
 						$uwlf = new UserWageListFactory();
 						$uwlf->getByUserIdAndStartDateAndEndDate( $user_id, $wage_effective_date, $wage_effective_date );
@@ -896,13 +976,9 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 							$uwf->setLaborBurdenPercent( Misc::importCallInputParseFunction( 'labor_burden_percent', $mapped_row['labor_burden_percent'], $filtered_import_map['labor_burden_percent']['default_value'], $filtered_import_map['labor_burden_percent']['parse_hint'] ) );
 						}
 
-						if ( isset($mapped_row['wage_effective_date']) AND $mapped_row['wage_effective_date'] != '' ) {
-							$uwf->setEffectiveDate( $wage_effective_date );
-							echo "Effective: ". TTDate::getDate('DATE', Misc::importCallInputParseFunction( 'wage_effective_date', $mapped_row['wage_effective_date'], $filtered_import_map['wage_effective_date']['default_value'], $filtered_import_map['wage_effective_date']['parse_hint'] ) );
-						} else {
-							$uwf->setEffectiveDate( time() );
-							echo "Effective: ". TTDate::getDate('DATE', time() );
-						}
+						$uwf->setEffectiveDate( $wage_effective_date );
+						echo "Effective: ". TTDate::getDate('DATE', $wage_effective_date );
+
 						unset($wage_effective_date);
 
 						if ( $uwf->isValid() ) {
@@ -913,7 +989,6 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 							$commit_trans = FALSE;
 							$e++;
 
-
 							$errors = $uwf->Validator->getErrorsArray();
 							if ( is_array($errors) ) {
 								foreach( $errors as $error_arr ) {
@@ -1133,6 +1208,8 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 			ob_flush();
 			flush();
 			$i++;
+
+			//break; //Test only the first user.
 		}
 
 		if ( $e > 0 ) {
