@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3626 $
- * $Id: PayStubCalculationTest.php 3626 2010-05-27 21:19:00Z ipso $
- * $Date: 2010-05-27 14:19:00 -0700 (Thu, 27 May 2010) $
+ * $Revision: 6071 $
+ * $Id: PayStubCalculationTest.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -69,13 +69,14 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		TTDate::setTimeZone('PST8PDT');
 
 		$dd = new DemoData();
-		$dd->setUserNamePostFix( rand(1000,99999) );
+		$dd->setEnableQuickPunch( FALSE ); //Helps prevent duplicate punch IDs and validation failures.
+		$dd->setUserNamePostFix( '_'.uniqid() ); //Needs to be super random to prevent conflicts and random failing tests.
 		$this->company_id = $dd->createCompany();
 		Debug::text('Company ID: '. $this->company_id, __FILE__, __LINE__, __METHOD__,10);
 
 		$dd->createCurrency( $this->company_id, 10 );
 
-		$dd->createPermissionGroups( $this->company_id );
+		$dd->createPermissionGroups( $this->company_id, 40 ); //Administrator only.
 
 		$dd->createPayStubAccount( $this->company_id );
 		$this->createPayStubAccounts();
@@ -120,6 +121,9 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 
 		$this->createPayStub();
 
+		$this->assertGreaterThan( 0, $this->company_id );
+		$this->assertGreaterThan( 0, $this->user_id );
+
         return TRUE;
     }
 
@@ -381,19 +385,6 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		$ppsf->setTransactionDateBusinessDay( TRUE );
 		$ppsf->setTimeZone('PST8PDT');
 
-/*
-		$ppsf->setPrimaryDate( ($anchor_date+(86400*14)) );
-		$ppsf->setPrimaryDateLastDayOfMonth( FALSE );
-		$ppsf->setPrimaryTransactionDate( ($anchor_date+(86400*21)) );
-		$ppsf->setPrimaryTransactionDateLastDayOfMonth( FALSE );
-		$ppsf->setPrimaryTransactionDateBusinessDay( FALSE );
-
-		$ppsf->setSecondaryDate( ($anchor_date+(86400*28)) );
-		$ppsf->setSecondaryDateLastDayOfMonth( FALSE );
-		$ppsf->setSecondaryTransactionDate( ($anchor_date+(86400*35))  );
-		$ppsf->setSecondaryTransactionDateLastDayOfMonth( FALSE );
-		$ppsf->setSecondaryTransactionDateBusinessDay( FALSE );
-*/
 		$ppsf->setDayStartTime( 0 );
 		$ppsf->setNewDayTriggerTime( (4*3600) );
 		$ppsf->setMaximumShiftTime( (16*3600) );
@@ -883,25 +874,16 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		$this->assertEquals( $pse_arr[$pse_accounts['premium_2']][1]['ytd_amount'], '11.99' );
 
 		//Vacation accrual release
-		//$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual_release']][0]['amount'], '64.97' );
-		//$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual_release']][0]['ytd_amount'], '64.97' );
-
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual_release']][0]['amount'], '114.67' );
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual_release']][0]['ytd_amount'], '114.67' );
 
 		//Vacation accrual deduction
-		//$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][0]['amount'], '129.93' );
-		//$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][0]['ytd_amount'], '0.00' );
-
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][0]['amount'], '99.01' );
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][0]['ytd_amount'], '0.00' );
 
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][1]['amount'], '130.33' );
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][1]['ytd_amount'], '0.00' );
 
-		//$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][2]['amount'], '-64.97' );
-		//$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][2]['ytd_amount'], '163.97' );
-
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][2]['amount'], '-114.67' );
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][2]['ytd_amount'], '114.67' );
 
