@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2012 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2490 $
- * $Id: PayStubTest.php 2490 2009-04-24 22:13:40Z ipso $
- * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
+ * $Revision: 6071 $
+ * $Id: PayStubTest.php 6071 2012-01-19 17:30:49Z ipso $
+ * $Date: 2012-01-19 09:30:49 -0800 (Thu, 19 Jan 2012) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -67,13 +67,14 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
         Debug::text('Running setUp(): ', __FILE__, __LINE__, __METHOD__,10);
 
 		$dd = new DemoData();
-		$dd->setUserNamePostFix( rand(1000,99999) );
+		$dd->setEnableQuickPunch( FALSE ); //Helps prevent duplicate punch IDs and validation failures.
+		$dd->setUserNamePostFix( '_'.uniqid() ); //Needs to be super random to prevent conflicts and random failing tests.
 		$this->company_id = $dd->createCompany();
 		Debug::text('Company ID: '. $this->company_id, __FILE__, __LINE__, __METHOD__,10);
 
 		$dd->createCurrency( $this->company_id, 10 );
 
-		$dd->createPermissionGroups( $this->company_id );
+		$dd->createPermissionGroups( $this->company_id, 40 ); //Administrator only.
 
 		$dd->createUserWageGroups( $this->company_id );
 
@@ -88,6 +89,9 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 		$this->createPayPeriods();
 		$this->getAllPayPeriods();
 
+		$this->assertGreaterThan( 0, $this->company_id );
+		$this->assertGreaterThan( 0, $this->user_id );
+
         return TRUE;
     }
 
@@ -130,27 +134,12 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 		$ppsf->setTransactionDate( 7 );
 
 		$ppsf->setTransactionDateBusinessDay( TRUE );
+		$ppsf->setTimeZone('PST8PDT');
 
-/*
-		$ppsf->setPrimaryDate( ($anchor_date+(86400*14)) );
-		$ppsf->setPrimaryDateLastDayOfMonth( FALSE );
-		$ppsf->setPrimaryTransactionDate( ($anchor_date+(86400*21)) );
-		$ppsf->setPrimaryTransactionDateLastDayOfMonth( FALSE );
-		$ppsf->setPrimaryTransactionDateBusinessDay( FALSE );
-
-		$ppsf->setSecondaryDate( ($anchor_date+(86400*28)) );
-		$ppsf->setSecondaryDateLastDayOfMonth( FALSE );
-		$ppsf->setSecondaryTransactionDate( ($anchor_date+(86400*35))  );
-		$ppsf->setSecondaryTransactionDateLastDayOfMonth( FALSE );
-		$ppsf->setSecondaryTransactionDateBusinessDay( FALSE );
-*/
 		$ppsf->setDayStartTime( 0 );
 		$ppsf->setNewDayTriggerTime( (4*3600) );
 		$ppsf->setMaximumShiftTime( (16*3600) );
 
-		//$ppsf->setContinuousTime( 64800 );
-
-
 		$ppsf->setEnableInitialPayPeriods( FALSE );
 		if ( $ppsf->isValid() ) {
 			$insert_id = $ppsf->Save(FALSE);
@@ -272,6 +261,7 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 
 		$pay_stub = new PayStubFactory();
 		$pay_stub->setUser( $this->user_id );
+		$pay_stub->setCurrency( $pay_stub->getUserObject()->getCurrency() );
 		$pay_stub->setPayPeriod( $this->pay_period_objs[0]->getId() );
 		$pay_stub->setStatus('NEW');
 
@@ -361,6 +351,101 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 		return TRUE;
 	}
 
+	function testSinglePayStubLargeAmounts() {
+		//Test all parts of a single pay stub.
+
+		$pay_stub = new PayStubFactory();
+		$pay_stub->setUser( $this->user_id );
+		$pay_stub->setCurrency( $pay_stub->getUserObject()->getCurrency() );
+		$pay_stub->setPayPeriod( $this->pay_period_objs[0]->getId() );
+		$pay_stub->setStatus('NEW');
+
+		//$pay_stub->setStartDate( $this->pay_period_objs[0]->getStartDate() );
+		//$pay_stub->setEndDate( $this->pay_period_objs[0]->getEndDate() );
+		//$pay_stub->setTransactionDate( $this->pay_period_objs[0]->getTransactionDate() );
+
+		$pay_stub->setDefaultDates();
+
+		$pay_stub->loadPreviousPayStub();
+
+		$pse_accounts = array(
+							'regular_time' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 10, 'Regular Time'),
+							'over_time_1' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 10, 'Over Time 1'),
+							'vacation_accrual_release' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 10, 'Vacation Accrual Release'),
+							'federal_income_tax' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Federal Income Tax'),
+							'state_income_tax' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'State Income Tax'),
+							'medicare' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 30, 'Medicare'),
+							'state_unemployment' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 30, 'State Unemployment Ins.'),
+							'vacation_accrual' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 50, 'Vacation Accrual'),
+							);
+
+		//addEntry( $pay_stub_entry_account_id, $amount, $units = NULL, $rate = NULL, $description = NULL, $ps_amendment_id = NULL, $ytd_amount = NULL, $ytd_units = NULL) {
+		$pay_stub->addEntry( $pse_accounts['regular_time'], 10000000.01 );
+		$pay_stub->addEntry( $pse_accounts['regular_time'], 10.01 );
+
+		$pay_stub->addEntry( $pse_accounts['over_time_1'], 100.02 );
+		$pay_stub->addEntry( $pse_accounts['over_time_1'], 0, NULL, NULL, NULL, NULL, 1.00 );
+		$pay_stub->addEntry( $pse_accounts['vacation_accrual_release'], 1.00 );
+
+		$pay_stub->addEntry( $pse_accounts['federal_income_tax'], 50.01 );
+		$pay_stub->addEntry( $pse_accounts['state_income_tax'], 25.04 );
+
+		$pay_stub->addEntry( $pse_accounts['medicare'], 0, NULL, NULL, NULL, NULL, 1.00 );
+		$pay_stub->addEntry( $pse_accounts['medicare'], 10.01 );
+		$pay_stub->addEntry( $pse_accounts['state_unemployment'], 15.05 );
+
+		$pay_stub->addEntry( $pse_accounts['vacation_accrual'], 5.01 );
+
+		$pay_stub->setEnableProcessEntries(TRUE);
+		$pay_stub->processEntries();
+		if ( $pay_stub->isValid() == TRUE ) {
+			Debug::text('Pay Stub is valid, final save.', __FILE__, __LINE__, __METHOD__,10);
+			$pay_stub_id = $pay_stub->Save();
+		}
+
+		$pse_arr = $this->getPayStubEntryArray( $pay_stub_id );
+
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][0]['amount'], '10000000.01' );
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][0]['ytd_amount'], '0.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][1]['amount'], '10.01' );
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][1]['ytd_amount'], '10000010.02' );
+
+		$this->assertEquals( $pse_arr[$pse_accounts['over_time_1']][0]['amount'], '100.02' );
+		$this->assertEquals( $pse_arr[$pse_accounts['over_time_1']][0]['ytd_amount'], '0.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['over_time_1']][1]['amount'], '0.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['over_time_1']][1]['ytd_amount'], '101.02' );
+
+		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual_release']][0]['amount'], '1.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual_release']][0]['ytd_amount'], '1.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['federal_income_tax']][0]['amount'], '50.01' );
+		$this->assertEquals( $pse_arr[$pse_accounts['federal_income_tax']][0]['ytd_amount'], '50.01' );
+		$this->assertEquals( $pse_arr[$pse_accounts['state_income_tax']][0]['amount'], '25.04' );
+		$this->assertEquals( $pse_arr[$pse_accounts['state_income_tax']][0]['ytd_amount'], '25.04' );
+
+		$this->assertEquals( $pse_arr[$pse_accounts['medicare']][0]['amount'], '0.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['medicare']][0]['ytd_amount'], '1.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['medicare']][1]['amount'], '10.01' );
+		$this->assertEquals( $pse_arr[$pse_accounts['medicare']][1]['ytd_amount'], '11.01' );
+
+		$this->assertEquals( $pse_arr[$pse_accounts['state_unemployment']][0]['amount'], '15.05' );
+		$this->assertEquals( $pse_arr[$pse_accounts['state_unemployment']][0]['ytd_amount'], '15.05' );
+		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][0]['amount'], '-1.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][0]['ytd_amount'], '0.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][1]['amount'], '5.01' );
+		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][1]['ytd_amount'], '4.01' );
+
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount'], '10000111.04' );
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['ytd_amount'], '10000112.04' );
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'], '75.05' );
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['ytd_amount'], '75.05' );
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'], '10000035.99' );
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['ytd_amount'], '10000036.99' );
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['employer_contribution']][0]['amount'], '25.06' );
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['employer_contribution']][0]['ytd_amount'], '26.06' );
+
+		return TRUE;
+	}
+
 	function testMultiplePayStub() {
 		//Test all parts of multiple pay stubs that span a year boundary.
 
@@ -376,6 +461,7 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 		//Test UnUsed YTD entries...
 		$pay_stub = new PayStubFactory();
 		$pay_stub->setUser( $this->user_id );
+		$pay_stub->setCurrency( $pay_stub->getUserObject()->getCurrency() );
 		$pay_stub->setPayPeriod( $this->pay_period_objs[$start_pay_period_id]->getId() );
 		$pay_stub->setStatus('NEW');
 
@@ -653,6 +739,7 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 		//Test UnUsed YTD entries...
 		$pay_stub = new PayStubFactory();
 		$pay_stub->setUser( $this->user_id );
+		$pay_stub->setCurrency( $pay_stub->getUserObject()->getCurrency() );
 		$pay_stub->setPayPeriod( $this->pay_period_objs[$start_pay_period_id]->getId() );
 		$pay_stub->setStatus('NEW');
 
@@ -1328,6 +1415,5 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 
 		return TRUE;
 	}
-
 }
 ?>
\ No newline at end of file
